/********************************************************************
* Copyright (C) 2003-2008 Texas Instruments Incorporated.
* All Rights Reserved
*********************************************************************
* file: cslr_bcp_enc.h
*
* Brief: This file contains the Register Description for bcp_enc
*
*********************************************************************/
#ifndef _CSLR_BCP_ENC_MMR_H_
#define _CSLR_BCP_ENC_MMR_H_

#include <ti/csl/cslr.h>

#include <ti/csl/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure for ENC Interrupt Registers
\**************************************************************************/
typedef struct  {
    volatile Uint32 ENC_INTR_IRS; /* BCP Raw Status Register */
    volatile Uint32 ENC_INTR_IRS_SET; /* BCP Set Raw Status Register */
    volatile Uint32 ENC_INTR_IRS_CLR; /* BCP Clear Raw Status Register */
    volatile Uint32 ENC_INTR_EN; /* BCP Enable ENC_intr0 Register */
    volatile Uint32 ENC_INTR_EN_SET; /* BCP Set Enable ENC_intr0 Register */
    volatile Uint32 ENC_INTR_EN_CLR; /* BCP Clear Enable ENC_intr0 Register */
    volatile Uint32 ENC_INTR_EN_STS; /* BCP Enabled ENC_intr0 Register */
} CSL_Bcp_encEnc_interrupt_registersRegs; /* ENC interrupt register group */

/**************************************************************************\
* Register Overlay Structure for ENC Data Logger
\**************************************************************************/
typedef struct  {
    volatile Uint32 ENC_DLG_GLOBAL_HDR; /* Data logger control Register */
    volatile Uint32 ENC_DLG_TM_SW_TIMESTAMP; /* Data logger control Register */
    volatile Uint32 ENC_DLG_HW_TIMESTAMP_ENG_ERR; /* Data logger control Register */
    volatile Uint8 RSVD0[4];
} CSL_Bcp_encEnc_data_loggerRegs; /* Data Logger */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 POLY_COEF1; /* polynomial coefficient set 1 */
    volatile Uint32 POLY_COEF2; /* polynomial coefficient set 2 */
    volatile Uint32 POLY_COEF3; /* polynomial coefficient set 3 */
    volatile Uint32 SCR_INIT_0; /* scrambler initialization set 0 */
    volatile Uint32 SCR_POLY_0; /* scrambler Polynomial set 0 */
    volatile Uint32 CRC24_INIT_0; /* CRC-24 Initialization set 0 */
    volatile Uint32 CRC24_POLY_0; /* CRC-24 Polynomial set 0 */
    volatile Uint32 SCR_INIT_1; /* scrambler initialization set 1 */
    volatile Uint32 SCR_POLY_1; /* scrambler Polynomial set 1 */
    volatile Uint32 CRC16_INIT_1; /* CRC-16 Initialization set 1 */
    volatile Uint32 CRC16_POLY_1; /* CRC-16 Polynomial set 1 */
    volatile Uint32 SCR_INIT_2; /* scrambler initialization set 2 */
    volatile Uint32 SCR_POLY_2; /* scrambler Polynomial set 2 */
    volatile Uint8 RSVD1[76];
    CSL_Bcp_encEnc_interrupt_registersRegs ENC_INTERRUPT_REGISTERS[4];
    volatile Uint32 ENC_DATA_LOGGER_CTL; /* Data logger control Register */
    volatile Uint32 ENC_DATA_LOGGER_STATUS; /* Datalogger Status Register */
    volatile Uint32 ENC_GLOBAL_HDR; /* Submodule Global Header Register */
    volatile Uint8 RSVD2[22532];
    CSL_Bcp_encEnc_data_loggerRegs ENC_DATA_LOGGER[256];
} CSL_Bcp_encRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* ENC_intr_irs */

#define CSL_BCP_ENC_ENC_INTR_IRS_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_IRS_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_INTR_IRS_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_IRS_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_IRS_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_IRS_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_IRS_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_ENC_ENC_INTR_IRS_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_IRS_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_INTR_IRS_RESETVAL (0x00000000u)

/* ENC_intr_irs_set */

#define CSL_BCP_ENC_ENC_INTR_IRS_SET_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_IRS_SET_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_INTR_IRS_SET_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_IRS_SET_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_IRS_SET_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_IRS_SET_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_IRS_SET_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_ENC_ENC_INTR_IRS_SET_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_IRS_SET_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_INTR_IRS_SET_RESETVAL (0x00000000u)

/* ENC_intr_irs_clr */

#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_INTR_IRS_CLR_RESETVAL (0x00000000u)

/* ENC_intr_en */

#define CSL_BCP_ENC_ENC_INTR_EN_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_EN_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_INTR_EN_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_EN_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_EN_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_EN_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_EN_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_ENC_ENC_INTR_EN_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_EN_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_INTR_EN_RESETVAL (0x00000000u)

/* ENC_intr_en_set */

#define CSL_BCP_ENC_ENC_INTR_EN_SET_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_EN_SET_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_INTR_EN_SET_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_EN_SET_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_EN_SET_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_EN_SET_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_EN_SET_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_ENC_ENC_INTR_EN_SET_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_EN_SET_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_INTR_EN_SET_RESETVAL (0x00000000u)

/* ENC_intr_en_clr */

#define CSL_BCP_ENC_ENC_INTR_EN_CLR_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_EN_CLR_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_INTR_EN_CLR_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_EN_CLR_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_EN_CLR_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_EN_CLR_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_EN_CLR_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_ENC_ENC_INTR_EN_CLR_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_EN_CLR_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_INTR_EN_CLR_RESETVAL (0x00000000u)

/* ENC_intr_en_sts */

#define CSL_BCP_ENC_ENC_INTR_EN_STS_PPB_ERR_MASK (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_EN_STS_PPB_ERR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_INTR_EN_STS_PPB_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_EN_STS_DLG_DONE_INT_MASK (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_EN_STS_DLG_DONE_INT_SHIFT (0x00000001u)
#define CSL_BCP_ENC_ENC_INTR_EN_STS_DLG_DONE_INT_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_INTR_EN_STS_ENG_ERROR_MASK (0x000001FCu)
#define CSL_BCP_ENC_ENC_INTR_EN_STS_ENG_ERROR_SHIFT (0x00000002u)
#define CSL_BCP_ENC_ENC_INTR_EN_STS_ENG_ERROR_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_INTR_EN_STS_RESETVAL (0x00000000u)

/* ENC_dlg_global_hdr */

#define CSL_BCP_ENC_ENC_DLG_GLOBAL_HDR_GLOBAL_HDR_MASK (0xFFFFFFFFu)
#define CSL_BCP_ENC_ENC_DLG_GLOBAL_HDR_GLOBAL_HDR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_DLG_GLOBAL_HDR_GLOBAL_HDR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_DLG_GLOBAL_HDR_RESETVAL (0x00000000u)

/* ENC_dlg_tm_sw_timestamp */

#define CSL_BCP_ENC_ENC_DLG_TM_SW_TIMESTAMP_TM_SW_TIMESTAMP_MASK (0xFFFFFFFFu)
#define CSL_BCP_ENC_ENC_DLG_TM_SW_TIMESTAMP_TM_SW_TIMESTAMP_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_DLG_TM_SW_TIMESTAMP_TM_SW_TIMESTAMP_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_DLG_TM_SW_TIMESTAMP_RESETVAL (0x00000000u)

/* ENC_dlg_hw_timestamp_eng_err */

#define CSL_BCP_ENC_ENC_DLG_HW_TIMESTAMP_ENG_ERR_ENG_ERR_MASK (0xFF000000u)
#define CSL_BCP_ENC_ENC_DLG_HW_TIMESTAMP_ENG_ERR_ENG_ERR_SHIFT (0x00000018u)
#define CSL_BCP_ENC_ENC_DLG_HW_TIMESTAMP_ENG_ERR_ENG_ERR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_DLG_HW_TIMESTAMP_ENG_ERR_TM_HW_TIMESTAMP_MASK (0x00FFFFFFu)
#define CSL_BCP_ENC_ENC_DLG_HW_TIMESTAMP_ENG_ERR_TM_HW_TIMESTAMP_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_DLG_HW_TIMESTAMP_ENG_ERR_TM_HW_TIMESTAMP_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_DLG_HW_TIMESTAMP_ENG_ERR_RESETVAL (0x00000000u)

/* POLY_COEF1 */


#define CSL_BCP_ENC_POLY_COEF1_POLYCOEF1_MASK (0x00FFFFFFu)
#define CSL_BCP_ENC_POLY_COEF1_POLYCOEF1_SHIFT (0x00000000u)
#define CSL_BCP_ENC_POLY_COEF1_POLYCOEF1_RESETVAL (0x004D9413u)

#define CSL_BCP_ENC_POLY_COEF1_RESETVAL  (0x004D9413u)

/* POLY_COEF2 */


#define CSL_BCP_ENC_POLY_COEF2_POLYCOEF2_MASK (0x00FFFFFFu)
#define CSL_BCP_ENC_POLY_COEF2_POLYCOEF2_SHIFT (0x00000000u)
#define CSL_BCP_ENC_POLY_COEF2_POLYCOEF2_RESETVAL (0x00D5AA5Fu)

#define CSL_BCP_ENC_POLY_COEF2_RESETVAL  (0x00D5AA5Fu)

/* POLY_COEF3 */


#define CSL_BCP_ENC_POLY_COEF3_POLYCOEF3_MASK (0x00FFFFFFu)
#define CSL_BCP_ENC_POLY_COEF3_POLYCOEF3_SHIFT (0x00000000u)
#define CSL_BCP_ENC_POLY_COEF3_POLYCOEF3_RESETVAL (0x00DDC3C0u)

#define CSL_BCP_ENC_POLY_COEF3_RESETVAL  (0x00DDC3C0u)

/* SCR_INIT_0 */

#define CSL_BCP_ENC_SCR_INIT_0_SCRINIT_MASK (0xFFFF0000u)
#define CSL_BCP_ENC_SCR_INIT_0_SCRINIT_SHIFT (0x00000010u)
#define CSL_BCP_ENC_SCR_INIT_0_SCRINIT_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_SCR_INIT_0_RESETVAL  (0x00000000u)

/* SCR_POLY_0 */

#define CSL_BCP_ENC_SCR_POLY_0_SCRPOLY_MASK (0xFFFF0000u)
#define CSL_BCP_ENC_SCR_POLY_0_SCRPOLY_SHIFT (0x00000010u)
#define CSL_BCP_ENC_SCR_POLY_0_SCRPOLY_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_SCR_POLY_0_RESETVAL  (0x00000000u)

/* CRC24_INIT_0 */

#define CSL_BCP_ENC_CRC24_INIT_0_CRC24INIT_MASK (0xFFFFFF00u)
#define CSL_BCP_ENC_CRC24_INIT_0_CRC24INIT_SHIFT (0x00000008u)
#define CSL_BCP_ENC_CRC24_INIT_0_CRC24INIT_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_CRC24_INIT_0_RESETVAL (0x00000000u)

/* CRC24_POLY_0 */

#define CSL_BCP_ENC_CRC24_POLY_0_CRC24POLY_MASK (0xFFFFFF00u)
#define CSL_BCP_ENC_CRC24_POLY_0_CRC24POLY_SHIFT (0x00000008u)
#define CSL_BCP_ENC_CRC24_POLY_0_CRC24POLY_RESETVAL (0x00800063u)


#define CSL_BCP_ENC_CRC24_POLY_0_RESETVAL (0x80006300u)

/* SCR_INIT_1 */

#define CSL_BCP_ENC_SCR_INIT_1_SCRINIT_MASK (0xFFFF0000u)
#define CSL_BCP_ENC_SCR_INIT_1_SCRINIT_SHIFT (0x00000010u)
#define CSL_BCP_ENC_SCR_INIT_1_SCRINIT_RESETVAL (0x00006E2Au)


#define CSL_BCP_ENC_SCR_INIT_1_RESETVAL  (0x6E2A0000u)

/* SCR_POLY_1 */

#define CSL_BCP_ENC_SCR_POLY_1_SCRPOLY_MASK (0xFFFF0000u)
#define CSL_BCP_ENC_SCR_POLY_1_SCRPOLY_SHIFT (0x00000010u)
#define CSL_BCP_ENC_SCR_POLY_1_SCRPOLY_RESETVAL (0x00000006u)


#define CSL_BCP_ENC_SCR_POLY_1_RESETVAL  (0x00060000u)

/* CRC16_INIT_1 */

#define CSL_BCP_ENC_CRC16_INIT_1_CRC16INIT_MASK (0xFFFF0000u)
#define CSL_BCP_ENC_CRC16_INIT_1_CRC16INIT_SHIFT (0x00000010u)
#define CSL_BCP_ENC_CRC16_INIT_1_CRC16INIT_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_CRC16_INIT_1_RESETVAL (0x00000000u)

/* CRC16_POLY_1 */

#define CSL_BCP_ENC_CRC16_POLY_1_CRC16POLY_MASK (0xFFFF0000u)
#define CSL_BCP_ENC_CRC16_POLY_1_CRC16POLY_SHIFT (0x00000010u)
#define CSL_BCP_ENC_CRC16_POLY_1_CRC16POLY_RESETVAL (0x00001021u)


#define CSL_BCP_ENC_CRC16_POLY_1_RESETVAL (0x10210000u)

/* SCR_INIT_2 */

#define CSL_BCP_ENC_SCR_INIT_2_SCRINIT_MASK (0xFFFF0000u)
#define CSL_BCP_ENC_SCR_INIT_2_SCRINIT_SHIFT (0x00000010u)
#define CSL_BCP_ENC_SCR_INIT_2_SCRINIT_RESETVAL (0x00006E2Au)


#define CSL_BCP_ENC_SCR_INIT_2_RESETVAL  (0x6E2A0000u)

/* SCR_POLY_2 */

#define CSL_BCP_ENC_SCR_POLY_2_SCRPOLY_MASK (0xFFFF0000u)
#define CSL_BCP_ENC_SCR_POLY_2_SCRPOLY_SHIFT (0x00000010u)
#define CSL_BCP_ENC_SCR_POLY_2_SCRPOLY_RESETVAL (0x00000006u)


#define CSL_BCP_ENC_SCR_POLY_2_RESETVAL  (0x00060000u)

/* ENC_data_logger_ctl */

#define CSL_BCP_ENC_ENC_DATA_LOGGER_CTL_DLG_CTL_MASK (0x00000007u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_CTL_DLG_CTL_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_CTL_DLG_CTL_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_DATA_LOGGER_CTL_DLG_ERR_MASK_MASK (0x01FF0000u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_CTL_DLG_ERR_MASK_SHIFT (0x00000010u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_CTL_DLG_ERR_MASK_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_DATA_LOGGER_CTL_RESETVAL (0x00000000u)

/* ENC_data_logger_status */

#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_WR_PTR_MASK (0x000000FFu)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_WR_PTR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_WR_PTR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_WR_WRAP_MASK (0x0000FF00u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_WR_WRAP_SHIFT (0x00000008u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_WR_WRAP_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_MEM_HAS_ERROR_MASK (0x00010000u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_MEM_HAS_ERROR_SHIFT (0x00000010u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_MEM_HAS_ERROR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_RUNNING_MASK (0x00020000u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_RUNNING_SHIFT (0x00000011u)
#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_DLG_RUNNING_RESETVAL (0x00000000u)


#define CSL_BCP_ENC_ENC_DATA_LOGGER_STATUS_RESETVAL (0x00000000u)

/* ENC_global_hdr */

#define CSL_BCP_ENC_ENC_GLOBAL_HDR_GLOBAL_HDR_MASK (0xFFFFFFFFu)
#define CSL_BCP_ENC_ENC_GLOBAL_HDR_GLOBAL_HDR_SHIFT (0x00000000u)
#define CSL_BCP_ENC_ENC_GLOBAL_HDR_GLOBAL_HDR_RESETVAL (0x00000000u)

#define CSL_BCP_ENC_ENC_GLOBAL_HDR_RESETVAL (0x00000000u)

#endif
