/**  
 * @file csl_serdes.h
 *
 * @brief 
 *  Header file for functional layer of CSL SERDES. 
 *
 *  It contains the various enumerations, structure definitions and function 
 *  declarations
 *
 *  \par
 *  ============================================================================
 *  @n   (C) Copyright 2013, Texas Instruments, Inc.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

/** ============================================================================ 
 *
 * @defgroup CSL_SERDES
 *
 * @section Introduction
 *
 * @subsection xxx Overview
 * This is the top level SERDES API with enumerations for various supported reference clocks, link rates, lane control rates across different modules.
 *
 *
 * @subsection References
 *    
 * ============================================================================
 */ 

#ifdef __cplusplus
extern "C" {
#endif
    
#include <ti/csl/soc.h>
#include <ti/csl/csl.h>

/** @addtogroup CSL_SERDES
 @{ */
/** ============================================================================
 *   @n@b CSL_SERDES_REF_CLOCK
 *
 * @brief      
 *
 *
 *  SERDES REF CLOCK speed enumerators */       
typedef enum 
{
    /** 100 MHz */        
   CSL_SERDES_REF_CLOCK_100M        =   0,

    /** 122.8 MHz */        
   CSL_SERDES_REF_CLOCK_122p88M     =   1,

    /** 125 MHz */        
   CSL_SERDES_REF_CLOCK_125M        =   2,

    /** 153.6 MHz */
   CSL_SERDES_REF_CLOCK_153p6M     =    3,

   /** 156.25 MHz */
   CSL_SERDES_REF_CLOCK_156p25M     =   4,

    /** 312.5 MHz */
   CSL_SERDES_REF_CLOCK_312p5M      =   5
} CSL_SERDES_REF_CLOCK;


/** ============================================================================
 * @brief      
 *
 *  SERDES LINK RATE speed enumerators */       
typedef enum 
{
    /** 1.25 GHz */
   CSL_SERDES_LINK_RATE_1p25G        =   0,

    /** 4.9152 GHz */
   CSL_SERDES_LINK_RATE_4p9152G      =   1,

    /** 5 GHz */        
   CSL_SERDES_LINK_RATE_5G           =   2,

    /** 6.144 GHz */        
   CSL_SERDES_LINK_RATE_6p144G       =   3,

    /** 6.25 GHz */
   CSL_SERDES_LINK_RATE_6p25G        =   4,

   /** 10 GHz */
  CSL_SERDES_LINK_RATE_10G     =         5,

    /** 10.3125 GHz */
   CSL_SERDES_LINK_RATE_10p3125G     =   6,

    /** 12.5 GHz */
   CSL_SERDES_LINK_RATE_12p5G        =   7
} CSL_SERDES_LINK_RATE;


/** ============================================================================ 
 * @brief      
 *
 *  SERDES LOOPBACK enumerators */ 

typedef enum
{
    /** Loopback Enabled */
    CSL_SERDES_LOOPBACK_ENABLED   =  0,

    /** Loopback Disabled */
    CSL_SERDES_LOOPBACK_DISABLED  =  1
} CSL_SERDES_LOOPBACK;


/** ============================================================================
 * @brief      
 *
 *  SERDES PLL STATUS enumerators */ 
typedef enum
{
    /** PLL Not Locked */
    CSL_SERDES_STATUS_PLL_NOT_LOCKED = 0,

    /** PLL Locked */
    CSL_SERDES_STATUS_PLL_LOCKED     = 1
} CSL_SERDES_STATUS;


/** ============================================================================
 * @brief      
 *
 *  SERDES INIT RETURN VALUE enumerators */ 
typedef enum
{
    /** Init Success */    
    CSL_SERDES_NO_ERR               = 0,

    /** Invalid Reference Clock */        
    CSL_SERDES_INVALID_REF_CLOCK    = 1,

    /** Invalid Lane Rate */    
    CSL_SERDES_INVALID_LANE_RATE    = 2
} CSL_SERDES_RESULT;


/** ============================================================================ 
 * @brief      
 *
 *  SERDES LANE CTRL TX/RX RATE enumerators */
typedef enum
{
    /** SERDES Full Rate */
    CSL_SERDES_LANE_FULL_RATE      = 0,

    /** SERDES Half Rate */
    CSL_SERDES_LANE_HALF_RATE      = 1,

    /** SERDES Quarter Rate */
    CSL_SERDES_LANE_QUARTER_RATE   = 2
} CSL_SERDES_LANE_CTRL_RATE;


/** ============================================================================ 
 * @brief      
 *
 *  SERDES LANE CTRL STATUS enumerators */ 
typedef enum
{
    /** Lane Control Enable Success */
    CSL_SERDES_LANE_ENABLE_NO_ERR           = 0,

    /** Invalid Lane Control Rate */    
    CSL_SERDES_LANE_ENABLE_INVALID_RATE     = 1
} CSL_SERDES_LANE_ENABLE_STATUS;


/** ============================================================================ 
 * @brief      
 *
 *  SERDES PHY TYPE enumerators */ 
typedef enum
{
    /** 10GE SERDES */
    SERDES_10GE = 0,

    /** AIF2 B8 SERDES */
    SERDES_AIF2_B8     = 1,

    /** AIF2 B4 SERDES */
    SERDES_AIF2_B4     = 2,

    /** SRIO SERDES */
    SERDES_SRIO     = 3,

    /** PCIe SERDES */
    SERDES_PCIe     = 4,

    /** Hyperlink SERDES */
    SERDES_HYPERLINK     = 5,

    /** SGMII SERDES */
    SERDES_SGMII     = 6,

    /** DFE SERDES */
    SERDES_DFE       = 7,

    /** IQN SERDES */
    SERDES_IQN       = 8
} csl_serdes_phy_type;


/** @addtogroup CSL_SERDES
 @{ */
/** ============================================================================
 *   @n@b CSL_SERDES_CONFIG_CM_C1_C2
 *
 *   @b Description
 *   @n This API is used for configuring the CM, C1, C2 coefficients.
 *
 *   @b Arguments   base_addr, lane_num, CMcoeff, C1coeff, C2coeff, phy_type
 *
 *   <b> Return Value  </b>
 *   @n  None
 *
 *   <b> Pre Condition </b>
 *   @n  None
 *
 *   <b> Post Condition </b>
 *   @n  None
 *
 *   @b Reads
 *   @n None
 *
 *  <b> Usage Constraints: </b>
 *  @n  None
 *
 *   @b Example
 *   @verbatim

     CSL_SERDES_CONFIG_CM_C1_C2(CSL_HYPERLINK_0_SERDES_CFG_REGS, 0, 6, 3, 2, SERDES_HYPERLINK);

    @endverbatim
 * ===========================================================================
 */
CSL_IDEF_INLINE void CSL_SERDES_CONFIG_CM_C1_C2(uint32_t base_addr, uint32_t lane_num, uint32_t CMcoeff, uint32_t C1coeff, uint32_t C2coeff, csl_serdes_phy_type phy_type)
{

     if(phy_type != SERDES_10GE)
     {
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200*(lane_num+1) + 0x8), 15, 12, CMcoeff);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200*(lane_num+1) + 0x8), 4, 0, C1coeff);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200*(lane_num+1) + 0x8), 11, 8, C2coeff);     
     }
     else
     {
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200*(lane_num+1) + 0x8), 11, 8, CMcoeff);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200*(lane_num+1) + 0x8), 4, 0, C1coeff);
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200*(lane_num+1) + 0x4), 18, 18, C2coeff>>3);     
     CSL_FINSR(*(volatile uint32_t *)(base_addr + 0x200*(lane_num+1) + 0x8), 7, 5, C2coeff);     
     }

}


#ifdef __cplusplus
}
#endif
/* @} */
      

