/********************************************************************
* Copyright (C) 2003-2008 Texas Instruments Incorporated.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
#ifndef _CSLR_CPINTC_H_
#define _CSLR_CPINTC_H_

/* CSL Modification:
 *  The file has been modified from the AUTOGEN file for the following
 *  reasons:-
 *      a) Modified Registers CH_MAP_REG0-CH_MAP_REG255 to an array of bytes of CHMAP[1024]
 *      b) Modified Registers HINT_MAP_REG0-HINT_MAP_REG63 to an array of HINTMAP[64]
 *      c) Modified Registers RAW_STATUS_REG0-RAW_STATUS_REG31 to an array of RAW_STATUS_REG[32]
 *      d) Modified Registers ENA_STATUS_REG0-ENA_STATUS_REG32 to an array of ENA_STATUS_REG[32]
 *      e) Modified Registers ENABLE_REG0-ENABLE_REG31 to an array of ENABLE_REG[32]
 *      f) Modified Registers ENABLE_CLR_REG0-ENABLE_CLR_REG31 to an array of ENABLE_CLR_REG[32]
 *      g) Modified Registers PRI_HINT_REG0-PRI_HINT_REG255 to an array of PRI_HINT_REG[256]
 *      h) Modified Registers POLARITY_REG0-POLARITY_REG31 to an array of POLARITY_REG[32]
 *      i) Modified Registers TYPE_REG0-TYPE_REG31 to an array of TYPE_REG[32]
 *      j) Modified Registers DBG_SELECT_REG0-DBG_SELECT_REG63 to an array of DBG_SELECT_REG[64]
 *      k) Modified Registers SECURE_ENABLE_REG0-SECURE_ENABLE_REG31 to an array of SECURE_ENABLE_REG[32]
 *      l) Modified Registers SECURE_ENABLE_CLR_REG0-SECURE_ENABLE_CLR_REG31 to an array of SECURE_ENABLE_CLR_REG[32]
 *      m) Modified Registers NEST_LEVEL_REG0-NEST_LEVEL_REG255 to an array of NEST_LEVEL_REG[256]
 *      n) Modified Registers ENABLE_HINT_REG0-ENABLE_HINT_REG7 to an array of ENABLE_HINT_REG[8]
 *      o) Modified Registers VECTOR_ADDRESS_REG_0-VECTOR_ADDRESS_REG_1023 to an array of VECTOR_ADDRESS_REG[1024]
 *      p) Modified the header file includes to be RTSC compliant
 */

#include <ti/csl/cslr.h>
#include <ti/csl/tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 REVISION_REG;
    volatile Uint32 CONTROL_REG;
    volatile Uint8 RSVD0[4];
    volatile Uint32 HOST_CONTROL_REG;
    volatile Uint32 GLOBAL_ENABLE_HINT_REG;
    volatile Uint8 RSVD1[8];
    volatile Uint32 GLB_NEST_LEVEL_REG;
    volatile Uint32 STATUS_SET_INDEX_REG;
    volatile Uint32 STATUS_CLR_INDEX_REG;
    volatile Uint32 ENABLE_SET_INDEX_REG;
    volatile Uint32 ENABLE_CLR_INDEX_REG;
    volatile Uint8 RSVD2[4];
    volatile Uint32 HINT_ENABLE_SET_INDEX_REG;
    volatile Uint32 HINT_ENABLE_CLR_INDEX_REG;
    volatile Uint8 RSVD3[28];
    volatile Uint32 VECTOR_NULL_REG;
    volatile Uint8 RSVD4[36];
    volatile Uint32 GLB_PRI_INTR_REG;
    volatile Uint32 GLB_VECTOR_ADDR_REG;
    volatile Uint8 RSVD5[8];
    volatile Uint32 GLOBAL_SECURE_ENABLE_REG;
    volatile Uint32 SECURE_PRI_INTR_REG;
    volatile Uint8 RSVD6[360];
#ifdef CSL_MODIFICATION
    volatile Uint32 RAW_STATUS_REG0;
    volatile Uint32 RAW_STATUS_REG1;
    volatile Uint32 RAW_STATUS_REG2;
    volatile Uint32 RAW_STATUS_REG3;
    volatile Uint32 RAW_STATUS_REG4;
    volatile Uint32 RAW_STATUS_REG5;
    volatile Uint32 RAW_STATUS_REG6;
    volatile Uint32 RAW_STATUS_REG7;
    volatile Uint32 RAW_STATUS_REG8;
    volatile Uint32 RAW_STATUS_REG9;
    volatile Uint32 RAW_STATUS_REG10;
    volatile Uint32 RAW_STATUS_REG11;
    volatile Uint32 RAW_STATUS_REG12;
    volatile Uint32 RAW_STATUS_REG13;
    volatile Uint32 RAW_STATUS_REG14;
    volatile Uint32 RAW_STATUS_REG15;
    volatile Uint32 RAW_STATUS_REG16;
    volatile Uint32 RAW_STATUS_REG17;
    volatile Uint32 RAW_STATUS_REG18;
    volatile Uint32 RAW_STATUS_REG19;
    volatile Uint32 RAW_STATUS_REG20;
    volatile Uint32 RAW_STATUS_REG21;
    volatile Uint32 RAW_STATUS_REG22;
    volatile Uint32 RAW_STATUS_REG23;
    volatile Uint32 RAW_STATUS_REG24;
    volatile Uint32 RAW_STATUS_REG25;
    volatile Uint32 RAW_STATUS_REG26;
    volatile Uint32 RAW_STATUS_REG27;
    volatile Uint32 RAW_STATUS_REG28;
    volatile Uint32 RAW_STATUS_REG29;
    volatile Uint32 RAW_STATUS_REG30;
    volatile Uint32 RAW_STATUS_REG31;
#else
    volatile Uint32 RAW_STATUS_REG[32];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 ENA_STATUS_REG0;
    volatile Uint32 ENA_STATUS_REG1;
    volatile Uint32 ENA_STATUS_REG2;
    volatile Uint32 ENA_STATUS_REG3;
    volatile Uint32 ENA_STATUS_REG4;
    volatile Uint32 ENA_STATUS_REG5;
    volatile Uint32 ENA_STATUS_REG6;
    volatile Uint32 ENA_STATUS_REG7;
    volatile Uint32 ENA_STATUS_REG8;
    volatile Uint32 ENA_STATUS_REG9;
    volatile Uint32 ENA_STATUS_REG10;
    volatile Uint32 ENA_STATUS_REG11;
    volatile Uint32 ENA_STATUS_REG12;
    volatile Uint32 ENA_STATUS_REG13;
    volatile Uint32 ENA_STATUS_REG14;
    volatile Uint32 ENA_STATUS_REG15;
    volatile Uint32 ENA_STATUS_REG16;
    volatile Uint32 ENA_STATUS_REG17;
    volatile Uint32 ENA_STATUS_REG18;
    volatile Uint32 ENA_STATUS_REG19;
    volatile Uint32 ENA_STATUS_REG20;
    volatile Uint32 ENA_STATUS_REG21;
    volatile Uint32 ENA_STATUS_REG22;
    volatile Uint32 ENA_STATUS_REG23;
    volatile Uint32 ENA_STATUS_REG24;
    volatile Uint32 ENA_STATUS_REG25;
    volatile Uint32 ENA_STATUS_REG26;
    volatile Uint32 ENA_STATUS_REG27;
    volatile Uint32 ENA_STATUS_REG28;
    volatile Uint32 ENA_STATUS_REG29;
    volatile Uint32 ENA_STATUS_REG30;
    volatile Uint32 ENA_STATUS_REG31;
#else
    volatile Uint32 ENA_STATUS_REG[32];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 ENABLE_REG0;
    volatile Uint32 ENABLE_REG1;
    volatile Uint32 ENABLE_REG2;
    volatile Uint32 ENABLE_REG3;
    volatile Uint32 ENABLE_REG4;
    volatile Uint32 ENABLE_REG5;
    volatile Uint32 ENABLE_REG6;
    volatile Uint32 ENABLE_REG7;
    volatile Uint32 ENABLE_REG8;
    volatile Uint32 ENABLE_REG9;
    volatile Uint32 ENABLE_REG10;
    volatile Uint32 ENABLE_REG11;
    volatile Uint32 ENABLE_REG12;
    volatile Uint32 ENABLE_REG13;
    volatile Uint32 ENABLE_REG14;
    volatile Uint32 ENABLE_REG15;
    volatile Uint32 ENABLE_REG16;
    volatile Uint32 ENABLE_REG17;
    volatile Uint32 ENABLE_REG18;
    volatile Uint32 ENABLE_REG19;
    volatile Uint32 ENABLE_REG20;
    volatile Uint32 ENABLE_REG21;
    volatile Uint32 ENABLE_REG22;
    volatile Uint32 ENABLE_REG23;
    volatile Uint32 ENABLE_REG24;
    volatile Uint32 ENABLE_REG25;
    volatile Uint32 ENABLE_REG26;
    volatile Uint32 ENABLE_REG27;
    volatile Uint32 ENABLE_REG28;
    volatile Uint32 ENABLE_REG29;
    volatile Uint32 ENABLE_REG30;
    volatile Uint32 ENABLE_REG31;
#else
    volatile Uint32 ENABLE_REG[32];
#endif
#ifdef CSL_MODIFICATION 
    volatile Uint32 ENABLE_CLR_REG0;
    volatile Uint32 ENABLE_CLR_REG1;
    volatile Uint32 ENABLE_CLR_REG2;
    volatile Uint32 ENABLE_CLR_REG3;
    volatile Uint32 ENABLE_CLR_REG4;
    volatile Uint32 ENABLE_CLR_REG5;
    volatile Uint32 ENABLE_CLR_REG6;
    volatile Uint32 ENABLE_CLR_REG7;
    volatile Uint32 ENABLE_CLR_REG8;
    volatile Uint32 ENABLE_CLR_REG9;
    volatile Uint32 ENABLE_CLR_REG10;
    volatile Uint32 ENABLE_CLR_REG11;
    volatile Uint32 ENABLE_CLR_REG12;
    volatile Uint32 ENABLE_CLR_REG13;
    volatile Uint32 ENABLE_CLR_REG14;
    volatile Uint32 ENABLE_CLR_REG15;
    volatile Uint32 ENABLE_CLR_REG16;
    volatile Uint32 ENABLE_CLR_REG17;
    volatile Uint32 ENABLE_CLR_REG18;
    volatile Uint32 ENABLE_CLR_REG19;
    volatile Uint32 ENABLE_CLR_REG20;
    volatile Uint32 ENABLE_CLR_REG21;
    volatile Uint32 ENABLE_CLR_REG22;
    volatile Uint32 ENABLE_CLR_REG23;
    volatile Uint32 ENABLE_CLR_REG24;
    volatile Uint32 ENABLE_CLR_REG25;
    volatile Uint32 ENABLE_CLR_REG26;
    volatile Uint32 ENABLE_CLR_REG27;
    volatile Uint32 ENABLE_CLR_REG28;
    volatile Uint32 ENABLE_CLR_REG29;
    volatile Uint32 ENABLE_CLR_REG30;
    volatile Uint32 ENABLE_CLR_REG31;
#else
    volatile Uint32 ENABLE_CLR_REG[32];
#endif    
#ifdef CSL_MODIFICATION
    volatile Uint32 CH_MAP_REG0;
    volatile Uint32 CH_MAP_REG1;
    volatile Uint32 CH_MAP_REG2;
    volatile Uint32 CH_MAP_REG3;
    volatile Uint32 CH_MAP_REG4;
    volatile Uint32 CH_MAP_REG5;
    volatile Uint32 CH_MAP_REG6;
    volatile Uint32 CH_MAP_REG7;
    volatile Uint32 CH_MAP_REG8;
    volatile Uint32 CH_MAP_REG9;
    volatile Uint32 CH_MAP_REG10;
    volatile Uint32 CH_MAP_REG11;
    volatile Uint32 CH_MAP_REG12;
    volatile Uint32 CH_MAP_REG13;
    volatile Uint32 CH_MAP_REG14;
    volatile Uint32 CH_MAP_REG15;
    volatile Uint32 CH_MAP_REG16;
    volatile Uint32 CH_MAP_REG17;
    volatile Uint32 CH_MAP_REG18;
    volatile Uint32 CH_MAP_REG19;
    volatile Uint32 CH_MAP_REG20;
    volatile Uint32 CH_MAP_REG21;
    volatile Uint32 CH_MAP_REG22;
    volatile Uint32 CH_MAP_REG23;
    volatile Uint32 CH_MAP_REG24;
    volatile Uint32 CH_MAP_REG25;
    volatile Uint32 CH_MAP_REG26;
    volatile Uint32 CH_MAP_REG27;
    volatile Uint32 CH_MAP_REG28;
    volatile Uint32 CH_MAP_REG29;
    volatile Uint32 CH_MAP_REG30;
    volatile Uint32 CH_MAP_REG31;
    volatile Uint32 CH_MAP_REG32;
    volatile Uint32 CH_MAP_REG33;
    volatile Uint32 CH_MAP_REG34;
    volatile Uint32 CH_MAP_REG35;
    volatile Uint32 CH_MAP_REG36;
    volatile Uint32 CH_MAP_REG37;
    volatile Uint32 CH_MAP_REG38;
    volatile Uint32 CH_MAP_REG39;
    volatile Uint32 CH_MAP_REG40;
    volatile Uint32 CH_MAP_REG41;
    volatile Uint32 CH_MAP_REG42;
    volatile Uint32 CH_MAP_REG43;
    volatile Uint32 CH_MAP_REG44;
    volatile Uint32 CH_MAP_REG45;
    volatile Uint32 CH_MAP_REG46;
    volatile Uint32 CH_MAP_REG47;
    volatile Uint32 CH_MAP_REG48;
    volatile Uint32 CH_MAP_REG49;
    volatile Uint32 CH_MAP_REG50;
    volatile Uint32 CH_MAP_REG51;
    volatile Uint32 CH_MAP_REG52;
    volatile Uint32 CH_MAP_REG53;
    volatile Uint32 CH_MAP_REG54;
    volatile Uint32 CH_MAP_REG55;
    volatile Uint32 CH_MAP_REG56;
    volatile Uint32 CH_MAP_REG57;
    volatile Uint32 CH_MAP_REG58;
    volatile Uint32 CH_MAP_REG59;
    volatile Uint32 CH_MAP_REG60;
    volatile Uint32 CH_MAP_REG61;
    volatile Uint32 CH_MAP_REG62;
    volatile Uint32 CH_MAP_REG63;
    volatile Uint32 CH_MAP_REG64;
    volatile Uint32 CH_MAP_REG65;
    volatile Uint32 CH_MAP_REG66;
    volatile Uint32 CH_MAP_REG67;
    volatile Uint32 CH_MAP_REG68;
    volatile Uint32 CH_MAP_REG69;
    volatile Uint32 CH_MAP_REG70;
    volatile Uint32 CH_MAP_REG71;
    volatile Uint32 CH_MAP_REG72;
    volatile Uint32 CH_MAP_REG73;
    volatile Uint32 CH_MAP_REG74;
    volatile Uint32 CH_MAP_REG75;
    volatile Uint32 CH_MAP_REG76;
    volatile Uint32 CH_MAP_REG77;
    volatile Uint32 CH_MAP_REG78;
    volatile Uint32 CH_MAP_REG79;
    volatile Uint32 CH_MAP_REG80;
    volatile Uint32 CH_MAP_REG81;
    volatile Uint32 CH_MAP_REG82;
    volatile Uint32 CH_MAP_REG83;
    volatile Uint32 CH_MAP_REG84;
    volatile Uint32 CH_MAP_REG85;
    volatile Uint32 CH_MAP_REG86;
    volatile Uint32 CH_MAP_REG87;
    volatile Uint32 CH_MAP_REG88;
    volatile Uint32 CH_MAP_REG89;
    volatile Uint32 CH_MAP_REG90;
    volatile Uint32 CH_MAP_REG91;
    volatile Uint32 CH_MAP_REG92;
    volatile Uint32 CH_MAP_REG93;
    volatile Uint32 CH_MAP_REG94;
    volatile Uint32 CH_MAP_REG95;
    volatile Uint32 CH_MAP_REG96;
    volatile Uint32 CH_MAP_REG97;
    volatile Uint32 CH_MAP_REG98;
    volatile Uint32 CH_MAP_REG99;
    volatile Uint32 CH_MAP_REG100;
    volatile Uint32 CH_MAP_REG101;
    volatile Uint32 CH_MAP_REG102;
    volatile Uint32 CH_MAP_REG103;
    volatile Uint32 CH_MAP_REG104;
    volatile Uint32 CH_MAP_REG105;
    volatile Uint32 CH_MAP_REG106;
    volatile Uint32 CH_MAP_REG107;
    volatile Uint32 CH_MAP_REG108;
    volatile Uint32 CH_MAP_REG109;
    volatile Uint32 CH_MAP_REG110;
    volatile Uint32 CH_MAP_REG111;
    volatile Uint32 CH_MAP_REG112;
    volatile Uint32 CH_MAP_REG113;
    volatile Uint32 CH_MAP_REG114;
    volatile Uint32 CH_MAP_REG115;
    volatile Uint32 CH_MAP_REG116;
    volatile Uint32 CH_MAP_REG117;
    volatile Uint32 CH_MAP_REG118;
    volatile Uint32 CH_MAP_REG119;
    volatile Uint32 CH_MAP_REG120;
    volatile Uint32 CH_MAP_REG121;
    volatile Uint32 CH_MAP_REG122;
    volatile Uint32 CH_MAP_REG123;
    volatile Uint32 CH_MAP_REG124;
    volatile Uint32 CH_MAP_REG125;
    volatile Uint32 CH_MAP_REG126;
    volatile Uint32 CH_MAP_REG127;
    volatile Uint32 CH_MAP_REG128;
    volatile Uint32 CH_MAP_REG129;
    volatile Uint32 CH_MAP_REG130;
    volatile Uint32 CH_MAP_REG131;
    volatile Uint32 CH_MAP_REG132;
    volatile Uint32 CH_MAP_REG133;
    volatile Uint32 CH_MAP_REG134;
    volatile Uint32 CH_MAP_REG135;
    volatile Uint32 CH_MAP_REG136;
    volatile Uint32 CH_MAP_REG137;
    volatile Uint32 CH_MAP_REG138;
    volatile Uint32 CH_MAP_REG139;
    volatile Uint32 CH_MAP_REG140;
    volatile Uint32 CH_MAP_REG141;
    volatile Uint32 CH_MAP_REG142;
    volatile Uint32 CH_MAP_REG143;
    volatile Uint32 CH_MAP_REG144;
    volatile Uint32 CH_MAP_REG145;
    volatile Uint32 CH_MAP_REG146;
    volatile Uint32 CH_MAP_REG147;
    volatile Uint32 CH_MAP_REG148;
    volatile Uint32 CH_MAP_REG149;
    volatile Uint32 CH_MAP_REG150;
    volatile Uint32 CH_MAP_REG151;
    volatile Uint32 CH_MAP_REG152;
    volatile Uint32 CH_MAP_REG153;
    volatile Uint32 CH_MAP_REG154;
    volatile Uint32 CH_MAP_REG155;
    volatile Uint32 CH_MAP_REG156;
    volatile Uint32 CH_MAP_REG157;
    volatile Uint32 CH_MAP_REG158;
    volatile Uint32 CH_MAP_REG159;
    volatile Uint32 CH_MAP_REG160;
    volatile Uint32 CH_MAP_REG161;
    volatile Uint32 CH_MAP_REG162;
    volatile Uint32 CH_MAP_REG163;
    volatile Uint32 CH_MAP_REG164;
    volatile Uint32 CH_MAP_REG165;
    volatile Uint32 CH_MAP_REG166;
    volatile Uint32 CH_MAP_REG167;
    volatile Uint32 CH_MAP_REG168;
    volatile Uint32 CH_MAP_REG169;
    volatile Uint32 CH_MAP_REG170;
    volatile Uint32 CH_MAP_REG171;
    volatile Uint32 CH_MAP_REG172;
    volatile Uint32 CH_MAP_REG173;
    volatile Uint32 CH_MAP_REG174;
    volatile Uint32 CH_MAP_REG175;
    volatile Uint32 CH_MAP_REG176;
    volatile Uint32 CH_MAP_REG177;
    volatile Uint32 CH_MAP_REG178;
    volatile Uint32 CH_MAP_REG179;
    volatile Uint32 CH_MAP_REG180;
    volatile Uint32 CH_MAP_REG181;
    volatile Uint32 CH_MAP_REG182;
    volatile Uint32 CH_MAP_REG183;
    volatile Uint32 CH_MAP_REG184;
    volatile Uint32 CH_MAP_REG185;
    volatile Uint32 CH_MAP_REG186;
    volatile Uint32 CH_MAP_REG187;
    volatile Uint32 CH_MAP_REG188;
    volatile Uint32 CH_MAP_REG189;
    volatile Uint32 CH_MAP_REG190;
    volatile Uint32 CH_MAP_REG191;
    volatile Uint32 CH_MAP_REG192;
    volatile Uint32 CH_MAP_REG193;
    volatile Uint32 CH_MAP_REG194;
    volatile Uint32 CH_MAP_REG195;
    volatile Uint32 CH_MAP_REG196;
    volatile Uint32 CH_MAP_REG197;
    volatile Uint32 CH_MAP_REG198;
    volatile Uint32 CH_MAP_REG199;
    volatile Uint32 CH_MAP_REG200;
    volatile Uint32 CH_MAP_REG201;
    volatile Uint32 CH_MAP_REG202;
    volatile Uint32 CH_MAP_REG203;
    volatile Uint32 CH_MAP_REG204;
    volatile Uint32 CH_MAP_REG205;
    volatile Uint32 CH_MAP_REG206;
    volatile Uint32 CH_MAP_REG207;
    volatile Uint32 CH_MAP_REG208;
    volatile Uint32 CH_MAP_REG209;
    volatile Uint32 CH_MAP_REG210;
    volatile Uint32 CH_MAP_REG211;
    volatile Uint32 CH_MAP_REG212;
    volatile Uint32 CH_MAP_REG213;
    volatile Uint32 CH_MAP_REG214;
    volatile Uint32 CH_MAP_REG215;
    volatile Uint32 CH_MAP_REG216;
    volatile Uint32 CH_MAP_REG217;
    volatile Uint32 CH_MAP_REG218;
    volatile Uint32 CH_MAP_REG219;
    volatile Uint32 CH_MAP_REG220;
    volatile Uint32 CH_MAP_REG221;
    volatile Uint32 CH_MAP_REG222;
    volatile Uint32 CH_MAP_REG223;
    volatile Uint32 CH_MAP_REG224;
    volatile Uint32 CH_MAP_REG225;
    volatile Uint32 CH_MAP_REG226;
    volatile Uint32 CH_MAP_REG227;
    volatile Uint32 CH_MAP_REG228;
    volatile Uint32 CH_MAP_REG229;
    volatile Uint32 CH_MAP_REG230;
    volatile Uint32 CH_MAP_REG231;
    volatile Uint32 CH_MAP_REG232;
    volatile Uint32 CH_MAP_REG233;
    volatile Uint32 CH_MAP_REG234;
    volatile Uint32 CH_MAP_REG235;
    volatile Uint32 CH_MAP_REG236;
    volatile Uint32 CH_MAP_REG237;
    volatile Uint32 CH_MAP_REG238;
    volatile Uint32 CH_MAP_REG239;
    volatile Uint32 CH_MAP_REG240;
    volatile Uint32 CH_MAP_REG241;
    volatile Uint32 CH_MAP_REG242;
    volatile Uint32 CH_MAP_REG243;
    volatile Uint32 CH_MAP_REG244;
    volatile Uint32 CH_MAP_REG245;
    volatile Uint32 CH_MAP_REG246;
    volatile Uint32 CH_MAP_REG247;
    volatile Uint32 CH_MAP_REG248;
    volatile Uint32 CH_MAP_REG249;
    volatile Uint32 CH_MAP_REG250;
    volatile Uint32 CH_MAP_REG251;
    volatile Uint32 CH_MAP_REG252;
    volatile Uint32 CH_MAP_REG253;
    volatile Uint32 CH_MAP_REG254;
    volatile Uint32 CH_MAP_REG255;
#else
    volatile Uint8  CH_MAP[1024];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 HINT_MAP_REG0;
    volatile Uint32 HINT_MAP_REG1;
    volatile Uint32 HINT_MAP_REG2;
    volatile Uint32 HINT_MAP_REG3;
    volatile Uint32 HINT_MAP_REG4;
    volatile Uint32 HINT_MAP_REG5;
    volatile Uint32 HINT_MAP_REG6;
    volatile Uint32 HINT_MAP_REG7;
    volatile Uint32 HINT_MAP_REG8;
    volatile Uint32 HINT_MAP_REG9;
    volatile Uint32 HINT_MAP_REG10;
    volatile Uint32 HINT_MAP_REG11;
    volatile Uint32 HINT_MAP_REG12;
    volatile Uint32 HINT_MAP_REG13;
    volatile Uint32 HINT_MAP_REG14;
    volatile Uint32 HINT_MAP_REG15;
    volatile Uint32 HINT_MAP_REG16;
    volatile Uint32 HINT_MAP_REG17;
    volatile Uint32 HINT_MAP_REG18;
    volatile Uint32 HINT_MAP_REG19;
    volatile Uint32 HINT_MAP_REG20;
    volatile Uint32 HINT_MAP_REG21;
    volatile Uint32 HINT_MAP_REG22;
    volatile Uint32 HINT_MAP_REG23;
    volatile Uint32 HINT_MAP_REG24;
    volatile Uint32 HINT_MAP_REG25;
    volatile Uint32 HINT_MAP_REG26;
    volatile Uint32 HINT_MAP_REG27;
    volatile Uint32 HINT_MAP_REG28;
    volatile Uint32 HINT_MAP_REG29;
    volatile Uint32 HINT_MAP_REG30;
    volatile Uint32 HINT_MAP_REG31;
    volatile Uint32 HINT_MAP_REG32;
    volatile Uint32 HINT_MAP_REG33;
    volatile Uint32 HINT_MAP_REG34;
    volatile Uint32 HINT_MAP_REG35;
    volatile Uint32 HINT_MAP_REG36;
    volatile Uint32 HINT_MAP_REG37;
    volatile Uint32 HINT_MAP_REG38;
    volatile Uint32 HINT_MAP_REG39;
    volatile Uint32 HINT_MAP_REG40;
    volatile Uint32 HINT_MAP_REG41;
    volatile Uint32 HINT_MAP_REG42;
    volatile Uint32 HINT_MAP_REG43;
    volatile Uint32 HINT_MAP_REG44;
    volatile Uint32 HINT_MAP_REG45;
    volatile Uint32 HINT_MAP_REG46;
    volatile Uint32 HINT_MAP_REG47;
    volatile Uint32 HINT_MAP_REG48;
    volatile Uint32 HINT_MAP_REG49;
    volatile Uint32 HINT_MAP_REG50;
    volatile Uint32 HINT_MAP_REG51;
    volatile Uint32 HINT_MAP_REG52;
    volatile Uint32 HINT_MAP_REG53;
    volatile Uint32 HINT_MAP_REG54;
    volatile Uint32 HINT_MAP_REG55;
    volatile Uint32 HINT_MAP_REG56;
    volatile Uint32 HINT_MAP_REG57;
    volatile Uint32 HINT_MAP_REG58;
    volatile Uint32 HINT_MAP_REG59;
    volatile Uint32 HINT_MAP_REG60;
    volatile Uint32 HINT_MAP_REG61;
    volatile Uint32 HINT_MAP_REG62;
    volatile Uint32 HINT_MAP_REG63;
#else
    volatile Uint32 HINT_MAP[64];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 PRI_HINT_REG0;
    volatile Uint32 PRI_HINT_REG1;
    volatile Uint32 PRI_HINT_REG2;
    volatile Uint32 PRI_HINT_REG3;
    volatile Uint32 PRI_HINT_REG4;
    volatile Uint32 PRI_HINT_REG5;
    volatile Uint32 PRI_HINT_REG6;
    volatile Uint32 PRI_HINT_REG7;
    volatile Uint32 PRI_HINT_REG8;
    volatile Uint32 PRI_HINT_REG9;
    volatile Uint32 PRI_HINT_REG10;
    volatile Uint32 PRI_HINT_REG11;
    volatile Uint32 PRI_HINT_REG12;
    volatile Uint32 PRI_HINT_REG13;
    volatile Uint32 PRI_HINT_REG14;
    volatile Uint32 PRI_HINT_REG15;
    volatile Uint32 PRI_HINT_REG16;
    volatile Uint32 PRI_HINT_REG17;
    volatile Uint32 PRI_HINT_REG18;
    volatile Uint32 PRI_HINT_REG19;
    volatile Uint32 PRI_HINT_REG20;
    volatile Uint32 PRI_HINT_REG21;
    volatile Uint32 PRI_HINT_REG22;
    volatile Uint32 PRI_HINT_REG23;
    volatile Uint32 PRI_HINT_REG24;
    volatile Uint32 PRI_HINT_REG25;
    volatile Uint32 PRI_HINT_REG26;
    volatile Uint32 PRI_HINT_REG27;
    volatile Uint32 PRI_HINT_REG28;
    volatile Uint32 PRI_HINT_REG29;
    volatile Uint32 PRI_HINT_REG30;
    volatile Uint32 PRI_HINT_REG31;
    volatile Uint32 PRI_HINT_REG32;
    volatile Uint32 PRI_HINT_REG33;
    volatile Uint32 PRI_HINT_REG34;
    volatile Uint32 PRI_HINT_REG35;
    volatile Uint32 PRI_HINT_REG36;
    volatile Uint32 PRI_HINT_REG37;
    volatile Uint32 PRI_HINT_REG38;
    volatile Uint32 PRI_HINT_REG39;
    volatile Uint32 PRI_HINT_REG40;
    volatile Uint32 PRI_HINT_REG41;
    volatile Uint32 PRI_HINT_REG42;
    volatile Uint32 PRI_HINT_REG43;
    volatile Uint32 PRI_HINT_REG44;
    volatile Uint32 PRI_HINT_REG45;
    volatile Uint32 PRI_HINT_REG46;
    volatile Uint32 PRI_HINT_REG47;
    volatile Uint32 PRI_HINT_REG48;
    volatile Uint32 PRI_HINT_REG49;
    volatile Uint32 PRI_HINT_REG50;
    volatile Uint32 PRI_HINT_REG51;
    volatile Uint32 PRI_HINT_REG52;
    volatile Uint32 PRI_HINT_REG53;
    volatile Uint32 PRI_HINT_REG54;
    volatile Uint32 PRI_HINT_REG55;
    volatile Uint32 PRI_HINT_REG56;
    volatile Uint32 PRI_HINT_REG57;
    volatile Uint32 PRI_HINT_REG58;
    volatile Uint32 PRI_HINT_REG59;
    volatile Uint32 PRI_HINT_REG60;
    volatile Uint32 PRI_HINT_REG61;
    volatile Uint32 PRI_HINT_REG62;
    volatile Uint32 PRI_HINT_REG63;
    volatile Uint32 PRI_HINT_REG64;
    volatile Uint32 PRI_HINT_REG65;
    volatile Uint32 PRI_HINT_REG66;
    volatile Uint32 PRI_HINT_REG67;
    volatile Uint32 PRI_HINT_REG68;
    volatile Uint32 PRI_HINT_REG69;
    volatile Uint32 PRI_HINT_REG70;
    volatile Uint32 PRI_HINT_REG71;
    volatile Uint32 PRI_HINT_REG72;
    volatile Uint32 PRI_HINT_REG73;
    volatile Uint32 PRI_HINT_REG74;
    volatile Uint32 PRI_HINT_REG75;
    volatile Uint32 PRI_HINT_REG76;
    volatile Uint32 PRI_HINT_REG77;
    volatile Uint32 PRI_HINT_REG78;
    volatile Uint32 PRI_HINT_REG79;
    volatile Uint32 PRI_HINT_REG80;
    volatile Uint32 PRI_HINT_REG81;
    volatile Uint32 PRI_HINT_REG82;
    volatile Uint32 PRI_HINT_REG83;
    volatile Uint32 PRI_HINT_REG84;
    volatile Uint32 PRI_HINT_REG85;
    volatile Uint32 PRI_HINT_REG86;
    volatile Uint32 PRI_HINT_REG87;
    volatile Uint32 PRI_HINT_REG88;
    volatile Uint32 PRI_HINT_REG89;
    volatile Uint32 PRI_HINT_REG90;
    volatile Uint32 PRI_HINT_REG91;
    volatile Uint32 PRI_HINT_REG92;
    volatile Uint32 PRI_HINT_REG93;
    volatile Uint32 PRI_HINT_REG94;
    volatile Uint32 PRI_HINT_REG95;
    volatile Uint32 PRI_HINT_REG96;
    volatile Uint32 PRI_HINT_REG97;
    volatile Uint32 PRI_HINT_REG98;
    volatile Uint32 PRI_HINT_REG99;
    volatile Uint32 PRI_HINT_REG100;
    volatile Uint32 PRI_HINT_REG101;
    volatile Uint32 PRI_HINT_REG102;
    volatile Uint32 PRI_HINT_REG103;
    volatile Uint32 PRI_HINT_REG104;
    volatile Uint32 PRI_HINT_REG105;
    volatile Uint32 PRI_HINT_REG106;
    volatile Uint32 PRI_HINT_REG107;
    volatile Uint32 PRI_HINT_REG108;
    volatile Uint32 PRI_HINT_REG109;
    volatile Uint32 PRI_HINT_REG110;
    volatile Uint32 PRI_HINT_REG111;
    volatile Uint32 PRI_HINT_REG112;
    volatile Uint32 PRI_HINT_REG113;
    volatile Uint32 PRI_HINT_REG114;
    volatile Uint32 PRI_HINT_REG115;
    volatile Uint32 PRI_HINT_REG116;
    volatile Uint32 PRI_HINT_REG117;
    volatile Uint32 PRI_HINT_REG118;
    volatile Uint32 PRI_HINT_REG119;
    volatile Uint32 PRI_HINT_REG120;
    volatile Uint32 PRI_HINT_REG121;
    volatile Uint32 PRI_HINT_REG122;
    volatile Uint32 PRI_HINT_REG123;
    volatile Uint32 PRI_HINT_REG124;
    volatile Uint32 PRI_HINT_REG125;
    volatile Uint32 PRI_HINT_REG126;
    volatile Uint32 PRI_HINT_REG127;
    volatile Uint32 PRI_HINT_REG128;
    volatile Uint32 PRI_HINT_REG129;
    volatile Uint32 PRI_HINT_REG130;
    volatile Uint32 PRI_HINT_REG131;
    volatile Uint32 PRI_HINT_REG132;
    volatile Uint32 PRI_HINT_REG133;
    volatile Uint32 PRI_HINT_REG134;
    volatile Uint32 PRI_HINT_REG135;
    volatile Uint32 PRI_HINT_REG136;
    volatile Uint32 PRI_HINT_REG137;
    volatile Uint32 PRI_HINT_REG138;
    volatile Uint32 PRI_HINT_REG139;
    volatile Uint32 PRI_HINT_REG140;
    volatile Uint32 PRI_HINT_REG141;
    volatile Uint32 PRI_HINT_REG142;
    volatile Uint32 PRI_HINT_REG143;
    volatile Uint32 PRI_HINT_REG144;
    volatile Uint32 PRI_HINT_REG145;
    volatile Uint32 PRI_HINT_REG146;
    volatile Uint32 PRI_HINT_REG147;
    volatile Uint32 PRI_HINT_REG148;
    volatile Uint32 PRI_HINT_REG149;
    volatile Uint32 PRI_HINT_REG150;
    volatile Uint32 PRI_HINT_REG151;
    volatile Uint32 PRI_HINT_REG152;
    volatile Uint32 PRI_HINT_REG153;
    volatile Uint32 PRI_HINT_REG154;
    volatile Uint32 PRI_HINT_REG155;
    volatile Uint32 PRI_HINT_REG156;
    volatile Uint32 PRI_HINT_REG157;
    volatile Uint32 PRI_HINT_REG158;
    volatile Uint32 PRI_HINT_REG159;
    volatile Uint32 PRI_HINT_REG160;
    volatile Uint32 PRI_HINT_REG161;
    volatile Uint32 PRI_HINT_REG162;
    volatile Uint32 PRI_HINT_REG163;
    volatile Uint32 PRI_HINT_REG164;
    volatile Uint32 PRI_HINT_REG165;
    volatile Uint32 PRI_HINT_REG166;
    volatile Uint32 PRI_HINT_REG167;
    volatile Uint32 PRI_HINT_REG168;
    volatile Uint32 PRI_HINT_REG169;
    volatile Uint32 PRI_HINT_REG170;
    volatile Uint32 PRI_HINT_REG171;
    volatile Uint32 PRI_HINT_REG172;
    volatile Uint32 PRI_HINT_REG173;
    volatile Uint32 PRI_HINT_REG174;
    volatile Uint32 PRI_HINT_REG175;
    volatile Uint32 PRI_HINT_REG176;
    volatile Uint32 PRI_HINT_REG177;
    volatile Uint32 PRI_HINT_REG178;
    volatile Uint32 PRI_HINT_REG179;
    volatile Uint32 PRI_HINT_REG180;
    volatile Uint32 PRI_HINT_REG181;
    volatile Uint32 PRI_HINT_REG182;
    volatile Uint32 PRI_HINT_REG183;
    volatile Uint32 PRI_HINT_REG184;
    volatile Uint32 PRI_HINT_REG185;
    volatile Uint32 PRI_HINT_REG186;
    volatile Uint32 PRI_HINT_REG187;
    volatile Uint32 PRI_HINT_REG188;
    volatile Uint32 PRI_HINT_REG189;
    volatile Uint32 PRI_HINT_REG190;
    volatile Uint32 PRI_HINT_REG191;
    volatile Uint32 PRI_HINT_REG192;
    volatile Uint32 PRI_HINT_REG193;
    volatile Uint32 PRI_HINT_REG194;
    volatile Uint32 PRI_HINT_REG195;
    volatile Uint32 PRI_HINT_REG196;
    volatile Uint32 PRI_HINT_REG197;
    volatile Uint32 PRI_HINT_REG198;
    volatile Uint32 PRI_HINT_REG199;
    volatile Uint32 PRI_HINT_REG200;
    volatile Uint32 PRI_HINT_REG201;
    volatile Uint32 PRI_HINT_REG202;
    volatile Uint32 PRI_HINT_REG203;
    volatile Uint32 PRI_HINT_REG204;
    volatile Uint32 PRI_HINT_REG205;
    volatile Uint32 PRI_HINT_REG206;
    volatile Uint32 PRI_HINT_REG207;
    volatile Uint32 PRI_HINT_REG208;
    volatile Uint32 PRI_HINT_REG209;
    volatile Uint32 PRI_HINT_REG210;
    volatile Uint32 PRI_HINT_REG211;
    volatile Uint32 PRI_HINT_REG212;
    volatile Uint32 PRI_HINT_REG213;
    volatile Uint32 PRI_HINT_REG214;
    volatile Uint32 PRI_HINT_REG215;
    volatile Uint32 PRI_HINT_REG216;
    volatile Uint32 PRI_HINT_REG217;
    volatile Uint32 PRI_HINT_REG218;
    volatile Uint32 PRI_HINT_REG219;
    volatile Uint32 PRI_HINT_REG220;
    volatile Uint32 PRI_HINT_REG221;
    volatile Uint32 PRI_HINT_REG222;
    volatile Uint32 PRI_HINT_REG223;
    volatile Uint32 PRI_HINT_REG224;
    volatile Uint32 PRI_HINT_REG225;
    volatile Uint32 PRI_HINT_REG226;
    volatile Uint32 PRI_HINT_REG227;
    volatile Uint32 PRI_HINT_REG228;
    volatile Uint32 PRI_HINT_REG229;
    volatile Uint32 PRI_HINT_REG230;
    volatile Uint32 PRI_HINT_REG231;
    volatile Uint32 PRI_HINT_REG232;
    volatile Uint32 PRI_HINT_REG233;
    volatile Uint32 PRI_HINT_REG234;
    volatile Uint32 PRI_HINT_REG235;
    volatile Uint32 PRI_HINT_REG236;
    volatile Uint32 PRI_HINT_REG237;
    volatile Uint32 PRI_HINT_REG238;
    volatile Uint32 PRI_HINT_REG239;
    volatile Uint32 PRI_HINT_REG240;
    volatile Uint32 PRI_HINT_REG241;
    volatile Uint32 PRI_HINT_REG242;
    volatile Uint32 PRI_HINT_REG243;
    volatile Uint32 PRI_HINT_REG244;
    volatile Uint32 PRI_HINT_REG245;
    volatile Uint32 PRI_HINT_REG246;
    volatile Uint32 PRI_HINT_REG247;
    volatile Uint32 PRI_HINT_REG248;
    volatile Uint32 PRI_HINT_REG249;
    volatile Uint32 PRI_HINT_REG250;
    volatile Uint32 PRI_HINT_REG251;
    volatile Uint32 PRI_HINT_REG252;
    volatile Uint32 PRI_HINT_REG253;
    volatile Uint32 PRI_HINT_REG254;
    volatile Uint32 PRI_HINT_REG255;
#else
    volatile Uint32 PRI_HINT_REG[256];
#endif
#ifdef CSL_MODIFICATION
    volatile Uint32 POLARITY_REG0;
    volatile Uint32 POLARITY_REG1;
    volatile Uint32 POLARITY_REG2;
    volatile Uint32 POLARITY_REG3;
    volatile Uint32 POLARITY_REG4;
    volatile Uint32 POLARITY_REG5;
    volatile Uint32 POLARITY_REG6;
    volatile Uint32 POLARITY_REG7;
    volatile Uint32 POLARITY_REG8;
    volatile Uint32 POLARITY_REG9;
    volatile Uint32 POLARITY_REG10;
    volatile Uint32 POLARITY_REG11;
    volatile Uint32 POLARITY_REG12;
    volatile Uint32 POLARITY_REG13;
    volatile Uint32 POLARITY_REG14;
    volatile Uint32 POLARITY_REG15;
    volatile Uint32 POLARITY_REG16;
    volatile Uint32 POLARITY_REG17;
    volatile Uint32 POLARITY_REG18;
    volatile Uint32 POLARITY_REG19;
    volatile Uint32 POLARITY_REG20;
    volatile Uint32 POLARITY_REG21;
    volatile Uint32 POLARITY_REG22;
    volatile Uint32 POLARITY_REG23;
    volatile Uint32 POLARITY_REG24;
    volatile Uint32 POLARITY_REG25;
    volatile Uint32 POLARITY_REG26;
    volatile Uint32 POLARITY_REG27;
    volatile Uint32 POLARITY_REG28;
    volatile Uint32 POLARITY_REG29;
    volatile Uint32 POLARITY_REG30;
    volatile Uint32 POLARITY_REG31;
#else
    volatile Uint32 POLARITY_REG[32];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 TYPE_REG0;
    volatile Uint32 TYPE_REG1;
    volatile Uint32 TYPE_REG2;
    volatile Uint32 TYPE_REG3;
    volatile Uint32 TYPE_REG4;
    volatile Uint32 TYPE_REG5;
    volatile Uint32 TYPE_REG6;
    volatile Uint32 TYPE_REG7;
    volatile Uint32 TYPE_REG8;
    volatile Uint32 TYPE_REG9;
    volatile Uint32 TYPE_REG10;
    volatile Uint32 TYPE_REG11;
    volatile Uint32 TYPE_REG12;
    volatile Uint32 TYPE_REG13;
    volatile Uint32 TYPE_REG14;
    volatile Uint32 TYPE_REG15;
    volatile Uint32 TYPE_REG16;
    volatile Uint32 TYPE_REG17;
    volatile Uint32 TYPE_REG18;
    volatile Uint32 TYPE_REG19;
    volatile Uint32 TYPE_REG20;
    volatile Uint32 TYPE_REG21;
    volatile Uint32 TYPE_REG22;
    volatile Uint32 TYPE_REG23;
    volatile Uint32 TYPE_REG24;
    volatile Uint32 TYPE_REG25;
    volatile Uint32 TYPE_REG26;
    volatile Uint32 TYPE_REG27;
    volatile Uint32 TYPE_REG28;
    volatile Uint32 TYPE_REG29;
    volatile Uint32 TYPE_REG30;
    volatile Uint32 TYPE_REG31;
#else
    volatile Uint32 TYPE_REG[32];
#endif    
    volatile Uint8 RSVD7[256];
#ifdef CSL_MODIFICATION    
    volatile Uint32 DBG_SELECT_REG0;
    volatile Uint32 DBG_SELECT_REG1;
    volatile Uint32 DBG_SELECT_REG2;
    volatile Uint32 DBG_SELECT_REG3;
    volatile Uint32 DBG_SELECT_REG4;
    volatile Uint32 DBG_SELECT_REG5;
    volatile Uint32 DBG_SELECT_REG6;
    volatile Uint32 DBG_SELECT_REG7;
    volatile Uint32 DBG_SELECT_REG8;
    volatile Uint32 DBG_SELECT_REG9;
    volatile Uint32 DBG_SELECT_REG10;
    volatile Uint32 DBG_SELECT_REG11;
    volatile Uint32 DBG_SELECT_REG12;
    volatile Uint32 DBG_SELECT_REG13;
    volatile Uint32 DBG_SELECT_REG14;
    volatile Uint32 DBG_SELECT_REG15;
    volatile Uint32 DBG_SELECT_REG16;
    volatile Uint32 DBG_SELECT_REG17;
    volatile Uint32 DBG_SELECT_REG18;
    volatile Uint32 DBG_SELECT_REG19;
    volatile Uint32 DBG_SELECT_REG20;
    volatile Uint32 DBG_SELECT_REG21;
    volatile Uint32 DBG_SELECT_REG22;
    volatile Uint32 DBG_SELECT_REG23;
    volatile Uint32 DBG_SELECT_REG24;
    volatile Uint32 DBG_SELECT_REG25;
    volatile Uint32 DBG_SELECT_REG26;
    volatile Uint32 DBG_SELECT_REG27;
    volatile Uint32 DBG_SELECT_REG28;
    volatile Uint32 DBG_SELECT_REG29;
    volatile Uint32 DBG_SELECT_REG30;
    volatile Uint32 DBG_SELECT_REG31;
    volatile Uint32 DBG_SELECT_REG32;
    volatile Uint32 DBG_SELECT_REG33;
    volatile Uint32 DBG_SELECT_REG34;
    volatile Uint32 DBG_SELECT_REG35;
    volatile Uint32 DBG_SELECT_REG36;
    volatile Uint32 DBG_SELECT_REG37;
    volatile Uint32 DBG_SELECT_REG38;
    volatile Uint32 DBG_SELECT_REG39;
    volatile Uint32 DBG_SELECT_REG40;
    volatile Uint32 DBG_SELECT_REG41;
    volatile Uint32 DBG_SELECT_REG42;
    volatile Uint32 DBG_SELECT_REG43;
    volatile Uint32 DBG_SELECT_REG44;
    volatile Uint32 DBG_SELECT_REG45;
    volatile Uint32 DBG_SELECT_REG46;
    volatile Uint32 DBG_SELECT_REG47;
    volatile Uint32 DBG_SELECT_REG48;
    volatile Uint32 DBG_SELECT_REG49;
    volatile Uint32 DBG_SELECT_REG50;
    volatile Uint32 DBG_SELECT_REG51;
    volatile Uint32 DBG_SELECT_REG52;
    volatile Uint32 DBG_SELECT_REG53;
    volatile Uint32 DBG_SELECT_REG54;
    volatile Uint32 DBG_SELECT_REG55;
    volatile Uint32 DBG_SELECT_REG56;
    volatile Uint32 DBG_SELECT_REG57;
    volatile Uint32 DBG_SELECT_REG58;
    volatile Uint32 DBG_SELECT_REG59;
    volatile Uint32 DBG_SELECT_REG60;
    volatile Uint32 DBG_SELECT_REG61;
    volatile Uint32 DBG_SELECT_REG62;
    volatile Uint32 DBG_SELECT_REG63;
#else
    volatile Uint32 DBG_SELECT_REG[64];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 SECURE_ENABLE_REG0;
    volatile Uint32 SECURE_ENABLE_REG1;
    volatile Uint32 SECURE_ENABLE_REG2;
    volatile Uint32 SECURE_ENABLE_REG3;
    volatile Uint32 SECURE_ENABLE_REG4;
    volatile Uint32 SECURE_ENABLE_REG5;
    volatile Uint32 SECURE_ENABLE_REG6;
    volatile Uint32 SECURE_ENABLE_REG7;
    volatile Uint32 SECURE_ENABLE_REG8;
    volatile Uint32 SECURE_ENABLE_REG9;
    volatile Uint32 SECURE_ENABLE_REG10;
    volatile Uint32 SECURE_ENABLE_REG11;
    volatile Uint32 SECURE_ENABLE_REG12;
    volatile Uint32 SECURE_ENABLE_REG13;
    volatile Uint32 SECURE_ENABLE_REG14;
    volatile Uint32 SECURE_ENABLE_REG15;
    volatile Uint32 SECURE_ENABLE_REG16;
    volatile Uint32 SECURE_ENABLE_REG17;
    volatile Uint32 SECURE_ENABLE_REG18;
    volatile Uint32 SECURE_ENABLE_REG19;
    volatile Uint32 SECURE_ENABLE_REG20;
    volatile Uint32 SECURE_ENABLE_REG21;
    volatile Uint32 SECURE_ENABLE_REG22;
    volatile Uint32 SECURE_ENABLE_REG23;
    volatile Uint32 SECURE_ENABLE_REG24;
    volatile Uint32 SECURE_ENABLE_REG25;
    volatile Uint32 SECURE_ENABLE_REG26;
    volatile Uint32 SECURE_ENABLE_REG27;
    volatile Uint32 SECURE_ENABLE_REG28;
    volatile Uint32 SECURE_ENABLE_REG29;
    volatile Uint32 SECURE_ENABLE_REG30;
    volatile Uint32 SECURE_ENABLE_REG31;
#else
    volatile Uint32 SECURE_ENABLE_REG[32];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 SECURE_ENABLE_CLR_REG0;
    volatile Uint32 SECURE_ENABLE_CLR_REG1;
    volatile Uint32 SECURE_ENABLE_CLR_REG2;
    volatile Uint32 SECURE_ENABLE_CLR_REG3;
    volatile Uint32 SECURE_ENABLE_CLR_REG4;
    volatile Uint32 SECURE_ENABLE_CLR_REG5;
    volatile Uint32 SECURE_ENABLE_CLR_REG6;
    volatile Uint32 SECURE_ENABLE_CLR_REG7;
    volatile Uint32 SECURE_ENABLE_CLR_REG8;
    volatile Uint32 SECURE_ENABLE_CLR_REG9;
    volatile Uint32 SECURE_ENABLE_CLR_REG10;
    volatile Uint32 SECURE_ENABLE_CLR_REG11;
    volatile Uint32 SECURE_ENABLE_CLR_REG12;
    volatile Uint32 SECURE_ENABLE_CLR_REG13;
    volatile Uint32 SECURE_ENABLE_CLR_REG14;
    volatile Uint32 SECURE_ENABLE_CLR_REG15;
    volatile Uint32 SECURE_ENABLE_CLR_REG16;
    volatile Uint32 SECURE_ENABLE_CLR_REG17;
    volatile Uint32 SECURE_ENABLE_CLR_REG18;
    volatile Uint32 SECURE_ENABLE_CLR_REG19;
    volatile Uint32 SECURE_ENABLE_CLR_REG20;
    volatile Uint32 SECURE_ENABLE_CLR_REG21;
    volatile Uint32 SECURE_ENABLE_CLR_REG22;
    volatile Uint32 SECURE_ENABLE_CLR_REG23;
    volatile Uint32 SECURE_ENABLE_CLR_REG24;
    volatile Uint32 SECURE_ENABLE_CLR_REG25;
    volatile Uint32 SECURE_ENABLE_CLR_REG26;
    volatile Uint32 SECURE_ENABLE_CLR_REG27;
    volatile Uint32 SECURE_ENABLE_CLR_REG28;
    volatile Uint32 SECURE_ENABLE_CLR_REG29;
    volatile Uint32 SECURE_ENABLE_CLR_REG30;
    volatile Uint32 SECURE_ENABLE_CLR_REG31;
#else
    volatile Uint32 SECURE_ENABLE_CLR_REG[32];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 NEST_LEVEL_REG0;
    volatile Uint32 NEST_LEVEL_REG1;
    volatile Uint32 NEST_LEVEL_REG2;
    volatile Uint32 NEST_LEVEL_REG3;
    volatile Uint32 NEST_LEVEL_REG4;
    volatile Uint32 NEST_LEVEL_REG5;
    volatile Uint32 NEST_LEVEL_REG6;
    volatile Uint32 NEST_LEVEL_REG7;
    volatile Uint32 NEST_LEVEL_REG8;
    volatile Uint32 NEST_LEVEL_REG9;
    volatile Uint32 NEST_LEVEL_REG10;
    volatile Uint32 NEST_LEVEL_REG11;
    volatile Uint32 NEST_LEVEL_REG12;
    volatile Uint32 NEST_LEVEL_REG13;
    volatile Uint32 NEST_LEVEL_REG14;
    volatile Uint32 NEST_LEVEL_REG15;
    volatile Uint32 NEST_LEVEL_REG16;
    volatile Uint32 NEST_LEVEL_REG17;
    volatile Uint32 NEST_LEVEL_REG18;
    volatile Uint32 NEST_LEVEL_REG19;
    volatile Uint32 NEST_LEVEL_REG20;
    volatile Uint32 NEST_LEVEL_REG21;
    volatile Uint32 NEST_LEVEL_REG22;
    volatile Uint32 NEST_LEVEL_REG23;
    volatile Uint32 NEST_LEVEL_REG24;
    volatile Uint32 NEST_LEVEL_REG25;
    volatile Uint32 NEST_LEVEL_REG26;
    volatile Uint32 NEST_LEVEL_REG27;
    volatile Uint32 NEST_LEVEL_REG28;
    volatile Uint32 NEST_LEVEL_REG29;
    volatile Uint32 NEST_LEVEL_REG30;
    volatile Uint32 NEST_LEVEL_REG31;
    volatile Uint32 NEST_LEVEL_REG32;
    volatile Uint32 NEST_LEVEL_REG33;
    volatile Uint32 NEST_LEVEL_REG34;
    volatile Uint32 NEST_LEVEL_REG35;
    volatile Uint32 NEST_LEVEL_REG36;
    volatile Uint32 NEST_LEVEL_REG37;
    volatile Uint32 NEST_LEVEL_REG38;
    volatile Uint32 NEST_LEVEL_REG39;
    volatile Uint32 NEST_LEVEL_REG40;
    volatile Uint32 NEST_LEVEL_REG41;
    volatile Uint32 NEST_LEVEL_REG42;
    volatile Uint32 NEST_LEVEL_REG43;
    volatile Uint32 NEST_LEVEL_REG44;
    volatile Uint32 NEST_LEVEL_REG45;
    volatile Uint32 NEST_LEVEL_REG46;
    volatile Uint32 NEST_LEVEL_REG47;
    volatile Uint32 NEST_LEVEL_REG48;
    volatile Uint32 NEST_LEVEL_REG49;
    volatile Uint32 NEST_LEVEL_REG50;
    volatile Uint32 NEST_LEVEL_REG51;
    volatile Uint32 NEST_LEVEL_REG52;
    volatile Uint32 NEST_LEVEL_REG53;
    volatile Uint32 NEST_LEVEL_REG54;
    volatile Uint32 NEST_LEVEL_REG55;
    volatile Uint32 NEST_LEVEL_REG56;
    volatile Uint32 NEST_LEVEL_REG57;
    volatile Uint32 NEST_LEVEL_REG58;
    volatile Uint32 NEST_LEVEL_REG59;
    volatile Uint32 NEST_LEVEL_REG60;
    volatile Uint32 NEST_LEVEL_REG61;
    volatile Uint32 NEST_LEVEL_REG62;
    volatile Uint32 NEST_LEVEL_REG63;
    volatile Uint32 NEST_LEVEL_REG64;
    volatile Uint32 NEST_LEVEL_REG65;
    volatile Uint32 NEST_LEVEL_REG66;
    volatile Uint32 NEST_LEVEL_REG67;
    volatile Uint32 NEST_LEVEL_REG68;
    volatile Uint32 NEST_LEVEL_REG69;
    volatile Uint32 NEST_LEVEL_REG70;
    volatile Uint32 NEST_LEVEL_REG71;
    volatile Uint32 NEST_LEVEL_REG72;
    volatile Uint32 NEST_LEVEL_REG73;
    volatile Uint32 NEST_LEVEL_REG74;
    volatile Uint32 NEST_LEVEL_REG75;
    volatile Uint32 NEST_LEVEL_REG76;
    volatile Uint32 NEST_LEVEL_REG77;
    volatile Uint32 NEST_LEVEL_REG78;
    volatile Uint32 NEST_LEVEL_REG79;
    volatile Uint32 NEST_LEVEL_REG80;
    volatile Uint32 NEST_LEVEL_REG81;
    volatile Uint32 NEST_LEVEL_REG82;
    volatile Uint32 NEST_LEVEL_REG83;
    volatile Uint32 NEST_LEVEL_REG84;
    volatile Uint32 NEST_LEVEL_REG85;
    volatile Uint32 NEST_LEVEL_REG86;
    volatile Uint32 NEST_LEVEL_REG87;
    volatile Uint32 NEST_LEVEL_REG88;
    volatile Uint32 NEST_LEVEL_REG89;
    volatile Uint32 NEST_LEVEL_REG90;
    volatile Uint32 NEST_LEVEL_REG91;
    volatile Uint32 NEST_LEVEL_REG92;
    volatile Uint32 NEST_LEVEL_REG93;
    volatile Uint32 NEST_LEVEL_REG94;
    volatile Uint32 NEST_LEVEL_REG95;
    volatile Uint32 NEST_LEVEL_REG96;
    volatile Uint32 NEST_LEVEL_REG97;
    volatile Uint32 NEST_LEVEL_REG98;
    volatile Uint32 NEST_LEVEL_REG99;
    volatile Uint32 NEST_LEVEL_REG100;
    volatile Uint32 NEST_LEVEL_REG101;
    volatile Uint32 NEST_LEVEL_REG102;
    volatile Uint32 NEST_LEVEL_REG103;
    volatile Uint32 NEST_LEVEL_REG104;
    volatile Uint32 NEST_LEVEL_REG105;
    volatile Uint32 NEST_LEVEL_REG106;
    volatile Uint32 NEST_LEVEL_REG107;
    volatile Uint32 NEST_LEVEL_REG108;
    volatile Uint32 NEST_LEVEL_REG109;
    volatile Uint32 NEST_LEVEL_REG110;
    volatile Uint32 NEST_LEVEL_REG111;
    volatile Uint32 NEST_LEVEL_REG112;
    volatile Uint32 NEST_LEVEL_REG113;
    volatile Uint32 NEST_LEVEL_REG114;
    volatile Uint32 NEST_LEVEL_REG115;
    volatile Uint32 NEST_LEVEL_REG116;
    volatile Uint32 NEST_LEVEL_REG117;
    volatile Uint32 NEST_LEVEL_REG118;
    volatile Uint32 NEST_LEVEL_REG119;
    volatile Uint32 NEST_LEVEL_REG120;
    volatile Uint32 NEST_LEVEL_REG121;
    volatile Uint32 NEST_LEVEL_REG122;
    volatile Uint32 NEST_LEVEL_REG123;
    volatile Uint32 NEST_LEVEL_REG124;
    volatile Uint32 NEST_LEVEL_REG125;
    volatile Uint32 NEST_LEVEL_REG126;
    volatile Uint32 NEST_LEVEL_REG127;
    volatile Uint32 NEST_LEVEL_REG128;
    volatile Uint32 NEST_LEVEL_REG129;
    volatile Uint32 NEST_LEVEL_REG130;
    volatile Uint32 NEST_LEVEL_REG131;
    volatile Uint32 NEST_LEVEL_REG132;
    volatile Uint32 NEST_LEVEL_REG133;
    volatile Uint32 NEST_LEVEL_REG134;
    volatile Uint32 NEST_LEVEL_REG135;
    volatile Uint32 NEST_LEVEL_REG136;
    volatile Uint32 NEST_LEVEL_REG137;
    volatile Uint32 NEST_LEVEL_REG138;
    volatile Uint32 NEST_LEVEL_REG139;
    volatile Uint32 NEST_LEVEL_REG140;
    volatile Uint32 NEST_LEVEL_REG141;
    volatile Uint32 NEST_LEVEL_REG142;
    volatile Uint32 NEST_LEVEL_REG143;
    volatile Uint32 NEST_LEVEL_REG144;
    volatile Uint32 NEST_LEVEL_REG145;
    volatile Uint32 NEST_LEVEL_REG146;
    volatile Uint32 NEST_LEVEL_REG147;
    volatile Uint32 NEST_LEVEL_REG148;
    volatile Uint32 NEST_LEVEL_REG149;
    volatile Uint32 NEST_LEVEL_REG150;
    volatile Uint32 NEST_LEVEL_REG151;
    volatile Uint32 NEST_LEVEL_REG152;
    volatile Uint32 NEST_LEVEL_REG153;
    volatile Uint32 NEST_LEVEL_REG154;
    volatile Uint32 NEST_LEVEL_REG155;
    volatile Uint32 NEST_LEVEL_REG156;
    volatile Uint32 NEST_LEVEL_REG157;
    volatile Uint32 NEST_LEVEL_REG158;
    volatile Uint32 NEST_LEVEL_REG159;
    volatile Uint32 NEST_LEVEL_REG160;
    volatile Uint32 NEST_LEVEL_REG161;
    volatile Uint32 NEST_LEVEL_REG162;
    volatile Uint32 NEST_LEVEL_REG163;
    volatile Uint32 NEST_LEVEL_REG164;
    volatile Uint32 NEST_LEVEL_REG165;
    volatile Uint32 NEST_LEVEL_REG166;
    volatile Uint32 NEST_LEVEL_REG167;
    volatile Uint32 NEST_LEVEL_REG168;
    volatile Uint32 NEST_LEVEL_REG169;
    volatile Uint32 NEST_LEVEL_REG170;
    volatile Uint32 NEST_LEVEL_REG171;
    volatile Uint32 NEST_LEVEL_REG172;
    volatile Uint32 NEST_LEVEL_REG173;
    volatile Uint32 NEST_LEVEL_REG174;
    volatile Uint32 NEST_LEVEL_REG175;
    volatile Uint32 NEST_LEVEL_REG176;
    volatile Uint32 NEST_LEVEL_REG177;
    volatile Uint32 NEST_LEVEL_REG178;
    volatile Uint32 NEST_LEVEL_REG179;
    volatile Uint32 NEST_LEVEL_REG180;
    volatile Uint32 NEST_LEVEL_REG181;
    volatile Uint32 NEST_LEVEL_REG182;
    volatile Uint32 NEST_LEVEL_REG183;
    volatile Uint32 NEST_LEVEL_REG184;
    volatile Uint32 NEST_LEVEL_REG185;
    volatile Uint32 NEST_LEVEL_REG186;
    volatile Uint32 NEST_LEVEL_REG187;
    volatile Uint32 NEST_LEVEL_REG188;
    volatile Uint32 NEST_LEVEL_REG189;
    volatile Uint32 NEST_LEVEL_REG190;
    volatile Uint32 NEST_LEVEL_REG191;
    volatile Uint32 NEST_LEVEL_REG192;
    volatile Uint32 NEST_LEVEL_REG193;
    volatile Uint32 NEST_LEVEL_REG194;
    volatile Uint32 NEST_LEVEL_REG195;
    volatile Uint32 NEST_LEVEL_REG196;
    volatile Uint32 NEST_LEVEL_REG197;
    volatile Uint32 NEST_LEVEL_REG198;
    volatile Uint32 NEST_LEVEL_REG199;
    volatile Uint32 NEST_LEVEL_REG200;
    volatile Uint32 NEST_LEVEL_REG201;
    volatile Uint32 NEST_LEVEL_REG202;
    volatile Uint32 NEST_LEVEL_REG203;
    volatile Uint32 NEST_LEVEL_REG204;
    volatile Uint32 NEST_LEVEL_REG205;
    volatile Uint32 NEST_LEVEL_REG206;
    volatile Uint32 NEST_LEVEL_REG207;
    volatile Uint32 NEST_LEVEL_REG208;
    volatile Uint32 NEST_LEVEL_REG209;
    volatile Uint32 NEST_LEVEL_REG210;
    volatile Uint32 NEST_LEVEL_REG211;
    volatile Uint32 NEST_LEVEL_REG212;
    volatile Uint32 NEST_LEVEL_REG213;
    volatile Uint32 NEST_LEVEL_REG214;
    volatile Uint32 NEST_LEVEL_REG215;
    volatile Uint32 NEST_LEVEL_REG216;
    volatile Uint32 NEST_LEVEL_REG217;
    volatile Uint32 NEST_LEVEL_REG218;
    volatile Uint32 NEST_LEVEL_REG219;
    volatile Uint32 NEST_LEVEL_REG220;
    volatile Uint32 NEST_LEVEL_REG221;
    volatile Uint32 NEST_LEVEL_REG222;
    volatile Uint32 NEST_LEVEL_REG223;
    volatile Uint32 NEST_LEVEL_REG224;
    volatile Uint32 NEST_LEVEL_REG225;
    volatile Uint32 NEST_LEVEL_REG226;
    volatile Uint32 NEST_LEVEL_REG227;
    volatile Uint32 NEST_LEVEL_REG228;
    volatile Uint32 NEST_LEVEL_REG229;
    volatile Uint32 NEST_LEVEL_REG230;
    volatile Uint32 NEST_LEVEL_REG231;
    volatile Uint32 NEST_LEVEL_REG232;
    volatile Uint32 NEST_LEVEL_REG233;
    volatile Uint32 NEST_LEVEL_REG234;
    volatile Uint32 NEST_LEVEL_REG235;
    volatile Uint32 NEST_LEVEL_REG236;
    volatile Uint32 NEST_LEVEL_REG237;
    volatile Uint32 NEST_LEVEL_REG238;
    volatile Uint32 NEST_LEVEL_REG239;
    volatile Uint32 NEST_LEVEL_REG240;
    volatile Uint32 NEST_LEVEL_REG241;
    volatile Uint32 NEST_LEVEL_REG242;
    volatile Uint32 NEST_LEVEL_REG243;
    volatile Uint32 NEST_LEVEL_REG244;
    volatile Uint32 NEST_LEVEL_REG245;
    volatile Uint32 NEST_LEVEL_REG246;
    volatile Uint32 NEST_LEVEL_REG247;
    volatile Uint32 NEST_LEVEL_REG248;
    volatile Uint32 NEST_LEVEL_REG249;
    volatile Uint32 NEST_LEVEL_REG250;
    volatile Uint32 NEST_LEVEL_REG251;
    volatile Uint32 NEST_LEVEL_REG252;
    volatile Uint32 NEST_LEVEL_REG253;
    volatile Uint32 NEST_LEVEL_REG254;
    volatile Uint32 NEST_LEVEL_REG255;
#else
    volatile Uint32 NEST_LEVEL_REG[256];
#endif
#ifdef CSL_MODIFICATION    
    volatile Uint32 ENABLE_HINT_REG0;
    volatile Uint32 ENABLE_HINT_REG1;
    volatile Uint32 ENABLE_HINT_REG2;
    volatile Uint32 ENABLE_HINT_REG3;
    volatile Uint32 ENABLE_HINT_REG4;
    volatile Uint32 ENABLE_HINT_REG5;
    volatile Uint32 ENABLE_HINT_REG6;
    volatile Uint32 ENABLE_HINT_REG7;
#else
    volatile Uint32 ENABLE_HINT_REG[8];
#endif    
    volatile Uint8 RSVD8[2784];
#ifdef CSL_MODIFICATION    
    volatile Uint32 VECTOR_ADDRESS_REG_0;
    volatile Uint32 VECTOR_ADDRESS_REG_1;
    volatile Uint32 VECTOR_ADDRESS_REG_2;
    volatile Uint32 VECTOR_ADDRESS_REG_3;
    volatile Uint32 VECTOR_ADDRESS_REG_4;
    volatile Uint32 VECTOR_ADDRESS_REG_5;
    volatile Uint32 VECTOR_ADDRESS_REG_6;
    volatile Uint32 VECTOR_ADDRESS_REG_7;
    volatile Uint32 VECTOR_ADDRESS_REG_8;
    volatile Uint32 VECTOR_ADDRESS_REG_9;
    volatile Uint32 VECTOR_ADDRESS_REG_10;
    volatile Uint32 VECTOR_ADDRESS_REG_11;
    volatile Uint32 VECTOR_ADDRESS_REG_12;
    volatile Uint32 VECTOR_ADDRESS_REG_13;
    volatile Uint32 VECTOR_ADDRESS_REG_14;
    volatile Uint32 VECTOR_ADDRESS_REG_15;
    volatile Uint32 VECTOR_ADDRESS_REG_16;
    volatile Uint32 VECTOR_ADDRESS_REG_17;
    volatile Uint32 VECTOR_ADDRESS_REG_18;
    volatile Uint32 VECTOR_ADDRESS_REG_19;
    volatile Uint32 VECTOR_ADDRESS_REG_20;
    volatile Uint32 VECTOR_ADDRESS_REG_21;
    volatile Uint32 VECTOR_ADDRESS_REG_22;
    volatile Uint32 VECTOR_ADDRESS_REG_23;
    volatile Uint32 VECTOR_ADDRESS_REG_24;
    volatile Uint32 VECTOR_ADDRESS_REG_25;
    volatile Uint32 VECTOR_ADDRESS_REG_26;
    volatile Uint32 VECTOR_ADDRESS_REG_27;
    volatile Uint32 VECTOR_ADDRESS_REG_28;
    volatile Uint32 VECTOR_ADDRESS_REG_29;
    volatile Uint32 VECTOR_ADDRESS_REG_30;
    volatile Uint32 VECTOR_ADDRESS_REG_31;
    volatile Uint32 VECTOR_ADDRESS_REG_32;
    volatile Uint32 VECTOR_ADDRESS_REG_33;
    volatile Uint32 VECTOR_ADDRESS_REG_34;
    volatile Uint32 VECTOR_ADDRESS_REG_35;
    volatile Uint32 VECTOR_ADDRESS_REG_36;
    volatile Uint32 VECTOR_ADDRESS_REG_37;
    volatile Uint32 VECTOR_ADDRESS_REG_38;
    volatile Uint32 VECTOR_ADDRESS_REG_39;
    volatile Uint32 VECTOR_ADDRESS_REG_40;
    volatile Uint32 VECTOR_ADDRESS_REG_41;
    volatile Uint32 VECTOR_ADDRESS_REG_42;
    volatile Uint32 VECTOR_ADDRESS_REG_43;
    volatile Uint32 VECTOR_ADDRESS_REG_44;
    volatile Uint32 VECTOR_ADDRESS_REG_45;
    volatile Uint32 VECTOR_ADDRESS_REG_46;
    volatile Uint32 VECTOR_ADDRESS_REG_47;
    volatile Uint32 VECTOR_ADDRESS_REG_48;
    volatile Uint32 VECTOR_ADDRESS_REG_49;
    volatile Uint32 VECTOR_ADDRESS_REG_50;
    volatile Uint32 VECTOR_ADDRESS_REG_51;
    volatile Uint32 VECTOR_ADDRESS_REG_52;
    volatile Uint32 VECTOR_ADDRESS_REG_53;
    volatile Uint32 VECTOR_ADDRESS_REG_54;
    volatile Uint32 VECTOR_ADDRESS_REG_55;
    volatile Uint32 VECTOR_ADDRESS_REG_56;
    volatile Uint32 VECTOR_ADDRESS_REG_57;
    volatile Uint32 VECTOR_ADDRESS_REG_58;
    volatile Uint32 VECTOR_ADDRESS_REG_59;
    volatile Uint32 VECTOR_ADDRESS_REG_60;
    volatile Uint32 VECTOR_ADDRESS_REG_61;
    volatile Uint32 VECTOR_ADDRESS_REG_62;
    volatile Uint32 VECTOR_ADDRESS_REG_63;
    volatile Uint32 VECTOR_ADDRESS_REG_64;
    volatile Uint32 VECTOR_ADDRESS_REG_65;
    volatile Uint32 VECTOR_ADDRESS_REG_66;
    volatile Uint32 VECTOR_ADDRESS_REG_67;
    volatile Uint32 VECTOR_ADDRESS_REG_68;
    volatile Uint32 VECTOR_ADDRESS_REG_69;
    volatile Uint32 VECTOR_ADDRESS_REG_70;
    volatile Uint32 VECTOR_ADDRESS_REG_71;
    volatile Uint32 VECTOR_ADDRESS_REG_72;
    volatile Uint32 VECTOR_ADDRESS_REG_73;
    volatile Uint32 VECTOR_ADDRESS_REG_74;
    volatile Uint32 VECTOR_ADDRESS_REG_75;
    volatile Uint32 VECTOR_ADDRESS_REG_76;
    volatile Uint32 VECTOR_ADDRESS_REG_77;
    volatile Uint32 VECTOR_ADDRESS_REG_78;
    volatile Uint32 VECTOR_ADDRESS_REG_79;
    volatile Uint32 VECTOR_ADDRESS_REG_80;
    volatile Uint32 VECTOR_ADDRESS_REG_81;
    volatile Uint32 VECTOR_ADDRESS_REG_82;
    volatile Uint32 VECTOR_ADDRESS_REG_83;
    volatile Uint32 VECTOR_ADDRESS_REG_84;
    volatile Uint32 VECTOR_ADDRESS_REG_85;
    volatile Uint32 VECTOR_ADDRESS_REG_86;
    volatile Uint32 VECTOR_ADDRESS_REG_87;
    volatile Uint32 VECTOR_ADDRESS_REG_88;
    volatile Uint32 VECTOR_ADDRESS_REG_89;
    volatile Uint32 VECTOR_ADDRESS_REG_90;
    volatile Uint32 VECTOR_ADDRESS_REG_91;
    volatile Uint32 VECTOR_ADDRESS_REG_92;
    volatile Uint32 VECTOR_ADDRESS_REG_93;
    volatile Uint32 VECTOR_ADDRESS_REG_94;
    volatile Uint32 VECTOR_ADDRESS_REG_95;
    volatile Uint32 VECTOR_ADDRESS_REG_96;
    volatile Uint32 VECTOR_ADDRESS_REG_97;
    volatile Uint32 VECTOR_ADDRESS_REG_98;
    volatile Uint32 VECTOR_ADDRESS_REG_99;
    volatile Uint32 VECTOR_ADDRESS_REG_100;
    volatile Uint32 VECTOR_ADDRESS_REG_101;
    volatile Uint32 VECTOR_ADDRESS_REG_102;
    volatile Uint32 VECTOR_ADDRESS_REG_103;
    volatile Uint32 VECTOR_ADDRESS_REG_104;
    volatile Uint32 VECTOR_ADDRESS_REG_105;
    volatile Uint32 VECTOR_ADDRESS_REG_106;
    volatile Uint32 VECTOR_ADDRESS_REG_107;
    volatile Uint32 VECTOR_ADDRESS_REG_108;
    volatile Uint32 VECTOR_ADDRESS_REG_109;
    volatile Uint32 VECTOR_ADDRESS_REG_110;
    volatile Uint32 VECTOR_ADDRESS_REG_111;
    volatile Uint32 VECTOR_ADDRESS_REG_112;
    volatile Uint32 VECTOR_ADDRESS_REG_113;
    volatile Uint32 VECTOR_ADDRESS_REG_114;
    volatile Uint32 VECTOR_ADDRESS_REG_115;
    volatile Uint32 VECTOR_ADDRESS_REG_116;
    volatile Uint32 VECTOR_ADDRESS_REG_117;
    volatile Uint32 VECTOR_ADDRESS_REG_118;
    volatile Uint32 VECTOR_ADDRESS_REG_119;
    volatile Uint32 VECTOR_ADDRESS_REG_120;
    volatile Uint32 VECTOR_ADDRESS_REG_121;
    volatile Uint32 VECTOR_ADDRESS_REG_122;
    volatile Uint32 VECTOR_ADDRESS_REG_123;
    volatile Uint32 VECTOR_ADDRESS_REG_124;
    volatile Uint32 VECTOR_ADDRESS_REG_125;
    volatile Uint32 VECTOR_ADDRESS_REG_126;
    volatile Uint32 VECTOR_ADDRESS_REG_127;
    volatile Uint32 VECTOR_ADDRESS_REG_128;
    volatile Uint32 VECTOR_ADDRESS_REG_129;
    volatile Uint32 VECTOR_ADDRESS_REG_130;
    volatile Uint32 VECTOR_ADDRESS_REG_131;
    volatile Uint32 VECTOR_ADDRESS_REG_132;
    volatile Uint32 VECTOR_ADDRESS_REG_133;
    volatile Uint32 VECTOR_ADDRESS_REG_134;
    volatile Uint32 VECTOR_ADDRESS_REG_135;
    volatile Uint32 VECTOR_ADDRESS_REG_136;
    volatile Uint32 VECTOR_ADDRESS_REG_137;
    volatile Uint32 VECTOR_ADDRESS_REG_138;
    volatile Uint32 VECTOR_ADDRESS_REG_139;
    volatile Uint32 VECTOR_ADDRESS_REG_140;
    volatile Uint32 VECTOR_ADDRESS_REG_141;
    volatile Uint32 VECTOR_ADDRESS_REG_142;
    volatile Uint32 VECTOR_ADDRESS_REG_143;
    volatile Uint32 VECTOR_ADDRESS_REG_144;
    volatile Uint32 VECTOR_ADDRESS_REG_145;
    volatile Uint32 VECTOR_ADDRESS_REG_146;
    volatile Uint32 VECTOR_ADDRESS_REG_147;
    volatile Uint32 VECTOR_ADDRESS_REG_148;
    volatile Uint32 VECTOR_ADDRESS_REG_149;
    volatile Uint32 VECTOR_ADDRESS_REG_150;
    volatile Uint32 VECTOR_ADDRESS_REG_151;
    volatile Uint32 VECTOR_ADDRESS_REG_152;
    volatile Uint32 VECTOR_ADDRESS_REG_153;
    volatile Uint32 VECTOR_ADDRESS_REG_154;
    volatile Uint32 VECTOR_ADDRESS_REG_155;
    volatile Uint32 VECTOR_ADDRESS_REG_156;
    volatile Uint32 VECTOR_ADDRESS_REG_157;
    volatile Uint32 VECTOR_ADDRESS_REG_158;
    volatile Uint32 VECTOR_ADDRESS_REG_159;
    volatile Uint32 VECTOR_ADDRESS_REG_160;
    volatile Uint32 VECTOR_ADDRESS_REG_161;
    volatile Uint32 VECTOR_ADDRESS_REG_162;
    volatile Uint32 VECTOR_ADDRESS_REG_163;
    volatile Uint32 VECTOR_ADDRESS_REG_164;
    volatile Uint32 VECTOR_ADDRESS_REG_165;
    volatile Uint32 VECTOR_ADDRESS_REG_166;
    volatile Uint32 VECTOR_ADDRESS_REG_167;
    volatile Uint32 VECTOR_ADDRESS_REG_168;
    volatile Uint32 VECTOR_ADDRESS_REG_169;
    volatile Uint32 VECTOR_ADDRESS_REG_170;
    volatile Uint32 VECTOR_ADDRESS_REG_171;
    volatile Uint32 VECTOR_ADDRESS_REG_172;
    volatile Uint32 VECTOR_ADDRESS_REG_173;
    volatile Uint32 VECTOR_ADDRESS_REG_174;
    volatile Uint32 VECTOR_ADDRESS_REG_175;
    volatile Uint32 VECTOR_ADDRESS_REG_176;
    volatile Uint32 VECTOR_ADDRESS_REG_177;
    volatile Uint32 VECTOR_ADDRESS_REG_178;
    volatile Uint32 VECTOR_ADDRESS_REG_179;
    volatile Uint32 VECTOR_ADDRESS_REG_180;
    volatile Uint32 VECTOR_ADDRESS_REG_181;
    volatile Uint32 VECTOR_ADDRESS_REG_182;
    volatile Uint32 VECTOR_ADDRESS_REG_183;
    volatile Uint32 VECTOR_ADDRESS_REG_184;
    volatile Uint32 VECTOR_ADDRESS_REG_185;
    volatile Uint32 VECTOR_ADDRESS_REG_186;
    volatile Uint32 VECTOR_ADDRESS_REG_187;
    volatile Uint32 VECTOR_ADDRESS_REG_188;
    volatile Uint32 VECTOR_ADDRESS_REG_189;
    volatile Uint32 VECTOR_ADDRESS_REG_190;
    volatile Uint32 VECTOR_ADDRESS_REG_191;
    volatile Uint32 VECTOR_ADDRESS_REG_192;
    volatile Uint32 VECTOR_ADDRESS_REG_193;
    volatile Uint32 VECTOR_ADDRESS_REG_194;
    volatile Uint32 VECTOR_ADDRESS_REG_195;
    volatile Uint32 VECTOR_ADDRESS_REG_196;
    volatile Uint32 VECTOR_ADDRESS_REG_197;
    volatile Uint32 VECTOR_ADDRESS_REG_198;
    volatile Uint32 VECTOR_ADDRESS_REG_199;
    volatile Uint32 VECTOR_ADDRESS_REG_200;
    volatile Uint32 VECTOR_ADDRESS_REG_201;
    volatile Uint32 VECTOR_ADDRESS_REG_202;
    volatile Uint32 VECTOR_ADDRESS_REG_203;
    volatile Uint32 VECTOR_ADDRESS_REG_204;
    volatile Uint32 VECTOR_ADDRESS_REG_205;
    volatile Uint32 VECTOR_ADDRESS_REG_206;
    volatile Uint32 VECTOR_ADDRESS_REG_207;
    volatile Uint32 VECTOR_ADDRESS_REG_208;
    volatile Uint32 VECTOR_ADDRESS_REG_209;
    volatile Uint32 VECTOR_ADDRESS_REG_210;
    volatile Uint32 VECTOR_ADDRESS_REG_211;
    volatile Uint32 VECTOR_ADDRESS_REG_212;
    volatile Uint32 VECTOR_ADDRESS_REG_213;
    volatile Uint32 VECTOR_ADDRESS_REG_214;
    volatile Uint32 VECTOR_ADDRESS_REG_215;
    volatile Uint32 VECTOR_ADDRESS_REG_216;
    volatile Uint32 VECTOR_ADDRESS_REG_217;
    volatile Uint32 VECTOR_ADDRESS_REG_218;
    volatile Uint32 VECTOR_ADDRESS_REG_219;
    volatile Uint32 VECTOR_ADDRESS_REG_220;
    volatile Uint32 VECTOR_ADDRESS_REG_221;
    volatile Uint32 VECTOR_ADDRESS_REG_222;
    volatile Uint32 VECTOR_ADDRESS_REG_223;
    volatile Uint32 VECTOR_ADDRESS_REG_224;
    volatile Uint32 VECTOR_ADDRESS_REG_225;
    volatile Uint32 VECTOR_ADDRESS_REG_226;
    volatile Uint32 VECTOR_ADDRESS_REG_227;
    volatile Uint32 VECTOR_ADDRESS_REG_228;
    volatile Uint32 VECTOR_ADDRESS_REG_229;
    volatile Uint32 VECTOR_ADDRESS_REG_230;
    volatile Uint32 VECTOR_ADDRESS_REG_231;
    volatile Uint32 VECTOR_ADDRESS_REG_232;
    volatile Uint32 VECTOR_ADDRESS_REG_233;
    volatile Uint32 VECTOR_ADDRESS_REG_234;
    volatile Uint32 VECTOR_ADDRESS_REG_235;
    volatile Uint32 VECTOR_ADDRESS_REG_236;
    volatile Uint32 VECTOR_ADDRESS_REG_237;
    volatile Uint32 VECTOR_ADDRESS_REG_238;
    volatile Uint32 VECTOR_ADDRESS_REG_239;
    volatile Uint32 VECTOR_ADDRESS_REG_240;
    volatile Uint32 VECTOR_ADDRESS_REG_241;
    volatile Uint32 VECTOR_ADDRESS_REG_242;
    volatile Uint32 VECTOR_ADDRESS_REG_243;
    volatile Uint32 VECTOR_ADDRESS_REG_244;
    volatile Uint32 VECTOR_ADDRESS_REG_245;
    volatile Uint32 VECTOR_ADDRESS_REG_246;
    volatile Uint32 VECTOR_ADDRESS_REG_247;
    volatile Uint32 VECTOR_ADDRESS_REG_248;
    volatile Uint32 VECTOR_ADDRESS_REG_249;
    volatile Uint32 VECTOR_ADDRESS_REG_250;
    volatile Uint32 VECTOR_ADDRESS_REG_251;
    volatile Uint32 VECTOR_ADDRESS_REG_252;
    volatile Uint32 VECTOR_ADDRESS_REG_253;
    volatile Uint32 VECTOR_ADDRESS_REG_254;
    volatile Uint32 VECTOR_ADDRESS_REG_255;
    volatile Uint32 VECTOR_ADDRESS_REG_256;
    volatile Uint32 VECTOR_ADDRESS_REG_257;
    volatile Uint32 VECTOR_ADDRESS_REG_258;
    volatile Uint32 VECTOR_ADDRESS_REG_259;
    volatile Uint32 VECTOR_ADDRESS_REG_260;
    volatile Uint32 VECTOR_ADDRESS_REG_261;
    volatile Uint32 VECTOR_ADDRESS_REG_262;
    volatile Uint32 VECTOR_ADDRESS_REG_263;
    volatile Uint32 VECTOR_ADDRESS_REG_264;
    volatile Uint32 VECTOR_ADDRESS_REG_265;
    volatile Uint32 VECTOR_ADDRESS_REG_266;
    volatile Uint32 VECTOR_ADDRESS_REG_267;
    volatile Uint32 VECTOR_ADDRESS_REG_268;
    volatile Uint32 VECTOR_ADDRESS_REG_269;
    volatile Uint32 VECTOR_ADDRESS_REG_270;
    volatile Uint32 VECTOR_ADDRESS_REG_271;
    volatile Uint32 VECTOR_ADDRESS_REG_272;
    volatile Uint32 VECTOR_ADDRESS_REG_273;
    volatile Uint32 VECTOR_ADDRESS_REG_274;
    volatile Uint32 VECTOR_ADDRESS_REG_275;
    volatile Uint32 VECTOR_ADDRESS_REG_276;
    volatile Uint32 VECTOR_ADDRESS_REG_277;
    volatile Uint32 VECTOR_ADDRESS_REG_278;
    volatile Uint32 VECTOR_ADDRESS_REG_279;
    volatile Uint32 VECTOR_ADDRESS_REG_280;
    volatile Uint32 VECTOR_ADDRESS_REG_281;
    volatile Uint32 VECTOR_ADDRESS_REG_282;
    volatile Uint32 VECTOR_ADDRESS_REG_283;
    volatile Uint32 VECTOR_ADDRESS_REG_284;
    volatile Uint32 VECTOR_ADDRESS_REG_285;
    volatile Uint32 VECTOR_ADDRESS_REG_286;
    volatile Uint32 VECTOR_ADDRESS_REG_287;
    volatile Uint32 VECTOR_ADDRESS_REG_288;
    volatile Uint32 VECTOR_ADDRESS_REG_289;
    volatile Uint32 VECTOR_ADDRESS_REG_290;
    volatile Uint32 VECTOR_ADDRESS_REG_291;
    volatile Uint32 VECTOR_ADDRESS_REG_292;
    volatile Uint32 VECTOR_ADDRESS_REG_293;
    volatile Uint32 VECTOR_ADDRESS_REG_294;
    volatile Uint32 VECTOR_ADDRESS_REG_295;
    volatile Uint32 VECTOR_ADDRESS_REG_296;
    volatile Uint32 VECTOR_ADDRESS_REG_297;
    volatile Uint32 VECTOR_ADDRESS_REG_298;
    volatile Uint32 VECTOR_ADDRESS_REG_299;
    volatile Uint32 VECTOR_ADDRESS_REG_300;
    volatile Uint32 VECTOR_ADDRESS_REG_301;
    volatile Uint32 VECTOR_ADDRESS_REG_302;
    volatile Uint32 VECTOR_ADDRESS_REG_303;
    volatile Uint32 VECTOR_ADDRESS_REG_304;
    volatile Uint32 VECTOR_ADDRESS_REG_305;
    volatile Uint32 VECTOR_ADDRESS_REG_306;
    volatile Uint32 VECTOR_ADDRESS_REG_307;
    volatile Uint32 VECTOR_ADDRESS_REG_308;
    volatile Uint32 VECTOR_ADDRESS_REG_309;
    volatile Uint32 VECTOR_ADDRESS_REG_310;
    volatile Uint32 VECTOR_ADDRESS_REG_311;
    volatile Uint32 VECTOR_ADDRESS_REG_312;
    volatile Uint32 VECTOR_ADDRESS_REG_313;
    volatile Uint32 VECTOR_ADDRESS_REG_314;
    volatile Uint32 VECTOR_ADDRESS_REG_315;
    volatile Uint32 VECTOR_ADDRESS_REG_316;
    volatile Uint32 VECTOR_ADDRESS_REG_317;
    volatile Uint32 VECTOR_ADDRESS_REG_318;
    volatile Uint32 VECTOR_ADDRESS_REG_319;
    volatile Uint32 VECTOR_ADDRESS_REG_320;
    volatile Uint32 VECTOR_ADDRESS_REG_321;
    volatile Uint32 VECTOR_ADDRESS_REG_322;
    volatile Uint32 VECTOR_ADDRESS_REG_323;
    volatile Uint32 VECTOR_ADDRESS_REG_324;
    volatile Uint32 VECTOR_ADDRESS_REG_325;
    volatile Uint32 VECTOR_ADDRESS_REG_326;
    volatile Uint32 VECTOR_ADDRESS_REG_327;
    volatile Uint32 VECTOR_ADDRESS_REG_328;
    volatile Uint32 VECTOR_ADDRESS_REG_329;
    volatile Uint32 VECTOR_ADDRESS_REG_330;
    volatile Uint32 VECTOR_ADDRESS_REG_331;
    volatile Uint32 VECTOR_ADDRESS_REG_332;
    volatile Uint32 VECTOR_ADDRESS_REG_333;
    volatile Uint32 VECTOR_ADDRESS_REG_334;
    volatile Uint32 VECTOR_ADDRESS_REG_335;
    volatile Uint32 VECTOR_ADDRESS_REG_336;
    volatile Uint32 VECTOR_ADDRESS_REG_337;
    volatile Uint32 VECTOR_ADDRESS_REG_338;
    volatile Uint32 VECTOR_ADDRESS_REG_339;
    volatile Uint32 VECTOR_ADDRESS_REG_340;
    volatile Uint32 VECTOR_ADDRESS_REG_341;
    volatile Uint32 VECTOR_ADDRESS_REG_342;
    volatile Uint32 VECTOR_ADDRESS_REG_343;
    volatile Uint32 VECTOR_ADDRESS_REG_344;
    volatile Uint32 VECTOR_ADDRESS_REG_345;
    volatile Uint32 VECTOR_ADDRESS_REG_346;
    volatile Uint32 VECTOR_ADDRESS_REG_347;
    volatile Uint32 VECTOR_ADDRESS_REG_348;
    volatile Uint32 VECTOR_ADDRESS_REG_349;
    volatile Uint32 VECTOR_ADDRESS_REG_350;
    volatile Uint32 VECTOR_ADDRESS_REG_351;
    volatile Uint32 VECTOR_ADDRESS_REG_352;
    volatile Uint32 VECTOR_ADDRESS_REG_353;
    volatile Uint32 VECTOR_ADDRESS_REG_354;
    volatile Uint32 VECTOR_ADDRESS_REG_355;
    volatile Uint32 VECTOR_ADDRESS_REG_356;
    volatile Uint32 VECTOR_ADDRESS_REG_357;
    volatile Uint32 VECTOR_ADDRESS_REG_358;
    volatile Uint32 VECTOR_ADDRESS_REG_359;
    volatile Uint32 VECTOR_ADDRESS_REG_360;
    volatile Uint32 VECTOR_ADDRESS_REG_361;
    volatile Uint32 VECTOR_ADDRESS_REG_362;
    volatile Uint32 VECTOR_ADDRESS_REG_363;
    volatile Uint32 VECTOR_ADDRESS_REG_364;
    volatile Uint32 VECTOR_ADDRESS_REG_365;
    volatile Uint32 VECTOR_ADDRESS_REG_366;
    volatile Uint32 VECTOR_ADDRESS_REG_367;
    volatile Uint32 VECTOR_ADDRESS_REG_368;
    volatile Uint32 VECTOR_ADDRESS_REG_369;
    volatile Uint32 VECTOR_ADDRESS_REG_370;
    volatile Uint32 VECTOR_ADDRESS_REG_371;
    volatile Uint32 VECTOR_ADDRESS_REG_372;
    volatile Uint32 VECTOR_ADDRESS_REG_373;
    volatile Uint32 VECTOR_ADDRESS_REG_374;
    volatile Uint32 VECTOR_ADDRESS_REG_375;
    volatile Uint32 VECTOR_ADDRESS_REG_376;
    volatile Uint32 VECTOR_ADDRESS_REG_377;
    volatile Uint32 VECTOR_ADDRESS_REG_378;
    volatile Uint32 VECTOR_ADDRESS_REG_379;
    volatile Uint32 VECTOR_ADDRESS_REG_380;
    volatile Uint32 VECTOR_ADDRESS_REG_381;
    volatile Uint32 VECTOR_ADDRESS_REG_382;
    volatile Uint32 VECTOR_ADDRESS_REG_383;
    volatile Uint32 VECTOR_ADDRESS_REG_384;
    volatile Uint32 VECTOR_ADDRESS_REG_385;
    volatile Uint32 VECTOR_ADDRESS_REG_386;
    volatile Uint32 VECTOR_ADDRESS_REG_387;
    volatile Uint32 VECTOR_ADDRESS_REG_388;
    volatile Uint32 VECTOR_ADDRESS_REG_389;
    volatile Uint32 VECTOR_ADDRESS_REG_390;
    volatile Uint32 VECTOR_ADDRESS_REG_391;
    volatile Uint32 VECTOR_ADDRESS_REG_392;
    volatile Uint32 VECTOR_ADDRESS_REG_393;
    volatile Uint32 VECTOR_ADDRESS_REG_394;
    volatile Uint32 VECTOR_ADDRESS_REG_395;
    volatile Uint32 VECTOR_ADDRESS_REG_396;
    volatile Uint32 VECTOR_ADDRESS_REG_397;
    volatile Uint32 VECTOR_ADDRESS_REG_398;
    volatile Uint32 VECTOR_ADDRESS_REG_399;
    volatile Uint32 VECTOR_ADDRESS_REG_400;
    volatile Uint32 VECTOR_ADDRESS_REG_401;
    volatile Uint32 VECTOR_ADDRESS_REG_402;
    volatile Uint32 VECTOR_ADDRESS_REG_403;
    volatile Uint32 VECTOR_ADDRESS_REG_404;
    volatile Uint32 VECTOR_ADDRESS_REG_405;
    volatile Uint32 VECTOR_ADDRESS_REG_406;
    volatile Uint32 VECTOR_ADDRESS_REG_407;
    volatile Uint32 VECTOR_ADDRESS_REG_408;
    volatile Uint32 VECTOR_ADDRESS_REG_409;
    volatile Uint32 VECTOR_ADDRESS_REG_410;
    volatile Uint32 VECTOR_ADDRESS_REG_411;
    volatile Uint32 VECTOR_ADDRESS_REG_412;
    volatile Uint32 VECTOR_ADDRESS_REG_413;
    volatile Uint32 VECTOR_ADDRESS_REG_414;
    volatile Uint32 VECTOR_ADDRESS_REG_415;
    volatile Uint32 VECTOR_ADDRESS_REG_416;
    volatile Uint32 VECTOR_ADDRESS_REG_417;
    volatile Uint32 VECTOR_ADDRESS_REG_418;
    volatile Uint32 VECTOR_ADDRESS_REG_419;
    volatile Uint32 VECTOR_ADDRESS_REG_420;
    volatile Uint32 VECTOR_ADDRESS_REG_421;
    volatile Uint32 VECTOR_ADDRESS_REG_422;
    volatile Uint32 VECTOR_ADDRESS_REG_423;
    volatile Uint32 VECTOR_ADDRESS_REG_424;
    volatile Uint32 VECTOR_ADDRESS_REG_425;
    volatile Uint32 VECTOR_ADDRESS_REG_426;
    volatile Uint32 VECTOR_ADDRESS_REG_427;
    volatile Uint32 VECTOR_ADDRESS_REG_428;
    volatile Uint32 VECTOR_ADDRESS_REG_429;
    volatile Uint32 VECTOR_ADDRESS_REG_430;
    volatile Uint32 VECTOR_ADDRESS_REG_431;
    volatile Uint32 VECTOR_ADDRESS_REG_432;
    volatile Uint32 VECTOR_ADDRESS_REG_433;
    volatile Uint32 VECTOR_ADDRESS_REG_434;
    volatile Uint32 VECTOR_ADDRESS_REG_435;
    volatile Uint32 VECTOR_ADDRESS_REG_436;
    volatile Uint32 VECTOR_ADDRESS_REG_437;
    volatile Uint32 VECTOR_ADDRESS_REG_438;
    volatile Uint32 VECTOR_ADDRESS_REG_439;
    volatile Uint32 VECTOR_ADDRESS_REG_440;
    volatile Uint32 VECTOR_ADDRESS_REG_441;
    volatile Uint32 VECTOR_ADDRESS_REG_442;
    volatile Uint32 VECTOR_ADDRESS_REG_443;
    volatile Uint32 VECTOR_ADDRESS_REG_444;
    volatile Uint32 VECTOR_ADDRESS_REG_445;
    volatile Uint32 VECTOR_ADDRESS_REG_446;
    volatile Uint32 VECTOR_ADDRESS_REG_447;
    volatile Uint32 VECTOR_ADDRESS_REG_448;
    volatile Uint32 VECTOR_ADDRESS_REG_449;
    volatile Uint32 VECTOR_ADDRESS_REG_450;
    volatile Uint32 VECTOR_ADDRESS_REG_451;
    volatile Uint32 VECTOR_ADDRESS_REG_452;
    volatile Uint32 VECTOR_ADDRESS_REG_453;
    volatile Uint32 VECTOR_ADDRESS_REG_454;
    volatile Uint32 VECTOR_ADDRESS_REG_455;
    volatile Uint32 VECTOR_ADDRESS_REG_456;
    volatile Uint32 VECTOR_ADDRESS_REG_457;
    volatile Uint32 VECTOR_ADDRESS_REG_458;
    volatile Uint32 VECTOR_ADDRESS_REG_459;
    volatile Uint32 VECTOR_ADDRESS_REG_460;
    volatile Uint32 VECTOR_ADDRESS_REG_461;
    volatile Uint32 VECTOR_ADDRESS_REG_462;
    volatile Uint32 VECTOR_ADDRESS_REG_463;
    volatile Uint32 VECTOR_ADDRESS_REG_464;
    volatile Uint32 VECTOR_ADDRESS_REG_465;
    volatile Uint32 VECTOR_ADDRESS_REG_466;
    volatile Uint32 VECTOR_ADDRESS_REG_467;
    volatile Uint32 VECTOR_ADDRESS_REG_468;
    volatile Uint32 VECTOR_ADDRESS_REG_469;
    volatile Uint32 VECTOR_ADDRESS_REG_470;
    volatile Uint32 VECTOR_ADDRESS_REG_471;
    volatile Uint32 VECTOR_ADDRESS_REG_472;
    volatile Uint32 VECTOR_ADDRESS_REG_473;
    volatile Uint32 VECTOR_ADDRESS_REG_474;
    volatile Uint32 VECTOR_ADDRESS_REG_475;
    volatile Uint32 VECTOR_ADDRESS_REG_476;
    volatile Uint32 VECTOR_ADDRESS_REG_477;
    volatile Uint32 VECTOR_ADDRESS_REG_478;
    volatile Uint32 VECTOR_ADDRESS_REG_479;
    volatile Uint32 VECTOR_ADDRESS_REG_480;
    volatile Uint32 VECTOR_ADDRESS_REG_481;
    volatile Uint32 VECTOR_ADDRESS_REG_482;
    volatile Uint32 VECTOR_ADDRESS_REG_483;
    volatile Uint32 VECTOR_ADDRESS_REG_484;
    volatile Uint32 VECTOR_ADDRESS_REG_485;
    volatile Uint32 VECTOR_ADDRESS_REG_486;
    volatile Uint32 VECTOR_ADDRESS_REG_487;
    volatile Uint32 VECTOR_ADDRESS_REG_488;
    volatile Uint32 VECTOR_ADDRESS_REG_489;
    volatile Uint32 VECTOR_ADDRESS_REG_490;
    volatile Uint32 VECTOR_ADDRESS_REG_491;
    volatile Uint32 VECTOR_ADDRESS_REG_492;
    volatile Uint32 VECTOR_ADDRESS_REG_493;
    volatile Uint32 VECTOR_ADDRESS_REG_494;
    volatile Uint32 VECTOR_ADDRESS_REG_495;
    volatile Uint32 VECTOR_ADDRESS_REG_496;
    volatile Uint32 VECTOR_ADDRESS_REG_497;
    volatile Uint32 VECTOR_ADDRESS_REG_498;
    volatile Uint32 VECTOR_ADDRESS_REG_499;
    volatile Uint32 VECTOR_ADDRESS_REG_500;
    volatile Uint32 VECTOR_ADDRESS_REG_501;
    volatile Uint32 VECTOR_ADDRESS_REG_502;
    volatile Uint32 VECTOR_ADDRESS_REG_503;
    volatile Uint32 VECTOR_ADDRESS_REG_504;
    volatile Uint32 VECTOR_ADDRESS_REG_505;
    volatile Uint32 VECTOR_ADDRESS_REG_506;
    volatile Uint32 VECTOR_ADDRESS_REG_507;
    volatile Uint32 VECTOR_ADDRESS_REG_508;
    volatile Uint32 VECTOR_ADDRESS_REG_509;
    volatile Uint32 VECTOR_ADDRESS_REG_510;
    volatile Uint32 VECTOR_ADDRESS_REG_511;
    volatile Uint32 VECTOR_ADDRESS_REG_512;
    volatile Uint32 VECTOR_ADDRESS_REG_513;
    volatile Uint32 VECTOR_ADDRESS_REG_514;
    volatile Uint32 VECTOR_ADDRESS_REG_515;
    volatile Uint32 VECTOR_ADDRESS_REG_516;
    volatile Uint32 VECTOR_ADDRESS_REG_517;
    volatile Uint32 VECTOR_ADDRESS_REG_518;
    volatile Uint32 VECTOR_ADDRESS_REG_519;
    volatile Uint32 VECTOR_ADDRESS_REG_520;
    volatile Uint32 VECTOR_ADDRESS_REG_521;
    volatile Uint32 VECTOR_ADDRESS_REG_522;
    volatile Uint32 VECTOR_ADDRESS_REG_523;
    volatile Uint32 VECTOR_ADDRESS_REG_524;
    volatile Uint32 VECTOR_ADDRESS_REG_525;
    volatile Uint32 VECTOR_ADDRESS_REG_526;
    volatile Uint32 VECTOR_ADDRESS_REG_527;
    volatile Uint32 VECTOR_ADDRESS_REG_528;
    volatile Uint32 VECTOR_ADDRESS_REG_529;
    volatile Uint32 VECTOR_ADDRESS_REG_530;
    volatile Uint32 VECTOR_ADDRESS_REG_531;
    volatile Uint32 VECTOR_ADDRESS_REG_532;
    volatile Uint32 VECTOR_ADDRESS_REG_533;
    volatile Uint32 VECTOR_ADDRESS_REG_534;
    volatile Uint32 VECTOR_ADDRESS_REG_535;
    volatile Uint32 VECTOR_ADDRESS_REG_536;
    volatile Uint32 VECTOR_ADDRESS_REG_537;
    volatile Uint32 VECTOR_ADDRESS_REG_538;
    volatile Uint32 VECTOR_ADDRESS_REG_539;
    volatile Uint32 VECTOR_ADDRESS_REG_540;
    volatile Uint32 VECTOR_ADDRESS_REG_541;
    volatile Uint32 VECTOR_ADDRESS_REG_542;
    volatile Uint32 VECTOR_ADDRESS_REG_543;
    volatile Uint32 VECTOR_ADDRESS_REG_544;
    volatile Uint32 VECTOR_ADDRESS_REG_545;
    volatile Uint32 VECTOR_ADDRESS_REG_546;
    volatile Uint32 VECTOR_ADDRESS_REG_547;
    volatile Uint32 VECTOR_ADDRESS_REG_548;
    volatile Uint32 VECTOR_ADDRESS_REG_549;
    volatile Uint32 VECTOR_ADDRESS_REG_550;
    volatile Uint32 VECTOR_ADDRESS_REG_551;
    volatile Uint32 VECTOR_ADDRESS_REG_552;
    volatile Uint32 VECTOR_ADDRESS_REG_553;
    volatile Uint32 VECTOR_ADDRESS_REG_554;
    volatile Uint32 VECTOR_ADDRESS_REG_555;
    volatile Uint32 VECTOR_ADDRESS_REG_556;
    volatile Uint32 VECTOR_ADDRESS_REG_557;
    volatile Uint32 VECTOR_ADDRESS_REG_558;
    volatile Uint32 VECTOR_ADDRESS_REG_559;
    volatile Uint32 VECTOR_ADDRESS_REG_560;
    volatile Uint32 VECTOR_ADDRESS_REG_561;
    volatile Uint32 VECTOR_ADDRESS_REG_562;
    volatile Uint32 VECTOR_ADDRESS_REG_563;
    volatile Uint32 VECTOR_ADDRESS_REG_564;
    volatile Uint32 VECTOR_ADDRESS_REG_565;
    volatile Uint32 VECTOR_ADDRESS_REG_566;
    volatile Uint32 VECTOR_ADDRESS_REG_567;
    volatile Uint32 VECTOR_ADDRESS_REG_568;
    volatile Uint32 VECTOR_ADDRESS_REG_569;
    volatile Uint32 VECTOR_ADDRESS_REG_570;
    volatile Uint32 VECTOR_ADDRESS_REG_571;
    volatile Uint32 VECTOR_ADDRESS_REG_572;
    volatile Uint32 VECTOR_ADDRESS_REG_573;
    volatile Uint32 VECTOR_ADDRESS_REG_574;
    volatile Uint32 VECTOR_ADDRESS_REG_575;
    volatile Uint32 VECTOR_ADDRESS_REG_576;
    volatile Uint32 VECTOR_ADDRESS_REG_577;
    volatile Uint32 VECTOR_ADDRESS_REG_578;
    volatile Uint32 VECTOR_ADDRESS_REG_579;
    volatile Uint32 VECTOR_ADDRESS_REG_580;
    volatile Uint32 VECTOR_ADDRESS_REG_581;
    volatile Uint32 VECTOR_ADDRESS_REG_582;
    volatile Uint32 VECTOR_ADDRESS_REG_583;
    volatile Uint32 VECTOR_ADDRESS_REG_584;
    volatile Uint32 VECTOR_ADDRESS_REG_585;
    volatile Uint32 VECTOR_ADDRESS_REG_586;
    volatile Uint32 VECTOR_ADDRESS_REG_587;
    volatile Uint32 VECTOR_ADDRESS_REG_588;
    volatile Uint32 VECTOR_ADDRESS_REG_589;
    volatile Uint32 VECTOR_ADDRESS_REG_590;
    volatile Uint32 VECTOR_ADDRESS_REG_591;
    volatile Uint32 VECTOR_ADDRESS_REG_592;
    volatile Uint32 VECTOR_ADDRESS_REG_593;
    volatile Uint32 VECTOR_ADDRESS_REG_594;
    volatile Uint32 VECTOR_ADDRESS_REG_595;
    volatile Uint32 VECTOR_ADDRESS_REG_596;
    volatile Uint32 VECTOR_ADDRESS_REG_597;
    volatile Uint32 VECTOR_ADDRESS_REG_598;
    volatile Uint32 VECTOR_ADDRESS_REG_599;
    volatile Uint32 VECTOR_ADDRESS_REG_600;
    volatile Uint32 VECTOR_ADDRESS_REG_601;
    volatile Uint32 VECTOR_ADDRESS_REG_602;
    volatile Uint32 VECTOR_ADDRESS_REG_603;
    volatile Uint32 VECTOR_ADDRESS_REG_604;
    volatile Uint32 VECTOR_ADDRESS_REG_605;
    volatile Uint32 VECTOR_ADDRESS_REG_606;
    volatile Uint32 VECTOR_ADDRESS_REG_607;
    volatile Uint32 VECTOR_ADDRESS_REG_608;
    volatile Uint32 VECTOR_ADDRESS_REG_609;
    volatile Uint32 VECTOR_ADDRESS_REG_610;
    volatile Uint32 VECTOR_ADDRESS_REG_611;
    volatile Uint32 VECTOR_ADDRESS_REG_612;
    volatile Uint32 VECTOR_ADDRESS_REG_613;
    volatile Uint32 VECTOR_ADDRESS_REG_614;
    volatile Uint32 VECTOR_ADDRESS_REG_615;
    volatile Uint32 VECTOR_ADDRESS_REG_616;
    volatile Uint32 VECTOR_ADDRESS_REG_617;
    volatile Uint32 VECTOR_ADDRESS_REG_618;
    volatile Uint32 VECTOR_ADDRESS_REG_619;
    volatile Uint32 VECTOR_ADDRESS_REG_620;
    volatile Uint32 VECTOR_ADDRESS_REG_621;
    volatile Uint32 VECTOR_ADDRESS_REG_622;
    volatile Uint32 VECTOR_ADDRESS_REG_623;
    volatile Uint32 VECTOR_ADDRESS_REG_624;
    volatile Uint32 VECTOR_ADDRESS_REG_625;
    volatile Uint32 VECTOR_ADDRESS_REG_626;
    volatile Uint32 VECTOR_ADDRESS_REG_627;
    volatile Uint32 VECTOR_ADDRESS_REG_628;
    volatile Uint32 VECTOR_ADDRESS_REG_629;
    volatile Uint32 VECTOR_ADDRESS_REG_630;
    volatile Uint32 VECTOR_ADDRESS_REG_631;
    volatile Uint32 VECTOR_ADDRESS_REG_632;
    volatile Uint32 VECTOR_ADDRESS_REG_633;
    volatile Uint32 VECTOR_ADDRESS_REG_634;
    volatile Uint32 VECTOR_ADDRESS_REG_635;
    volatile Uint32 VECTOR_ADDRESS_REG_636;
    volatile Uint32 VECTOR_ADDRESS_REG_637;
    volatile Uint32 VECTOR_ADDRESS_REG_638;
    volatile Uint32 VECTOR_ADDRESS_REG_639;
    volatile Uint32 VECTOR_ADDRESS_REG_640;
    volatile Uint32 VECTOR_ADDRESS_REG_641;
    volatile Uint32 VECTOR_ADDRESS_REG_642;
    volatile Uint32 VECTOR_ADDRESS_REG_643;
    volatile Uint32 VECTOR_ADDRESS_REG_644;
    volatile Uint32 VECTOR_ADDRESS_REG_645;
    volatile Uint32 VECTOR_ADDRESS_REG_646;
    volatile Uint32 VECTOR_ADDRESS_REG_647;
    volatile Uint32 VECTOR_ADDRESS_REG_648;
    volatile Uint32 VECTOR_ADDRESS_REG_649;
    volatile Uint32 VECTOR_ADDRESS_REG_650;
    volatile Uint32 VECTOR_ADDRESS_REG_651;
    volatile Uint32 VECTOR_ADDRESS_REG_652;
    volatile Uint32 VECTOR_ADDRESS_REG_653;
    volatile Uint32 VECTOR_ADDRESS_REG_654;
    volatile Uint32 VECTOR_ADDRESS_REG_655;
    volatile Uint32 VECTOR_ADDRESS_REG_656;
    volatile Uint32 VECTOR_ADDRESS_REG_657;
    volatile Uint32 VECTOR_ADDRESS_REG_658;
    volatile Uint32 VECTOR_ADDRESS_REG_659;
    volatile Uint32 VECTOR_ADDRESS_REG_660;
    volatile Uint32 VECTOR_ADDRESS_REG_661;
    volatile Uint32 VECTOR_ADDRESS_REG_662;
    volatile Uint32 VECTOR_ADDRESS_REG_663;
    volatile Uint32 VECTOR_ADDRESS_REG_664;
    volatile Uint32 VECTOR_ADDRESS_REG_665;
    volatile Uint32 VECTOR_ADDRESS_REG_666;
    volatile Uint32 VECTOR_ADDRESS_REG_667;
    volatile Uint32 VECTOR_ADDRESS_REG_668;
    volatile Uint32 VECTOR_ADDRESS_REG_669;
    volatile Uint32 VECTOR_ADDRESS_REG_670;
    volatile Uint32 VECTOR_ADDRESS_REG_671;
    volatile Uint32 VECTOR_ADDRESS_REG_672;
    volatile Uint32 VECTOR_ADDRESS_REG_673;
    volatile Uint32 VECTOR_ADDRESS_REG_674;
    volatile Uint32 VECTOR_ADDRESS_REG_675;
    volatile Uint32 VECTOR_ADDRESS_REG_676;
    volatile Uint32 VECTOR_ADDRESS_REG_677;
    volatile Uint32 VECTOR_ADDRESS_REG_678;
    volatile Uint32 VECTOR_ADDRESS_REG_679;
    volatile Uint32 VECTOR_ADDRESS_REG_680;
    volatile Uint32 VECTOR_ADDRESS_REG_681;
    volatile Uint32 VECTOR_ADDRESS_REG_682;
    volatile Uint32 VECTOR_ADDRESS_REG_683;
    volatile Uint32 VECTOR_ADDRESS_REG_684;
    volatile Uint32 VECTOR_ADDRESS_REG_685;
    volatile Uint32 VECTOR_ADDRESS_REG_686;
    volatile Uint32 VECTOR_ADDRESS_REG_687;
    volatile Uint32 VECTOR_ADDRESS_REG_688;
    volatile Uint32 VECTOR_ADDRESS_REG_689;
    volatile Uint32 VECTOR_ADDRESS_REG_690;
    volatile Uint32 VECTOR_ADDRESS_REG_691;
    volatile Uint32 VECTOR_ADDRESS_REG_692;
    volatile Uint32 VECTOR_ADDRESS_REG_693;
    volatile Uint32 VECTOR_ADDRESS_REG_694;
    volatile Uint32 VECTOR_ADDRESS_REG_695;
    volatile Uint32 VECTOR_ADDRESS_REG_696;
    volatile Uint32 VECTOR_ADDRESS_REG_697;
    volatile Uint32 VECTOR_ADDRESS_REG_698;
    volatile Uint32 VECTOR_ADDRESS_REG_699;
    volatile Uint32 VECTOR_ADDRESS_REG_700;
    volatile Uint32 VECTOR_ADDRESS_REG_701;
    volatile Uint32 VECTOR_ADDRESS_REG_702;
    volatile Uint32 VECTOR_ADDRESS_REG_703;
    volatile Uint32 VECTOR_ADDRESS_REG_704;
    volatile Uint32 VECTOR_ADDRESS_REG_705;
    volatile Uint32 VECTOR_ADDRESS_REG_706;
    volatile Uint32 VECTOR_ADDRESS_REG_707;
    volatile Uint32 VECTOR_ADDRESS_REG_708;
    volatile Uint32 VECTOR_ADDRESS_REG_709;
    volatile Uint32 VECTOR_ADDRESS_REG_710;
    volatile Uint32 VECTOR_ADDRESS_REG_711;
    volatile Uint32 VECTOR_ADDRESS_REG_712;
    volatile Uint32 VECTOR_ADDRESS_REG_713;
    volatile Uint32 VECTOR_ADDRESS_REG_714;
    volatile Uint32 VECTOR_ADDRESS_REG_715;
    volatile Uint32 VECTOR_ADDRESS_REG_716;
    volatile Uint32 VECTOR_ADDRESS_REG_717;
    volatile Uint32 VECTOR_ADDRESS_REG_718;
    volatile Uint32 VECTOR_ADDRESS_REG_719;
    volatile Uint32 VECTOR_ADDRESS_REG_720;
    volatile Uint32 VECTOR_ADDRESS_REG_721;
    volatile Uint32 VECTOR_ADDRESS_REG_722;
    volatile Uint32 VECTOR_ADDRESS_REG_723;
    volatile Uint32 VECTOR_ADDRESS_REG_724;
    volatile Uint32 VECTOR_ADDRESS_REG_725;
    volatile Uint32 VECTOR_ADDRESS_REG_726;
    volatile Uint32 VECTOR_ADDRESS_REG_727;
    volatile Uint32 VECTOR_ADDRESS_REG_728;
    volatile Uint32 VECTOR_ADDRESS_REG_729;
    volatile Uint32 VECTOR_ADDRESS_REG_730;
    volatile Uint32 VECTOR_ADDRESS_REG_731;
    volatile Uint32 VECTOR_ADDRESS_REG_732;
    volatile Uint32 VECTOR_ADDRESS_REG_733;
    volatile Uint32 VECTOR_ADDRESS_REG_734;
    volatile Uint32 VECTOR_ADDRESS_REG_735;
    volatile Uint32 VECTOR_ADDRESS_REG_736;
    volatile Uint32 VECTOR_ADDRESS_REG_737;
    volatile Uint32 VECTOR_ADDRESS_REG_738;
    volatile Uint32 VECTOR_ADDRESS_REG_739;
    volatile Uint32 VECTOR_ADDRESS_REG_740;
    volatile Uint32 VECTOR_ADDRESS_REG_741;
    volatile Uint32 VECTOR_ADDRESS_REG_742;
    volatile Uint32 VECTOR_ADDRESS_REG_743;
    volatile Uint32 VECTOR_ADDRESS_REG_744;
    volatile Uint32 VECTOR_ADDRESS_REG_745;
    volatile Uint32 VECTOR_ADDRESS_REG_746;
    volatile Uint32 VECTOR_ADDRESS_REG_747;
    volatile Uint32 VECTOR_ADDRESS_REG_748;
    volatile Uint32 VECTOR_ADDRESS_REG_749;
    volatile Uint32 VECTOR_ADDRESS_REG_750;
    volatile Uint32 VECTOR_ADDRESS_REG_751;
    volatile Uint32 VECTOR_ADDRESS_REG_752;
    volatile Uint32 VECTOR_ADDRESS_REG_753;
    volatile Uint32 VECTOR_ADDRESS_REG_754;
    volatile Uint32 VECTOR_ADDRESS_REG_755;
    volatile Uint32 VECTOR_ADDRESS_REG_756;
    volatile Uint32 VECTOR_ADDRESS_REG_757;
    volatile Uint32 VECTOR_ADDRESS_REG_758;
    volatile Uint32 VECTOR_ADDRESS_REG_759;
    volatile Uint32 VECTOR_ADDRESS_REG_760;
    volatile Uint32 VECTOR_ADDRESS_REG_761;
    volatile Uint32 VECTOR_ADDRESS_REG_762;
    volatile Uint32 VECTOR_ADDRESS_REG_763;
    volatile Uint32 VECTOR_ADDRESS_REG_764;
    volatile Uint32 VECTOR_ADDRESS_REG_765;
    volatile Uint32 VECTOR_ADDRESS_REG_766;
    volatile Uint32 VECTOR_ADDRESS_REG_767;
    volatile Uint32 VECTOR_ADDRESS_REG_768;
    volatile Uint32 VECTOR_ADDRESS_REG_769;
    volatile Uint32 VECTOR_ADDRESS_REG_770;
    volatile Uint32 VECTOR_ADDRESS_REG_771;
    volatile Uint32 VECTOR_ADDRESS_REG_772;
    volatile Uint32 VECTOR_ADDRESS_REG_773;
    volatile Uint32 VECTOR_ADDRESS_REG_774;
    volatile Uint32 VECTOR_ADDRESS_REG_775;
    volatile Uint32 VECTOR_ADDRESS_REG_776;
    volatile Uint32 VECTOR_ADDRESS_REG_777;
    volatile Uint32 VECTOR_ADDRESS_REG_778;
    volatile Uint32 VECTOR_ADDRESS_REG_779;
    volatile Uint32 VECTOR_ADDRESS_REG_780;
    volatile Uint32 VECTOR_ADDRESS_REG_781;
    volatile Uint32 VECTOR_ADDRESS_REG_782;
    volatile Uint32 VECTOR_ADDRESS_REG_783;
    volatile Uint32 VECTOR_ADDRESS_REG_784;
    volatile Uint32 VECTOR_ADDRESS_REG_785;
    volatile Uint32 VECTOR_ADDRESS_REG_786;
    volatile Uint32 VECTOR_ADDRESS_REG_787;
    volatile Uint32 VECTOR_ADDRESS_REG_788;
    volatile Uint32 VECTOR_ADDRESS_REG_789;
    volatile Uint32 VECTOR_ADDRESS_REG_790;
    volatile Uint32 VECTOR_ADDRESS_REG_791;
    volatile Uint32 VECTOR_ADDRESS_REG_792;
    volatile Uint32 VECTOR_ADDRESS_REG_793;
    volatile Uint32 VECTOR_ADDRESS_REG_794;
    volatile Uint32 VECTOR_ADDRESS_REG_795;
    volatile Uint32 VECTOR_ADDRESS_REG_796;
    volatile Uint32 VECTOR_ADDRESS_REG_797;
    volatile Uint32 VECTOR_ADDRESS_REG_798;
    volatile Uint32 VECTOR_ADDRESS_REG_799;
    volatile Uint32 VECTOR_ADDRESS_REG_800;
    volatile Uint32 VECTOR_ADDRESS_REG_801;
    volatile Uint32 VECTOR_ADDRESS_REG_802;
    volatile Uint32 VECTOR_ADDRESS_REG_803;
    volatile Uint32 VECTOR_ADDRESS_REG_804;
    volatile Uint32 VECTOR_ADDRESS_REG_805;
    volatile Uint32 VECTOR_ADDRESS_REG_806;
    volatile Uint32 VECTOR_ADDRESS_REG_807;
    volatile Uint32 VECTOR_ADDRESS_REG_808;
    volatile Uint32 VECTOR_ADDRESS_REG_809;
    volatile Uint32 VECTOR_ADDRESS_REG_810;
    volatile Uint32 VECTOR_ADDRESS_REG_811;
    volatile Uint32 VECTOR_ADDRESS_REG_812;
    volatile Uint32 VECTOR_ADDRESS_REG_813;
    volatile Uint32 VECTOR_ADDRESS_REG_814;
    volatile Uint32 VECTOR_ADDRESS_REG_815;
    volatile Uint32 VECTOR_ADDRESS_REG_816;
    volatile Uint32 VECTOR_ADDRESS_REG_817;
    volatile Uint32 VECTOR_ADDRESS_REG_818;
    volatile Uint32 VECTOR_ADDRESS_REG_819;
    volatile Uint32 VECTOR_ADDRESS_REG_820;
    volatile Uint32 VECTOR_ADDRESS_REG_821;
    volatile Uint32 VECTOR_ADDRESS_REG_822;
    volatile Uint32 VECTOR_ADDRESS_REG_823;
    volatile Uint32 VECTOR_ADDRESS_REG_824;
    volatile Uint32 VECTOR_ADDRESS_REG_825;
    volatile Uint32 VECTOR_ADDRESS_REG_826;
    volatile Uint32 VECTOR_ADDRESS_REG_827;
    volatile Uint32 VECTOR_ADDRESS_REG_828;
    volatile Uint32 VECTOR_ADDRESS_REG_829;
    volatile Uint32 VECTOR_ADDRESS_REG_830;
    volatile Uint32 VECTOR_ADDRESS_REG_831;
    volatile Uint32 VECTOR_ADDRESS_REG_832;
    volatile Uint32 VECTOR_ADDRESS_REG_833;
    volatile Uint32 VECTOR_ADDRESS_REG_834;
    volatile Uint32 VECTOR_ADDRESS_REG_835;
    volatile Uint32 VECTOR_ADDRESS_REG_836;
    volatile Uint32 VECTOR_ADDRESS_REG_837;
    volatile Uint32 VECTOR_ADDRESS_REG_838;
    volatile Uint32 VECTOR_ADDRESS_REG_839;
    volatile Uint32 VECTOR_ADDRESS_REG_840;
    volatile Uint32 VECTOR_ADDRESS_REG_841;
    volatile Uint32 VECTOR_ADDRESS_REG_842;
    volatile Uint32 VECTOR_ADDRESS_REG_843;
    volatile Uint32 VECTOR_ADDRESS_REG_844;
    volatile Uint32 VECTOR_ADDRESS_REG_845;
    volatile Uint32 VECTOR_ADDRESS_REG_846;
    volatile Uint32 VECTOR_ADDRESS_REG_847;
    volatile Uint32 VECTOR_ADDRESS_REG_848;
    volatile Uint32 VECTOR_ADDRESS_REG_849;
    volatile Uint32 VECTOR_ADDRESS_REG_850;
    volatile Uint32 VECTOR_ADDRESS_REG_851;
    volatile Uint32 VECTOR_ADDRESS_REG_852;
    volatile Uint32 VECTOR_ADDRESS_REG_853;
    volatile Uint32 VECTOR_ADDRESS_REG_854;
    volatile Uint32 VECTOR_ADDRESS_REG_855;
    volatile Uint32 VECTOR_ADDRESS_REG_856;
    volatile Uint32 VECTOR_ADDRESS_REG_857;
    volatile Uint32 VECTOR_ADDRESS_REG_858;
    volatile Uint32 VECTOR_ADDRESS_REG_859;
    volatile Uint32 VECTOR_ADDRESS_REG_860;
    volatile Uint32 VECTOR_ADDRESS_REG_861;
    volatile Uint32 VECTOR_ADDRESS_REG_862;
    volatile Uint32 VECTOR_ADDRESS_REG_863;
    volatile Uint32 VECTOR_ADDRESS_REG_864;
    volatile Uint32 VECTOR_ADDRESS_REG_865;
    volatile Uint32 VECTOR_ADDRESS_REG_866;
    volatile Uint32 VECTOR_ADDRESS_REG_867;
    volatile Uint32 VECTOR_ADDRESS_REG_868;
    volatile Uint32 VECTOR_ADDRESS_REG_869;
    volatile Uint32 VECTOR_ADDRESS_REG_870;
    volatile Uint32 VECTOR_ADDRESS_REG_871;
    volatile Uint32 VECTOR_ADDRESS_REG_872;
    volatile Uint32 VECTOR_ADDRESS_REG_873;
    volatile Uint32 VECTOR_ADDRESS_REG_874;
    volatile Uint32 VECTOR_ADDRESS_REG_875;
    volatile Uint32 VECTOR_ADDRESS_REG_876;
    volatile Uint32 VECTOR_ADDRESS_REG_877;
    volatile Uint32 VECTOR_ADDRESS_REG_878;
    volatile Uint32 VECTOR_ADDRESS_REG_879;
    volatile Uint32 VECTOR_ADDRESS_REG_880;
    volatile Uint32 VECTOR_ADDRESS_REG_881;
    volatile Uint32 VECTOR_ADDRESS_REG_882;
    volatile Uint32 VECTOR_ADDRESS_REG_883;
    volatile Uint32 VECTOR_ADDRESS_REG_884;
    volatile Uint32 VECTOR_ADDRESS_REG_885;
    volatile Uint32 VECTOR_ADDRESS_REG_886;
    volatile Uint32 VECTOR_ADDRESS_REG_887;
    volatile Uint32 VECTOR_ADDRESS_REG_888;
    volatile Uint32 VECTOR_ADDRESS_REG_889;
    volatile Uint32 VECTOR_ADDRESS_REG_890;
    volatile Uint32 VECTOR_ADDRESS_REG_891;
    volatile Uint32 VECTOR_ADDRESS_REG_892;
    volatile Uint32 VECTOR_ADDRESS_REG_893;
    volatile Uint32 VECTOR_ADDRESS_REG_894;
    volatile Uint32 VECTOR_ADDRESS_REG_895;
    volatile Uint32 VECTOR_ADDRESS_REG_896;
    volatile Uint32 VECTOR_ADDRESS_REG_897;
    volatile Uint32 VECTOR_ADDRESS_REG_898;
    volatile Uint32 VECTOR_ADDRESS_REG_899;
    volatile Uint32 VECTOR_ADDRESS_REG_900;
    volatile Uint32 VECTOR_ADDRESS_REG_901;
    volatile Uint32 VECTOR_ADDRESS_REG_902;
    volatile Uint32 VECTOR_ADDRESS_REG_903;
    volatile Uint32 VECTOR_ADDRESS_REG_904;
    volatile Uint32 VECTOR_ADDRESS_REG_905;
    volatile Uint32 VECTOR_ADDRESS_REG_906;
    volatile Uint32 VECTOR_ADDRESS_REG_907;
    volatile Uint32 VECTOR_ADDRESS_REG_908;
    volatile Uint32 VECTOR_ADDRESS_REG_909;
    volatile Uint32 VECTOR_ADDRESS_REG_910;
    volatile Uint32 VECTOR_ADDRESS_REG_911;
    volatile Uint32 VECTOR_ADDRESS_REG_912;
    volatile Uint32 VECTOR_ADDRESS_REG_913;
    volatile Uint32 VECTOR_ADDRESS_REG_914;
    volatile Uint32 VECTOR_ADDRESS_REG_915;
    volatile Uint32 VECTOR_ADDRESS_REG_916;
    volatile Uint32 VECTOR_ADDRESS_REG_917;
    volatile Uint32 VECTOR_ADDRESS_REG_918;
    volatile Uint32 VECTOR_ADDRESS_REG_919;
    volatile Uint32 VECTOR_ADDRESS_REG_920;
    volatile Uint32 VECTOR_ADDRESS_REG_921;
    volatile Uint32 VECTOR_ADDRESS_REG_922;
    volatile Uint32 VECTOR_ADDRESS_REG_923;
    volatile Uint32 VECTOR_ADDRESS_REG_924;
    volatile Uint32 VECTOR_ADDRESS_REG_925;
    volatile Uint32 VECTOR_ADDRESS_REG_926;
    volatile Uint32 VECTOR_ADDRESS_REG_927;
    volatile Uint32 VECTOR_ADDRESS_REG_928;
    volatile Uint32 VECTOR_ADDRESS_REG_929;
    volatile Uint32 VECTOR_ADDRESS_REG_930;
    volatile Uint32 VECTOR_ADDRESS_REG_931;
    volatile Uint32 VECTOR_ADDRESS_REG_932;
    volatile Uint32 VECTOR_ADDRESS_REG_933;
    volatile Uint32 VECTOR_ADDRESS_REG_934;
    volatile Uint32 VECTOR_ADDRESS_REG_935;
    volatile Uint32 VECTOR_ADDRESS_REG_936;
    volatile Uint32 VECTOR_ADDRESS_REG_937;
    volatile Uint32 VECTOR_ADDRESS_REG_938;
    volatile Uint32 VECTOR_ADDRESS_REG_939;
    volatile Uint32 VECTOR_ADDRESS_REG_940;
    volatile Uint32 VECTOR_ADDRESS_REG_941;
    volatile Uint32 VECTOR_ADDRESS_REG_942;
    volatile Uint32 VECTOR_ADDRESS_REG_943;
    volatile Uint32 VECTOR_ADDRESS_REG_944;
    volatile Uint32 VECTOR_ADDRESS_REG_945;
    volatile Uint32 VECTOR_ADDRESS_REG_946;
    volatile Uint32 VECTOR_ADDRESS_REG_947;
    volatile Uint32 VECTOR_ADDRESS_REG_948;
    volatile Uint32 VECTOR_ADDRESS_REG_949;
    volatile Uint32 VECTOR_ADDRESS_REG_950;
    volatile Uint32 VECTOR_ADDRESS_REG_951;
    volatile Uint32 VECTOR_ADDRESS_REG_952;
    volatile Uint32 VECTOR_ADDRESS_REG_953;
    volatile Uint32 VECTOR_ADDRESS_REG_954;
    volatile Uint32 VECTOR_ADDRESS_REG_955;
    volatile Uint32 VECTOR_ADDRESS_REG_956;
    volatile Uint32 VECTOR_ADDRESS_REG_957;
    volatile Uint32 VECTOR_ADDRESS_REG_958;
    volatile Uint32 VECTOR_ADDRESS_REG_959;
    volatile Uint32 VECTOR_ADDRESS_REG_960;
    volatile Uint32 VECTOR_ADDRESS_REG_961;
    volatile Uint32 VECTOR_ADDRESS_REG_962;
    volatile Uint32 VECTOR_ADDRESS_REG_963;
    volatile Uint32 VECTOR_ADDRESS_REG_964;
    volatile Uint32 VECTOR_ADDRESS_REG_965;
    volatile Uint32 VECTOR_ADDRESS_REG_966;
    volatile Uint32 VECTOR_ADDRESS_REG_967;
    volatile Uint32 VECTOR_ADDRESS_REG_968;
    volatile Uint32 VECTOR_ADDRESS_REG_969;
    volatile Uint32 VECTOR_ADDRESS_REG_970;
    volatile Uint32 VECTOR_ADDRESS_REG_971;
    volatile Uint32 VECTOR_ADDRESS_REG_972;
    volatile Uint32 VECTOR_ADDRESS_REG_973;
    volatile Uint32 VECTOR_ADDRESS_REG_974;
    volatile Uint32 VECTOR_ADDRESS_REG_975;
    volatile Uint32 VECTOR_ADDRESS_REG_976;
    volatile Uint32 VECTOR_ADDRESS_REG_977;
    volatile Uint32 VECTOR_ADDRESS_REG_978;
    volatile Uint32 VECTOR_ADDRESS_REG_979;
    volatile Uint32 VECTOR_ADDRESS_REG_980;
    volatile Uint32 VECTOR_ADDRESS_REG_981;
    volatile Uint32 VECTOR_ADDRESS_REG_982;
    volatile Uint32 VECTOR_ADDRESS_REG_983;
    volatile Uint32 VECTOR_ADDRESS_REG_984;
    volatile Uint32 VECTOR_ADDRESS_REG_985;
    volatile Uint32 VECTOR_ADDRESS_REG_986;
    volatile Uint32 VECTOR_ADDRESS_REG_987;
    volatile Uint32 VECTOR_ADDRESS_REG_988;
    volatile Uint32 VECTOR_ADDRESS_REG_989;
    volatile Uint32 VECTOR_ADDRESS_REG_990;
    volatile Uint32 VECTOR_ADDRESS_REG_991;
    volatile Uint32 VECTOR_ADDRESS_REG_992;
    volatile Uint32 VECTOR_ADDRESS_REG_993;
    volatile Uint32 VECTOR_ADDRESS_REG_994;
    volatile Uint32 VECTOR_ADDRESS_REG_995;
    volatile Uint32 VECTOR_ADDRESS_REG_996;
    volatile Uint32 VECTOR_ADDRESS_REG_997;
    volatile Uint32 VECTOR_ADDRESS_REG_998;
    volatile Uint32 VECTOR_ADDRESS_REG_999;
    volatile Uint32 VECTOR_ADDRESS_REG_1000;
    volatile Uint32 VECTOR_ADDRESS_REG_1001;
    volatile Uint32 VECTOR_ADDRESS_REG_1002;
    volatile Uint32 VECTOR_ADDRESS_REG_1003;
    volatile Uint32 VECTOR_ADDRESS_REG_1004;
    volatile Uint32 VECTOR_ADDRESS_REG_1005;
    volatile Uint32 VECTOR_ADDRESS_REG_1006;
    volatile Uint32 VECTOR_ADDRESS_REG_1007;
    volatile Uint32 VECTOR_ADDRESS_REG_1008;
    volatile Uint32 VECTOR_ADDRESS_REG_1009;
    volatile Uint32 VECTOR_ADDRESS_REG_1010;
    volatile Uint32 VECTOR_ADDRESS_REG_1011;
    volatile Uint32 VECTOR_ADDRESS_REG_1012;
    volatile Uint32 VECTOR_ADDRESS_REG_1013;
    volatile Uint32 VECTOR_ADDRESS_REG_1014;
    volatile Uint32 VECTOR_ADDRESS_REG_1015;
    volatile Uint32 VECTOR_ADDRESS_REG_1016;
    volatile Uint32 VECTOR_ADDRESS_REG_1017;
    volatile Uint32 VECTOR_ADDRESS_REG_1018;
    volatile Uint32 VECTOR_ADDRESS_REG_1019;
    volatile Uint32 VECTOR_ADDRESS_REG_1020;
    volatile Uint32 VECTOR_ADDRESS_REG_1021;
    volatile Uint32 VECTOR_ADDRESS_REG_1022;
    volatile Uint32 VECTOR_ADDRESS_REG_1023;
#else
    volatile Uint32 VECTOR_ADDRESS_REG[1024];
#endif
} CSL_CPINTCRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* revision_reg */

#define CSL_CPINTC_REVISION_REG_REV_SCHEME_MASK (0xC0000000u)
#define CSL_CPINTC_REVISION_REG_REV_SCHEME_SHIFT (0x0000001Eu)
#define CSL_CPINTC_REVISION_REG_REV_SCHEME_RESETVAL (0x00000001u)

#define CSL_CPINTC_REVISION_REG_REV_MODULE_MASK (0x0FFF0000u)
#define CSL_CPINTC_REVISION_REG_REV_MODULE_SHIFT (0x00000010u)
#define CSL_CPINTC_REVISION_REG_REV_MODULE_RESETVAL (0x00000E82u)

#define CSL_CPINTC_REVISION_REG_REV_RTL_MASK (0x0000F800u)
#define CSL_CPINTC_REVISION_REG_REV_RTL_SHIFT (0x0000000Bu)
#define CSL_CPINTC_REVISION_REG_REV_RTL_RESETVAL (0x00000015u)

#define CSL_CPINTC_REVISION_REG_REV_MAJOR_MASK (0x00000700u)
#define CSL_CPINTC_REVISION_REG_REV_MAJOR_SHIFT (0x00000008u)
#define CSL_CPINTC_REVISION_REG_REV_MAJOR_RESETVAL (0x00000001u)

#define CSL_CPINTC_REVISION_REG_REV_CUSTOM_MASK (0x000000C0u)
#define CSL_CPINTC_REVISION_REG_REV_CUSTOM_SHIFT (0x00000006u)
#define CSL_CPINTC_REVISION_REG_REV_CUSTOM_RESETVAL (0x00000000u)

#define CSL_CPINTC_REVISION_REG_REV_MINOR_MASK (0x0000003Fu)
#define CSL_CPINTC_REVISION_REG_REV_MINOR_SHIFT (0x00000000u)
#define CSL_CPINTC_REVISION_REG_REV_MINOR_RESETVAL (0x00000000u)

#define CSL_CPINTC_REVISION_REG_RESETVAL (0x4E82A900u)

/* control_reg */

#define CSL_CPINTC_CONTROL_REG_WAKEUP_MODE_MASK (0x00000002u)
#define CSL_CPINTC_CONTROL_REG_WAKEUP_MODE_SHIFT (0x00000001u)
#define CSL_CPINTC_CONTROL_REG_WAKEUP_MODE_RESETVAL (0x00000000u)

#define CSL_CPINTC_CONTROL_REG_NEST_MODE_MASK (0x0000000Cu)
#define CSL_CPINTC_CONTROL_REG_NEST_MODE_SHIFT (0x00000002u)
#define CSL_CPINTC_CONTROL_REG_NEST_MODE_RESETVAL (0x00000000u)

#define CSL_CPINTC_CONTROL_REG_PRIORITY_HOLD_MODE_MASK (0x00000010u)
#define CSL_CPINTC_CONTROL_REG_PRIORITY_HOLD_MODE_SHIFT (0x00000004u)
#define CSL_CPINTC_CONTROL_REG_PRIORITY_HOLD_MODE_RESETVAL (0x00000000u)

#define CSL_CPINTC_CONTROL_REG_RESETVAL  (0x00000000u)

/* host_control_reg */

#define CSL_CPINTC_HOST_CONTROL_REG_HOST_CONTROL_REG_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_HOST_CONTROL_REG_HOST_CONTROL_REG_SHIFT (0x00000000u)
#define CSL_CPINTC_HOST_CONTROL_REG_HOST_CONTROL_REG_RESETVAL (0x00000000u)

#define CSL_CPINTC_HOST_CONTROL_REG_RESETVAL (0x00000000u)

/* global_enable_hint_reg */

#define CSL_CPINTC_GLOBAL_ENABLE_HINT_REG_ENABLE_HINT_ANY_MASK (0x00000001u)
#define CSL_CPINTC_GLOBAL_ENABLE_HINT_REG_ENABLE_HINT_ANY_SHIFT (0x00000000u)
#define CSL_CPINTC_GLOBAL_ENABLE_HINT_REG_ENABLE_HINT_ANY_RESETVAL (0x00000000u)

#define CSL_CPINTC_GLOBAL_ENABLE_HINT_REG_RESETVAL (0x00000000u)

/* glb_nest_level_reg */

#define CSL_CPINTC_GLB_NEST_LEVEL_REG_GLB_NEST_LEVEL_MASK (0x000001FFu)
#define CSL_CPINTC_GLB_NEST_LEVEL_REG_GLB_NEST_LEVEL_SHIFT (0x00000000u)
#define CSL_CPINTC_GLB_NEST_LEVEL_REG_GLB_NEST_LEVEL_RESETVAL (0x00000100u)

#define CSL_CPINTC_GLB_NEST_LEVEL_REG_RESETVAL (0x00000100u)

/* status_set_index_reg */

#define CSL_CPINTC_STATUS_SET_INDEX_REG_STATUS_SET_INDEX_MASK (0x000003FFu)
#define CSL_CPINTC_STATUS_SET_INDEX_REG_STATUS_SET_INDEX_SHIFT (0x00000000u)
#define CSL_CPINTC_STATUS_SET_INDEX_REG_STATUS_SET_INDEX_RESETVAL (0x00000000u)

#define CSL_CPINTC_STATUS_SET_INDEX_REG_RESETVAL (0x00000000u)

/* status_clr_index_reg */

#define CSL_CPINTC_STATUS_CLR_INDEX_REG_STATUS_CLR_INDEX_MASK (0x000003FFu)
#define CSL_CPINTC_STATUS_CLR_INDEX_REG_STATUS_CLR_INDEX_SHIFT (0x00000000u)
#define CSL_CPINTC_STATUS_CLR_INDEX_REG_STATUS_CLR_INDEX_RESETVAL (0x00000000u)

#define CSL_CPINTC_STATUS_CLR_INDEX_REG_RESETVAL (0x00000000u)

/* enable_set_index_reg */

#define CSL_CPINTC_ENABLE_SET_INDEX_REG_ENABLE_SET_INDEX_MASK (0x000003FFu)
#define CSL_CPINTC_ENABLE_SET_INDEX_REG_ENABLE_SET_INDEX_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_SET_INDEX_REG_ENABLE_SET_INDEX_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_SET_INDEX_REG_RESETVAL (0x00000000u)

/* enable_clr_index_reg */

#define CSL_CPINTC_ENABLE_CLR_INDEX_REG_ENABLE_CLR_INDEX_MASK (0x000003FFu)
#define CSL_CPINTC_ENABLE_CLR_INDEX_REG_ENABLE_CLR_INDEX_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_INDEX_REG_ENABLE_CLR_INDEX_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_INDEX_REG_RESETVAL (0x00000000u)

/* hint_enable_set_index_reg */

#define CSL_CPINTC_HINT_ENABLE_SET_INDEX_REG_HINT_ENABLE_SET_INDEX_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_ENABLE_SET_INDEX_REG_HINT_ENABLE_SET_INDEX_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_ENABLE_SET_INDEX_REG_HINT_ENABLE_SET_INDEX_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_ENABLE_SET_INDEX_REG_RESETVAL (0x00000000u)

/* hint_enable_clr_index_reg */

#define CSL_CPINTC_HINT_ENABLE_CLR_INDEX_REG_HINT_ENABLE_CLR_INDEX_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_ENABLE_CLR_INDEX_REG_HINT_ENABLE_CLR_INDEX_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_ENABLE_CLR_INDEX_REG_HINT_ENABLE_CLR_INDEX_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_ENABLE_CLR_INDEX_REG_RESETVAL (0x00000000u)

/* vector_null_reg */

#define CSL_CPINTC_VECTOR_NULL_REG_VECTOR_NULL_ADDR_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_NULL_REG_VECTOR_NULL_ADDR_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_NULL_REG_VECTOR_NULL_ADDR_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_NULL_REG_RESETVAL (0x00000000u)

/* glb_pri_intr_reg */

#define CSL_CPINTC_GLB_PRI_INTR_REG_GLB_PRI_INTR_MASK (0x000003FFu)
#define CSL_CPINTC_GLB_PRI_INTR_REG_GLB_PRI_INTR_SHIFT (0x00000000u)
#define CSL_CPINTC_GLB_PRI_INTR_REG_GLB_PRI_INTR_RESETVAL (0x00000000u)

#define CSL_CPINTC_GLB_PRI_INTR_REG_GLB_NONE_MASK (0x80000000u)
#define CSL_CPINTC_GLB_PRI_INTR_REG_GLB_NONE_SHIFT (0x0000001Fu)
#define CSL_CPINTC_GLB_PRI_INTR_REG_GLB_NONE_RESETVAL (0x00000001u)

#define CSL_CPINTC_GLB_PRI_INTR_REG_RESETVAL (0x80000000u)

/* glb_vector_addr_reg */

#define CSL_CPINTC_GLB_VECTOR_ADDR_REG_GLB_VECTOR_ADDR_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_GLB_VECTOR_ADDR_REG_GLB_VECTOR_ADDR_SHIFT (0x00000000u)
#define CSL_CPINTC_GLB_VECTOR_ADDR_REG_GLB_VECTOR_ADDR_RESETVAL (0x00000000u)

#define CSL_CPINTC_GLB_VECTOR_ADDR_REG_RESETVAL (0x00000000u)

/* global_secure_enable_reg */

#define CSL_CPINTC_GLOBAL_SECURE_ENABLE_REG_SEC_ENABLE_ANY_MASK (0x00000001u)
#define CSL_CPINTC_GLOBAL_SECURE_ENABLE_REG_SEC_ENABLE_ANY_SHIFT (0x00000000u)
#define CSL_CPINTC_GLOBAL_SECURE_ENABLE_REG_SEC_ENABLE_ANY_RESETVAL (0x00000000u)

#define CSL_CPINTC_GLOBAL_SECURE_ENABLE_REG_SECURE_ADV_EN_MASK (0x00000002u)
#define CSL_CPINTC_GLOBAL_SECURE_ENABLE_REG_SECURE_ADV_EN_SHIFT (0x00000001u)
#define CSL_CPINTC_GLOBAL_SECURE_ENABLE_REG_SECURE_ADV_EN_RESETVAL (0x00000000u)

#define CSL_CPINTC_GLOBAL_SECURE_ENABLE_REG_RESETVAL (0x00000000u)

/* secure_pri_intr_reg */

#define CSL_CPINTC_SECURE_PRI_INTR_REG_SEC_PRI_INTR_MASK (0x000003FFu)
#define CSL_CPINTC_SECURE_PRI_INTR_REG_SEC_PRI_INTR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_PRI_INTR_REG_SEC_PRI_INTR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_PRI_INTR_REG_SEC_PRI_NONE_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_PRI_INTR_REG_SEC_PRI_NONE_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_PRI_INTR_REG_SEC_PRI_NONE_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_PRI_INTR_REG_RESETVAL (0x00000000u)

/* raw_status_reg0 */

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_0_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_0_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_1_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_1_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_2_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_2_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_3_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_3_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_4_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_4_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_5_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_5_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_6_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_6_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_7_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_7_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_8_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_8_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_9_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_9_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_10_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_10_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_11_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_11_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_12_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_12_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_13_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_13_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_14_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_14_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_15_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_15_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_16_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_16_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_17_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_17_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_18_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_18_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_19_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_19_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_20_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_20_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_21_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_21_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_22_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_22_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_23_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_23_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_24_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_24_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_25_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_25_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_26_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_26_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_27_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_27_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_28_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_28_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_29_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_29_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_30_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_30_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_31_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG0_RAW_STATUS_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG0_RESETVAL (0x00000000u)

/* raw_status_reg1 */

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_32_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_32_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_33_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_33_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_34_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_34_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_35_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_35_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_36_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_36_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_37_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_37_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_38_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_38_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_39_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_39_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_40_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_40_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_41_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_41_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_42_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_42_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_43_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_43_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_44_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_44_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_45_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_45_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_46_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_46_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_47_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_47_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_48_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_48_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_49_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_49_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_50_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_50_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_51_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_51_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_52_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_52_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_53_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_53_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_54_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_54_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_55_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_55_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_56_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_56_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_57_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_57_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_58_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_58_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_59_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_59_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_60_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_60_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_61_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_61_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_62_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_62_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_63_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG1_RAW_STATUS_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG1_RESETVAL (0x00000000u)

/* raw_status_reg2 */

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_64_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_64_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_65_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_65_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_66_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_66_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_67_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_67_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_68_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_68_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_69_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_69_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_70_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_70_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_71_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_71_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_72_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_72_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_73_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_73_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_74_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_74_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_75_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_75_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_76_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_76_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_77_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_77_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_78_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_78_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_79_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_79_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_80_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_80_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_81_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_81_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_82_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_82_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_83_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_83_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_84_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_84_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_85_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_85_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_86_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_86_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_87_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_87_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_88_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_88_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_89_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_89_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_90_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_90_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_91_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_91_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_92_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_92_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_93_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_93_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_94_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_94_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_95_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_95_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG2_RAW_STATUS_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG2_RESETVAL (0x00000000u)

/* raw_status_reg3 */

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_96_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_96_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_97_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_97_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_98_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_98_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_99_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_99_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_100_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_100_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_101_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_101_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_102_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_102_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_103_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_103_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_104_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_104_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_105_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_105_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_106_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_106_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_107_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_107_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_108_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_108_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_109_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_109_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_110_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_110_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_111_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_111_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_112_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_112_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_113_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_113_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_114_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_114_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_115_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_115_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_116_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_116_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_117_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_117_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_118_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_118_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_119_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_119_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_120_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_120_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_121_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_121_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_122_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_122_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_123_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_123_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_124_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_124_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_125_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_125_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_126_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_126_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_127_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_127_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG3_RAW_STATUS_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG3_RESETVAL (0x00000000u)

/* raw_status_reg4 */

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_128_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_128_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_129_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_129_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_130_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_130_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_131_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_131_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_132_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_132_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_133_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_133_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_134_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_134_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_135_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_135_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_136_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_136_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_137_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_137_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_138_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_138_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_139_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_139_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_140_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_140_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_141_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_141_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_142_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_142_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_143_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_143_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_144_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_144_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_145_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_145_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_146_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_146_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_147_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_147_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_148_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_148_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_149_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_149_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_150_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_150_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_151_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_151_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_152_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_152_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_153_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_153_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_154_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_154_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_155_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_155_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_156_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_156_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_157_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_157_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_158_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_158_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_159_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_159_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG4_RAW_STATUS_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG4_RESETVAL (0x00000000u)

/* raw_status_reg5 */

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_160_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_160_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_161_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_161_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_162_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_162_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_163_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_163_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_164_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_164_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_165_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_165_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_166_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_166_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_167_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_167_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_168_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_168_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_169_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_169_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_170_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_170_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_171_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_171_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_172_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_172_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_173_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_173_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_174_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_174_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_175_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_175_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_176_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_176_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_177_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_177_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_178_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_178_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_179_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_179_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_180_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_180_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_181_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_181_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_182_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_182_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_183_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_183_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_184_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_184_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_185_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_185_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_186_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_186_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_187_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_187_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_188_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_188_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_189_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_189_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_190_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_190_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_191_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_191_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG5_RAW_STATUS_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG5_RESETVAL (0x00000000u)

/* raw_status_reg6 */

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_192_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_192_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_193_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_193_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_194_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_194_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_195_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_195_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_196_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_196_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_197_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_197_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_198_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_198_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_199_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_199_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_200_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_200_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_201_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_201_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_202_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_202_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_203_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_203_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_204_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_204_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_205_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_205_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_206_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_206_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_207_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_207_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_208_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_208_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_209_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_209_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_210_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_210_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_211_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_211_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_212_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_212_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_213_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_213_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_214_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_214_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_215_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_215_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_216_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_216_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_217_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_217_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_218_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_218_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_219_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_219_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_220_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_220_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_221_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_221_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_222_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_222_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_223_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_223_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG6_RAW_STATUS_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG6_RESETVAL (0x00000000u)

/* raw_status_reg7 */

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_224_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_224_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_225_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_225_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_226_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_226_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_227_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_227_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_228_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_228_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_229_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_229_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_230_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_230_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_231_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_231_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_232_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_232_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_233_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_233_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_234_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_234_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_235_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_235_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_236_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_236_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_237_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_237_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_238_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_238_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_239_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_239_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_240_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_240_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_241_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_241_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_242_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_242_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_243_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_243_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_244_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_244_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_245_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_245_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_246_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_246_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_247_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_247_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_248_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_248_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_249_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_249_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_250_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_250_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_251_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_251_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_252_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_252_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_253_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_253_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_254_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_254_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_255_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_255_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG7_RAW_STATUS_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG7_RESETVAL (0x00000000u)

/* raw_status_reg8 */

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_256_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_256_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_256_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_257_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_257_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_257_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_258_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_258_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_258_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_259_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_259_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_259_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_260_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_260_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_260_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_261_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_261_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_261_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_262_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_262_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_262_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_263_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_263_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_263_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_264_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_264_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_264_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_265_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_265_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_265_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_266_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_266_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_266_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_267_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_267_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_267_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_268_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_268_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_268_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_269_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_269_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_269_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_270_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_270_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_270_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_271_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_271_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_271_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_272_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_272_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_272_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_273_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_273_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_273_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_274_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_274_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_274_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_275_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_275_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_275_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_276_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_276_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_276_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_277_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_277_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_277_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_278_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_278_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_278_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_279_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_279_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_279_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_280_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_280_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_280_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_281_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_281_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_281_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_282_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_282_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_282_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_283_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_283_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_283_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_284_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_284_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_284_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_285_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_285_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_285_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_286_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_286_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_286_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_287_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_287_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG8_RAW_STATUS_287_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG8_RESETVAL (0x00000000u)

/* raw_status_reg9 */

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_288_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_288_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_288_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_289_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_289_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_289_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_290_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_290_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_290_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_291_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_291_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_291_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_292_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_292_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_292_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_293_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_293_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_293_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_294_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_294_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_294_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_295_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_295_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_295_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_296_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_296_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_296_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_297_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_297_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_297_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_298_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_298_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_298_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_299_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_299_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_299_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_300_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_300_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_300_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_301_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_301_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_301_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_302_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_302_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_302_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_303_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_303_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_303_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_304_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_304_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_304_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_305_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_305_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_305_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_306_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_306_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_306_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_307_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_307_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_307_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_308_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_308_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_308_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_309_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_309_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_309_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_310_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_310_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_310_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_311_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_311_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_311_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_312_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_312_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_312_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_313_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_313_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_313_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_314_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_314_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_314_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_315_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_315_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_315_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_316_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_316_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_316_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_317_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_317_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_317_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_318_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_318_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_318_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_319_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_319_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG9_RAW_STATUS_319_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG9_RESETVAL (0x00000000u)

/* raw_status_reg10 */

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_320_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_320_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_320_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_321_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_321_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_321_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_322_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_322_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_322_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_323_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_323_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_323_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_324_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_324_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_324_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_325_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_325_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_325_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_326_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_326_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_326_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_327_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_327_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_327_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_328_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_328_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_328_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_329_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_329_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_329_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_330_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_330_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_330_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_331_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_331_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_331_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_332_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_332_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_332_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_333_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_333_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_333_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_334_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_334_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_334_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_335_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_335_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_335_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_336_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_336_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_336_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_337_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_337_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_337_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_338_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_338_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_338_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_339_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_339_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_339_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_340_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_340_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_340_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_341_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_341_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_341_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_342_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_342_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_342_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_343_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_343_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_343_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_344_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_344_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_344_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_345_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_345_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_345_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_346_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_346_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_346_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_347_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_347_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_347_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_348_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_348_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_348_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_349_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_349_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_349_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_350_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_350_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_350_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_351_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_351_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG10_RAW_STATUS_351_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG10_RESETVAL (0x00000000u)

/* raw_status_reg11 */

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_352_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_352_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_352_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_353_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_353_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_353_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_354_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_354_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_354_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_355_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_355_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_355_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_356_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_356_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_356_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_357_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_357_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_357_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_358_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_358_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_358_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_359_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_359_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_359_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_360_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_360_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_360_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_361_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_361_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_361_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_362_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_362_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_362_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_363_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_363_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_363_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_364_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_364_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_364_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_365_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_365_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_365_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_366_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_366_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_366_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_367_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_367_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_367_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_368_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_368_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_368_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_369_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_369_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_369_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_370_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_370_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_370_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_371_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_371_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_371_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_372_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_372_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_372_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_373_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_373_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_373_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_374_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_374_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_374_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_375_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_375_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_375_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_376_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_376_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_376_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_377_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_377_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_377_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_378_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_378_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_378_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_379_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_379_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_379_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_380_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_380_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_380_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_381_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_381_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_381_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_382_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_382_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_382_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_383_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_383_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG11_RAW_STATUS_383_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG11_RESETVAL (0x00000000u)

/* raw_status_reg12 */

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_384_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_384_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_384_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_385_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_385_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_385_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_386_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_386_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_386_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_387_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_387_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_387_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_388_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_388_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_388_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_389_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_389_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_389_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_390_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_390_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_390_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_391_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_391_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_391_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_392_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_392_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_392_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_393_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_393_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_393_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_394_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_394_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_394_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_395_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_395_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_395_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_396_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_396_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_396_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_397_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_397_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_397_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_398_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_398_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_398_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_399_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_399_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_399_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_400_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_400_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_400_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_401_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_401_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_401_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_402_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_402_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_402_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_403_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_403_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_403_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_404_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_404_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_404_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_405_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_405_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_405_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_406_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_406_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_406_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_407_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_407_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_407_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_408_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_408_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_408_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_409_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_409_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_409_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_410_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_410_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_410_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_411_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_411_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_411_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_412_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_412_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_412_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_413_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_413_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_413_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_414_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_414_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_414_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_415_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_415_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG12_RAW_STATUS_415_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG12_RESETVAL (0x00000000u)

/* raw_status_reg13 */

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_416_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_416_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_416_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_417_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_417_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_417_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_418_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_418_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_418_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_419_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_419_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_419_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_420_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_420_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_420_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_421_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_421_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_421_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_422_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_422_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_422_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_423_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_423_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_423_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_424_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_424_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_424_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_425_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_425_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_425_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_426_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_426_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_426_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_427_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_427_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_427_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_428_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_428_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_428_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_429_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_429_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_429_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_430_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_430_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_430_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_431_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_431_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_431_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_432_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_432_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_432_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_433_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_433_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_433_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_434_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_434_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_434_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_435_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_435_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_435_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_436_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_436_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_436_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_437_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_437_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_437_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_438_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_438_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_438_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_439_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_439_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_439_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_440_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_440_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_440_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_441_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_441_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_441_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_442_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_442_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_442_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_443_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_443_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_443_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_444_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_444_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_444_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_445_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_445_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_445_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_446_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_446_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_446_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_447_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_447_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG13_RAW_STATUS_447_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG13_RESETVAL (0x00000000u)

/* raw_status_reg14 */

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_448_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_448_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_448_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_449_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_449_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_449_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_450_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_450_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_450_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_451_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_451_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_451_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_452_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_452_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_452_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_453_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_453_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_453_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_454_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_454_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_454_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_455_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_455_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_455_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_456_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_456_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_456_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_457_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_457_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_457_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_458_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_458_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_458_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_459_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_459_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_459_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_460_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_460_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_460_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_461_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_461_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_461_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_462_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_462_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_462_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_463_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_463_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_463_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_464_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_464_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_464_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_465_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_465_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_465_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_466_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_466_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_466_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_467_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_467_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_467_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_468_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_468_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_468_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_469_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_469_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_469_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_470_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_470_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_470_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_471_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_471_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_471_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_472_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_472_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_472_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_473_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_473_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_473_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_474_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_474_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_474_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_475_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_475_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_475_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_476_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_476_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_476_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_477_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_477_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_477_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_478_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_478_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_478_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_479_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_479_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG14_RAW_STATUS_479_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG14_RESETVAL (0x00000000u)

/* raw_status_reg15 */

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_480_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_480_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_480_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_481_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_481_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_481_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_482_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_482_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_482_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_483_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_483_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_483_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_484_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_484_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_484_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_485_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_485_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_485_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_486_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_486_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_486_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_487_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_487_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_487_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_488_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_488_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_488_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_489_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_489_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_489_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_490_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_490_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_490_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_491_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_491_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_491_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_492_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_492_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_492_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_493_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_493_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_493_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_494_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_494_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_494_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_495_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_495_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_495_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_496_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_496_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_496_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_497_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_497_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_497_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_498_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_498_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_498_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_499_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_499_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_499_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_500_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_500_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_500_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_501_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_501_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_501_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_502_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_502_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_502_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_503_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_503_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_503_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_504_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_504_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_504_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_505_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_505_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_505_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_506_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_506_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_506_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_507_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_507_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_507_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_508_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_508_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_508_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_509_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_509_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_509_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_510_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_510_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_510_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_511_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_511_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG15_RAW_STATUS_511_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG15_RESETVAL (0x00000000u)

/* raw_status_reg16 */

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_512_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_512_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_512_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_513_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_513_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_513_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_514_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_514_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_514_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_515_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_515_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_515_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_516_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_516_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_516_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_517_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_517_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_517_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_518_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_518_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_518_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_519_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_519_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_519_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_520_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_520_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_520_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_521_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_521_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_521_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_522_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_522_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_522_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_523_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_523_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_523_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_524_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_524_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_524_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_525_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_525_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_525_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_526_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_526_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_526_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_527_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_527_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_527_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_528_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_528_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_528_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_529_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_529_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_529_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_530_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_530_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_530_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_531_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_531_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_531_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_532_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_532_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_532_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_533_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_533_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_533_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_534_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_534_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_534_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_535_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_535_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_535_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_536_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_536_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_536_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_537_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_537_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_537_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_538_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_538_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_538_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_539_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_539_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_539_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_540_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_540_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_540_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_541_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_541_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_541_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_542_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_542_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_542_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_543_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_543_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG16_RAW_STATUS_543_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG16_RESETVAL (0x00000000u)

/* raw_status_reg17 */

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_544_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_544_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_544_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_545_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_545_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_545_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_546_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_546_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_546_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_547_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_547_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_547_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_548_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_548_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_548_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_549_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_549_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_549_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_550_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_550_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_550_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_551_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_551_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_551_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_552_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_552_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_552_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_553_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_553_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_553_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_554_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_554_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_554_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_555_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_555_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_555_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_556_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_556_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_556_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_557_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_557_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_557_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_558_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_558_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_558_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_559_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_559_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_559_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_560_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_560_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_560_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_561_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_561_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_561_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_562_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_562_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_562_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_563_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_563_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_563_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_564_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_564_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_564_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_565_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_565_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_565_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_566_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_566_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_566_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_567_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_567_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_567_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_568_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_568_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_568_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_569_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_569_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_569_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_570_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_570_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_570_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_571_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_571_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_571_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_572_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_572_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_572_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_573_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_573_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_573_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_574_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_574_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_574_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_575_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_575_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG17_RAW_STATUS_575_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG17_RESETVAL (0x00000000u)

/* raw_status_reg18 */

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_576_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_576_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_576_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_577_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_577_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_577_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_578_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_578_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_578_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_579_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_579_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_579_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_580_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_580_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_580_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_581_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_581_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_581_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_582_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_582_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_582_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_583_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_583_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_583_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_584_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_584_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_584_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_585_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_585_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_585_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_586_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_586_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_586_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_587_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_587_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_587_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_588_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_588_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_588_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_589_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_589_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_589_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_590_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_590_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_590_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_591_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_591_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_591_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_592_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_592_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_592_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_593_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_593_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_593_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_594_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_594_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_594_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_595_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_595_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_595_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_596_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_596_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_596_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_597_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_597_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_597_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_598_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_598_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_598_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_599_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_599_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_599_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_600_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_600_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_600_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_601_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_601_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_601_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_602_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_602_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_602_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_603_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_603_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_603_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_604_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_604_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_604_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_605_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_605_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_605_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_606_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_606_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_606_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_607_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_607_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG18_RAW_STATUS_607_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG18_RESETVAL (0x00000000u)

/* raw_status_reg19 */

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_608_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_608_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_608_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_609_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_609_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_609_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_610_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_610_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_610_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_611_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_611_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_611_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_612_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_612_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_612_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_613_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_613_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_613_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_614_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_614_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_614_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_615_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_615_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_615_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_616_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_616_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_616_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_617_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_617_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_617_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_618_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_618_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_618_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_619_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_619_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_619_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_620_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_620_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_620_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_621_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_621_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_621_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_622_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_622_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_622_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_623_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_623_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_623_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_624_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_624_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_624_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_625_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_625_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_625_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_626_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_626_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_626_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_627_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_627_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_627_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_628_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_628_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_628_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_629_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_629_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_629_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_630_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_630_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_630_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_631_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_631_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_631_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_632_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_632_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_632_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_633_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_633_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_633_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_634_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_634_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_634_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_635_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_635_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_635_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_636_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_636_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_636_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_637_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_637_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_637_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_638_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_638_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_638_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_639_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_639_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG19_RAW_STATUS_639_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG19_RESETVAL (0x00000000u)

/* raw_status_reg20 */

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_640_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_640_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_640_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_641_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_641_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_641_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_642_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_642_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_642_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_643_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_643_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_643_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_644_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_644_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_644_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_645_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_645_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_645_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_646_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_646_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_646_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_647_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_647_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_647_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_648_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_648_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_648_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_649_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_649_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_649_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_650_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_650_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_650_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_651_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_651_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_651_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_652_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_652_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_652_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_653_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_653_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_653_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_654_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_654_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_654_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_655_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_655_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_655_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_656_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_656_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_656_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_657_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_657_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_657_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_658_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_658_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_658_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_659_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_659_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_659_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_660_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_660_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_660_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_661_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_661_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_661_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_662_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_662_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_662_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_663_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_663_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_663_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_664_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_664_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_664_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_665_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_665_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_665_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_666_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_666_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_666_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_667_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_667_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_667_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_668_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_668_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_668_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_669_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_669_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_669_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_670_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_670_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_670_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_671_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_671_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG20_RAW_STATUS_671_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG20_RESETVAL (0x00000000u)

/* raw_status_reg21 */

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_672_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_672_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_672_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_673_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_673_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_673_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_674_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_674_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_674_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_675_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_675_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_675_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_676_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_676_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_676_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_677_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_677_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_677_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_678_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_678_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_678_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_679_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_679_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_679_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_680_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_680_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_680_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_681_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_681_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_681_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_682_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_682_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_682_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_683_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_683_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_683_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_684_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_684_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_684_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_685_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_685_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_685_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_686_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_686_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_686_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_687_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_687_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_687_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_688_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_688_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_688_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_689_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_689_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_689_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_690_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_690_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_690_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_691_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_691_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_691_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_692_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_692_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_692_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_693_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_693_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_693_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_694_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_694_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_694_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_695_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_695_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_695_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_696_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_696_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_696_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_697_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_697_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_697_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_698_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_698_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_698_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_699_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_699_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_699_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_700_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_700_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_700_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_701_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_701_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_701_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_702_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_702_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_702_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_703_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_703_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG21_RAW_STATUS_703_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG21_RESETVAL (0x00000000u)

/* raw_status_reg22 */

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_704_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_704_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_704_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_705_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_705_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_705_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_706_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_706_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_706_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_707_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_707_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_707_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_708_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_708_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_708_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_709_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_709_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_709_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_710_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_710_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_710_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_711_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_711_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_711_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_712_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_712_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_712_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_713_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_713_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_713_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_714_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_714_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_714_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_715_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_715_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_715_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_716_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_716_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_716_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_717_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_717_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_717_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_718_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_718_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_718_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_719_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_719_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_719_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_720_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_720_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_720_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_721_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_721_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_721_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_722_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_722_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_722_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_723_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_723_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_723_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_724_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_724_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_724_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_725_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_725_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_725_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_726_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_726_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_726_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_727_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_727_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_727_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_728_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_728_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_728_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_729_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_729_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_729_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_730_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_730_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_730_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_731_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_731_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_731_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_732_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_732_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_732_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_733_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_733_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_733_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_734_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_734_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_734_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_735_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_735_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG22_RAW_STATUS_735_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG22_RESETVAL (0x00000000u)

/* raw_status_reg23 */

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_736_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_736_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_736_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_737_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_737_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_737_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_738_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_738_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_738_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_739_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_739_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_739_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_740_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_740_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_740_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_741_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_741_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_741_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_742_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_742_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_742_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_743_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_743_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_743_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_744_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_744_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_744_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_745_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_745_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_745_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_746_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_746_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_746_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_747_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_747_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_747_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_748_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_748_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_748_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_749_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_749_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_749_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_750_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_750_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_750_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_751_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_751_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_751_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_752_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_752_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_752_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_753_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_753_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_753_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_754_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_754_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_754_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_755_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_755_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_755_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_756_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_756_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_756_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_757_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_757_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_757_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_758_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_758_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_758_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_759_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_759_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_759_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_760_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_760_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_760_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_761_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_761_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_761_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_762_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_762_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_762_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_763_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_763_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_763_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_764_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_764_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_764_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_765_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_765_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_765_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_766_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_766_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_766_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_767_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_767_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG23_RAW_STATUS_767_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG23_RESETVAL (0x00000000u)

/* raw_status_reg24 */

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_768_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_768_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_768_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_769_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_769_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_769_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_770_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_770_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_770_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_771_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_771_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_771_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_772_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_772_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_772_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_773_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_773_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_773_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_774_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_774_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_774_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_775_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_775_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_775_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_776_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_776_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_776_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_777_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_777_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_777_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_778_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_778_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_778_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_779_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_779_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_779_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_780_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_780_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_780_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_781_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_781_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_781_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_782_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_782_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_782_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_783_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_783_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_783_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_784_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_784_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_784_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_785_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_785_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_785_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_786_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_786_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_786_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_787_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_787_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_787_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_788_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_788_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_788_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_789_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_789_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_789_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_790_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_790_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_790_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_791_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_791_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_791_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_792_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_792_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_792_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_793_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_793_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_793_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_794_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_794_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_794_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_795_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_795_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_795_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_796_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_796_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_796_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_797_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_797_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_797_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_798_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_798_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_798_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_799_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_799_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG24_RAW_STATUS_799_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG24_RESETVAL (0x00000000u)

/* raw_status_reg25 */

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_800_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_800_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_800_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_801_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_801_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_801_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_802_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_802_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_802_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_803_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_803_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_803_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_804_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_804_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_804_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_805_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_805_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_805_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_806_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_806_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_806_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_807_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_807_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_807_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_808_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_808_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_808_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_809_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_809_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_809_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_810_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_810_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_810_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_811_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_811_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_811_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_812_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_812_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_812_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_813_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_813_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_813_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_814_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_814_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_814_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_815_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_815_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_815_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_816_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_816_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_816_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_817_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_817_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_817_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_818_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_818_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_818_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_819_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_819_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_819_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_820_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_820_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_820_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_821_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_821_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_821_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_822_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_822_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_822_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_823_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_823_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_823_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_824_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_824_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_824_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_825_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_825_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_825_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_826_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_826_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_826_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_827_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_827_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_827_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_828_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_828_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_828_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_829_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_829_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_829_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_830_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_830_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_830_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_831_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_831_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG25_RAW_STATUS_831_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG25_RESETVAL (0x00000000u)

/* raw_status_reg26 */

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_832_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_832_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_832_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_833_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_833_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_833_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_834_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_834_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_834_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_835_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_835_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_835_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_836_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_836_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_836_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_837_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_837_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_837_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_838_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_838_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_838_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_839_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_839_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_839_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_840_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_840_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_840_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_841_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_841_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_841_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_842_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_842_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_842_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_843_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_843_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_843_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_844_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_844_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_844_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_845_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_845_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_845_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_846_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_846_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_846_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_847_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_847_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_847_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_848_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_848_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_848_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_849_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_849_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_849_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_850_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_850_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_850_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_851_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_851_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_851_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_852_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_852_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_852_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_853_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_853_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_853_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_854_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_854_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_854_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_855_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_855_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_855_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_856_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_856_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_856_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_857_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_857_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_857_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_858_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_858_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_858_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_859_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_859_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_859_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_860_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_860_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_860_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_861_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_861_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_861_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_862_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_862_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_862_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_863_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_863_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG26_RAW_STATUS_863_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG26_RESETVAL (0x00000000u)

/* raw_status_reg27 */

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_864_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_864_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_864_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_865_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_865_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_865_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_866_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_866_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_866_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_867_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_867_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_867_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_868_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_868_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_868_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_869_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_869_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_869_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_870_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_870_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_870_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_871_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_871_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_871_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_872_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_872_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_872_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_873_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_873_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_873_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_874_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_874_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_874_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_875_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_875_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_875_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_876_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_876_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_876_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_877_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_877_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_877_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_878_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_878_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_878_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_879_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_879_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_879_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_880_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_880_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_880_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_881_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_881_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_881_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_882_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_882_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_882_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_883_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_883_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_883_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_884_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_884_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_884_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_885_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_885_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_885_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_886_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_886_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_886_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_887_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_887_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_887_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_888_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_888_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_888_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_889_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_889_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_889_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_890_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_890_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_890_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_891_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_891_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_891_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_892_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_892_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_892_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_893_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_893_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_893_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_894_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_894_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_894_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_895_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_895_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG27_RAW_STATUS_895_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG27_RESETVAL (0x00000000u)

/* raw_status_reg28 */

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_896_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_896_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_896_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_897_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_897_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_897_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_898_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_898_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_898_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_899_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_899_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_899_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_900_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_900_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_900_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_901_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_901_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_901_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_902_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_902_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_902_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_903_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_903_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_903_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_904_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_904_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_904_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_905_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_905_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_905_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_906_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_906_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_906_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_907_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_907_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_907_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_908_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_908_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_908_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_909_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_909_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_909_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_910_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_910_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_910_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_911_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_911_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_911_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_912_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_912_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_912_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_913_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_913_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_913_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_914_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_914_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_914_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_915_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_915_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_915_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_916_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_916_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_916_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_917_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_917_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_917_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_918_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_918_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_918_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_919_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_919_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_919_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_920_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_920_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_920_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_921_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_921_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_921_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_922_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_922_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_922_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_923_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_923_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_923_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_924_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_924_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_924_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_925_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_925_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_925_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_926_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_926_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_926_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_927_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_927_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG28_RAW_STATUS_927_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG28_RESETVAL (0x00000000u)

/* raw_status_reg29 */

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_928_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_928_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_928_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_929_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_929_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_929_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_930_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_930_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_930_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_931_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_931_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_931_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_932_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_932_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_932_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_933_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_933_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_933_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_934_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_934_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_934_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_935_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_935_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_935_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_936_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_936_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_936_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_937_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_937_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_937_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_938_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_938_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_938_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_939_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_939_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_939_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_940_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_940_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_940_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_941_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_941_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_941_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_942_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_942_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_942_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_943_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_943_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_943_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_944_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_944_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_944_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_945_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_945_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_945_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_946_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_946_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_946_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_947_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_947_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_947_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_948_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_948_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_948_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_949_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_949_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_949_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_950_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_950_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_950_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_951_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_951_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_951_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_952_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_952_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_952_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_953_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_953_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_953_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_954_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_954_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_954_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_955_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_955_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_955_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_956_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_956_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_956_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_957_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_957_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_957_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_958_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_958_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_958_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_959_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_959_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG29_RAW_STATUS_959_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG29_RESETVAL (0x00000000u)

/* raw_status_reg30 */

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_960_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_960_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_960_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_961_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_961_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_961_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_962_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_962_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_962_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_963_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_963_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_963_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_964_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_964_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_964_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_965_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_965_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_965_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_966_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_966_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_966_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_967_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_967_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_967_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_968_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_968_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_968_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_969_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_969_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_969_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_970_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_970_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_970_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_971_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_971_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_971_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_972_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_972_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_972_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_973_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_973_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_973_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_974_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_974_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_974_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_975_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_975_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_975_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_976_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_976_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_976_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_977_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_977_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_977_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_978_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_978_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_978_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_979_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_979_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_979_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_980_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_980_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_980_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_981_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_981_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_981_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_982_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_982_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_982_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_983_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_983_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_983_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_984_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_984_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_984_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_985_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_985_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_985_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_986_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_986_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_986_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_987_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_987_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_987_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_988_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_988_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_988_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_989_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_989_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_989_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_990_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_990_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_990_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_991_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_991_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG30_RAW_STATUS_991_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG30_RESETVAL (0x00000000u)

/* raw_status_reg31 */

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_992_MASK (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_992_SHIFT (0x00000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_992_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_993_MASK (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_993_SHIFT (0x00000001u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_993_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_994_MASK (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_994_SHIFT (0x00000002u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_994_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_995_MASK (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_995_SHIFT (0x00000003u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_995_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_996_MASK (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_996_SHIFT (0x00000004u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_996_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_997_MASK (0x00000020u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_997_SHIFT (0x00000005u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_997_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_998_MASK (0x00000040u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_998_SHIFT (0x00000006u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_998_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_999_MASK (0x00000080u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_999_SHIFT (0x00000007u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_999_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1000_MASK (0x00000100u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1000_SHIFT (0x00000008u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1000_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1001_MASK (0x00000200u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1001_SHIFT (0x00000009u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1001_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1002_MASK (0x00000400u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1002_SHIFT (0x0000000Au)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1002_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1003_MASK (0x00000800u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1003_SHIFT (0x0000000Bu)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1003_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1004_MASK (0x00001000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1004_SHIFT (0x0000000Cu)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1004_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1005_MASK (0x00002000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1005_SHIFT (0x0000000Du)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1005_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1006_MASK (0x00004000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1006_SHIFT (0x0000000Eu)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1006_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1007_MASK (0x00008000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1007_SHIFT (0x0000000Fu)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1007_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1008_MASK (0x00010000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1008_SHIFT (0x00000010u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1008_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1009_MASK (0x00020000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1009_SHIFT (0x00000011u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1009_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1010_MASK (0x00040000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1010_SHIFT (0x00000012u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1010_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1011_MASK (0x00080000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1011_SHIFT (0x00000013u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1011_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1012_MASK (0x00100000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1012_SHIFT (0x00000014u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1012_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1013_MASK (0x00200000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1013_SHIFT (0x00000015u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1013_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1014_MASK (0x00400000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1014_SHIFT (0x00000016u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1014_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1015_MASK (0x00800000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1015_SHIFT (0x00000017u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1015_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1016_MASK (0x01000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1016_SHIFT (0x00000018u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1016_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1017_MASK (0x02000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1017_SHIFT (0x00000019u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1017_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1018_MASK (0x04000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1018_SHIFT (0x0000001Au)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1018_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1019_MASK (0x08000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1019_SHIFT (0x0000001Bu)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1019_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1020_MASK (0x10000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1020_SHIFT (0x0000001Cu)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1020_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1021_MASK (0x20000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1021_SHIFT (0x0000001Du)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1021_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1022_MASK (0x40000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1022_SHIFT (0x0000001Eu)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1022_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1023_MASK (0x80000000u)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1023_SHIFT (0x0000001Fu)
#define CSL_CPINTC_RAW_STATUS_REG31_RAW_STATUS_1023_RESETVAL (0x00000000u)

#define CSL_CPINTC_RAW_STATUS_REG31_RESETVAL (0x00000000u)

/* ena_status_reg0 */

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_0_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_0_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_1_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_1_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_2_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_2_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_3_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_3_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_4_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_4_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_5_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_5_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_6_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_6_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_7_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_7_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_8_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_8_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_9_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_9_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_10_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_10_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_11_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_11_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_12_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_12_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_13_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_13_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_14_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_14_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_15_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_15_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_16_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_16_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_17_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_17_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_18_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_18_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_19_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_19_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_20_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_20_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_21_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_21_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_22_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_22_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_23_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_23_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_24_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_24_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_25_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_25_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_26_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_26_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_27_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_27_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_28_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_28_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_29_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_29_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_30_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_30_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_31_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG0_ENA_STATUS_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG0_RESETVAL (0x00000000u)

/* ena_status_reg1 */

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_32_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_32_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_33_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_33_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_34_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_34_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_35_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_35_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_36_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_36_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_37_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_37_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_38_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_38_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_39_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_39_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_40_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_40_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_41_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_41_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_42_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_42_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_43_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_43_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_44_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_44_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_45_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_45_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_46_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_46_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_47_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_47_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_48_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_48_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_49_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_49_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_50_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_50_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_51_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_51_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_52_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_52_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_53_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_53_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_54_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_54_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_55_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_55_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_56_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_56_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_57_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_57_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_58_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_58_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_59_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_59_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_60_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_60_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_61_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_61_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_62_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_62_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_63_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG1_ENA_STATUS_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG1_RESETVAL (0x00000000u)

/* ena_status_reg2 */

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_64_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_64_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_65_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_65_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_66_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_66_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_67_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_67_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_68_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_68_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_69_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_69_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_70_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_70_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_71_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_71_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_72_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_72_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_73_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_73_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_74_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_74_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_75_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_75_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_76_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_76_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_77_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_77_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_78_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_78_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_79_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_79_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_80_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_80_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_81_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_81_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_82_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_82_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_83_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_83_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_84_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_84_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_85_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_85_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_86_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_86_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_87_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_87_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_88_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_88_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_89_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_89_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_90_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_90_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_91_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_91_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_92_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_92_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_93_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_93_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_94_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_94_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_95_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_95_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG2_ENA_STATUS_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG2_RESETVAL (0x00000000u)

/* ena_status_reg3 */

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_96_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_96_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_97_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_97_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_98_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_98_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_99_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_99_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_100_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_100_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_101_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_101_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_102_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_102_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_103_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_103_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_104_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_104_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_105_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_105_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_106_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_106_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_107_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_107_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_108_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_108_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_109_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_109_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_110_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_110_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_111_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_111_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_112_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_112_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_113_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_113_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_114_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_114_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_115_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_115_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_116_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_116_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_117_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_117_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_118_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_118_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_119_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_119_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_120_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_120_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_121_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_121_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_122_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_122_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_123_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_123_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_124_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_124_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_125_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_125_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_126_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_126_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_127_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_127_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG3_ENA_STATUS_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG3_RESETVAL (0x00000000u)

/* ena_status_reg4 */

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_128_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_128_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_129_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_129_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_130_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_130_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_131_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_131_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_132_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_132_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_133_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_133_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_134_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_134_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_135_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_135_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_136_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_136_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_137_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_137_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_138_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_138_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_139_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_139_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_140_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_140_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_141_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_141_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_142_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_142_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_143_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_143_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_144_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_144_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_145_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_145_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_146_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_146_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_147_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_147_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_148_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_148_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_149_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_149_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_150_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_150_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_151_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_151_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_152_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_152_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_153_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_153_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_154_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_154_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_155_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_155_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_156_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_156_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_157_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_157_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_158_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_158_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_159_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_159_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG4_ENA_STATUS_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG4_RESETVAL (0x00000000u)

/* ena_status_reg5 */

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_160_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_160_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_161_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_161_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_162_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_162_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_163_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_163_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_164_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_164_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_165_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_165_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_166_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_166_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_167_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_167_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_168_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_168_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_169_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_169_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_170_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_170_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_171_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_171_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_172_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_172_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_173_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_173_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_174_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_174_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_175_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_175_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_176_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_176_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_177_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_177_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_178_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_178_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_179_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_179_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_180_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_180_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_181_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_181_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_182_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_182_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_183_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_183_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_184_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_184_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_185_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_185_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_186_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_186_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_187_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_187_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_188_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_188_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_189_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_189_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_190_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_190_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_191_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_191_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG5_ENA_STATUS_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG5_RESETVAL (0x00000000u)

/* ena_status_reg6 */

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_192_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_192_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_193_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_193_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_194_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_194_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_195_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_195_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_196_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_196_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_197_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_197_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_198_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_198_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_199_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_199_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_200_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_200_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_201_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_201_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_202_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_202_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_203_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_203_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_204_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_204_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_205_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_205_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_206_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_206_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_207_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_207_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_208_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_208_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_209_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_209_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_210_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_210_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_211_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_211_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_212_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_212_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_213_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_213_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_214_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_214_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_215_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_215_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_216_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_216_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_217_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_217_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_218_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_218_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_219_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_219_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_220_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_220_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_221_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_221_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_222_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_222_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_223_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_223_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG6_ENA_STATUS_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG6_RESETVAL (0x00000000u)

/* ena_status_reg7 */

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_224_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_224_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_225_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_225_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_226_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_226_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_227_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_227_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_228_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_228_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_229_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_229_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_230_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_230_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_231_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_231_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_232_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_232_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_233_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_233_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_234_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_234_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_235_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_235_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_236_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_236_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_237_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_237_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_238_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_238_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_239_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_239_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_240_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_240_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_241_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_241_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_242_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_242_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_243_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_243_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_244_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_244_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_245_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_245_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_246_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_246_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_247_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_247_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_248_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_248_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_249_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_249_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_250_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_250_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_251_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_251_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_252_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_252_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_253_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_253_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_254_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_254_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_255_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_255_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG7_ENA_STATUS_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG7_RESETVAL (0x00000000u)

/* ena_status_reg8 */

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_256_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_256_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_256_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_257_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_257_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_257_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_258_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_258_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_258_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_259_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_259_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_259_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_260_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_260_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_260_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_261_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_261_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_261_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_262_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_262_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_262_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_263_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_263_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_263_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_264_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_264_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_264_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_265_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_265_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_265_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_266_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_266_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_266_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_267_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_267_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_267_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_268_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_268_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_268_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_269_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_269_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_269_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_270_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_270_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_270_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_271_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_271_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_271_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_272_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_272_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_272_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_273_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_273_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_273_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_274_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_274_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_274_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_275_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_275_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_275_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_276_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_276_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_276_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_277_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_277_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_277_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_278_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_278_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_278_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_279_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_279_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_279_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_280_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_280_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_280_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_281_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_281_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_281_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_282_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_282_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_282_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_283_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_283_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_283_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_284_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_284_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_284_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_285_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_285_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_285_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_286_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_286_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_286_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_287_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_287_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG8_ENA_STATUS_287_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG8_RESETVAL (0x00000000u)

/* ena_status_reg9 */

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_288_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_288_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_288_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_289_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_289_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_289_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_290_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_290_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_290_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_291_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_291_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_291_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_292_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_292_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_292_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_293_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_293_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_293_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_294_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_294_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_294_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_295_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_295_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_295_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_296_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_296_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_296_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_297_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_297_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_297_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_298_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_298_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_298_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_299_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_299_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_299_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_300_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_300_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_300_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_301_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_301_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_301_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_302_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_302_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_302_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_303_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_303_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_303_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_304_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_304_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_304_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_305_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_305_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_305_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_306_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_306_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_306_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_307_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_307_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_307_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_308_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_308_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_308_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_309_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_309_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_309_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_310_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_310_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_310_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_311_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_311_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_311_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_312_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_312_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_312_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_313_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_313_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_313_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_314_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_314_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_314_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_315_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_315_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_315_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_316_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_316_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_316_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_317_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_317_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_317_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_318_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_318_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_318_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_319_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_319_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG9_ENA_STATUS_319_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG9_RESETVAL (0x00000000u)

/* ena_status_reg10 */

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_320_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_320_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_320_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_321_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_321_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_321_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_322_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_322_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_322_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_323_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_323_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_323_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_324_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_324_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_324_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_325_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_325_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_325_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_326_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_326_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_326_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_327_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_327_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_327_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_328_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_328_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_328_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_329_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_329_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_329_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_330_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_330_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_330_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_331_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_331_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_331_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_332_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_332_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_332_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_333_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_333_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_333_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_334_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_334_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_334_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_335_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_335_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_335_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_336_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_336_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_336_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_337_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_337_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_337_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_338_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_338_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_338_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_339_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_339_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_339_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_340_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_340_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_340_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_341_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_341_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_341_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_342_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_342_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_342_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_343_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_343_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_343_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_344_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_344_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_344_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_345_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_345_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_345_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_346_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_346_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_346_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_347_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_347_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_347_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_348_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_348_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_348_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_349_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_349_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_349_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_350_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_350_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_350_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_351_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_351_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG10_ENA_STATUS_351_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG10_RESETVAL (0x00000000u)

/* ena_status_reg11 */

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_352_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_352_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_352_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_353_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_353_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_353_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_354_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_354_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_354_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_355_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_355_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_355_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_356_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_356_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_356_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_357_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_357_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_357_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_358_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_358_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_358_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_359_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_359_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_359_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_360_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_360_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_360_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_361_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_361_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_361_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_362_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_362_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_362_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_363_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_363_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_363_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_364_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_364_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_364_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_365_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_365_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_365_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_366_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_366_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_366_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_367_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_367_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_367_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_368_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_368_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_368_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_369_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_369_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_369_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_370_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_370_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_370_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_371_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_371_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_371_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_372_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_372_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_372_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_373_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_373_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_373_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_374_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_374_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_374_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_375_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_375_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_375_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_376_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_376_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_376_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_377_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_377_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_377_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_378_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_378_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_378_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_379_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_379_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_379_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_380_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_380_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_380_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_381_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_381_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_381_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_382_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_382_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_382_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_383_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_383_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG11_ENA_STATUS_383_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG11_RESETVAL (0x00000000u)

/* ena_status_reg12 */

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_384_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_384_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_384_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_385_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_385_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_385_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_386_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_386_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_386_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_387_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_387_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_387_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_388_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_388_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_388_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_389_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_389_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_389_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_390_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_390_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_390_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_391_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_391_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_391_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_392_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_392_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_392_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_393_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_393_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_393_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_394_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_394_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_394_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_395_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_395_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_395_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_396_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_396_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_396_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_397_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_397_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_397_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_398_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_398_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_398_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_399_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_399_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_399_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_400_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_400_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_400_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_401_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_401_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_401_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_402_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_402_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_402_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_403_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_403_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_403_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_404_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_404_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_404_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_405_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_405_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_405_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_406_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_406_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_406_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_407_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_407_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_407_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_408_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_408_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_408_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_409_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_409_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_409_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_410_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_410_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_410_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_411_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_411_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_411_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_412_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_412_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_412_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_413_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_413_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_413_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_414_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_414_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_414_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_415_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_415_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG12_ENA_STATUS_415_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG12_RESETVAL (0x00000000u)

/* ena_status_reg13 */

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_416_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_416_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_416_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_417_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_417_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_417_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_418_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_418_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_418_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_419_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_419_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_419_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_420_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_420_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_420_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_421_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_421_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_421_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_422_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_422_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_422_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_423_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_423_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_423_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_424_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_424_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_424_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_425_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_425_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_425_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_426_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_426_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_426_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_427_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_427_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_427_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_428_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_428_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_428_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_429_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_429_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_429_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_430_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_430_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_430_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_431_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_431_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_431_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_432_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_432_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_432_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_433_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_433_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_433_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_434_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_434_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_434_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_435_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_435_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_435_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_436_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_436_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_436_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_437_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_437_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_437_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_438_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_438_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_438_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_439_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_439_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_439_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_440_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_440_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_440_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_441_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_441_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_441_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_442_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_442_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_442_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_443_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_443_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_443_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_444_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_444_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_444_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_445_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_445_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_445_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_446_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_446_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_446_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_447_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_447_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG13_ENA_STATUS_447_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG13_RESETVAL (0x00000000u)

/* ena_status_reg14 */

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_448_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_448_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_448_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_449_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_449_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_449_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_450_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_450_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_450_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_451_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_451_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_451_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_452_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_452_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_452_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_453_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_453_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_453_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_454_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_454_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_454_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_455_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_455_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_455_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_456_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_456_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_456_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_457_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_457_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_457_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_458_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_458_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_458_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_459_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_459_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_459_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_460_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_460_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_460_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_461_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_461_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_461_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_462_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_462_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_462_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_463_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_463_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_463_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_464_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_464_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_464_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_465_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_465_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_465_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_466_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_466_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_466_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_467_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_467_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_467_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_468_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_468_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_468_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_469_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_469_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_469_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_470_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_470_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_470_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_471_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_471_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_471_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_472_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_472_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_472_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_473_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_473_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_473_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_474_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_474_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_474_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_475_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_475_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_475_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_476_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_476_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_476_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_477_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_477_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_477_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_478_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_478_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_478_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_479_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_479_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG14_ENA_STATUS_479_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG14_RESETVAL (0x00000000u)

/* ena_status_reg15 */

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_480_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_480_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_480_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_481_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_481_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_481_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_482_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_482_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_482_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_483_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_483_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_483_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_484_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_484_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_484_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_485_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_485_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_485_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_486_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_486_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_486_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_487_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_487_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_487_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_488_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_488_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_488_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_489_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_489_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_489_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_490_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_490_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_490_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_491_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_491_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_491_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_492_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_492_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_492_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_493_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_493_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_493_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_494_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_494_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_494_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_495_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_495_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_495_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_496_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_496_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_496_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_497_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_497_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_497_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_498_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_498_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_498_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_499_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_499_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_499_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_500_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_500_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_500_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_501_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_501_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_501_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_502_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_502_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_502_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_503_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_503_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_503_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_504_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_504_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_504_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_505_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_505_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_505_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_506_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_506_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_506_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_507_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_507_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_507_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_508_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_508_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_508_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_509_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_509_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_509_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_510_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_510_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_510_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_511_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_511_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG15_ENA_STATUS_511_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG15_RESETVAL (0x00000000u)

/* ena_status_reg16 */

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_512_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_512_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_512_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_513_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_513_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_513_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_514_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_514_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_514_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_515_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_515_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_515_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_516_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_516_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_516_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_517_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_517_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_517_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_518_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_518_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_518_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_519_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_519_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_519_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_520_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_520_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_520_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_521_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_521_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_521_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_522_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_522_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_522_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_523_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_523_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_523_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_524_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_524_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_524_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_525_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_525_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_525_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_526_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_526_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_526_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_527_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_527_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_527_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_528_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_528_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_528_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_529_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_529_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_529_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_530_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_530_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_530_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_531_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_531_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_531_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_532_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_532_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_532_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_533_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_533_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_533_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_534_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_534_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_534_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_535_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_535_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_535_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_536_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_536_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_536_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_537_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_537_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_537_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_538_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_538_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_538_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_539_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_539_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_539_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_540_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_540_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_540_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_541_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_541_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_541_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_542_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_542_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_542_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_543_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_543_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG16_ENA_STATUS_543_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG16_RESETVAL (0x00000000u)

/* ena_status_reg17 */

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_544_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_544_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_544_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_545_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_545_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_545_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_546_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_546_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_546_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_547_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_547_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_547_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_548_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_548_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_548_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_549_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_549_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_549_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_550_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_550_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_550_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_551_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_551_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_551_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_552_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_552_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_552_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_553_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_553_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_553_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_554_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_554_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_554_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_555_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_555_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_555_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_556_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_556_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_556_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_557_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_557_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_557_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_558_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_558_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_558_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_559_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_559_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_559_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_560_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_560_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_560_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_561_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_561_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_561_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_562_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_562_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_562_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_563_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_563_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_563_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_564_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_564_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_564_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_565_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_565_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_565_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_566_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_566_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_566_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_567_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_567_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_567_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_568_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_568_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_568_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_569_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_569_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_569_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_570_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_570_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_570_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_571_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_571_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_571_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_572_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_572_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_572_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_573_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_573_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_573_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_574_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_574_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_574_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_575_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_575_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG17_ENA_STATUS_575_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG17_RESETVAL (0x00000000u)

/* ena_status_reg18 */

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_576_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_576_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_576_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_577_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_577_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_577_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_578_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_578_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_578_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_579_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_579_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_579_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_580_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_580_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_580_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_581_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_581_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_581_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_582_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_582_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_582_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_583_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_583_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_583_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_584_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_584_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_584_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_585_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_585_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_585_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_586_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_586_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_586_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_587_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_587_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_587_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_588_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_588_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_588_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_589_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_589_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_589_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_590_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_590_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_590_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_591_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_591_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_591_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_592_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_592_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_592_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_593_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_593_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_593_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_594_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_594_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_594_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_595_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_595_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_595_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_596_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_596_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_596_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_597_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_597_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_597_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_598_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_598_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_598_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_599_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_599_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_599_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_600_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_600_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_600_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_601_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_601_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_601_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_602_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_602_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_602_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_603_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_603_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_603_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_604_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_604_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_604_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_605_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_605_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_605_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_606_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_606_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_606_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_607_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_607_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG18_ENA_STATUS_607_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG18_RESETVAL (0x00000000u)

/* ena_status_reg19 */

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_608_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_608_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_608_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_609_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_609_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_609_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_610_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_610_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_610_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_611_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_611_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_611_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_612_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_612_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_612_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_613_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_613_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_613_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_614_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_614_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_614_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_615_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_615_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_615_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_616_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_616_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_616_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_617_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_617_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_617_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_618_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_618_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_618_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_619_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_619_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_619_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_620_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_620_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_620_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_621_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_621_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_621_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_622_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_622_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_622_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_623_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_623_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_623_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_624_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_624_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_624_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_625_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_625_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_625_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_626_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_626_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_626_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_627_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_627_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_627_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_628_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_628_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_628_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_629_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_629_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_629_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_630_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_630_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_630_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_631_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_631_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_631_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_632_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_632_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_632_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_633_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_633_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_633_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_634_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_634_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_634_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_635_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_635_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_635_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_636_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_636_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_636_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_637_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_637_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_637_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_638_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_638_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_638_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_639_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_639_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG19_ENA_STATUS_639_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG19_RESETVAL (0x00000000u)

/* ena_status_reg20 */

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_640_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_640_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_640_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_641_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_641_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_641_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_642_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_642_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_642_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_643_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_643_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_643_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_644_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_644_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_644_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_645_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_645_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_645_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_646_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_646_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_646_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_647_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_647_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_647_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_648_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_648_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_648_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_649_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_649_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_649_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_650_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_650_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_650_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_651_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_651_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_651_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_652_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_652_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_652_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_653_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_653_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_653_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_654_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_654_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_654_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_655_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_655_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_655_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_656_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_656_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_656_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_657_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_657_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_657_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_658_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_658_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_658_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_659_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_659_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_659_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_660_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_660_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_660_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_661_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_661_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_661_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_662_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_662_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_662_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_663_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_663_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_663_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_664_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_664_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_664_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_665_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_665_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_665_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_666_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_666_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_666_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_667_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_667_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_667_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_668_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_668_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_668_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_669_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_669_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_669_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_670_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_670_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_670_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_671_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_671_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG20_ENA_STATUS_671_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG20_RESETVAL (0x00000000u)

/* ena_status_reg21 */

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_672_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_672_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_672_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_673_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_673_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_673_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_674_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_674_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_674_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_675_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_675_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_675_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_676_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_676_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_676_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_677_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_677_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_677_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_678_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_678_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_678_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_679_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_679_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_679_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_680_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_680_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_680_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_681_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_681_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_681_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_682_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_682_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_682_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_683_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_683_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_683_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_684_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_684_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_684_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_685_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_685_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_685_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_686_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_686_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_686_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_687_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_687_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_687_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_688_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_688_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_688_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_689_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_689_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_689_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_690_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_690_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_690_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_691_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_691_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_691_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_692_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_692_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_692_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_693_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_693_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_693_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_694_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_694_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_694_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_695_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_695_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_695_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_696_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_696_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_696_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_697_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_697_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_697_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_698_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_698_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_698_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_699_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_699_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_699_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_700_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_700_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_700_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_701_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_701_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_701_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_702_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_702_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_702_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_703_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_703_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG21_ENA_STATUS_703_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG21_RESETVAL (0x00000000u)

/* ena_status_reg22 */

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_704_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_704_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_704_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_705_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_705_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_705_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_706_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_706_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_706_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_707_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_707_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_707_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_708_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_708_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_708_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_709_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_709_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_709_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_710_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_710_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_710_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_711_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_711_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_711_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_712_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_712_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_712_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_713_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_713_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_713_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_714_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_714_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_714_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_715_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_715_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_715_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_716_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_716_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_716_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_717_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_717_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_717_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_718_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_718_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_718_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_719_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_719_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_719_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_720_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_720_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_720_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_721_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_721_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_721_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_722_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_722_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_722_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_723_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_723_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_723_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_724_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_724_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_724_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_725_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_725_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_725_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_726_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_726_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_726_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_727_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_727_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_727_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_728_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_728_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_728_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_729_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_729_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_729_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_730_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_730_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_730_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_731_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_731_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_731_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_732_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_732_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_732_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_733_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_733_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_733_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_734_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_734_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_734_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_735_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_735_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG22_ENA_STATUS_735_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG22_RESETVAL (0x00000000u)

/* ena_status_reg23 */

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_736_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_736_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_736_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_737_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_737_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_737_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_738_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_738_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_738_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_739_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_739_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_739_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_740_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_740_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_740_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_741_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_741_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_741_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_742_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_742_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_742_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_743_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_743_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_743_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_744_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_744_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_744_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_745_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_745_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_745_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_746_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_746_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_746_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_747_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_747_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_747_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_748_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_748_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_748_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_749_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_749_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_749_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_750_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_750_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_750_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_751_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_751_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_751_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_752_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_752_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_752_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_753_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_753_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_753_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_754_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_754_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_754_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_755_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_755_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_755_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_756_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_756_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_756_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_757_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_757_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_757_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_758_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_758_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_758_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_759_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_759_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_759_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_760_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_760_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_760_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_761_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_761_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_761_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_762_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_762_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_762_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_763_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_763_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_763_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_764_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_764_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_764_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_765_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_765_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_765_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_766_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_766_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_766_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_767_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_767_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG23_ENA_STATUS_767_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG23_RESETVAL (0x00000000u)

/* ena_status_reg24 */

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_768_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_768_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_768_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_769_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_769_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_769_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_770_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_770_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_770_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_771_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_771_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_771_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_772_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_772_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_772_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_773_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_773_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_773_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_774_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_774_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_774_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_775_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_775_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_775_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_776_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_776_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_776_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_777_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_777_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_777_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_778_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_778_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_778_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_779_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_779_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_779_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_780_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_780_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_780_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_781_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_781_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_781_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_782_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_782_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_782_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_783_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_783_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_783_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_784_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_784_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_784_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_785_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_785_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_785_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_786_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_786_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_786_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_787_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_787_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_787_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_788_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_788_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_788_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_789_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_789_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_789_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_790_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_790_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_790_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_791_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_791_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_791_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_792_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_792_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_792_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_793_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_793_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_793_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_794_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_794_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_794_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_795_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_795_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_795_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_796_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_796_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_796_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_797_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_797_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_797_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_798_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_798_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_798_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_799_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_799_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG24_ENA_STATUS_799_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG24_RESETVAL (0x00000000u)

/* ena_status_reg25 */

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_800_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_800_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_800_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_801_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_801_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_801_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_802_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_802_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_802_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_803_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_803_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_803_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_804_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_804_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_804_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_805_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_805_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_805_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_806_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_806_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_806_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_807_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_807_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_807_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_808_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_808_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_808_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_809_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_809_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_809_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_810_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_810_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_810_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_811_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_811_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_811_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_812_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_812_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_812_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_813_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_813_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_813_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_814_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_814_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_814_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_815_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_815_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_815_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_816_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_816_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_816_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_817_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_817_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_817_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_818_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_818_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_818_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_819_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_819_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_819_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_820_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_820_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_820_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_821_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_821_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_821_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_822_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_822_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_822_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_823_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_823_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_823_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_824_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_824_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_824_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_825_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_825_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_825_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_826_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_826_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_826_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_827_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_827_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_827_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_828_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_828_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_828_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_829_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_829_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_829_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_830_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_830_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_830_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_831_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_831_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG25_ENA_STATUS_831_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG25_RESETVAL (0x00000000u)

/* ena_status_reg26 */

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_832_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_832_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_832_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_833_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_833_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_833_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_834_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_834_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_834_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_835_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_835_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_835_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_836_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_836_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_836_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_837_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_837_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_837_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_838_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_838_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_838_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_839_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_839_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_839_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_840_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_840_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_840_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_841_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_841_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_841_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_842_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_842_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_842_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_843_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_843_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_843_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_844_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_844_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_844_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_845_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_845_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_845_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_846_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_846_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_846_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_847_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_847_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_847_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_848_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_848_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_848_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_849_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_849_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_849_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_850_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_850_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_850_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_851_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_851_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_851_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_852_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_852_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_852_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_853_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_853_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_853_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_854_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_854_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_854_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_855_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_855_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_855_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_856_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_856_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_856_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_857_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_857_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_857_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_858_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_858_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_858_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_859_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_859_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_859_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_860_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_860_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_860_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_861_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_861_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_861_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_862_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_862_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_862_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_863_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_863_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG26_ENA_STATUS_863_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG26_RESETVAL (0x00000000u)

/* ena_status_reg27 */

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_864_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_864_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_864_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_865_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_865_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_865_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_866_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_866_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_866_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_867_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_867_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_867_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_868_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_868_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_868_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_869_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_869_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_869_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_870_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_870_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_870_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_871_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_871_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_871_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_872_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_872_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_872_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_873_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_873_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_873_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_874_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_874_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_874_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_875_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_875_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_875_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_876_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_876_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_876_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_877_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_877_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_877_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_878_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_878_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_878_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_879_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_879_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_879_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_880_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_880_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_880_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_881_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_881_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_881_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_882_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_882_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_882_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_883_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_883_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_883_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_884_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_884_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_884_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_885_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_885_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_885_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_886_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_886_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_886_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_887_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_887_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_887_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_888_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_888_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_888_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_889_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_889_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_889_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_890_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_890_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_890_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_891_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_891_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_891_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_892_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_892_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_892_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_893_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_893_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_893_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_894_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_894_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_894_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_895_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_895_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG27_ENA_STATUS_895_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG27_RESETVAL (0x00000000u)

/* ena_status_reg28 */

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_896_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_896_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_896_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_897_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_897_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_897_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_898_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_898_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_898_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_899_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_899_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_899_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_900_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_900_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_900_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_901_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_901_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_901_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_902_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_902_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_902_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_903_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_903_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_903_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_904_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_904_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_904_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_905_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_905_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_905_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_906_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_906_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_906_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_907_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_907_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_907_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_908_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_908_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_908_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_909_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_909_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_909_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_910_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_910_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_910_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_911_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_911_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_911_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_912_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_912_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_912_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_913_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_913_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_913_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_914_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_914_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_914_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_915_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_915_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_915_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_916_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_916_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_916_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_917_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_917_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_917_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_918_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_918_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_918_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_919_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_919_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_919_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_920_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_920_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_920_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_921_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_921_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_921_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_922_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_922_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_922_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_923_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_923_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_923_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_924_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_924_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_924_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_925_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_925_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_925_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_926_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_926_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_926_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_927_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_927_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG28_ENA_STATUS_927_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG28_RESETVAL (0x00000000u)

/* ena_status_reg29 */

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_928_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_928_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_928_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_929_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_929_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_929_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_930_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_930_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_930_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_931_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_931_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_931_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_932_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_932_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_932_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_933_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_933_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_933_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_934_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_934_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_934_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_935_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_935_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_935_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_936_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_936_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_936_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_937_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_937_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_937_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_938_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_938_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_938_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_939_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_939_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_939_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_940_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_940_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_940_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_941_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_941_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_941_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_942_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_942_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_942_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_943_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_943_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_943_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_944_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_944_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_944_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_945_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_945_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_945_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_946_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_946_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_946_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_947_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_947_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_947_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_948_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_948_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_948_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_949_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_949_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_949_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_950_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_950_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_950_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_951_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_951_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_951_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_952_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_952_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_952_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_953_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_953_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_953_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_954_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_954_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_954_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_955_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_955_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_955_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_956_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_956_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_956_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_957_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_957_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_957_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_958_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_958_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_958_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_959_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_959_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG29_ENA_STATUS_959_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG29_RESETVAL (0x00000000u)

/* ena_status_reg30 */

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_960_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_960_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_960_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_961_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_961_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_961_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_962_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_962_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_962_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_963_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_963_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_963_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_964_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_964_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_964_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_965_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_965_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_965_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_966_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_966_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_966_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_967_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_967_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_967_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_968_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_968_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_968_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_969_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_969_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_969_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_970_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_970_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_970_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_971_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_971_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_971_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_972_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_972_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_972_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_973_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_973_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_973_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_974_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_974_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_974_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_975_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_975_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_975_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_976_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_976_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_976_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_977_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_977_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_977_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_978_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_978_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_978_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_979_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_979_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_979_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_980_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_980_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_980_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_981_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_981_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_981_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_982_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_982_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_982_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_983_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_983_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_983_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_984_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_984_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_984_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_985_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_985_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_985_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_986_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_986_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_986_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_987_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_987_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_987_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_988_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_988_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_988_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_989_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_989_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_989_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_990_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_990_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_990_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_991_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_991_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG30_ENA_STATUS_991_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG30_RESETVAL (0x00000000u)

/* ena_status_reg31 */

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_992_MASK (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_992_SHIFT (0x00000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_992_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_993_MASK (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_993_SHIFT (0x00000001u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_993_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_994_MASK (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_994_SHIFT (0x00000002u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_994_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_995_MASK (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_995_SHIFT (0x00000003u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_995_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_996_MASK (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_996_SHIFT (0x00000004u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_996_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_997_MASK (0x00000020u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_997_SHIFT (0x00000005u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_997_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_998_MASK (0x00000040u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_998_SHIFT (0x00000006u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_998_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_999_MASK (0x00000080u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_999_SHIFT (0x00000007u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_999_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1000_MASK (0x00000100u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1000_SHIFT (0x00000008u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1000_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1001_MASK (0x00000200u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1001_SHIFT (0x00000009u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1001_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1002_MASK (0x00000400u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1002_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1002_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1003_MASK (0x00000800u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1003_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1003_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1004_MASK (0x00001000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1004_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1004_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1005_MASK (0x00002000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1005_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1005_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1006_MASK (0x00004000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1006_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1006_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1007_MASK (0x00008000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1007_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1007_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1008_MASK (0x00010000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1008_SHIFT (0x00000010u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1008_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1009_MASK (0x00020000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1009_SHIFT (0x00000011u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1009_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1010_MASK (0x00040000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1010_SHIFT (0x00000012u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1010_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1011_MASK (0x00080000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1011_SHIFT (0x00000013u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1011_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1012_MASK (0x00100000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1012_SHIFT (0x00000014u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1012_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1013_MASK (0x00200000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1013_SHIFT (0x00000015u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1013_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1014_MASK (0x00400000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1014_SHIFT (0x00000016u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1014_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1015_MASK (0x00800000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1015_SHIFT (0x00000017u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1015_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1016_MASK (0x01000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1016_SHIFT (0x00000018u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1016_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1017_MASK (0x02000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1017_SHIFT (0x00000019u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1017_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1018_MASK (0x04000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1018_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1018_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1019_MASK (0x08000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1019_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1019_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1020_MASK (0x10000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1020_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1020_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1021_MASK (0x20000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1021_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1021_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1022_MASK (0x40000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1022_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1022_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1023_MASK (0x80000000u)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1023_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENA_STATUS_REG31_ENA_STATUS_1023_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENA_STATUS_REG31_RESETVAL (0x00000000u)

/* enable_reg0 */

#define CSL_CPINTC_ENABLE_REG0_ENABLE_0_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_0_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_1_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_1_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_2_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_2_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_3_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_3_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_4_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_4_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_5_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_5_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_6_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_6_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_7_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_7_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_8_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_8_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_9_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_9_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_10_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_10_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_11_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_11_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_12_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_12_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_13_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_13_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_14_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_14_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_15_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_15_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_16_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_16_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_17_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_17_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_18_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_18_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_19_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_19_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_20_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_20_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_21_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_21_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_22_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_22_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_23_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_23_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_24_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_24_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_25_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_25_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_26_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_26_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_27_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_27_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_28_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_28_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_29_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_29_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_30_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_30_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_ENABLE_31_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG0_ENABLE_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG0_RESETVAL  (0x00000000u)

/* enable_reg1 */

#define CSL_CPINTC_ENABLE_REG1_ENABLE_32_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_32_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_33_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_33_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_34_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_34_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_35_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_35_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_36_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_36_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_37_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_37_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_38_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_38_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_39_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_39_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_40_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_40_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_41_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_41_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_42_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_42_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_43_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_43_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_44_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_44_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_45_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_45_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_46_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_46_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_47_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_47_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_48_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_48_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_49_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_49_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_50_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_50_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_51_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_51_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_52_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_52_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_53_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_53_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_54_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_54_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_55_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_55_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_56_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_56_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_57_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_57_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_58_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_58_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_59_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_59_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_60_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_60_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_61_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_61_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_62_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_62_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_ENABLE_63_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG1_ENABLE_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG1_RESETVAL  (0x00000000u)

/* enable_reg2 */

#define CSL_CPINTC_ENABLE_REG2_ENABLE_64_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_64_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_65_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_65_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_66_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_66_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_67_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_67_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_68_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_68_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_69_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_69_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_70_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_70_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_71_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_71_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_72_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_72_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_73_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_73_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_74_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_74_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_75_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_75_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_76_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_76_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_77_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_77_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_78_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_78_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_79_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_79_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_80_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_80_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_81_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_81_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_82_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_82_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_83_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_83_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_84_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_84_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_85_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_85_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_86_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_86_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_87_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_87_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_88_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_88_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_89_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_89_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_90_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_90_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_91_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_91_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_92_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_92_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_93_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_93_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_94_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_94_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_ENABLE_95_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_95_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG2_ENABLE_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG2_RESETVAL  (0x00000000u)

/* enable_reg3 */

#define CSL_CPINTC_ENABLE_REG3_ENABLE_96_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_96_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_97_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_97_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_98_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_98_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_99_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_99_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_100_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_100_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_101_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_101_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_102_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_102_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_103_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_103_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_104_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_104_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_105_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_105_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_106_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_106_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_107_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_107_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_108_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_108_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_109_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_109_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_110_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_110_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_111_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_111_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_112_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_112_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_113_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_113_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_114_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_114_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_115_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_115_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_116_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_116_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_117_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_117_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_118_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_118_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_119_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_119_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_120_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_120_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_121_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_121_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_122_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_122_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_123_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_123_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_124_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_124_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_125_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_125_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_126_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_126_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_ENABLE_127_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_127_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG3_ENABLE_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG3_RESETVAL  (0x00000000u)

/* enable_reg4 */

#define CSL_CPINTC_ENABLE_REG4_ENABLE_128_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_128_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_129_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_129_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_130_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_130_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_131_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_131_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_132_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_132_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_133_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_133_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_134_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_134_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_135_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_135_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_136_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_136_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_137_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_137_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_138_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_138_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_139_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_139_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_140_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_140_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_141_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_141_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_142_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_142_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_143_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_143_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_144_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_144_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_145_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_145_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_146_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_146_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_147_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_147_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_148_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_148_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_149_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_149_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_150_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_150_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_151_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_151_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_152_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_152_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_153_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_153_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_154_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_154_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_155_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_155_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_156_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_156_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_157_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_157_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_158_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_158_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_ENABLE_159_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_159_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG4_ENABLE_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG4_RESETVAL  (0x00000000u)

/* enable_reg5 */

#define CSL_CPINTC_ENABLE_REG5_ENABLE_160_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_160_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_161_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_161_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_162_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_162_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_163_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_163_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_164_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_164_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_165_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_165_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_166_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_166_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_167_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_167_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_168_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_168_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_169_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_169_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_170_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_170_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_171_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_171_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_172_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_172_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_173_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_173_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_174_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_174_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_175_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_175_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_176_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_176_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_177_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_177_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_178_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_178_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_179_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_179_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_180_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_180_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_181_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_181_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_182_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_182_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_183_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_183_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_184_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_184_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_185_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_185_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_186_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_186_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_187_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_187_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_188_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_188_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_189_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_189_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_190_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_190_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_ENABLE_191_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_191_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG5_ENABLE_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG5_RESETVAL  (0x00000000u)

/* enable_reg6 */

#define CSL_CPINTC_ENABLE_REG6_ENABLE_192_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_192_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_193_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_193_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_194_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_194_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_195_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_195_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_196_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_196_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_197_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_197_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_198_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_198_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_199_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_199_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_200_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_200_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_201_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_201_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_202_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_202_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_203_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_203_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_204_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_204_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_205_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_205_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_206_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_206_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_207_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_207_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_208_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_208_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_209_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_209_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_210_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_210_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_211_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_211_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_212_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_212_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_213_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_213_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_214_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_214_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_215_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_215_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_216_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_216_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_217_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_217_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_218_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_218_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_219_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_219_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_220_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_220_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_221_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_221_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_222_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_222_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_ENABLE_223_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_223_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG6_ENABLE_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG6_RESETVAL  (0x00000000u)

/* enable_reg7 */

#define CSL_CPINTC_ENABLE_REG7_ENABLE_224_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_224_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_225_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_225_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_226_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_226_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_227_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_227_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_228_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_228_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_229_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_229_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_230_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_230_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_231_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_231_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_232_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_232_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_233_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_233_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_234_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_234_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_235_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_235_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_236_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_236_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_237_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_237_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_238_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_238_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_239_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_239_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_240_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_240_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_241_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_241_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_242_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_242_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_243_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_243_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_244_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_244_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_245_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_245_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_246_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_246_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_247_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_247_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_248_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_248_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_249_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_249_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_250_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_250_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_251_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_251_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_252_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_252_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_253_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_253_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_254_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_254_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_ENABLE_255_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_255_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG7_ENABLE_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG7_RESETVAL  (0x00000000u)

/* enable_reg8 */

#define CSL_CPINTC_ENABLE_REG8_ENABLE_256_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_256_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_256_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_257_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_257_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_257_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_258_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_258_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_258_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_259_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_259_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_259_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_260_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_260_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_260_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_261_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_261_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_261_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_262_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_262_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_262_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_263_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_263_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_263_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_264_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_264_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_264_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_265_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_265_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_265_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_266_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_266_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_266_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_267_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_267_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_267_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_268_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_268_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_268_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_269_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_269_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_269_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_270_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_270_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_270_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_271_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_271_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_271_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_272_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_272_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_272_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_273_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_273_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_273_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_274_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_274_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_274_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_275_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_275_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_275_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_276_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_276_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_276_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_277_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_277_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_277_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_278_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_278_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_278_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_279_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_279_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_279_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_280_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_280_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_280_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_281_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_281_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_281_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_282_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_282_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_282_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_283_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_283_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_283_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_284_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_284_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_284_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_285_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_285_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_285_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_286_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_286_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_286_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_ENABLE_287_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_287_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG8_ENABLE_287_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG8_RESETVAL  (0x00000000u)

/* enable_reg9 */

#define CSL_CPINTC_ENABLE_REG9_ENABLE_288_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_288_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_288_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_289_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_289_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_289_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_290_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_290_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_290_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_291_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_291_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_291_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_292_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_292_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_292_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_293_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_293_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_293_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_294_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_294_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_294_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_295_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_295_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_295_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_296_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_296_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_296_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_297_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_297_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_297_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_298_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_298_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_298_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_299_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_299_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_299_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_300_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_300_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_300_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_301_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_301_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_301_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_302_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_302_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_302_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_303_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_303_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_303_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_304_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_304_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_304_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_305_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_305_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_305_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_306_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_306_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_306_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_307_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_307_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_307_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_308_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_308_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_308_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_309_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_309_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_309_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_310_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_310_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_310_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_311_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_311_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_311_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_312_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_312_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_312_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_313_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_313_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_313_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_314_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_314_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_314_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_315_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_315_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_315_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_316_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_316_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_316_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_317_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_317_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_317_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_318_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_318_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_318_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_ENABLE_319_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_319_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG9_ENABLE_319_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG9_RESETVAL  (0x00000000u)

/* enable_reg10 */

#define CSL_CPINTC_ENABLE_REG10_ENABLE_320_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_320_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_320_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_321_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_321_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_321_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_322_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_322_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_322_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_323_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_323_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_323_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_324_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_324_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_324_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_325_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_325_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_325_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_326_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_326_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_326_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_327_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_327_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_327_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_328_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_328_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_328_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_329_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_329_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_329_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_330_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_330_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_330_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_331_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_331_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_331_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_332_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_332_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_332_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_333_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_333_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_333_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_334_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_334_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_334_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_335_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_335_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_335_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_336_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_336_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_336_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_337_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_337_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_337_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_338_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_338_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_338_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_339_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_339_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_339_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_340_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_340_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_340_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_341_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_341_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_341_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_342_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_342_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_342_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_343_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_343_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_343_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_344_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_344_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_344_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_345_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_345_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_345_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_346_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_346_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_346_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_347_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_347_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_347_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_348_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_348_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_348_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_349_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_349_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_349_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_350_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_350_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_350_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_ENABLE_351_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_351_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG10_ENABLE_351_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG10_RESETVAL (0x00000000u)

/* enable_reg11 */

#define CSL_CPINTC_ENABLE_REG11_ENABLE_352_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_352_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_352_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_353_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_353_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_353_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_354_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_354_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_354_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_355_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_355_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_355_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_356_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_356_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_356_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_357_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_357_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_357_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_358_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_358_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_358_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_359_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_359_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_359_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_360_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_360_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_360_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_361_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_361_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_361_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_362_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_362_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_362_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_363_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_363_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_363_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_364_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_364_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_364_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_365_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_365_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_365_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_366_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_366_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_366_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_367_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_367_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_367_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_368_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_368_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_368_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_369_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_369_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_369_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_370_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_370_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_370_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_371_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_371_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_371_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_372_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_372_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_372_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_373_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_373_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_373_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_374_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_374_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_374_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_375_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_375_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_375_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_376_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_376_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_376_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_377_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_377_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_377_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_378_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_378_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_378_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_379_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_379_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_379_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_380_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_380_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_380_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_381_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_381_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_381_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_382_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_382_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_382_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_ENABLE_383_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_383_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG11_ENABLE_383_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG11_RESETVAL (0x00000000u)

/* enable_reg12 */

#define CSL_CPINTC_ENABLE_REG12_ENABLE_384_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_384_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_384_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_385_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_385_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_385_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_386_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_386_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_386_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_387_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_387_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_387_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_388_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_388_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_388_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_389_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_389_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_389_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_390_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_390_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_390_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_391_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_391_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_391_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_392_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_392_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_392_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_393_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_393_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_393_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_394_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_394_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_394_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_395_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_395_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_395_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_396_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_396_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_396_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_397_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_397_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_397_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_398_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_398_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_398_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_399_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_399_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_399_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_400_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_400_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_400_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_401_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_401_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_401_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_402_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_402_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_402_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_403_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_403_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_403_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_404_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_404_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_404_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_405_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_405_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_405_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_406_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_406_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_406_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_407_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_407_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_407_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_408_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_408_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_408_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_409_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_409_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_409_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_410_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_410_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_410_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_411_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_411_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_411_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_412_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_412_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_412_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_413_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_413_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_413_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_414_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_414_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_414_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_ENABLE_415_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_415_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG12_ENABLE_415_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG12_RESETVAL (0x00000000u)

/* enable_reg13 */

#define CSL_CPINTC_ENABLE_REG13_ENABLE_416_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_416_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_416_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_417_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_417_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_417_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_418_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_418_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_418_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_419_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_419_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_419_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_420_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_420_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_420_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_421_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_421_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_421_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_422_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_422_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_422_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_423_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_423_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_423_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_424_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_424_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_424_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_425_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_425_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_425_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_426_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_426_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_426_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_427_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_427_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_427_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_428_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_428_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_428_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_429_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_429_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_429_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_430_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_430_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_430_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_431_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_431_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_431_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_432_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_432_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_432_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_433_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_433_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_433_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_434_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_434_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_434_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_435_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_435_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_435_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_436_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_436_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_436_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_437_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_437_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_437_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_438_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_438_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_438_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_439_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_439_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_439_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_440_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_440_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_440_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_441_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_441_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_441_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_442_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_442_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_442_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_443_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_443_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_443_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_444_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_444_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_444_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_445_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_445_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_445_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_446_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_446_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_446_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_ENABLE_447_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_447_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG13_ENABLE_447_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG13_RESETVAL (0x00000000u)

/* enable_reg14 */

#define CSL_CPINTC_ENABLE_REG14_ENABLE_448_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_448_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_448_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_449_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_449_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_449_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_450_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_450_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_450_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_451_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_451_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_451_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_452_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_452_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_452_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_453_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_453_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_453_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_454_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_454_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_454_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_455_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_455_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_455_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_456_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_456_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_456_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_457_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_457_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_457_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_458_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_458_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_458_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_459_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_459_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_459_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_460_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_460_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_460_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_461_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_461_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_461_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_462_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_462_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_462_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_463_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_463_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_463_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_464_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_464_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_464_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_465_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_465_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_465_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_466_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_466_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_466_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_467_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_467_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_467_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_468_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_468_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_468_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_469_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_469_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_469_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_470_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_470_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_470_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_471_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_471_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_471_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_472_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_472_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_472_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_473_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_473_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_473_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_474_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_474_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_474_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_475_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_475_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_475_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_476_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_476_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_476_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_477_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_477_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_477_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_478_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_478_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_478_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_ENABLE_479_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_479_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG14_ENABLE_479_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG14_RESETVAL (0x00000000u)

/* enable_reg15 */

#define CSL_CPINTC_ENABLE_REG15_ENABLE_480_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_480_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_480_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_481_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_481_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_481_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_482_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_482_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_482_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_483_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_483_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_483_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_484_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_484_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_484_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_485_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_485_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_485_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_486_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_486_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_486_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_487_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_487_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_487_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_488_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_488_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_488_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_489_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_489_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_489_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_490_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_490_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_490_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_491_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_491_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_491_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_492_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_492_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_492_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_493_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_493_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_493_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_494_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_494_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_494_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_495_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_495_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_495_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_496_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_496_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_496_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_497_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_497_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_497_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_498_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_498_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_498_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_499_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_499_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_499_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_500_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_500_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_500_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_501_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_501_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_501_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_502_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_502_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_502_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_503_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_503_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_503_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_504_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_504_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_504_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_505_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_505_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_505_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_506_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_506_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_506_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_507_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_507_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_507_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_508_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_508_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_508_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_509_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_509_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_509_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_510_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_510_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_510_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_ENABLE_511_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_511_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG15_ENABLE_511_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG15_RESETVAL (0x00000000u)

/* enable_reg16 */

#define CSL_CPINTC_ENABLE_REG16_ENABLE_512_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_512_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_512_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_513_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_513_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_513_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_514_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_514_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_514_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_515_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_515_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_515_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_516_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_516_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_516_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_517_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_517_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_517_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_518_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_518_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_518_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_519_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_519_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_519_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_520_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_520_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_520_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_521_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_521_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_521_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_522_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_522_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_522_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_523_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_523_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_523_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_524_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_524_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_524_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_525_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_525_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_525_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_526_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_526_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_526_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_527_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_527_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_527_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_528_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_528_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_528_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_529_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_529_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_529_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_530_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_530_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_530_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_531_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_531_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_531_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_532_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_532_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_532_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_533_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_533_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_533_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_534_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_534_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_534_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_535_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_535_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_535_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_536_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_536_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_536_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_537_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_537_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_537_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_538_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_538_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_538_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_539_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_539_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_539_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_540_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_540_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_540_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_541_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_541_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_541_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_542_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_542_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_542_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_ENABLE_543_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_543_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG16_ENABLE_543_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG16_RESETVAL (0x00000000u)

/* enable_reg17 */

#define CSL_CPINTC_ENABLE_REG17_ENABLE_544_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_544_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_544_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_545_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_545_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_545_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_546_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_546_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_546_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_547_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_547_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_547_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_548_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_548_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_548_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_549_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_549_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_549_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_550_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_550_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_550_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_551_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_551_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_551_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_552_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_552_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_552_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_553_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_553_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_553_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_554_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_554_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_554_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_555_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_555_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_555_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_556_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_556_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_556_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_557_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_557_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_557_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_558_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_558_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_558_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_559_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_559_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_559_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_560_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_560_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_560_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_561_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_561_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_561_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_562_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_562_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_562_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_563_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_563_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_563_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_564_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_564_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_564_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_565_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_565_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_565_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_566_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_566_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_566_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_567_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_567_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_567_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_568_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_568_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_568_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_569_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_569_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_569_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_570_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_570_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_570_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_571_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_571_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_571_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_572_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_572_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_572_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_573_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_573_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_573_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_574_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_574_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_574_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_ENABLE_575_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_575_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG17_ENABLE_575_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG17_RESETVAL (0x00000000u)

/* enable_reg18 */

#define CSL_CPINTC_ENABLE_REG18_ENABLE_576_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_576_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_576_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_577_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_577_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_577_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_578_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_578_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_578_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_579_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_579_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_579_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_580_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_580_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_580_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_581_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_581_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_581_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_582_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_582_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_582_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_583_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_583_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_583_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_584_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_584_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_584_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_585_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_585_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_585_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_586_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_586_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_586_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_587_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_587_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_587_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_588_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_588_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_588_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_589_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_589_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_589_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_590_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_590_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_590_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_591_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_591_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_591_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_592_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_592_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_592_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_593_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_593_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_593_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_594_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_594_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_594_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_595_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_595_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_595_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_596_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_596_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_596_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_597_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_597_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_597_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_598_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_598_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_598_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_599_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_599_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_599_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_600_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_600_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_600_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_601_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_601_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_601_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_602_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_602_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_602_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_603_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_603_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_603_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_604_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_604_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_604_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_605_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_605_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_605_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_606_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_606_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_606_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_ENABLE_607_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_607_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG18_ENABLE_607_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG18_RESETVAL (0x00000000u)

/* enable_reg19 */

#define CSL_CPINTC_ENABLE_REG19_ENABLE_608_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_608_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_608_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_609_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_609_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_609_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_610_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_610_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_610_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_611_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_611_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_611_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_612_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_612_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_612_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_613_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_613_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_613_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_614_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_614_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_614_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_615_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_615_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_615_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_616_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_616_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_616_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_617_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_617_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_617_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_618_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_618_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_618_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_619_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_619_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_619_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_620_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_620_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_620_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_621_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_621_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_621_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_622_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_622_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_622_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_623_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_623_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_623_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_624_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_624_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_624_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_625_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_625_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_625_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_626_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_626_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_626_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_627_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_627_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_627_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_628_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_628_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_628_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_629_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_629_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_629_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_630_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_630_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_630_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_631_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_631_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_631_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_632_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_632_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_632_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_633_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_633_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_633_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_634_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_634_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_634_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_635_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_635_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_635_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_636_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_636_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_636_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_637_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_637_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_637_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_638_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_638_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_638_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_ENABLE_639_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_639_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG19_ENABLE_639_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG19_RESETVAL (0x00000000u)

/* enable_reg20 */

#define CSL_CPINTC_ENABLE_REG20_ENABLE_640_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_640_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_640_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_641_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_641_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_641_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_642_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_642_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_642_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_643_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_643_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_643_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_644_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_644_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_644_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_645_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_645_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_645_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_646_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_646_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_646_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_647_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_647_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_647_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_648_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_648_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_648_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_649_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_649_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_649_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_650_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_650_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_650_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_651_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_651_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_651_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_652_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_652_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_652_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_653_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_653_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_653_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_654_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_654_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_654_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_655_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_655_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_655_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_656_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_656_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_656_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_657_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_657_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_657_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_658_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_658_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_658_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_659_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_659_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_659_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_660_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_660_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_660_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_661_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_661_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_661_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_662_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_662_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_662_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_663_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_663_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_663_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_664_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_664_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_664_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_665_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_665_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_665_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_666_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_666_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_666_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_667_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_667_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_667_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_668_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_668_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_668_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_669_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_669_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_669_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_670_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_670_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_670_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_ENABLE_671_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_671_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG20_ENABLE_671_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG20_RESETVAL (0x00000000u)

/* enable_reg21 */

#define CSL_CPINTC_ENABLE_REG21_ENABLE_672_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_672_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_672_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_673_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_673_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_673_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_674_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_674_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_674_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_675_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_675_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_675_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_676_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_676_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_676_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_677_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_677_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_677_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_678_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_678_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_678_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_679_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_679_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_679_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_680_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_680_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_680_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_681_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_681_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_681_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_682_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_682_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_682_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_683_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_683_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_683_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_684_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_684_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_684_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_685_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_685_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_685_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_686_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_686_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_686_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_687_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_687_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_687_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_688_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_688_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_688_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_689_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_689_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_689_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_690_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_690_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_690_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_691_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_691_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_691_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_692_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_692_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_692_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_693_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_693_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_693_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_694_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_694_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_694_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_695_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_695_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_695_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_696_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_696_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_696_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_697_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_697_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_697_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_698_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_698_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_698_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_699_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_699_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_699_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_700_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_700_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_700_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_701_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_701_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_701_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_702_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_702_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_702_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_ENABLE_703_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_703_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG21_ENABLE_703_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG21_RESETVAL (0x00000000u)

/* enable_reg22 */

#define CSL_CPINTC_ENABLE_REG22_ENABLE_704_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_704_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_704_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_705_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_705_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_705_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_706_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_706_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_706_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_707_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_707_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_707_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_708_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_708_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_708_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_709_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_709_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_709_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_710_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_710_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_710_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_711_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_711_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_711_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_712_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_712_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_712_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_713_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_713_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_713_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_714_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_714_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_714_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_715_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_715_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_715_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_716_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_716_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_716_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_717_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_717_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_717_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_718_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_718_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_718_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_719_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_719_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_719_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_720_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_720_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_720_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_721_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_721_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_721_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_722_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_722_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_722_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_723_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_723_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_723_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_724_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_724_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_724_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_725_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_725_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_725_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_726_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_726_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_726_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_727_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_727_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_727_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_728_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_728_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_728_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_729_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_729_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_729_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_730_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_730_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_730_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_731_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_731_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_731_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_732_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_732_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_732_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_733_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_733_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_733_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_734_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_734_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_734_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_ENABLE_735_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_735_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG22_ENABLE_735_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG22_RESETVAL (0x00000000u)

/* enable_reg23 */

#define CSL_CPINTC_ENABLE_REG23_ENABLE_736_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_736_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_736_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_737_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_737_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_737_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_738_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_738_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_738_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_739_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_739_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_739_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_740_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_740_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_740_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_741_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_741_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_741_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_742_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_742_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_742_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_743_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_743_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_743_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_744_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_744_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_744_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_745_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_745_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_745_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_746_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_746_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_746_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_747_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_747_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_747_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_748_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_748_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_748_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_749_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_749_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_749_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_750_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_750_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_750_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_751_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_751_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_751_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_752_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_752_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_752_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_753_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_753_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_753_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_754_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_754_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_754_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_755_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_755_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_755_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_756_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_756_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_756_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_757_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_757_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_757_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_758_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_758_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_758_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_759_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_759_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_759_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_760_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_760_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_760_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_761_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_761_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_761_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_762_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_762_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_762_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_763_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_763_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_763_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_764_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_764_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_764_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_765_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_765_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_765_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_766_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_766_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_766_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_ENABLE_767_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_767_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG23_ENABLE_767_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG23_RESETVAL (0x00000000u)

/* enable_reg24 */

#define CSL_CPINTC_ENABLE_REG24_ENABLE_768_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_768_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_768_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_769_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_769_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_769_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_770_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_770_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_770_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_771_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_771_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_771_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_772_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_772_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_772_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_773_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_773_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_773_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_774_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_774_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_774_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_775_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_775_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_775_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_776_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_776_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_776_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_777_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_777_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_777_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_778_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_778_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_778_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_779_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_779_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_779_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_780_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_780_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_780_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_781_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_781_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_781_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_782_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_782_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_782_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_783_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_783_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_783_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_784_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_784_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_784_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_785_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_785_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_785_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_786_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_786_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_786_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_787_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_787_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_787_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_788_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_788_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_788_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_789_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_789_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_789_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_790_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_790_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_790_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_791_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_791_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_791_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_792_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_792_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_792_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_793_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_793_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_793_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_794_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_794_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_794_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_795_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_795_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_795_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_796_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_796_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_796_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_797_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_797_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_797_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_798_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_798_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_798_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_ENABLE_799_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_799_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG24_ENABLE_799_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG24_RESETVAL (0x00000000u)

/* enable_reg25 */

#define CSL_CPINTC_ENABLE_REG25_ENABLE_800_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_800_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_800_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_801_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_801_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_801_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_802_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_802_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_802_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_803_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_803_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_803_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_804_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_804_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_804_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_805_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_805_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_805_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_806_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_806_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_806_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_807_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_807_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_807_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_808_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_808_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_808_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_809_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_809_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_809_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_810_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_810_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_810_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_811_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_811_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_811_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_812_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_812_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_812_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_813_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_813_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_813_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_814_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_814_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_814_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_815_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_815_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_815_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_816_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_816_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_816_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_817_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_817_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_817_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_818_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_818_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_818_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_819_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_819_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_819_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_820_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_820_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_820_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_821_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_821_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_821_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_822_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_822_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_822_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_823_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_823_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_823_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_824_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_824_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_824_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_825_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_825_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_825_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_826_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_826_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_826_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_827_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_827_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_827_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_828_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_828_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_828_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_829_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_829_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_829_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_830_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_830_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_830_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_ENABLE_831_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_831_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG25_ENABLE_831_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG25_RESETVAL (0x00000000u)

/* enable_reg26 */

#define CSL_CPINTC_ENABLE_REG26_ENABLE_832_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_832_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_832_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_833_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_833_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_833_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_834_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_834_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_834_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_835_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_835_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_835_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_836_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_836_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_836_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_837_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_837_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_837_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_838_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_838_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_838_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_839_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_839_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_839_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_840_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_840_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_840_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_841_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_841_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_841_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_842_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_842_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_842_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_843_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_843_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_843_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_844_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_844_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_844_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_845_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_845_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_845_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_846_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_846_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_846_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_847_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_847_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_847_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_848_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_848_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_848_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_849_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_849_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_849_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_850_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_850_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_850_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_851_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_851_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_851_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_852_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_852_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_852_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_853_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_853_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_853_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_854_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_854_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_854_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_855_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_855_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_855_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_856_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_856_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_856_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_857_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_857_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_857_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_858_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_858_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_858_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_859_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_859_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_859_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_860_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_860_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_860_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_861_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_861_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_861_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_862_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_862_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_862_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_ENABLE_863_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_863_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG26_ENABLE_863_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG26_RESETVAL (0x00000000u)

/* enable_reg27 */

#define CSL_CPINTC_ENABLE_REG27_ENABLE_864_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_864_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_864_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_865_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_865_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_865_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_866_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_866_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_866_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_867_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_867_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_867_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_868_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_868_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_868_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_869_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_869_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_869_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_870_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_870_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_870_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_871_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_871_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_871_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_872_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_872_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_872_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_873_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_873_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_873_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_874_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_874_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_874_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_875_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_875_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_875_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_876_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_876_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_876_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_877_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_877_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_877_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_878_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_878_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_878_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_879_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_879_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_879_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_880_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_880_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_880_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_881_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_881_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_881_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_882_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_882_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_882_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_883_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_883_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_883_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_884_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_884_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_884_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_885_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_885_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_885_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_886_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_886_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_886_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_887_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_887_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_887_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_888_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_888_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_888_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_889_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_889_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_889_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_890_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_890_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_890_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_891_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_891_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_891_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_892_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_892_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_892_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_893_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_893_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_893_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_894_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_894_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_894_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_ENABLE_895_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_895_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG27_ENABLE_895_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG27_RESETVAL (0x00000000u)

/* enable_reg28 */

#define CSL_CPINTC_ENABLE_REG28_ENABLE_896_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_896_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_896_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_897_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_897_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_897_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_898_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_898_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_898_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_899_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_899_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_899_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_900_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_900_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_900_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_901_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_901_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_901_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_902_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_902_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_902_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_903_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_903_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_903_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_904_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_904_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_904_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_905_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_905_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_905_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_906_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_906_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_906_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_907_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_907_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_907_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_908_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_908_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_908_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_909_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_909_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_909_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_910_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_910_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_910_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_911_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_911_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_911_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_912_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_912_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_912_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_913_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_913_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_913_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_914_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_914_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_914_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_915_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_915_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_915_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_916_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_916_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_916_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_917_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_917_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_917_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_918_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_918_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_918_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_919_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_919_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_919_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_920_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_920_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_920_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_921_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_921_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_921_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_922_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_922_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_922_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_923_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_923_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_923_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_924_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_924_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_924_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_925_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_925_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_925_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_926_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_926_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_926_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_ENABLE_927_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_927_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG28_ENABLE_927_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG28_RESETVAL (0x00000000u)

/* enable_reg29 */

#define CSL_CPINTC_ENABLE_REG29_ENABLE_928_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_928_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_928_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_929_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_929_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_929_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_930_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_930_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_930_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_931_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_931_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_931_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_932_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_932_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_932_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_933_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_933_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_933_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_934_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_934_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_934_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_935_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_935_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_935_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_936_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_936_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_936_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_937_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_937_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_937_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_938_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_938_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_938_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_939_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_939_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_939_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_940_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_940_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_940_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_941_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_941_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_941_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_942_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_942_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_942_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_943_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_943_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_943_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_944_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_944_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_944_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_945_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_945_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_945_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_946_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_946_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_946_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_947_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_947_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_947_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_948_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_948_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_948_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_949_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_949_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_949_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_950_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_950_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_950_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_951_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_951_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_951_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_952_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_952_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_952_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_953_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_953_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_953_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_954_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_954_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_954_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_955_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_955_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_955_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_956_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_956_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_956_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_957_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_957_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_957_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_958_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_958_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_958_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_ENABLE_959_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_959_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG29_ENABLE_959_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG29_RESETVAL (0x00000000u)

/* enable_reg30 */

#define CSL_CPINTC_ENABLE_REG30_ENABLE_960_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_960_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_960_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_961_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_961_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_961_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_962_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_962_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_962_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_963_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_963_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_963_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_964_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_964_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_964_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_965_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_965_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_965_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_966_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_966_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_966_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_967_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_967_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_967_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_968_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_968_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_968_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_969_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_969_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_969_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_970_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_970_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_970_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_971_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_971_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_971_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_972_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_972_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_972_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_973_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_973_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_973_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_974_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_974_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_974_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_975_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_975_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_975_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_976_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_976_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_976_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_977_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_977_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_977_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_978_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_978_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_978_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_979_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_979_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_979_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_980_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_980_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_980_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_981_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_981_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_981_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_982_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_982_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_982_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_983_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_983_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_983_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_984_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_984_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_984_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_985_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_985_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_985_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_986_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_986_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_986_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_987_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_987_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_987_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_988_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_988_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_988_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_989_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_989_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_989_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_990_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_990_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_990_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_ENABLE_991_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_991_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG30_ENABLE_991_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG30_RESETVAL (0x00000000u)

/* enable_reg31 */

#define CSL_CPINTC_ENABLE_REG31_ENABLE_992_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_992_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_992_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_993_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_993_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_993_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_994_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_994_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_994_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_995_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_995_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_995_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_996_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_996_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_996_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_997_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_997_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_997_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_998_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_998_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_998_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_999_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_999_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_999_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1000_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1000_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1000_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1001_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1001_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1001_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1002_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1002_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1002_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1003_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1003_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1003_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1004_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1004_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1004_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1005_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1005_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1005_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1006_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1006_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1006_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1007_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1007_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1007_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1008_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1008_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1008_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1009_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1009_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1009_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1010_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1010_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1010_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1011_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1011_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1011_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1012_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1012_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1012_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1013_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1013_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1013_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1014_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1014_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1014_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1015_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1015_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1015_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1016_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1016_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1016_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1017_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1017_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1017_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1018_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1018_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1018_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1019_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1019_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1019_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1020_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1020_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1020_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1021_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1021_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1021_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1022_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1022_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1022_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_ENABLE_1023_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1023_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_REG31_ENABLE_1023_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_REG31_RESETVAL (0x00000000u)

/* enable_clr_reg0 */

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_0_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_0_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_0_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_1_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_1_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_1_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_2_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_2_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_2_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_3_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_3_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_3_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_4_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_4_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_4_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_5_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_5_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_5_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_6_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_6_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_6_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_7_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_7_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_7_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_8_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_8_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_8_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_9_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_9_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_9_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_10_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_10_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_10_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_11_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_11_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_11_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_12_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_12_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_12_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_13_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_13_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_13_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_14_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_14_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_14_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_15_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_15_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_15_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_16_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_16_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_16_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_17_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_17_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_17_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_18_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_18_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_18_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_19_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_19_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_19_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_20_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_20_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_20_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_21_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_21_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_21_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_22_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_22_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_22_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_23_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_23_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_23_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_24_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_24_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_24_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_25_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_25_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_25_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_26_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_26_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_26_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_27_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_27_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_27_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_28_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_28_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_28_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_29_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_29_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_29_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_30_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_30_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_30_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_31_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_31_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG0_ENABLE_31_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG0_RESETVAL (0x00000000u)

/* enable_clr_reg1 */

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_32_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_32_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_32_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_33_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_33_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_33_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_34_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_34_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_34_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_35_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_35_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_35_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_36_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_36_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_36_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_37_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_37_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_37_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_38_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_38_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_38_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_39_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_39_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_39_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_40_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_40_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_40_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_41_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_41_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_41_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_42_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_42_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_42_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_43_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_43_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_43_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_44_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_44_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_44_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_45_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_45_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_45_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_46_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_46_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_46_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_47_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_47_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_47_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_48_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_48_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_48_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_49_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_49_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_49_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_50_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_50_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_50_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_51_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_51_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_51_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_52_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_52_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_52_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_53_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_53_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_53_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_54_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_54_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_54_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_55_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_55_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_55_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_56_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_56_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_56_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_57_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_57_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_57_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_58_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_58_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_58_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_59_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_59_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_59_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_60_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_60_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_60_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_61_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_61_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_61_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_62_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_62_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_62_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_63_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_63_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG1_ENABLE_63_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG1_RESETVAL (0x00000000u)

/* enable_clr_reg2 */

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_64_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_64_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_64_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_65_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_65_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_65_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_66_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_66_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_66_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_67_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_67_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_67_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_68_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_68_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_68_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_69_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_69_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_69_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_70_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_70_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_70_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_71_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_71_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_71_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_72_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_72_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_72_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_73_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_73_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_73_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_74_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_74_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_74_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_75_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_75_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_75_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_76_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_76_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_76_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_77_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_77_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_77_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_78_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_78_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_78_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_79_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_79_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_79_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_80_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_80_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_80_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_81_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_81_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_81_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_82_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_82_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_82_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_83_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_83_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_83_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_84_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_84_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_84_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_85_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_85_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_85_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_86_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_86_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_86_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_87_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_87_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_87_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_88_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_88_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_88_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_89_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_89_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_89_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_90_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_90_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_90_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_91_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_91_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_91_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_92_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_92_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_92_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_93_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_93_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_93_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_94_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_94_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_94_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_95_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_95_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG2_ENABLE_95_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG2_RESETVAL (0x00000000u)

/* enable_clr_reg3 */

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_96_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_96_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_96_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_97_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_97_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_97_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_98_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_98_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_98_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_99_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_99_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_99_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_100_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_100_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_100_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_101_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_101_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_101_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_102_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_102_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_102_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_103_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_103_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_103_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_104_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_104_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_104_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_105_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_105_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_105_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_106_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_106_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_106_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_107_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_107_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_107_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_108_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_108_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_108_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_109_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_109_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_109_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_110_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_110_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_110_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_111_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_111_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_111_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_112_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_112_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_112_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_113_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_113_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_113_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_114_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_114_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_114_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_115_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_115_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_115_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_116_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_116_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_116_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_117_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_117_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_117_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_118_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_118_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_118_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_119_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_119_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_119_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_120_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_120_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_120_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_121_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_121_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_121_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_122_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_122_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_122_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_123_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_123_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_123_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_124_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_124_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_124_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_125_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_125_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_125_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_126_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_126_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_126_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_127_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_127_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG3_ENABLE_127_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG3_RESETVAL (0x00000000u)

/* enable_clr_reg4 */

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_128_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_128_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_128_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_129_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_129_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_129_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_130_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_130_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_130_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_131_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_131_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_131_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_132_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_132_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_132_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_133_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_133_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_133_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_134_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_134_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_134_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_135_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_135_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_135_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_136_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_136_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_136_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_137_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_137_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_137_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_138_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_138_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_138_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_139_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_139_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_139_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_140_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_140_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_140_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_141_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_141_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_141_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_142_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_142_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_142_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_143_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_143_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_143_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_144_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_144_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_144_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_145_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_145_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_145_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_146_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_146_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_146_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_147_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_147_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_147_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_148_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_148_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_148_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_149_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_149_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_149_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_150_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_150_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_150_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_151_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_151_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_151_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_152_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_152_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_152_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_153_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_153_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_153_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_154_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_154_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_154_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_155_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_155_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_155_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_156_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_156_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_156_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_157_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_157_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_157_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_158_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_158_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_158_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_159_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_159_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG4_ENABLE_159_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG4_RESETVAL (0x00000000u)

/* enable_clr_reg5 */

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_160_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_160_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_160_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_161_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_161_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_161_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_162_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_162_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_162_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_163_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_163_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_163_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_164_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_164_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_164_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_165_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_165_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_165_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_166_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_166_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_166_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_167_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_167_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_167_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_168_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_168_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_168_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_169_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_169_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_169_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_170_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_170_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_170_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_171_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_171_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_171_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_172_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_172_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_172_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_173_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_173_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_173_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_174_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_174_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_174_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_175_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_175_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_175_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_176_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_176_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_176_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_177_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_177_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_177_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_178_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_178_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_178_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_179_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_179_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_179_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_180_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_180_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_180_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_181_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_181_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_181_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_182_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_182_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_182_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_183_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_183_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_183_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_184_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_184_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_184_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_185_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_185_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_185_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_186_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_186_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_186_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_187_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_187_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_187_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_188_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_188_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_188_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_189_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_189_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_189_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_190_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_190_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_190_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_191_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_191_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG5_ENABLE_191_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG5_RESETVAL (0x00000000u)

/* enable_clr_reg6 */

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_192_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_192_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_192_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_193_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_193_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_193_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_194_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_194_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_194_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_195_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_195_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_195_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_196_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_196_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_196_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_197_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_197_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_197_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_198_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_198_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_198_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_199_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_199_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_199_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_200_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_200_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_200_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_201_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_201_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_201_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_202_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_202_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_202_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_203_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_203_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_203_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_204_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_204_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_204_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_205_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_205_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_205_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_206_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_206_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_206_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_207_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_207_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_207_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_208_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_208_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_208_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_209_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_209_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_209_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_210_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_210_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_210_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_211_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_211_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_211_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_212_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_212_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_212_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_213_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_213_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_213_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_214_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_214_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_214_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_215_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_215_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_215_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_216_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_216_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_216_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_217_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_217_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_217_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_218_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_218_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_218_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_219_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_219_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_219_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_220_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_220_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_220_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_221_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_221_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_221_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_222_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_222_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_222_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_223_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_223_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG6_ENABLE_223_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG6_RESETVAL (0x00000000u)

/* enable_clr_reg7 */

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_224_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_224_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_224_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_225_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_225_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_225_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_226_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_226_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_226_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_227_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_227_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_227_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_228_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_228_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_228_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_229_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_229_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_229_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_230_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_230_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_230_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_231_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_231_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_231_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_232_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_232_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_232_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_233_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_233_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_233_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_234_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_234_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_234_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_235_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_235_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_235_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_236_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_236_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_236_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_237_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_237_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_237_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_238_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_238_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_238_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_239_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_239_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_239_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_240_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_240_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_240_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_241_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_241_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_241_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_242_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_242_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_242_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_243_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_243_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_243_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_244_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_244_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_244_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_245_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_245_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_245_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_246_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_246_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_246_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_247_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_247_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_247_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_248_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_248_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_248_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_249_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_249_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_249_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_250_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_250_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_250_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_251_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_251_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_251_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_252_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_252_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_252_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_253_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_253_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_253_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_254_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_254_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_254_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_255_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_255_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG7_ENABLE_255_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG7_RESETVAL (0x00000000u)

/* enable_clr_reg8 */

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_256_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_256_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_256_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_257_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_257_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_257_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_258_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_258_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_258_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_259_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_259_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_259_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_260_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_260_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_260_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_261_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_261_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_261_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_262_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_262_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_262_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_263_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_263_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_263_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_264_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_264_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_264_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_265_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_265_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_265_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_266_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_266_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_266_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_267_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_267_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_267_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_268_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_268_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_268_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_269_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_269_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_269_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_270_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_270_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_270_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_271_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_271_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_271_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_272_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_272_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_272_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_273_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_273_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_273_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_274_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_274_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_274_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_275_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_275_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_275_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_276_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_276_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_276_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_277_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_277_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_277_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_278_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_278_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_278_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_279_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_279_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_279_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_280_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_280_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_280_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_281_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_281_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_281_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_282_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_282_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_282_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_283_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_283_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_283_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_284_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_284_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_284_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_285_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_285_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_285_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_286_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_286_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_286_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_287_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_287_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG8_ENABLE_287_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG8_RESETVAL (0x00000000u)

/* enable_clr_reg9 */

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_288_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_288_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_288_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_289_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_289_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_289_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_290_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_290_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_290_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_291_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_291_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_291_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_292_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_292_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_292_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_293_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_293_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_293_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_294_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_294_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_294_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_295_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_295_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_295_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_296_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_296_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_296_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_297_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_297_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_297_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_298_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_298_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_298_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_299_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_299_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_299_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_300_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_300_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_300_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_301_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_301_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_301_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_302_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_302_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_302_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_303_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_303_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_303_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_304_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_304_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_304_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_305_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_305_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_305_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_306_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_306_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_306_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_307_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_307_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_307_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_308_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_308_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_308_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_309_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_309_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_309_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_310_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_310_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_310_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_311_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_311_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_311_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_312_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_312_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_312_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_313_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_313_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_313_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_314_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_314_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_314_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_315_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_315_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_315_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_316_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_316_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_316_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_317_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_317_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_317_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_318_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_318_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_318_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_319_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_319_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG9_ENABLE_319_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG9_RESETVAL (0x00000000u)

/* enable_clr_reg10 */

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_320_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_320_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_320_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_321_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_321_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_321_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_322_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_322_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_322_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_323_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_323_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_323_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_324_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_324_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_324_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_325_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_325_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_325_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_326_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_326_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_326_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_327_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_327_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_327_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_328_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_328_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_328_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_329_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_329_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_329_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_330_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_330_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_330_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_331_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_331_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_331_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_332_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_332_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_332_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_333_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_333_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_333_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_334_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_334_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_334_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_335_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_335_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_335_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_336_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_336_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_336_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_337_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_337_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_337_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_338_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_338_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_338_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_339_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_339_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_339_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_340_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_340_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_340_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_341_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_341_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_341_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_342_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_342_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_342_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_343_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_343_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_343_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_344_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_344_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_344_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_345_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_345_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_345_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_346_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_346_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_346_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_347_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_347_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_347_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_348_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_348_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_348_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_349_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_349_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_349_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_350_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_350_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_350_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_351_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_351_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG10_ENABLE_351_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG10_RESETVAL (0x00000000u)

/* enable_clr_reg11 */

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_352_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_352_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_352_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_353_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_353_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_353_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_354_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_354_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_354_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_355_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_355_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_355_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_356_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_356_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_356_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_357_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_357_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_357_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_358_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_358_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_358_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_359_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_359_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_359_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_360_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_360_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_360_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_361_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_361_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_361_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_362_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_362_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_362_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_363_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_363_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_363_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_364_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_364_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_364_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_365_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_365_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_365_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_366_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_366_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_366_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_367_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_367_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_367_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_368_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_368_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_368_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_369_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_369_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_369_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_370_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_370_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_370_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_371_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_371_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_371_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_372_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_372_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_372_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_373_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_373_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_373_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_374_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_374_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_374_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_375_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_375_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_375_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_376_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_376_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_376_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_377_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_377_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_377_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_378_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_378_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_378_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_379_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_379_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_379_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_380_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_380_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_380_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_381_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_381_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_381_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_382_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_382_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_382_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_383_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_383_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG11_ENABLE_383_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG11_RESETVAL (0x00000000u)

/* enable_clr_reg12 */

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_384_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_384_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_384_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_385_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_385_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_385_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_386_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_386_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_386_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_387_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_387_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_387_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_388_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_388_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_388_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_389_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_389_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_389_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_390_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_390_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_390_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_391_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_391_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_391_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_392_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_392_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_392_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_393_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_393_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_393_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_394_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_394_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_394_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_395_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_395_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_395_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_396_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_396_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_396_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_397_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_397_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_397_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_398_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_398_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_398_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_399_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_399_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_399_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_400_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_400_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_400_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_401_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_401_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_401_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_402_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_402_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_402_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_403_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_403_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_403_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_404_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_404_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_404_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_405_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_405_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_405_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_406_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_406_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_406_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_407_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_407_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_407_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_408_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_408_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_408_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_409_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_409_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_409_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_410_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_410_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_410_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_411_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_411_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_411_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_412_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_412_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_412_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_413_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_413_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_413_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_414_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_414_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_414_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_415_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_415_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG12_ENABLE_415_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG12_RESETVAL (0x00000000u)

/* enable_clr_reg13 */

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_416_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_416_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_416_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_417_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_417_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_417_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_418_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_418_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_418_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_419_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_419_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_419_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_420_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_420_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_420_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_421_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_421_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_421_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_422_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_422_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_422_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_423_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_423_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_423_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_424_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_424_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_424_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_425_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_425_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_425_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_426_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_426_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_426_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_427_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_427_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_427_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_428_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_428_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_428_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_429_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_429_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_429_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_430_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_430_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_430_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_431_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_431_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_431_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_432_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_432_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_432_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_433_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_433_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_433_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_434_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_434_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_434_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_435_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_435_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_435_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_436_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_436_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_436_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_437_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_437_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_437_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_438_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_438_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_438_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_439_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_439_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_439_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_440_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_440_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_440_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_441_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_441_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_441_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_442_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_442_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_442_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_443_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_443_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_443_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_444_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_444_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_444_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_445_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_445_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_445_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_446_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_446_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_446_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_447_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_447_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG13_ENABLE_447_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG13_RESETVAL (0x00000000u)

/* enable_clr_reg14 */

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_448_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_448_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_448_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_449_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_449_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_449_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_450_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_450_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_450_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_451_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_451_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_451_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_452_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_452_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_452_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_453_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_453_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_453_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_454_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_454_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_454_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_455_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_455_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_455_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_456_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_456_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_456_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_457_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_457_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_457_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_458_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_458_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_458_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_459_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_459_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_459_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_460_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_460_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_460_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_461_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_461_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_461_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_462_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_462_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_462_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_463_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_463_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_463_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_464_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_464_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_464_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_465_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_465_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_465_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_466_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_466_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_466_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_467_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_467_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_467_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_468_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_468_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_468_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_469_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_469_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_469_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_470_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_470_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_470_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_471_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_471_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_471_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_472_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_472_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_472_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_473_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_473_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_473_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_474_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_474_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_474_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_475_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_475_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_475_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_476_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_476_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_476_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_477_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_477_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_477_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_478_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_478_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_478_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_479_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_479_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG14_ENABLE_479_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG14_RESETVAL (0x00000000u)

/* enable_clr_reg15 */

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_480_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_480_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_480_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_481_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_481_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_481_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_482_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_482_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_482_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_483_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_483_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_483_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_484_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_484_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_484_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_485_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_485_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_485_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_486_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_486_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_486_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_487_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_487_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_487_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_488_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_488_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_488_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_489_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_489_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_489_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_490_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_490_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_490_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_491_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_491_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_491_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_492_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_492_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_492_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_493_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_493_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_493_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_494_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_494_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_494_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_495_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_495_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_495_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_496_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_496_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_496_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_497_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_497_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_497_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_498_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_498_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_498_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_499_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_499_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_499_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_500_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_500_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_500_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_501_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_501_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_501_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_502_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_502_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_502_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_503_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_503_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_503_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_504_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_504_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_504_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_505_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_505_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_505_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_506_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_506_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_506_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_507_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_507_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_507_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_508_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_508_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_508_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_509_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_509_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_509_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_510_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_510_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_510_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_511_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_511_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG15_ENABLE_511_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG15_RESETVAL (0x00000000u)

/* enable_clr_reg16 */

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_512_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_512_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_512_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_513_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_513_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_513_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_514_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_514_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_514_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_515_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_515_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_515_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_516_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_516_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_516_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_517_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_517_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_517_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_518_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_518_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_518_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_519_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_519_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_519_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_520_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_520_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_520_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_521_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_521_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_521_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_522_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_522_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_522_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_523_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_523_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_523_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_524_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_524_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_524_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_525_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_525_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_525_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_526_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_526_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_526_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_527_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_527_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_527_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_528_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_528_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_528_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_529_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_529_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_529_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_530_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_530_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_530_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_531_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_531_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_531_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_532_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_532_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_532_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_533_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_533_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_533_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_534_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_534_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_534_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_535_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_535_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_535_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_536_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_536_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_536_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_537_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_537_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_537_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_538_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_538_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_538_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_539_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_539_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_539_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_540_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_540_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_540_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_541_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_541_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_541_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_542_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_542_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_542_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_543_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_543_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG16_ENABLE_543_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG16_RESETVAL (0x00000000u)

/* enable_clr_reg17 */

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_544_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_544_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_544_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_545_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_545_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_545_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_546_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_546_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_546_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_547_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_547_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_547_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_548_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_548_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_548_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_549_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_549_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_549_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_550_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_550_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_550_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_551_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_551_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_551_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_552_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_552_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_552_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_553_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_553_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_553_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_554_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_554_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_554_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_555_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_555_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_555_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_556_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_556_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_556_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_557_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_557_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_557_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_558_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_558_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_558_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_559_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_559_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_559_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_560_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_560_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_560_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_561_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_561_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_561_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_562_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_562_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_562_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_563_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_563_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_563_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_564_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_564_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_564_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_565_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_565_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_565_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_566_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_566_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_566_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_567_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_567_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_567_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_568_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_568_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_568_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_569_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_569_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_569_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_570_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_570_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_570_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_571_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_571_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_571_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_572_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_572_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_572_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_573_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_573_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_573_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_574_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_574_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_574_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_575_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_575_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG17_ENABLE_575_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG17_RESETVAL (0x00000000u)

/* enable_clr_reg18 */

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_576_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_576_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_576_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_577_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_577_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_577_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_578_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_578_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_578_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_579_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_579_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_579_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_580_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_580_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_580_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_581_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_581_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_581_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_582_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_582_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_582_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_583_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_583_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_583_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_584_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_584_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_584_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_585_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_585_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_585_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_586_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_586_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_586_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_587_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_587_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_587_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_588_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_588_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_588_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_589_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_589_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_589_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_590_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_590_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_590_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_591_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_591_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_591_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_592_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_592_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_592_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_593_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_593_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_593_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_594_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_594_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_594_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_595_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_595_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_595_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_596_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_596_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_596_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_597_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_597_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_597_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_598_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_598_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_598_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_599_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_599_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_599_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_600_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_600_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_600_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_601_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_601_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_601_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_602_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_602_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_602_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_603_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_603_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_603_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_604_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_604_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_604_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_605_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_605_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_605_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_606_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_606_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_606_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_607_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_607_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG18_ENABLE_607_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG18_RESETVAL (0x00000000u)

/* enable_clr_reg19 */

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_608_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_608_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_608_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_609_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_609_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_609_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_610_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_610_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_610_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_611_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_611_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_611_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_612_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_612_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_612_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_613_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_613_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_613_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_614_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_614_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_614_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_615_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_615_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_615_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_616_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_616_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_616_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_617_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_617_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_617_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_618_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_618_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_618_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_619_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_619_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_619_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_620_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_620_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_620_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_621_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_621_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_621_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_622_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_622_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_622_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_623_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_623_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_623_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_624_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_624_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_624_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_625_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_625_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_625_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_626_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_626_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_626_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_627_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_627_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_627_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_628_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_628_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_628_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_629_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_629_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_629_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_630_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_630_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_630_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_631_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_631_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_631_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_632_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_632_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_632_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_633_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_633_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_633_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_634_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_634_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_634_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_635_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_635_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_635_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_636_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_636_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_636_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_637_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_637_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_637_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_638_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_638_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_638_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_639_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_639_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG19_ENABLE_639_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG19_RESETVAL (0x00000000u)

/* enable_clr_reg20 */

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_640_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_640_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_640_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_641_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_641_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_641_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_642_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_642_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_642_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_643_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_643_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_643_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_644_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_644_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_644_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_645_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_645_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_645_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_646_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_646_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_646_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_647_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_647_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_647_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_648_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_648_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_648_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_649_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_649_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_649_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_650_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_650_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_650_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_651_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_651_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_651_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_652_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_652_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_652_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_653_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_653_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_653_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_654_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_654_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_654_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_655_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_655_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_655_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_656_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_656_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_656_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_657_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_657_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_657_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_658_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_658_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_658_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_659_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_659_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_659_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_660_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_660_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_660_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_661_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_661_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_661_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_662_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_662_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_662_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_663_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_663_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_663_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_664_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_664_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_664_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_665_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_665_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_665_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_666_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_666_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_666_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_667_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_667_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_667_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_668_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_668_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_668_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_669_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_669_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_669_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_670_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_670_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_670_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_671_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_671_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG20_ENABLE_671_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG20_RESETVAL (0x00000000u)

/* enable_clr_reg21 */

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_672_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_672_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_672_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_673_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_673_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_673_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_674_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_674_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_674_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_675_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_675_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_675_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_676_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_676_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_676_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_677_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_677_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_677_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_678_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_678_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_678_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_679_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_679_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_679_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_680_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_680_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_680_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_681_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_681_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_681_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_682_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_682_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_682_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_683_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_683_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_683_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_684_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_684_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_684_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_685_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_685_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_685_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_686_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_686_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_686_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_687_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_687_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_687_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_688_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_688_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_688_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_689_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_689_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_689_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_690_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_690_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_690_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_691_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_691_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_691_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_692_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_692_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_692_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_693_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_693_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_693_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_694_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_694_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_694_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_695_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_695_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_695_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_696_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_696_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_696_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_697_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_697_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_697_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_698_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_698_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_698_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_699_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_699_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_699_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_700_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_700_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_700_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_701_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_701_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_701_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_702_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_702_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_702_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_703_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_703_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG21_ENABLE_703_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG21_RESETVAL (0x00000000u)

/* enable_clr_reg22 */

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_704_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_704_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_704_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_705_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_705_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_705_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_706_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_706_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_706_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_707_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_707_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_707_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_708_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_708_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_708_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_709_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_709_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_709_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_710_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_710_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_710_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_711_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_711_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_711_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_712_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_712_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_712_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_713_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_713_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_713_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_714_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_714_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_714_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_715_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_715_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_715_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_716_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_716_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_716_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_717_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_717_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_717_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_718_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_718_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_718_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_719_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_719_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_719_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_720_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_720_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_720_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_721_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_721_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_721_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_722_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_722_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_722_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_723_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_723_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_723_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_724_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_724_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_724_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_725_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_725_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_725_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_726_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_726_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_726_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_727_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_727_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_727_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_728_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_728_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_728_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_729_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_729_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_729_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_730_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_730_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_730_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_731_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_731_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_731_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_732_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_732_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_732_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_733_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_733_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_733_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_734_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_734_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_734_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_735_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_735_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG22_ENABLE_735_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG22_RESETVAL (0x00000000u)

/* enable_clr_reg23 */

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_736_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_736_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_736_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_737_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_737_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_737_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_738_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_738_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_738_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_739_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_739_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_739_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_740_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_740_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_740_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_741_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_741_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_741_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_742_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_742_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_742_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_743_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_743_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_743_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_744_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_744_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_744_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_745_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_745_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_745_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_746_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_746_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_746_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_747_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_747_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_747_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_748_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_748_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_748_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_749_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_749_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_749_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_750_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_750_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_750_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_751_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_751_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_751_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_752_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_752_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_752_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_753_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_753_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_753_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_754_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_754_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_754_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_755_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_755_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_755_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_756_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_756_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_756_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_757_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_757_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_757_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_758_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_758_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_758_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_759_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_759_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_759_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_760_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_760_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_760_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_761_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_761_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_761_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_762_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_762_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_762_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_763_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_763_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_763_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_764_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_764_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_764_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_765_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_765_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_765_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_766_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_766_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_766_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_767_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_767_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG23_ENABLE_767_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG23_RESETVAL (0x00000000u)

/* enable_clr_reg24 */

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_768_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_768_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_768_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_769_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_769_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_769_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_770_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_770_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_770_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_771_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_771_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_771_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_772_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_772_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_772_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_773_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_773_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_773_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_774_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_774_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_774_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_775_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_775_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_775_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_776_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_776_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_776_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_777_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_777_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_777_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_778_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_778_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_778_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_779_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_779_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_779_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_780_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_780_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_780_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_781_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_781_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_781_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_782_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_782_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_782_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_783_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_783_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_783_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_784_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_784_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_784_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_785_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_785_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_785_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_786_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_786_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_786_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_787_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_787_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_787_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_788_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_788_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_788_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_789_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_789_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_789_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_790_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_790_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_790_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_791_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_791_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_791_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_792_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_792_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_792_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_793_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_793_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_793_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_794_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_794_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_794_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_795_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_795_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_795_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_796_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_796_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_796_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_797_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_797_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_797_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_798_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_798_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_798_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_799_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_799_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG24_ENABLE_799_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG24_RESETVAL (0x00000000u)

/* enable_clr_reg25 */

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_800_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_800_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_800_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_801_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_801_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_801_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_802_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_802_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_802_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_803_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_803_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_803_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_804_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_804_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_804_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_805_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_805_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_805_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_806_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_806_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_806_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_807_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_807_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_807_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_808_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_808_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_808_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_809_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_809_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_809_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_810_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_810_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_810_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_811_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_811_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_811_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_812_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_812_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_812_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_813_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_813_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_813_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_814_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_814_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_814_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_815_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_815_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_815_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_816_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_816_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_816_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_817_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_817_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_817_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_818_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_818_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_818_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_819_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_819_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_819_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_820_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_820_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_820_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_821_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_821_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_821_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_822_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_822_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_822_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_823_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_823_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_823_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_824_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_824_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_824_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_825_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_825_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_825_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_826_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_826_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_826_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_827_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_827_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_827_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_828_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_828_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_828_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_829_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_829_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_829_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_830_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_830_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_830_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_831_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_831_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG25_ENABLE_831_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG25_RESETVAL (0x00000000u)

/* enable_clr_reg26 */

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_832_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_832_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_832_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_833_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_833_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_833_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_834_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_834_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_834_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_835_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_835_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_835_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_836_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_836_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_836_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_837_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_837_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_837_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_838_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_838_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_838_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_839_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_839_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_839_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_840_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_840_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_840_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_841_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_841_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_841_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_842_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_842_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_842_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_843_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_843_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_843_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_844_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_844_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_844_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_845_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_845_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_845_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_846_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_846_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_846_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_847_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_847_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_847_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_848_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_848_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_848_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_849_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_849_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_849_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_850_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_850_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_850_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_851_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_851_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_851_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_852_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_852_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_852_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_853_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_853_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_853_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_854_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_854_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_854_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_855_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_855_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_855_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_856_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_856_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_856_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_857_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_857_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_857_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_858_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_858_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_858_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_859_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_859_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_859_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_860_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_860_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_860_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_861_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_861_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_861_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_862_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_862_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_862_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_863_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_863_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG26_ENABLE_863_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG26_RESETVAL (0x00000000u)

/* enable_clr_reg27 */

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_864_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_864_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_864_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_865_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_865_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_865_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_866_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_866_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_866_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_867_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_867_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_867_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_868_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_868_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_868_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_869_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_869_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_869_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_870_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_870_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_870_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_871_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_871_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_871_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_872_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_872_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_872_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_873_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_873_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_873_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_874_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_874_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_874_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_875_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_875_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_875_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_876_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_876_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_876_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_877_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_877_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_877_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_878_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_878_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_878_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_879_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_879_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_879_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_880_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_880_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_880_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_881_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_881_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_881_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_882_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_882_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_882_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_883_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_883_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_883_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_884_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_884_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_884_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_885_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_885_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_885_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_886_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_886_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_886_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_887_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_887_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_887_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_888_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_888_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_888_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_889_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_889_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_889_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_890_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_890_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_890_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_891_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_891_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_891_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_892_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_892_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_892_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_893_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_893_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_893_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_894_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_894_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_894_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_895_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_895_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG27_ENABLE_895_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG27_RESETVAL (0x00000000u)

/* enable_clr_reg28 */

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_896_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_896_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_896_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_897_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_897_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_897_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_898_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_898_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_898_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_899_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_899_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_899_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_900_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_900_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_900_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_901_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_901_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_901_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_902_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_902_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_902_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_903_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_903_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_903_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_904_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_904_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_904_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_905_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_905_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_905_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_906_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_906_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_906_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_907_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_907_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_907_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_908_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_908_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_908_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_909_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_909_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_909_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_910_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_910_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_910_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_911_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_911_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_911_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_912_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_912_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_912_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_913_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_913_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_913_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_914_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_914_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_914_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_915_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_915_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_915_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_916_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_916_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_916_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_917_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_917_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_917_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_918_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_918_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_918_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_919_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_919_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_919_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_920_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_920_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_920_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_921_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_921_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_921_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_922_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_922_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_922_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_923_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_923_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_923_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_924_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_924_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_924_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_925_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_925_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_925_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_926_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_926_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_926_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_927_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_927_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG28_ENABLE_927_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG28_RESETVAL (0x00000000u)

/* enable_clr_reg29 */

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_928_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_928_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_928_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_929_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_929_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_929_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_930_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_930_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_930_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_931_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_931_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_931_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_932_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_932_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_932_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_933_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_933_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_933_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_934_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_934_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_934_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_935_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_935_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_935_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_936_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_936_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_936_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_937_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_937_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_937_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_938_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_938_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_938_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_939_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_939_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_939_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_940_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_940_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_940_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_941_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_941_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_941_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_942_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_942_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_942_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_943_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_943_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_943_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_944_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_944_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_944_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_945_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_945_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_945_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_946_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_946_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_946_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_947_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_947_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_947_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_948_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_948_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_948_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_949_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_949_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_949_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_950_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_950_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_950_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_951_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_951_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_951_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_952_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_952_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_952_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_953_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_953_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_953_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_954_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_954_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_954_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_955_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_955_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_955_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_956_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_956_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_956_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_957_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_957_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_957_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_958_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_958_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_958_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_959_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_959_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG29_ENABLE_959_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG29_RESETVAL (0x00000000u)

/* enable_clr_reg30 */

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_960_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_960_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_960_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_961_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_961_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_961_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_962_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_962_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_962_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_963_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_963_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_963_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_964_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_964_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_964_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_965_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_965_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_965_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_966_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_966_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_966_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_967_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_967_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_967_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_968_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_968_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_968_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_969_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_969_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_969_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_970_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_970_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_970_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_971_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_971_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_971_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_972_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_972_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_972_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_973_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_973_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_973_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_974_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_974_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_974_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_975_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_975_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_975_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_976_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_976_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_976_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_977_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_977_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_977_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_978_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_978_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_978_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_979_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_979_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_979_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_980_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_980_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_980_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_981_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_981_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_981_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_982_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_982_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_982_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_983_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_983_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_983_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_984_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_984_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_984_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_985_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_985_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_985_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_986_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_986_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_986_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_987_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_987_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_987_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_988_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_988_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_988_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_989_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_989_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_989_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_990_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_990_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_990_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_991_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_991_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG30_ENABLE_991_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG30_RESETVAL (0x00000000u)

/* enable_clr_reg31 */

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_992_CLR_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_992_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_992_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_993_CLR_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_993_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_993_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_994_CLR_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_994_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_994_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_995_CLR_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_995_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_995_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_996_CLR_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_996_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_996_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_997_CLR_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_997_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_997_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_998_CLR_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_998_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_998_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_999_CLR_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_999_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_999_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1000_CLR_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1000_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1000_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1001_CLR_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1001_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1001_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1002_CLR_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1002_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1002_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1003_CLR_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1003_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1003_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1004_CLR_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1004_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1004_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1005_CLR_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1005_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1005_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1006_CLR_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1006_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1006_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1007_CLR_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1007_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1007_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1008_CLR_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1008_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1008_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1009_CLR_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1009_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1009_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1010_CLR_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1010_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1010_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1011_CLR_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1011_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1011_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1012_CLR_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1012_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1012_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1013_CLR_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1013_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1013_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1014_CLR_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1014_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1014_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1015_CLR_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1015_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1015_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1016_CLR_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1016_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1016_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1017_CLR_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1017_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1017_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1018_CLR_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1018_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1018_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1019_CLR_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1019_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1019_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1020_CLR_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1020_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1020_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1021_CLR_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1021_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1021_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1022_CLR_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1022_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1022_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1023_CLR_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1023_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_CLR_REG31_ENABLE_1023_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_CLR_REG31_RESETVAL (0x00000000u)

/* ch_map_reg0 */

#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_0_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_0_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_1_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_1_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_2_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_2_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_3_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_3_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG0_CH_MAP_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG0_RESETVAL  (0x00000000u)

/* ch_map_reg1 */

#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_4_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_4_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_5_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_5_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_6_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_6_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_7_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_7_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG1_CH_MAP_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG1_RESETVAL  (0x00000000u)

/* ch_map_reg2 */

#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_8_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_8_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_9_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_9_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_10_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_10_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_11_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_11_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG2_CH_MAP_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG2_RESETVAL  (0x00000000u)

/* ch_map_reg3 */

#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_12_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_12_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_13_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_13_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_14_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_14_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_15_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_15_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG3_CH_MAP_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG3_RESETVAL  (0x00000000u)

/* ch_map_reg4 */

#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_16_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_16_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_17_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_17_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_18_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_18_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_19_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_19_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG4_CH_MAP_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG4_RESETVAL  (0x00000000u)

/* ch_map_reg5 */

#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_20_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_20_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_21_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_21_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_22_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_22_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_23_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_23_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG5_CH_MAP_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG5_RESETVAL  (0x00000000u)

/* ch_map_reg6 */

#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_24_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_24_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_25_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_25_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_26_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_26_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_27_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_27_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG6_CH_MAP_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG6_RESETVAL  (0x00000000u)

/* ch_map_reg7 */

#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_28_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_28_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_29_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_29_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_30_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_30_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_31_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_31_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG7_CH_MAP_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG7_RESETVAL  (0x00000000u)

/* ch_map_reg8 */

#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_32_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_32_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_33_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_33_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_34_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_34_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_35_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_35_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG8_CH_MAP_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG8_RESETVAL  (0x00000000u)

/* ch_map_reg9 */

#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_36_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_36_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_37_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_37_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_38_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_38_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_39_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_39_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG9_CH_MAP_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG9_RESETVAL  (0x00000000u)

/* ch_map_reg10 */

#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_40_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_40_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_41_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_41_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_42_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_42_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_43_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_43_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG10_CH_MAP_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG10_RESETVAL (0x00000000u)

/* ch_map_reg11 */

#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_44_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_44_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_45_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_45_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_46_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_46_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_47_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_47_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG11_CH_MAP_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG11_RESETVAL (0x00000000u)

/* ch_map_reg12 */

#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_48_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_48_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_49_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_49_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_50_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_50_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_51_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_51_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG12_CH_MAP_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG12_RESETVAL (0x00000000u)

/* ch_map_reg13 */

#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_52_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_52_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_53_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_53_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_54_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_54_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_55_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_55_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG13_CH_MAP_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG13_RESETVAL (0x00000000u)

/* ch_map_reg14 */

#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_56_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_56_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_57_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_57_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_58_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_58_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_59_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_59_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG14_CH_MAP_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG14_RESETVAL (0x00000000u)

/* ch_map_reg15 */

#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_60_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_60_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_61_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_61_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_62_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_62_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_63_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_63_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG15_CH_MAP_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG15_RESETVAL (0x00000000u)

/* ch_map_reg16 */

#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_64_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_64_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_65_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_65_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_66_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_66_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_67_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_67_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG16_CH_MAP_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG16_RESETVAL (0x00000000u)

/* ch_map_reg17 */

#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_68_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_68_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_69_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_69_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_70_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_70_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_71_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_71_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG17_CH_MAP_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG17_RESETVAL (0x00000000u)

/* ch_map_reg18 */

#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_72_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_72_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_73_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_73_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_74_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_74_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_75_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_75_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG18_CH_MAP_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG18_RESETVAL (0x00000000u)

/* ch_map_reg19 */

#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_76_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_76_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_77_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_77_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_78_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_78_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_79_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_79_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG19_CH_MAP_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG19_RESETVAL (0x00000000u)

/* ch_map_reg20 */

#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_80_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_80_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_81_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_81_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_82_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_82_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_83_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_83_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG20_CH_MAP_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG20_RESETVAL (0x00000000u)

/* ch_map_reg21 */

#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_84_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_84_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_85_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_85_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_86_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_86_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_87_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_87_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG21_CH_MAP_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG21_RESETVAL (0x00000000u)

/* ch_map_reg22 */

#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_88_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_88_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_89_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_89_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_90_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_90_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_91_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_91_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG22_CH_MAP_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG22_RESETVAL (0x00000000u)

/* ch_map_reg23 */

#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_92_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_92_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_93_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_93_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_94_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_94_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_95_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_95_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG23_CH_MAP_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG23_RESETVAL (0x00000000u)

/* ch_map_reg24 */

#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_96_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_96_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_97_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_97_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_98_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_98_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_99_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_99_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG24_CH_MAP_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG24_RESETVAL (0x00000000u)

/* ch_map_reg25 */

#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_100_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_100_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_101_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_101_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_102_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_102_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_103_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_103_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG25_CH_MAP_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG25_RESETVAL (0x00000000u)

/* ch_map_reg26 */

#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_104_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_104_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_105_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_105_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_106_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_106_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_107_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_107_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG26_CH_MAP_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG26_RESETVAL (0x00000000u)

/* ch_map_reg27 */

#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_108_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_108_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_109_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_109_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_110_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_110_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_111_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_111_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG27_CH_MAP_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG27_RESETVAL (0x00000000u)

/* ch_map_reg28 */

#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_112_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_112_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_113_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_113_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_114_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_114_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_115_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_115_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG28_CH_MAP_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG28_RESETVAL (0x00000000u)

/* ch_map_reg29 */

#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_116_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_116_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_117_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_117_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_118_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_118_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_119_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_119_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG29_CH_MAP_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG29_RESETVAL (0x00000000u)

/* ch_map_reg30 */

#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_120_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_120_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_121_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_121_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_122_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_122_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_123_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_123_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG30_CH_MAP_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG30_RESETVAL (0x00000000u)

/* ch_map_reg31 */

#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_124_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_124_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_125_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_125_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_126_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_126_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_127_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_127_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG31_CH_MAP_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG31_RESETVAL (0x00000000u)

/* ch_map_reg32 */

#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_128_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_128_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_129_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_129_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_130_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_130_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_131_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_131_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG32_CH_MAP_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG32_RESETVAL (0x00000000u)

/* ch_map_reg33 */

#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_132_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_132_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_133_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_133_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_134_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_134_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_135_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_135_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG33_CH_MAP_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG33_RESETVAL (0x00000000u)

/* ch_map_reg34 */

#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_136_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_136_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_137_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_137_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_138_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_138_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_139_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_139_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG34_CH_MAP_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG34_RESETVAL (0x00000000u)

/* ch_map_reg35 */

#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_140_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_140_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_141_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_141_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_142_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_142_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_143_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_143_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG35_CH_MAP_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG35_RESETVAL (0x00000000u)

/* ch_map_reg36 */

#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_144_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_144_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_145_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_145_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_146_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_146_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_147_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_147_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG36_CH_MAP_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG36_RESETVAL (0x00000000u)

/* ch_map_reg37 */

#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_148_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_148_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_149_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_149_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_150_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_150_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_151_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_151_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG37_CH_MAP_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG37_RESETVAL (0x00000000u)

/* ch_map_reg38 */

#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_152_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_152_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_153_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_153_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_154_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_154_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_155_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_155_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG38_CH_MAP_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG38_RESETVAL (0x00000000u)

/* ch_map_reg39 */

#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_156_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_156_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_157_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_157_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_158_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_158_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_159_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_159_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG39_CH_MAP_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG39_RESETVAL (0x00000000u)

/* ch_map_reg40 */

#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_160_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_160_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_161_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_161_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_162_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_162_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_163_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_163_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG40_CH_MAP_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG40_RESETVAL (0x00000000u)

/* ch_map_reg41 */

#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_164_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_164_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_165_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_165_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_166_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_166_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_167_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_167_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG41_CH_MAP_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG41_RESETVAL (0x00000000u)

/* ch_map_reg42 */

#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_168_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_168_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_169_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_169_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_170_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_170_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_171_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_171_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG42_CH_MAP_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG42_RESETVAL (0x00000000u)

/* ch_map_reg43 */

#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_172_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_172_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_173_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_173_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_174_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_174_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_175_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_175_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG43_CH_MAP_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG43_RESETVAL (0x00000000u)

/* ch_map_reg44 */

#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_176_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_176_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_177_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_177_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_178_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_178_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_179_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_179_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG44_CH_MAP_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG44_RESETVAL (0x00000000u)

/* ch_map_reg45 */

#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_180_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_180_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_181_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_181_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_182_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_182_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_183_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_183_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG45_CH_MAP_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG45_RESETVAL (0x00000000u)

/* ch_map_reg46 */

#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_184_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_184_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_185_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_185_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_186_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_186_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_187_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_187_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG46_CH_MAP_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG46_RESETVAL (0x00000000u)

/* ch_map_reg47 */

#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_188_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_188_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_189_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_189_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_190_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_190_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_191_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_191_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG47_CH_MAP_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG47_RESETVAL (0x00000000u)

/* ch_map_reg48 */

#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_192_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_192_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_193_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_193_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_194_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_194_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_195_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_195_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG48_CH_MAP_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG48_RESETVAL (0x00000000u)

/* ch_map_reg49 */

#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_196_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_196_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_197_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_197_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_198_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_198_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_199_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_199_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG49_CH_MAP_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG49_RESETVAL (0x00000000u)

/* ch_map_reg50 */

#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_200_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_200_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_201_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_201_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_202_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_202_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_203_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_203_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG50_CH_MAP_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG50_RESETVAL (0x00000000u)

/* ch_map_reg51 */

#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_204_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_204_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_205_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_205_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_206_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_206_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_207_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_207_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG51_CH_MAP_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG51_RESETVAL (0x00000000u)

/* ch_map_reg52 */

#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_208_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_208_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_209_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_209_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_210_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_210_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_211_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_211_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG52_CH_MAP_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG52_RESETVAL (0x00000000u)

/* ch_map_reg53 */

#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_212_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_212_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_213_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_213_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_214_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_214_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_215_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_215_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG53_CH_MAP_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG53_RESETVAL (0x00000000u)

/* ch_map_reg54 */

#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_216_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_216_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_217_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_217_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_218_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_218_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_219_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_219_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG54_CH_MAP_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG54_RESETVAL (0x00000000u)

/* ch_map_reg55 */

#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_220_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_220_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_221_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_221_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_222_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_222_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_223_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_223_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG55_CH_MAP_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG55_RESETVAL (0x00000000u)

/* ch_map_reg56 */

#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_224_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_224_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_225_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_225_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_226_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_226_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_227_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_227_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG56_CH_MAP_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG56_RESETVAL (0x00000000u)

/* ch_map_reg57 */

#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_228_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_228_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_229_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_229_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_230_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_230_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_231_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_231_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG57_CH_MAP_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG57_RESETVAL (0x00000000u)

/* ch_map_reg58 */

#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_232_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_232_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_233_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_233_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_234_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_234_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_235_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_235_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG58_CH_MAP_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG58_RESETVAL (0x00000000u)

/* ch_map_reg59 */

#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_236_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_236_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_237_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_237_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_238_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_238_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_239_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_239_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG59_CH_MAP_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG59_RESETVAL (0x00000000u)

/* ch_map_reg60 */

#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_240_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_240_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_241_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_241_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_242_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_242_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_243_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_243_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG60_CH_MAP_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG60_RESETVAL (0x00000000u)

/* ch_map_reg61 */

#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_244_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_244_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_245_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_245_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_246_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_246_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_247_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_247_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG61_CH_MAP_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG61_RESETVAL (0x00000000u)

/* ch_map_reg62 */

#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_248_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_248_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_249_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_249_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_250_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_250_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_251_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_251_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG62_CH_MAP_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG62_RESETVAL (0x00000000u)

/* ch_map_reg63 */

#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_252_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_252_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_253_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_253_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_254_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_254_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_255_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_255_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG63_CH_MAP_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG63_RESETVAL (0x00000000u)

/* ch_map_reg64 */

#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_256_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_256_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_256_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_257_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_257_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_257_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_258_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_258_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_258_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_259_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_259_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG64_CH_MAP_259_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG64_RESETVAL (0x00000000u)

/* ch_map_reg65 */

#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_260_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_260_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_260_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_261_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_261_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_261_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_262_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_262_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_262_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_263_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_263_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG65_CH_MAP_263_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG65_RESETVAL (0x00000000u)

/* ch_map_reg66 */

#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_264_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_264_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_264_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_265_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_265_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_265_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_266_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_266_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_266_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_267_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_267_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG66_CH_MAP_267_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG66_RESETVAL (0x00000000u)

/* ch_map_reg67 */

#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_268_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_268_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_268_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_269_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_269_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_269_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_270_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_270_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_270_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_271_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_271_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG67_CH_MAP_271_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG67_RESETVAL (0x00000000u)

/* ch_map_reg68 */

#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_272_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_272_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_272_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_273_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_273_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_273_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_274_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_274_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_274_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_275_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_275_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG68_CH_MAP_275_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG68_RESETVAL (0x00000000u)

/* ch_map_reg69 */

#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_276_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_276_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_276_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_277_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_277_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_277_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_278_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_278_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_278_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_279_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_279_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG69_CH_MAP_279_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG69_RESETVAL (0x00000000u)

/* ch_map_reg70 */

#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_280_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_280_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_280_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_281_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_281_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_281_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_282_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_282_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_282_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_283_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_283_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG70_CH_MAP_283_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG70_RESETVAL (0x00000000u)

/* ch_map_reg71 */

#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_284_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_284_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_284_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_285_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_285_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_285_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_286_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_286_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_286_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_287_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_287_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG71_CH_MAP_287_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG71_RESETVAL (0x00000000u)

/* ch_map_reg72 */

#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_288_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_288_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_288_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_289_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_289_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_289_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_290_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_290_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_290_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_291_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_291_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG72_CH_MAP_291_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG72_RESETVAL (0x00000000u)

/* ch_map_reg73 */

#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_292_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_292_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_292_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_293_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_293_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_293_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_294_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_294_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_294_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_295_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_295_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG73_CH_MAP_295_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG73_RESETVAL (0x00000000u)

/* ch_map_reg74 */

#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_296_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_296_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_296_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_297_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_297_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_297_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_298_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_298_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_298_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_299_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_299_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG74_CH_MAP_299_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG74_RESETVAL (0x00000000u)

/* ch_map_reg75 */

#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_300_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_300_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_300_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_301_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_301_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_301_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_302_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_302_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_302_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_303_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_303_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG75_CH_MAP_303_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG75_RESETVAL (0x00000000u)

/* ch_map_reg76 */

#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_304_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_304_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_304_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_305_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_305_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_305_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_306_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_306_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_306_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_307_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_307_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG76_CH_MAP_307_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG76_RESETVAL (0x00000000u)

/* ch_map_reg77 */

#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_308_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_308_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_308_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_309_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_309_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_309_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_310_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_310_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_310_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_311_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_311_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG77_CH_MAP_311_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG77_RESETVAL (0x00000000u)

/* ch_map_reg78 */

#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_312_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_312_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_312_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_313_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_313_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_313_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_314_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_314_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_314_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_315_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_315_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG78_CH_MAP_315_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG78_RESETVAL (0x00000000u)

/* ch_map_reg79 */

#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_316_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_316_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_316_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_317_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_317_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_317_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_318_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_318_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_318_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_319_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_319_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG79_CH_MAP_319_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG79_RESETVAL (0x00000000u)

/* ch_map_reg80 */

#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_320_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_320_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_320_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_321_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_321_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_321_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_322_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_322_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_322_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_323_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_323_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG80_CH_MAP_323_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG80_RESETVAL (0x00000000u)

/* ch_map_reg81 */

#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_324_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_324_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_324_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_325_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_325_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_325_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_326_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_326_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_326_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_327_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_327_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG81_CH_MAP_327_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG81_RESETVAL (0x00000000u)

/* ch_map_reg82 */

#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_328_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_328_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_328_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_329_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_329_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_329_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_330_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_330_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_330_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_331_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_331_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG82_CH_MAP_331_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG82_RESETVAL (0x00000000u)

/* ch_map_reg83 */

#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_332_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_332_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_332_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_333_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_333_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_333_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_334_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_334_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_334_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_335_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_335_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG83_CH_MAP_335_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG83_RESETVAL (0x00000000u)

/* ch_map_reg84 */

#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_336_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_336_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_336_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_337_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_337_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_337_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_338_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_338_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_338_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_339_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_339_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG84_CH_MAP_339_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG84_RESETVAL (0x00000000u)

/* ch_map_reg85 */

#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_340_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_340_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_340_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_341_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_341_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_341_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_342_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_342_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_342_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_343_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_343_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG85_CH_MAP_343_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG85_RESETVAL (0x00000000u)

/* ch_map_reg86 */

#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_344_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_344_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_344_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_345_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_345_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_345_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_346_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_346_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_346_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_347_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_347_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG86_CH_MAP_347_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG86_RESETVAL (0x00000000u)

/* ch_map_reg87 */

#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_348_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_348_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_348_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_349_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_349_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_349_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_350_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_350_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_350_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_351_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_351_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG87_CH_MAP_351_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG87_RESETVAL (0x00000000u)

/* ch_map_reg88 */

#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_352_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_352_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_352_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_353_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_353_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_353_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_354_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_354_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_354_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_355_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_355_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG88_CH_MAP_355_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG88_RESETVAL (0x00000000u)

/* ch_map_reg89 */

#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_356_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_356_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_356_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_357_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_357_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_357_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_358_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_358_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_358_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_359_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_359_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG89_CH_MAP_359_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG89_RESETVAL (0x00000000u)

/* ch_map_reg90 */

#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_360_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_360_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_360_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_361_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_361_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_361_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_362_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_362_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_362_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_363_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_363_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG90_CH_MAP_363_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG90_RESETVAL (0x00000000u)

/* ch_map_reg91 */

#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_364_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_364_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_364_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_365_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_365_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_365_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_366_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_366_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_366_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_367_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_367_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG91_CH_MAP_367_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG91_RESETVAL (0x00000000u)

/* ch_map_reg92 */

#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_368_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_368_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_368_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_369_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_369_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_369_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_370_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_370_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_370_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_371_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_371_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG92_CH_MAP_371_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG92_RESETVAL (0x00000000u)

/* ch_map_reg93 */

#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_372_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_372_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_372_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_373_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_373_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_373_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_374_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_374_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_374_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_375_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_375_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG93_CH_MAP_375_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG93_RESETVAL (0x00000000u)

/* ch_map_reg94 */

#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_376_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_376_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_376_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_377_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_377_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_377_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_378_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_378_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_378_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_379_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_379_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG94_CH_MAP_379_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG94_RESETVAL (0x00000000u)

/* ch_map_reg95 */

#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_380_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_380_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_380_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_381_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_381_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_381_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_382_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_382_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_382_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_383_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_383_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG95_CH_MAP_383_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG95_RESETVAL (0x00000000u)

/* ch_map_reg96 */

#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_384_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_384_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_384_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_385_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_385_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_385_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_386_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_386_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_386_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_387_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_387_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG96_CH_MAP_387_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG96_RESETVAL (0x00000000u)

/* ch_map_reg97 */

#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_388_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_388_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_388_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_389_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_389_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_389_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_390_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_390_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_390_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_391_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_391_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG97_CH_MAP_391_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG97_RESETVAL (0x00000000u)

/* ch_map_reg98 */

#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_392_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_392_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_392_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_393_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_393_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_393_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_394_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_394_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_394_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_395_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_395_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG98_CH_MAP_395_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG98_RESETVAL (0x00000000u)

/* ch_map_reg99 */

#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_396_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_396_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_396_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_397_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_397_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_397_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_398_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_398_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_398_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_399_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_399_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG99_CH_MAP_399_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG99_RESETVAL (0x00000000u)

/* ch_map_reg100 */

#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_400_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_400_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_400_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_401_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_401_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_401_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_402_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_402_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_402_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_403_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_403_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG100_CH_MAP_403_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG100_RESETVAL (0x00000000u)

/* ch_map_reg101 */

#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_404_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_404_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_404_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_405_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_405_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_405_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_406_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_406_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_406_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_407_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_407_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG101_CH_MAP_407_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG101_RESETVAL (0x00000000u)

/* ch_map_reg102 */

#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_408_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_408_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_408_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_409_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_409_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_409_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_410_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_410_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_410_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_411_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_411_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG102_CH_MAP_411_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG102_RESETVAL (0x00000000u)

/* ch_map_reg103 */

#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_412_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_412_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_412_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_413_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_413_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_413_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_414_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_414_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_414_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_415_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_415_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG103_CH_MAP_415_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG103_RESETVAL (0x00000000u)

/* ch_map_reg104 */

#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_416_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_416_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_416_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_417_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_417_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_417_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_418_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_418_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_418_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_419_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_419_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG104_CH_MAP_419_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG104_RESETVAL (0x00000000u)

/* ch_map_reg105 */

#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_420_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_420_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_420_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_421_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_421_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_421_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_422_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_422_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_422_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_423_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_423_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG105_CH_MAP_423_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG105_RESETVAL (0x00000000u)

/* ch_map_reg106 */

#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_424_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_424_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_424_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_425_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_425_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_425_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_426_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_426_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_426_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_427_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_427_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG106_CH_MAP_427_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG106_RESETVAL (0x00000000u)

/* ch_map_reg107 */

#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_428_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_428_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_428_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_429_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_429_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_429_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_430_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_430_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_430_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_431_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_431_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG107_CH_MAP_431_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG107_RESETVAL (0x00000000u)

/* ch_map_reg108 */

#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_432_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_432_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_432_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_433_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_433_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_433_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_434_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_434_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_434_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_435_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_435_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG108_CH_MAP_435_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG108_RESETVAL (0x00000000u)

/* ch_map_reg109 */

#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_436_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_436_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_436_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_437_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_437_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_437_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_438_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_438_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_438_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_439_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_439_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG109_CH_MAP_439_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG109_RESETVAL (0x00000000u)

/* ch_map_reg110 */

#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_440_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_440_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_440_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_441_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_441_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_441_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_442_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_442_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_442_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_443_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_443_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG110_CH_MAP_443_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG110_RESETVAL (0x00000000u)

/* ch_map_reg111 */

#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_444_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_444_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_444_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_445_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_445_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_445_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_446_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_446_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_446_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_447_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_447_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG111_CH_MAP_447_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG111_RESETVAL (0x00000000u)

/* ch_map_reg112 */

#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_448_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_448_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_448_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_449_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_449_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_449_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_450_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_450_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_450_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_451_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_451_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG112_CH_MAP_451_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG112_RESETVAL (0x00000000u)

/* ch_map_reg113 */

#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_452_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_452_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_452_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_453_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_453_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_453_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_454_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_454_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_454_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_455_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_455_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG113_CH_MAP_455_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG113_RESETVAL (0x00000000u)

/* ch_map_reg114 */

#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_456_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_456_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_456_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_457_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_457_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_457_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_458_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_458_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_458_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_459_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_459_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG114_CH_MAP_459_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG114_RESETVAL (0x00000000u)

/* ch_map_reg115 */

#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_460_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_460_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_460_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_461_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_461_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_461_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_462_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_462_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_462_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_463_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_463_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG115_CH_MAP_463_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG115_RESETVAL (0x00000000u)

/* ch_map_reg116 */

#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_464_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_464_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_464_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_465_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_465_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_465_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_466_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_466_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_466_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_467_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_467_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG116_CH_MAP_467_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG116_RESETVAL (0x00000000u)

/* ch_map_reg117 */

#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_468_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_468_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_468_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_469_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_469_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_469_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_470_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_470_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_470_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_471_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_471_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG117_CH_MAP_471_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG117_RESETVAL (0x00000000u)

/* ch_map_reg118 */

#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_472_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_472_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_472_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_473_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_473_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_473_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_474_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_474_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_474_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_475_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_475_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG118_CH_MAP_475_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG118_RESETVAL (0x00000000u)

/* ch_map_reg119 */

#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_476_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_476_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_476_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_477_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_477_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_477_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_478_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_478_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_478_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_479_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_479_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG119_CH_MAP_479_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG119_RESETVAL (0x00000000u)

/* ch_map_reg120 */

#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_480_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_480_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_480_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_481_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_481_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_481_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_482_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_482_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_482_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_483_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_483_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG120_CH_MAP_483_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG120_RESETVAL (0x00000000u)

/* ch_map_reg121 */

#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_484_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_484_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_484_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_485_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_485_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_485_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_486_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_486_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_486_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_487_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_487_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG121_CH_MAP_487_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG121_RESETVAL (0x00000000u)

/* ch_map_reg122 */

#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_488_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_488_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_488_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_489_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_489_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_489_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_490_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_490_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_490_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_491_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_491_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG122_CH_MAP_491_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG122_RESETVAL (0x00000000u)

/* ch_map_reg123 */

#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_492_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_492_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_492_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_493_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_493_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_493_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_494_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_494_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_494_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_495_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_495_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG123_CH_MAP_495_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG123_RESETVAL (0x00000000u)

/* ch_map_reg124 */

#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_496_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_496_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_496_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_497_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_497_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_497_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_498_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_498_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_498_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_499_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_499_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG124_CH_MAP_499_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG124_RESETVAL (0x00000000u)

/* ch_map_reg125 */

#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_500_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_500_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_500_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_501_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_501_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_501_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_502_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_502_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_502_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_503_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_503_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG125_CH_MAP_503_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG125_RESETVAL (0x00000000u)

/* ch_map_reg126 */

#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_504_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_504_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_504_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_505_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_505_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_505_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_506_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_506_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_506_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_507_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_507_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG126_CH_MAP_507_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG126_RESETVAL (0x00000000u)

/* ch_map_reg127 */

#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_508_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_508_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_508_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_509_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_509_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_509_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_510_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_510_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_510_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_511_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_511_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG127_CH_MAP_511_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG127_RESETVAL (0x00000000u)

/* ch_map_reg128 */

#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_512_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_512_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_512_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_513_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_513_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_513_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_514_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_514_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_514_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_515_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_515_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG128_CH_MAP_515_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG128_RESETVAL (0x00000000u)

/* ch_map_reg129 */

#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_516_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_516_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_516_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_517_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_517_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_517_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_518_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_518_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_518_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_519_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_519_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG129_CH_MAP_519_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG129_RESETVAL (0x00000000u)

/* ch_map_reg130 */

#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_520_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_520_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_520_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_521_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_521_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_521_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_522_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_522_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_522_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_523_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_523_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG130_CH_MAP_523_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG130_RESETVAL (0x00000000u)

/* ch_map_reg131 */

#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_524_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_524_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_524_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_525_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_525_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_525_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_526_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_526_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_526_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_527_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_527_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG131_CH_MAP_527_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG131_RESETVAL (0x00000000u)

/* ch_map_reg132 */

#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_528_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_528_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_528_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_529_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_529_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_529_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_530_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_530_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_530_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_531_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_531_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG132_CH_MAP_531_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG132_RESETVAL (0x00000000u)

/* ch_map_reg133 */

#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_532_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_532_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_532_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_533_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_533_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_533_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_534_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_534_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_534_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_535_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_535_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG133_CH_MAP_535_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG133_RESETVAL (0x00000000u)

/* ch_map_reg134 */

#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_536_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_536_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_536_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_537_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_537_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_537_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_538_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_538_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_538_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_539_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_539_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG134_CH_MAP_539_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG134_RESETVAL (0x00000000u)

/* ch_map_reg135 */

#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_540_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_540_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_540_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_541_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_541_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_541_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_542_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_542_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_542_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_543_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_543_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG135_CH_MAP_543_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG135_RESETVAL (0x00000000u)

/* ch_map_reg136 */

#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_544_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_544_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_544_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_545_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_545_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_545_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_546_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_546_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_546_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_547_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_547_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG136_CH_MAP_547_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG136_RESETVAL (0x00000000u)

/* ch_map_reg137 */

#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_548_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_548_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_548_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_549_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_549_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_549_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_550_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_550_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_550_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_551_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_551_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG137_CH_MAP_551_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG137_RESETVAL (0x00000000u)

/* ch_map_reg138 */

#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_552_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_552_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_552_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_553_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_553_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_553_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_554_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_554_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_554_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_555_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_555_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG138_CH_MAP_555_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG138_RESETVAL (0x00000000u)

/* ch_map_reg139 */

#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_556_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_556_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_556_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_557_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_557_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_557_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_558_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_558_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_558_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_559_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_559_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG139_CH_MAP_559_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG139_RESETVAL (0x00000000u)

/* ch_map_reg140 */

#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_560_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_560_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_560_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_561_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_561_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_561_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_562_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_562_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_562_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_563_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_563_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG140_CH_MAP_563_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG140_RESETVAL (0x00000000u)

/* ch_map_reg141 */

#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_564_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_564_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_564_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_565_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_565_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_565_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_566_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_566_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_566_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_567_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_567_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG141_CH_MAP_567_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG141_RESETVAL (0x00000000u)

/* ch_map_reg142 */

#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_568_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_568_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_568_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_569_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_569_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_569_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_570_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_570_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_570_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_571_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_571_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG142_CH_MAP_571_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG142_RESETVAL (0x00000000u)

/* ch_map_reg143 */

#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_572_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_572_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_572_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_573_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_573_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_573_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_574_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_574_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_574_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_575_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_575_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG143_CH_MAP_575_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG143_RESETVAL (0x00000000u)

/* ch_map_reg144 */

#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_576_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_576_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_576_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_577_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_577_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_577_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_578_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_578_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_578_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_579_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_579_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG144_CH_MAP_579_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG144_RESETVAL (0x00000000u)

/* ch_map_reg145 */

#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_580_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_580_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_580_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_581_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_581_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_581_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_582_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_582_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_582_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_583_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_583_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG145_CH_MAP_583_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG145_RESETVAL (0x00000000u)

/* ch_map_reg146 */

#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_584_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_584_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_584_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_585_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_585_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_585_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_586_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_586_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_586_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_587_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_587_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG146_CH_MAP_587_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG146_RESETVAL (0x00000000u)

/* ch_map_reg147 */

#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_588_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_588_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_588_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_589_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_589_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_589_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_590_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_590_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_590_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_591_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_591_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG147_CH_MAP_591_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG147_RESETVAL (0x00000000u)

/* ch_map_reg148 */

#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_592_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_592_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_592_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_593_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_593_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_593_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_594_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_594_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_594_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_595_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_595_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG148_CH_MAP_595_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG148_RESETVAL (0x00000000u)

/* ch_map_reg149 */

#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_596_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_596_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_596_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_597_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_597_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_597_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_598_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_598_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_598_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_599_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_599_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG149_CH_MAP_599_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG149_RESETVAL (0x00000000u)

/* ch_map_reg150 */

#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_600_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_600_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_600_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_601_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_601_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_601_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_602_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_602_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_602_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_603_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_603_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG150_CH_MAP_603_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG150_RESETVAL (0x00000000u)

/* ch_map_reg151 */

#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_604_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_604_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_604_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_605_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_605_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_605_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_606_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_606_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_606_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_607_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_607_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG151_CH_MAP_607_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG151_RESETVAL (0x00000000u)

/* ch_map_reg152 */

#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_608_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_608_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_608_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_609_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_609_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_609_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_610_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_610_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_610_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_611_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_611_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG152_CH_MAP_611_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG152_RESETVAL (0x00000000u)

/* ch_map_reg153 */

#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_612_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_612_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_612_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_613_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_613_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_613_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_614_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_614_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_614_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_615_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_615_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG153_CH_MAP_615_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG153_RESETVAL (0x00000000u)

/* ch_map_reg154 */

#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_616_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_616_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_616_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_617_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_617_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_617_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_618_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_618_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_618_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_619_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_619_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG154_CH_MAP_619_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG154_RESETVAL (0x00000000u)

/* ch_map_reg155 */

#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_620_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_620_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_620_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_621_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_621_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_621_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_622_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_622_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_622_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_623_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_623_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG155_CH_MAP_623_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG155_RESETVAL (0x00000000u)

/* ch_map_reg156 */

#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_624_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_624_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_624_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_625_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_625_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_625_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_626_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_626_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_626_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_627_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_627_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG156_CH_MAP_627_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG156_RESETVAL (0x00000000u)

/* ch_map_reg157 */

#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_628_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_628_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_628_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_629_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_629_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_629_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_630_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_630_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_630_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_631_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_631_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG157_CH_MAP_631_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG157_RESETVAL (0x00000000u)

/* ch_map_reg158 */

#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_632_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_632_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_632_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_633_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_633_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_633_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_634_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_634_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_634_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_635_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_635_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG158_CH_MAP_635_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG158_RESETVAL (0x00000000u)

/* ch_map_reg159 */

#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_636_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_636_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_636_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_637_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_637_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_637_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_638_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_638_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_638_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_639_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_639_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG159_CH_MAP_639_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG159_RESETVAL (0x00000000u)

/* ch_map_reg160 */

#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_640_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_640_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_640_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_641_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_641_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_641_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_642_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_642_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_642_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_643_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_643_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG160_CH_MAP_643_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG160_RESETVAL (0x00000000u)

/* ch_map_reg161 */

#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_644_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_644_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_644_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_645_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_645_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_645_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_646_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_646_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_646_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_647_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_647_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG161_CH_MAP_647_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG161_RESETVAL (0x00000000u)

/* ch_map_reg162 */

#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_648_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_648_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_648_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_649_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_649_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_649_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_650_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_650_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_650_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_651_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_651_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG162_CH_MAP_651_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG162_RESETVAL (0x00000000u)

/* ch_map_reg163 */

#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_652_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_652_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_652_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_653_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_653_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_653_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_654_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_654_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_654_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_655_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_655_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG163_CH_MAP_655_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG163_RESETVAL (0x00000000u)

/* ch_map_reg164 */

#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_656_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_656_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_656_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_657_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_657_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_657_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_658_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_658_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_658_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_659_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_659_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG164_CH_MAP_659_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG164_RESETVAL (0x00000000u)

/* ch_map_reg165 */

#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_660_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_660_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_660_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_661_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_661_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_661_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_662_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_662_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_662_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_663_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_663_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG165_CH_MAP_663_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG165_RESETVAL (0x00000000u)

/* ch_map_reg166 */

#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_664_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_664_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_664_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_665_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_665_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_665_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_666_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_666_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_666_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_667_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_667_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG166_CH_MAP_667_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG166_RESETVAL (0x00000000u)

/* ch_map_reg167 */

#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_668_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_668_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_668_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_669_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_669_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_669_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_670_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_670_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_670_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_671_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_671_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG167_CH_MAP_671_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG167_RESETVAL (0x00000000u)

/* ch_map_reg168 */

#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_672_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_672_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_672_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_673_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_673_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_673_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_674_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_674_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_674_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_675_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_675_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG168_CH_MAP_675_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG168_RESETVAL (0x00000000u)

/* ch_map_reg169 */

#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_676_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_676_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_676_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_677_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_677_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_677_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_678_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_678_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_678_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_679_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_679_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG169_CH_MAP_679_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG169_RESETVAL (0x00000000u)

/* ch_map_reg170 */

#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_680_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_680_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_680_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_681_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_681_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_681_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_682_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_682_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_682_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_683_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_683_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG170_CH_MAP_683_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG170_RESETVAL (0x00000000u)

/* ch_map_reg171 */

#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_684_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_684_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_684_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_685_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_685_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_685_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_686_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_686_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_686_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_687_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_687_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG171_CH_MAP_687_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG171_RESETVAL (0x00000000u)

/* ch_map_reg172 */

#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_688_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_688_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_688_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_689_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_689_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_689_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_690_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_690_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_690_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_691_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_691_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG172_CH_MAP_691_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG172_RESETVAL (0x00000000u)

/* ch_map_reg173 */

#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_692_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_692_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_692_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_693_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_693_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_693_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_694_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_694_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_694_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_695_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_695_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG173_CH_MAP_695_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG173_RESETVAL (0x00000000u)

/* ch_map_reg174 */

#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_696_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_696_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_696_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_697_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_697_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_697_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_698_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_698_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_698_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_699_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_699_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG174_CH_MAP_699_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG174_RESETVAL (0x00000000u)

/* ch_map_reg175 */

#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_700_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_700_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_700_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_701_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_701_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_701_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_702_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_702_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_702_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_703_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_703_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG175_CH_MAP_703_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG175_RESETVAL (0x00000000u)

/* ch_map_reg176 */

#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_704_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_704_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_704_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_705_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_705_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_705_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_706_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_706_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_706_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_707_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_707_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG176_CH_MAP_707_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG176_RESETVAL (0x00000000u)

/* ch_map_reg177 */

#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_708_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_708_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_708_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_709_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_709_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_709_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_710_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_710_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_710_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_711_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_711_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG177_CH_MAP_711_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG177_RESETVAL (0x00000000u)

/* ch_map_reg178 */

#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_712_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_712_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_712_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_713_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_713_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_713_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_714_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_714_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_714_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_715_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_715_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG178_CH_MAP_715_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG178_RESETVAL (0x00000000u)

/* ch_map_reg179 */

#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_716_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_716_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_716_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_717_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_717_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_717_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_718_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_718_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_718_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_719_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_719_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG179_CH_MAP_719_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG179_RESETVAL (0x00000000u)

/* ch_map_reg180 */

#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_720_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_720_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_720_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_721_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_721_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_721_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_722_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_722_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_722_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_723_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_723_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG180_CH_MAP_723_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG180_RESETVAL (0x00000000u)

/* ch_map_reg181 */

#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_724_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_724_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_724_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_725_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_725_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_725_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_726_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_726_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_726_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_727_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_727_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG181_CH_MAP_727_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG181_RESETVAL (0x00000000u)

/* ch_map_reg182 */

#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_728_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_728_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_728_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_729_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_729_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_729_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_730_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_730_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_730_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_731_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_731_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG182_CH_MAP_731_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG182_RESETVAL (0x00000000u)

/* ch_map_reg183 */

#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_732_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_732_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_732_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_733_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_733_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_733_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_734_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_734_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_734_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_735_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_735_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG183_CH_MAP_735_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG183_RESETVAL (0x00000000u)

/* ch_map_reg184 */

#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_736_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_736_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_736_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_737_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_737_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_737_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_738_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_738_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_738_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_739_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_739_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG184_CH_MAP_739_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG184_RESETVAL (0x00000000u)

/* ch_map_reg185 */

#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_740_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_740_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_740_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_741_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_741_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_741_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_742_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_742_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_742_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_743_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_743_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG185_CH_MAP_743_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG185_RESETVAL (0x00000000u)

/* ch_map_reg186 */

#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_744_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_744_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_744_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_745_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_745_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_745_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_746_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_746_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_746_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_747_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_747_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG186_CH_MAP_747_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG186_RESETVAL (0x00000000u)

/* ch_map_reg187 */

#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_748_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_748_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_748_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_749_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_749_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_749_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_750_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_750_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_750_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_751_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_751_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG187_CH_MAP_751_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG187_RESETVAL (0x00000000u)

/* ch_map_reg188 */

#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_752_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_752_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_752_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_753_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_753_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_753_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_754_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_754_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_754_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_755_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_755_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG188_CH_MAP_755_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG188_RESETVAL (0x00000000u)

/* ch_map_reg189 */

#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_756_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_756_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_756_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_757_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_757_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_757_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_758_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_758_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_758_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_759_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_759_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG189_CH_MAP_759_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG189_RESETVAL (0x00000000u)

/* ch_map_reg190 */

#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_760_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_760_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_760_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_761_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_761_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_761_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_762_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_762_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_762_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_763_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_763_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG190_CH_MAP_763_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG190_RESETVAL (0x00000000u)

/* ch_map_reg191 */

#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_764_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_764_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_764_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_765_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_765_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_765_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_766_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_766_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_766_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_767_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_767_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG191_CH_MAP_767_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG191_RESETVAL (0x00000000u)

/* ch_map_reg192 */

#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_768_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_768_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_768_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_769_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_769_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_769_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_770_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_770_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_770_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_771_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_771_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG192_CH_MAP_771_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG192_RESETVAL (0x00000000u)

/* ch_map_reg193 */

#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_772_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_772_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_772_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_773_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_773_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_773_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_774_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_774_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_774_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_775_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_775_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG193_CH_MAP_775_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG193_RESETVAL (0x00000000u)

/* ch_map_reg194 */

#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_776_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_776_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_776_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_777_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_777_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_777_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_778_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_778_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_778_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_779_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_779_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG194_CH_MAP_779_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG194_RESETVAL (0x00000000u)

/* ch_map_reg195 */

#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_780_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_780_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_780_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_781_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_781_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_781_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_782_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_782_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_782_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_783_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_783_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG195_CH_MAP_783_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG195_RESETVAL (0x00000000u)

/* ch_map_reg196 */

#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_784_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_784_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_784_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_785_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_785_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_785_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_786_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_786_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_786_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_787_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_787_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG196_CH_MAP_787_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG196_RESETVAL (0x00000000u)

/* ch_map_reg197 */

#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_788_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_788_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_788_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_789_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_789_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_789_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_790_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_790_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_790_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_791_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_791_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG197_CH_MAP_791_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG197_RESETVAL (0x00000000u)

/* ch_map_reg198 */

#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_792_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_792_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_792_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_793_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_793_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_793_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_794_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_794_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_794_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_795_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_795_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG198_CH_MAP_795_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG198_RESETVAL (0x00000000u)

/* ch_map_reg199 */

#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_796_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_796_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_796_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_797_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_797_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_797_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_798_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_798_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_798_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_799_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_799_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG199_CH_MAP_799_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG199_RESETVAL (0x00000000u)

/* ch_map_reg200 */

#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_800_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_800_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_800_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_801_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_801_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_801_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_802_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_802_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_802_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_803_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_803_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG200_CH_MAP_803_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG200_RESETVAL (0x00000000u)

/* ch_map_reg201 */

#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_804_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_804_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_804_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_805_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_805_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_805_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_806_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_806_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_806_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_807_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_807_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG201_CH_MAP_807_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG201_RESETVAL (0x00000000u)

/* ch_map_reg202 */

#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_808_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_808_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_808_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_809_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_809_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_809_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_810_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_810_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_810_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_811_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_811_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG202_CH_MAP_811_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG202_RESETVAL (0x00000000u)

/* ch_map_reg203 */

#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_812_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_812_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_812_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_813_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_813_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_813_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_814_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_814_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_814_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_815_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_815_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG203_CH_MAP_815_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG203_RESETVAL (0x00000000u)

/* ch_map_reg204 */

#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_816_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_816_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_816_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_817_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_817_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_817_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_818_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_818_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_818_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_819_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_819_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG204_CH_MAP_819_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG204_RESETVAL (0x00000000u)

/* ch_map_reg205 */

#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_820_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_820_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_820_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_821_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_821_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_821_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_822_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_822_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_822_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_823_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_823_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG205_CH_MAP_823_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG205_RESETVAL (0x00000000u)

/* ch_map_reg206 */

#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_824_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_824_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_824_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_825_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_825_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_825_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_826_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_826_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_826_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_827_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_827_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG206_CH_MAP_827_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG206_RESETVAL (0x00000000u)

/* ch_map_reg207 */

#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_828_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_828_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_828_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_829_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_829_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_829_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_830_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_830_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_830_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_831_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_831_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG207_CH_MAP_831_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG207_RESETVAL (0x00000000u)

/* ch_map_reg208 */

#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_832_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_832_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_832_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_833_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_833_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_833_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_834_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_834_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_834_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_835_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_835_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG208_CH_MAP_835_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG208_RESETVAL (0x00000000u)

/* ch_map_reg209 */

#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_836_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_836_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_836_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_837_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_837_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_837_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_838_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_838_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_838_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_839_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_839_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG209_CH_MAP_839_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG209_RESETVAL (0x00000000u)

/* ch_map_reg210 */

#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_840_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_840_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_840_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_841_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_841_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_841_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_842_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_842_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_842_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_843_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_843_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG210_CH_MAP_843_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG210_RESETVAL (0x00000000u)

/* ch_map_reg211 */

#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_844_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_844_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_844_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_845_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_845_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_845_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_846_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_846_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_846_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_847_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_847_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG211_CH_MAP_847_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG211_RESETVAL (0x00000000u)

/* ch_map_reg212 */

#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_848_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_848_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_848_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_849_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_849_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_849_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_850_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_850_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_850_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_851_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_851_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG212_CH_MAP_851_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG212_RESETVAL (0x00000000u)

/* ch_map_reg213 */

#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_852_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_852_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_852_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_853_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_853_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_853_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_854_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_854_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_854_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_855_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_855_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG213_CH_MAP_855_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG213_RESETVAL (0x00000000u)

/* ch_map_reg214 */

#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_856_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_856_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_856_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_857_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_857_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_857_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_858_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_858_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_858_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_859_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_859_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG214_CH_MAP_859_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG214_RESETVAL (0x00000000u)

/* ch_map_reg215 */

#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_860_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_860_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_860_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_861_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_861_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_861_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_862_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_862_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_862_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_863_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_863_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG215_CH_MAP_863_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG215_RESETVAL (0x00000000u)

/* ch_map_reg216 */

#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_864_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_864_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_864_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_865_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_865_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_865_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_866_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_866_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_866_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_867_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_867_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG216_CH_MAP_867_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG216_RESETVAL (0x00000000u)

/* ch_map_reg217 */

#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_868_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_868_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_868_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_869_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_869_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_869_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_870_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_870_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_870_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_871_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_871_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG217_CH_MAP_871_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG217_RESETVAL (0x00000000u)

/* ch_map_reg218 */

#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_872_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_872_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_872_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_873_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_873_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_873_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_874_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_874_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_874_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_875_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_875_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG218_CH_MAP_875_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG218_RESETVAL (0x00000000u)

/* ch_map_reg219 */

#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_876_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_876_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_876_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_877_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_877_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_877_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_878_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_878_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_878_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_879_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_879_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG219_CH_MAP_879_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG219_RESETVAL (0x00000000u)

/* ch_map_reg220 */

#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_880_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_880_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_880_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_881_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_881_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_881_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_882_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_882_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_882_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_883_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_883_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG220_CH_MAP_883_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG220_RESETVAL (0x00000000u)

/* ch_map_reg221 */

#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_884_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_884_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_884_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_885_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_885_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_885_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_886_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_886_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_886_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_887_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_887_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG221_CH_MAP_887_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG221_RESETVAL (0x00000000u)

/* ch_map_reg222 */

#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_888_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_888_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_888_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_889_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_889_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_889_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_890_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_890_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_890_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_891_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_891_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG222_CH_MAP_891_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG222_RESETVAL (0x00000000u)

/* ch_map_reg223 */

#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_892_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_892_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_892_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_893_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_893_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_893_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_894_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_894_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_894_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_895_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_895_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG223_CH_MAP_895_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG223_RESETVAL (0x00000000u)

/* ch_map_reg224 */

#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_896_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_896_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_896_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_897_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_897_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_897_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_898_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_898_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_898_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_899_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_899_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG224_CH_MAP_899_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG224_RESETVAL (0x00000000u)

/* ch_map_reg225 */

#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_900_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_900_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_900_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_901_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_901_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_901_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_902_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_902_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_902_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_903_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_903_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG225_CH_MAP_903_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG225_RESETVAL (0x00000000u)

/* ch_map_reg226 */

#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_904_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_904_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_904_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_905_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_905_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_905_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_906_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_906_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_906_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_907_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_907_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG226_CH_MAP_907_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG226_RESETVAL (0x00000000u)

/* ch_map_reg227 */

#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_908_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_908_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_908_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_909_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_909_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_909_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_910_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_910_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_910_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_911_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_911_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG227_CH_MAP_911_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG227_RESETVAL (0x00000000u)

/* ch_map_reg228 */

#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_912_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_912_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_912_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_913_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_913_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_913_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_914_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_914_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_914_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_915_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_915_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG228_CH_MAP_915_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG228_RESETVAL (0x00000000u)

/* ch_map_reg229 */

#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_916_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_916_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_916_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_917_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_917_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_917_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_918_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_918_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_918_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_919_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_919_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG229_CH_MAP_919_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG229_RESETVAL (0x00000000u)

/* ch_map_reg230 */

#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_920_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_920_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_920_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_921_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_921_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_921_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_922_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_922_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_922_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_923_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_923_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG230_CH_MAP_923_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG230_RESETVAL (0x00000000u)

/* ch_map_reg231 */

#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_924_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_924_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_924_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_925_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_925_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_925_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_926_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_926_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_926_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_927_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_927_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG231_CH_MAP_927_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG231_RESETVAL (0x00000000u)

/* ch_map_reg232 */

#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_928_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_928_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_928_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_929_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_929_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_929_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_930_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_930_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_930_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_931_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_931_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG232_CH_MAP_931_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG232_RESETVAL (0x00000000u)

/* ch_map_reg233 */

#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_932_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_932_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_932_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_933_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_933_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_933_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_934_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_934_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_934_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_935_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_935_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG233_CH_MAP_935_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG233_RESETVAL (0x00000000u)

/* ch_map_reg234 */

#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_936_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_936_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_936_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_937_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_937_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_937_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_938_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_938_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_938_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_939_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_939_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG234_CH_MAP_939_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG234_RESETVAL (0x00000000u)

/* ch_map_reg235 */

#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_940_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_940_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_940_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_941_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_941_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_941_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_942_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_942_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_942_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_943_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_943_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG235_CH_MAP_943_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG235_RESETVAL (0x00000000u)

/* ch_map_reg236 */

#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_944_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_944_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_944_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_945_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_945_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_945_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_946_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_946_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_946_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_947_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_947_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG236_CH_MAP_947_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG236_RESETVAL (0x00000000u)

/* ch_map_reg237 */

#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_948_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_948_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_948_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_949_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_949_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_949_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_950_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_950_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_950_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_951_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_951_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG237_CH_MAP_951_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG237_RESETVAL (0x00000000u)

/* ch_map_reg238 */

#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_952_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_952_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_952_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_953_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_953_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_953_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_954_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_954_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_954_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_955_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_955_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG238_CH_MAP_955_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG238_RESETVAL (0x00000000u)

/* ch_map_reg239 */

#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_956_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_956_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_956_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_957_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_957_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_957_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_958_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_958_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_958_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_959_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_959_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG239_CH_MAP_959_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG239_RESETVAL (0x00000000u)

/* ch_map_reg240 */

#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_960_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_960_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_960_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_961_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_961_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_961_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_962_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_962_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_962_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_963_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_963_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG240_CH_MAP_963_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG240_RESETVAL (0x00000000u)

/* ch_map_reg241 */

#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_964_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_964_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_964_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_965_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_965_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_965_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_966_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_966_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_966_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_967_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_967_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG241_CH_MAP_967_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG241_RESETVAL (0x00000000u)

/* ch_map_reg242 */

#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_968_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_968_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_968_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_969_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_969_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_969_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_970_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_970_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_970_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_971_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_971_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG242_CH_MAP_971_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG242_RESETVAL (0x00000000u)

/* ch_map_reg243 */

#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_972_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_972_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_972_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_973_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_973_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_973_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_974_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_974_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_974_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_975_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_975_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG243_CH_MAP_975_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG243_RESETVAL (0x00000000u)

/* ch_map_reg244 */

#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_976_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_976_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_976_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_977_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_977_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_977_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_978_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_978_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_978_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_979_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_979_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG244_CH_MAP_979_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG244_RESETVAL (0x00000000u)

/* ch_map_reg245 */

#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_980_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_980_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_980_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_981_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_981_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_981_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_982_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_982_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_982_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_983_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_983_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG245_CH_MAP_983_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG245_RESETVAL (0x00000000u)

/* ch_map_reg246 */

#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_984_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_984_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_984_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_985_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_985_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_985_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_986_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_986_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_986_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_987_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_987_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG246_CH_MAP_987_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG246_RESETVAL (0x00000000u)

/* ch_map_reg247 */

#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_988_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_988_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_988_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_989_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_989_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_989_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_990_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_990_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_990_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_991_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_991_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG247_CH_MAP_991_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG247_RESETVAL (0x00000000u)

/* ch_map_reg248 */

#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_992_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_992_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_992_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_993_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_993_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_993_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_994_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_994_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_994_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_995_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_995_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG248_CH_MAP_995_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG248_RESETVAL (0x00000000u)

/* ch_map_reg249 */

#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_996_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_996_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_996_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_997_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_997_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_997_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_998_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_998_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_998_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_999_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_999_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG249_CH_MAP_999_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG249_RESETVAL (0x00000000u)

/* ch_map_reg250 */

#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1000_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1000_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1000_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1001_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1001_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1001_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1002_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1002_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1002_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1003_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1003_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG250_CH_MAP_1003_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG250_RESETVAL (0x00000000u)

/* ch_map_reg251 */

#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1004_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1004_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1004_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1005_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1005_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1005_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1006_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1006_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1006_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1007_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1007_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG251_CH_MAP_1007_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG251_RESETVAL (0x00000000u)

/* ch_map_reg252 */

#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1008_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1008_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1008_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1009_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1009_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1009_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1010_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1010_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1010_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1011_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1011_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG252_CH_MAP_1011_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG252_RESETVAL (0x00000000u)

/* ch_map_reg253 */

#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1012_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1012_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1012_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1013_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1013_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1013_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1014_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1014_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1014_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1015_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1015_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG253_CH_MAP_1015_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG253_RESETVAL (0x00000000u)

/* ch_map_reg254 */

#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1016_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1016_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1016_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1017_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1017_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1017_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1018_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1018_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1018_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1019_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1019_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG254_CH_MAP_1019_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG254_RESETVAL (0x00000000u)

/* ch_map_reg255 */

#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1020_MASK (0x000000FFu)
#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1020_SHIFT (0x00000000u)
#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1020_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1021_MASK (0x0000FF00u)
#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1021_SHIFT (0x00000008u)
#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1021_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1022_MASK (0x00FF0000u)
#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1022_SHIFT (0x00000010u)
#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1022_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1023_MASK (0xFF000000u)
#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1023_SHIFT (0x00000018u)
#define CSL_CPINTC_CH_MAP_REG255_CH_MAP_1023_RESETVAL (0x00000000u)

#define CSL_CPINTC_CH_MAP_REG255_RESETVAL (0x00000000u)

/* hint_map_reg0 */

#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_0_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_0_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_1_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_1_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_2_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_2_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_3_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_3_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG0_HINT_MAP_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG0_RESETVAL (0x00000000u)

/* hint_map_reg1 */

#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_4_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_4_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_5_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_5_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_6_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_6_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_7_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_7_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG1_HINT_MAP_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG1_RESETVAL (0x00000000u)

/* hint_map_reg2 */

#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_8_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_8_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_9_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_9_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_10_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_10_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_11_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_11_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG2_HINT_MAP_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG2_RESETVAL (0x00000000u)

/* hint_map_reg3 */

#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_12_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_12_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_13_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_13_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_14_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_14_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_15_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_15_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG3_HINT_MAP_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG3_RESETVAL (0x00000000u)

/* hint_map_reg4 */

#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_16_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_16_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_17_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_17_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_18_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_18_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_19_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_19_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG4_HINT_MAP_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG4_RESETVAL (0x00000000u)

/* hint_map_reg5 */

#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_20_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_20_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_21_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_21_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_22_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_22_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_23_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_23_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG5_HINT_MAP_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG5_RESETVAL (0x00000000u)

/* hint_map_reg6 */

#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_24_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_24_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_25_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_25_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_26_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_26_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_27_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_27_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG6_HINT_MAP_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG6_RESETVAL (0x00000000u)

/* hint_map_reg7 */

#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_28_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_28_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_29_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_29_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_30_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_30_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_31_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_31_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG7_HINT_MAP_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG7_RESETVAL (0x00000000u)

/* hint_map_reg8 */

#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_32_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_32_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_33_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_33_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_34_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_34_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_35_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_35_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG8_HINT_MAP_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG8_RESETVAL (0x00000000u)

/* hint_map_reg9 */

#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_36_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_36_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_37_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_37_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_38_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_38_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_39_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_39_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG9_HINT_MAP_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG9_RESETVAL (0x00000000u)

/* hint_map_reg10 */

#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_40_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_40_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_41_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_41_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_42_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_42_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_43_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_43_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG10_HINT_MAP_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG10_RESETVAL (0x00000000u)

/* hint_map_reg11 */

#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_44_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_44_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_45_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_45_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_46_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_46_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_47_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_47_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG11_HINT_MAP_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG11_RESETVAL (0x00000000u)

/* hint_map_reg12 */

#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_48_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_48_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_49_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_49_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_50_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_50_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_51_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_51_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG12_HINT_MAP_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG12_RESETVAL (0x00000000u)

/* hint_map_reg13 */

#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_52_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_52_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_53_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_53_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_54_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_54_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_55_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_55_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG13_HINT_MAP_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG13_RESETVAL (0x00000000u)

/* hint_map_reg14 */

#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_56_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_56_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_57_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_57_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_58_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_58_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_59_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_59_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG14_HINT_MAP_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG14_RESETVAL (0x00000000u)

/* hint_map_reg15 */

#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_60_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_60_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_61_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_61_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_62_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_62_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_63_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_63_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG15_HINT_MAP_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG15_RESETVAL (0x00000000u)

/* hint_map_reg16 */

#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_64_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_64_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_65_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_65_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_66_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_66_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_67_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_67_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG16_HINT_MAP_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG16_RESETVAL (0x00000000u)

/* hint_map_reg17 */

#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_68_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_68_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_69_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_69_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_70_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_70_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_71_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_71_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG17_HINT_MAP_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG17_RESETVAL (0x00000000u)

/* hint_map_reg18 */

#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_72_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_72_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_73_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_73_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_74_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_74_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_75_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_75_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG18_HINT_MAP_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG18_RESETVAL (0x00000000u)

/* hint_map_reg19 */

#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_76_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_76_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_77_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_77_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_78_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_78_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_79_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_79_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG19_HINT_MAP_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG19_RESETVAL (0x00000000u)

/* hint_map_reg20 */

#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_80_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_80_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_81_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_81_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_82_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_82_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_83_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_83_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG20_HINT_MAP_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG20_RESETVAL (0x00000000u)

/* hint_map_reg21 */

#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_84_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_84_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_85_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_85_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_86_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_86_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_87_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_87_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG21_HINT_MAP_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG21_RESETVAL (0x00000000u)

/* hint_map_reg22 */

#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_88_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_88_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_89_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_89_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_90_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_90_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_91_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_91_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG22_HINT_MAP_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG22_RESETVAL (0x00000000u)

/* hint_map_reg23 */

#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_92_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_92_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_93_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_93_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_94_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_94_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_95_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_95_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG23_HINT_MAP_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG23_RESETVAL (0x00000000u)

/* hint_map_reg24 */

#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_96_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_96_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_97_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_97_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_98_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_98_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_99_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_99_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG24_HINT_MAP_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG24_RESETVAL (0x00000000u)

/* hint_map_reg25 */

#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_100_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_100_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_101_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_101_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_102_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_102_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_103_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_103_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG25_HINT_MAP_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG25_RESETVAL (0x00000000u)

/* hint_map_reg26 */

#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_104_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_104_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_105_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_105_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_106_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_106_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_107_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_107_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG26_HINT_MAP_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG26_RESETVAL (0x00000000u)

/* hint_map_reg27 */

#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_108_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_108_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_109_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_109_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_110_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_110_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_111_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_111_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG27_HINT_MAP_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG27_RESETVAL (0x00000000u)

/* hint_map_reg28 */

#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_112_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_112_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_113_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_113_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_114_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_114_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_115_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_115_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG28_HINT_MAP_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG28_RESETVAL (0x00000000u)

/* hint_map_reg29 */

#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_116_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_116_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_117_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_117_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_118_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_118_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_119_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_119_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG29_HINT_MAP_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG29_RESETVAL (0x00000000u)

/* hint_map_reg30 */

#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_120_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_120_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_121_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_121_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_122_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_122_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_123_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_123_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG30_HINT_MAP_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG30_RESETVAL (0x00000000u)

/* hint_map_reg31 */

#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_124_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_124_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_125_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_125_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_126_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_126_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_127_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_127_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG31_HINT_MAP_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG31_RESETVAL (0x00000000u)

/* hint_map_reg32 */

#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_128_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_128_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_129_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_129_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_130_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_130_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_131_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_131_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG32_HINT_MAP_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG32_RESETVAL (0x00000000u)

/* hint_map_reg33 */

#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_132_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_132_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_133_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_133_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_134_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_134_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_135_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_135_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG33_HINT_MAP_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG33_RESETVAL (0x00000000u)

/* hint_map_reg34 */

#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_136_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_136_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_137_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_137_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_138_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_138_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_139_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_139_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG34_HINT_MAP_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG34_RESETVAL (0x00000000u)

/* hint_map_reg35 */

#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_140_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_140_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_141_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_141_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_142_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_142_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_143_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_143_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG35_HINT_MAP_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG35_RESETVAL (0x00000000u)

/* hint_map_reg36 */

#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_144_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_144_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_145_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_145_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_146_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_146_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_147_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_147_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG36_HINT_MAP_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG36_RESETVAL (0x00000000u)

/* hint_map_reg37 */

#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_148_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_148_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_149_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_149_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_150_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_150_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_151_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_151_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG37_HINT_MAP_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG37_RESETVAL (0x00000000u)

/* hint_map_reg38 */

#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_152_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_152_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_153_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_153_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_154_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_154_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_155_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_155_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG38_HINT_MAP_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG38_RESETVAL (0x00000000u)

/* hint_map_reg39 */

#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_156_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_156_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_157_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_157_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_158_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_158_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_159_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_159_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG39_HINT_MAP_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG39_RESETVAL (0x00000000u)

/* hint_map_reg40 */

#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_160_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_160_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_161_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_161_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_162_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_162_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_163_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_163_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG40_HINT_MAP_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG40_RESETVAL (0x00000000u)

/* hint_map_reg41 */

#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_164_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_164_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_165_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_165_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_166_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_166_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_167_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_167_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG41_HINT_MAP_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG41_RESETVAL (0x00000000u)

/* hint_map_reg42 */

#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_168_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_168_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_169_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_169_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_170_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_170_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_171_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_171_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG42_HINT_MAP_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG42_RESETVAL (0x00000000u)

/* hint_map_reg43 */

#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_172_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_172_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_173_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_173_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_174_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_174_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_175_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_175_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG43_HINT_MAP_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG43_RESETVAL (0x00000000u)

/* hint_map_reg44 */

#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_176_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_176_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_177_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_177_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_178_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_178_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_179_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_179_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG44_HINT_MAP_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG44_RESETVAL (0x00000000u)

/* hint_map_reg45 */

#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_180_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_180_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_181_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_181_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_182_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_182_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_183_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_183_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG45_HINT_MAP_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG45_RESETVAL (0x00000000u)

/* hint_map_reg46 */

#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_184_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_184_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_185_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_185_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_186_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_186_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_187_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_187_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG46_HINT_MAP_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG46_RESETVAL (0x00000000u)

/* hint_map_reg47 */

#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_188_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_188_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_189_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_189_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_190_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_190_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_191_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_191_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG47_HINT_MAP_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG47_RESETVAL (0x00000000u)

/* hint_map_reg48 */

#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_192_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_192_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_193_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_193_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_194_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_194_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_195_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_195_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG48_HINT_MAP_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG48_RESETVAL (0x00000000u)

/* hint_map_reg49 */

#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_196_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_196_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_197_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_197_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_198_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_198_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_199_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_199_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG49_HINT_MAP_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG49_RESETVAL (0x00000000u)

/* hint_map_reg50 */

#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_200_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_200_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_201_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_201_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_202_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_202_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_203_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_203_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG50_HINT_MAP_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG50_RESETVAL (0x00000000u)

/* hint_map_reg51 */

#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_204_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_204_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_205_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_205_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_206_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_206_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_207_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_207_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG51_HINT_MAP_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG51_RESETVAL (0x00000000u)

/* hint_map_reg52 */

#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_208_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_208_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_209_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_209_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_210_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_210_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_211_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_211_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG52_HINT_MAP_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG52_RESETVAL (0x00000000u)

/* hint_map_reg53 */

#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_212_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_212_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_213_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_213_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_214_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_214_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_215_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_215_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG53_HINT_MAP_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG53_RESETVAL (0x00000000u)

/* hint_map_reg54 */

#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_216_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_216_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_217_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_217_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_218_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_218_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_219_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_219_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG54_HINT_MAP_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG54_RESETVAL (0x00000000u)

/* hint_map_reg55 */

#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_220_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_220_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_221_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_221_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_222_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_222_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_223_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_223_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG55_HINT_MAP_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG55_RESETVAL (0x00000000u)

/* hint_map_reg56 */

#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_224_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_224_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_225_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_225_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_226_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_226_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_227_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_227_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG56_HINT_MAP_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG56_RESETVAL (0x00000000u)

/* hint_map_reg57 */

#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_228_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_228_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_229_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_229_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_230_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_230_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_231_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_231_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG57_HINT_MAP_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG57_RESETVAL (0x00000000u)

/* hint_map_reg58 */

#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_232_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_232_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_233_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_233_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_234_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_234_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_235_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_235_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG58_HINT_MAP_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG58_RESETVAL (0x00000000u)

/* hint_map_reg59 */

#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_236_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_236_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_237_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_237_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_238_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_238_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_239_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_239_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG59_HINT_MAP_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG59_RESETVAL (0x00000000u)

/* hint_map_reg60 */

#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_240_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_240_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_241_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_241_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_242_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_242_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_243_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_243_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG60_HINT_MAP_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG60_RESETVAL (0x00000000u)

/* hint_map_reg61 */

#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_244_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_244_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_245_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_245_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_246_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_246_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_247_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_247_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG61_HINT_MAP_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG61_RESETVAL (0x00000000u)

/* hint_map_reg62 */

#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_248_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_248_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_249_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_249_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_250_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_250_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_251_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_251_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG62_HINT_MAP_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG62_RESETVAL (0x00000000u)

/* hint_map_reg63 */

#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_252_MASK (0x000000FFu)
#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_252_SHIFT (0x00000000u)
#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_253_MASK (0x0000FF00u)
#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_253_SHIFT (0x00000008u)
#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_254_MASK (0x00FF0000u)
#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_254_SHIFT (0x00000010u)
#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_255_MASK (0xFF000000u)
#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_255_SHIFT (0x00000018u)
#define CSL_CPINTC_HINT_MAP_REG63_HINT_MAP_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_HINT_MAP_REG63_RESETVAL (0x00000000u)

/* pri_hint_reg0 */

#define CSL_CPINTC_PRI_HINT_REG0_PRI_HINT_0_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG0_PRI_HINT_0_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG0_PRI_HINT_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG0_NONE_HINT_0_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG0_NONE_HINT_0_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG0_NONE_HINT_0_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG0_RESETVAL (0x80000000u)

/* pri_hint_reg1 */

#define CSL_CPINTC_PRI_HINT_REG1_PRI_HINT_1_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG1_PRI_HINT_1_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG1_PRI_HINT_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG1_NONE_HINT_1_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG1_NONE_HINT_1_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG1_NONE_HINT_1_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG1_RESETVAL (0x80000000u)

/* pri_hint_reg2 */

#define CSL_CPINTC_PRI_HINT_REG2_PRI_HINT_2_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG2_PRI_HINT_2_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG2_PRI_HINT_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG2_NONE_HINT_2_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG2_NONE_HINT_2_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG2_NONE_HINT_2_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG2_RESETVAL (0x80000000u)

/* pri_hint_reg3 */

#define CSL_CPINTC_PRI_HINT_REG3_PRI_HINT_3_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG3_PRI_HINT_3_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG3_PRI_HINT_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG3_NONE_HINT_3_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG3_NONE_HINT_3_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG3_NONE_HINT_3_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG3_RESETVAL (0x80000000u)

/* pri_hint_reg4 */

#define CSL_CPINTC_PRI_HINT_REG4_PRI_HINT_4_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG4_PRI_HINT_4_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG4_PRI_HINT_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG4_NONE_HINT_4_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG4_NONE_HINT_4_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG4_NONE_HINT_4_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG4_RESETVAL (0x80000000u)

/* pri_hint_reg5 */

#define CSL_CPINTC_PRI_HINT_REG5_PRI_HINT_5_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG5_PRI_HINT_5_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG5_PRI_HINT_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG5_NONE_HINT_5_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG5_NONE_HINT_5_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG5_NONE_HINT_5_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG5_RESETVAL (0x80000000u)

/* pri_hint_reg6 */

#define CSL_CPINTC_PRI_HINT_REG6_PRI_HINT_6_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG6_PRI_HINT_6_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG6_PRI_HINT_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG6_NONE_HINT_6_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG6_NONE_HINT_6_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG6_NONE_HINT_6_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG6_RESETVAL (0x80000000u)

/* pri_hint_reg7 */

#define CSL_CPINTC_PRI_HINT_REG7_PRI_HINT_7_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG7_PRI_HINT_7_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG7_PRI_HINT_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG7_NONE_HINT_7_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG7_NONE_HINT_7_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG7_NONE_HINT_7_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG7_RESETVAL (0x80000000u)

/* pri_hint_reg8 */

#define CSL_CPINTC_PRI_HINT_REG8_PRI_HINT_8_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG8_PRI_HINT_8_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG8_PRI_HINT_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG8_NONE_HINT_8_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG8_NONE_HINT_8_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG8_NONE_HINT_8_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG8_RESETVAL (0x80000000u)

/* pri_hint_reg9 */

#define CSL_CPINTC_PRI_HINT_REG9_PRI_HINT_9_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG9_PRI_HINT_9_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG9_PRI_HINT_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG9_NONE_HINT_9_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG9_NONE_HINT_9_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG9_NONE_HINT_9_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG9_RESETVAL (0x80000000u)

/* pri_hint_reg10 */

#define CSL_CPINTC_PRI_HINT_REG10_PRI_HINT_10_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG10_PRI_HINT_10_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG10_PRI_HINT_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG10_NONE_HINT_10_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG10_NONE_HINT_10_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG10_NONE_HINT_10_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG10_RESETVAL (0x80000000u)

/* pri_hint_reg11 */

#define CSL_CPINTC_PRI_HINT_REG11_PRI_HINT_11_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG11_PRI_HINT_11_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG11_PRI_HINT_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG11_NONE_HINT_11_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG11_NONE_HINT_11_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG11_NONE_HINT_11_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG11_RESETVAL (0x80000000u)

/* pri_hint_reg12 */

#define CSL_CPINTC_PRI_HINT_REG12_PRI_HINT_12_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG12_PRI_HINT_12_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG12_PRI_HINT_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG12_NONE_HINT_12_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG12_NONE_HINT_12_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG12_NONE_HINT_12_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG12_RESETVAL (0x80000000u)

/* pri_hint_reg13 */

#define CSL_CPINTC_PRI_HINT_REG13_PRI_HINT_13_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG13_PRI_HINT_13_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG13_PRI_HINT_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG13_NONE_HINT_13_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG13_NONE_HINT_13_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG13_NONE_HINT_13_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG13_RESETVAL (0x80000000u)

/* pri_hint_reg14 */

#define CSL_CPINTC_PRI_HINT_REG14_PRI_HINT_14_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG14_PRI_HINT_14_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG14_PRI_HINT_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG14_NONE_HINT_14_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG14_NONE_HINT_14_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG14_NONE_HINT_14_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG14_RESETVAL (0x80000000u)

/* pri_hint_reg15 */

#define CSL_CPINTC_PRI_HINT_REG15_PRI_HINT_15_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG15_PRI_HINT_15_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG15_PRI_HINT_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG15_NONE_HINT_15_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG15_NONE_HINT_15_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG15_NONE_HINT_15_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG15_RESETVAL (0x80000000u)

/* pri_hint_reg16 */

#define CSL_CPINTC_PRI_HINT_REG16_PRI_HINT_16_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG16_PRI_HINT_16_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG16_PRI_HINT_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG16_NONE_HINT_16_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG16_NONE_HINT_16_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG16_NONE_HINT_16_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG16_RESETVAL (0x80000000u)

/* pri_hint_reg17 */

#define CSL_CPINTC_PRI_HINT_REG17_PRI_HINT_17_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG17_PRI_HINT_17_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG17_PRI_HINT_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG17_NONE_HINT_17_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG17_NONE_HINT_17_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG17_NONE_HINT_17_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG17_RESETVAL (0x80000000u)

/* pri_hint_reg18 */

#define CSL_CPINTC_PRI_HINT_REG18_PRI_HINT_18_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG18_PRI_HINT_18_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG18_PRI_HINT_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG18_NONE_HINT_18_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG18_NONE_HINT_18_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG18_NONE_HINT_18_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG18_RESETVAL (0x80000000u)

/* pri_hint_reg19 */

#define CSL_CPINTC_PRI_HINT_REG19_PRI_HINT_19_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG19_PRI_HINT_19_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG19_PRI_HINT_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG19_NONE_HINT_19_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG19_NONE_HINT_19_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG19_NONE_HINT_19_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG19_RESETVAL (0x80000000u)

/* pri_hint_reg20 */

#define CSL_CPINTC_PRI_HINT_REG20_PRI_HINT_20_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG20_PRI_HINT_20_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG20_PRI_HINT_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG20_NONE_HINT_20_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG20_NONE_HINT_20_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG20_NONE_HINT_20_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG20_RESETVAL (0x80000000u)

/* pri_hint_reg21 */

#define CSL_CPINTC_PRI_HINT_REG21_PRI_HINT_21_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG21_PRI_HINT_21_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG21_PRI_HINT_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG21_NONE_HINT_21_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG21_NONE_HINT_21_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG21_NONE_HINT_21_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG21_RESETVAL (0x80000000u)

/* pri_hint_reg22 */

#define CSL_CPINTC_PRI_HINT_REG22_PRI_HINT_22_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG22_PRI_HINT_22_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG22_PRI_HINT_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG22_NONE_HINT_22_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG22_NONE_HINT_22_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG22_NONE_HINT_22_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG22_RESETVAL (0x80000000u)

/* pri_hint_reg23 */

#define CSL_CPINTC_PRI_HINT_REG23_PRI_HINT_23_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG23_PRI_HINT_23_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG23_PRI_HINT_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG23_NONE_HINT_23_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG23_NONE_HINT_23_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG23_NONE_HINT_23_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG23_RESETVAL (0x80000000u)

/* pri_hint_reg24 */

#define CSL_CPINTC_PRI_HINT_REG24_PRI_HINT_24_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG24_PRI_HINT_24_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG24_PRI_HINT_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG24_NONE_HINT_24_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG24_NONE_HINT_24_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG24_NONE_HINT_24_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG24_RESETVAL (0x80000000u)

/* pri_hint_reg25 */

#define CSL_CPINTC_PRI_HINT_REG25_PRI_HINT_25_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG25_PRI_HINT_25_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG25_PRI_HINT_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG25_NONE_HINT_25_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG25_NONE_HINT_25_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG25_NONE_HINT_25_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG25_RESETVAL (0x80000000u)

/* pri_hint_reg26 */

#define CSL_CPINTC_PRI_HINT_REG26_PRI_HINT_26_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG26_PRI_HINT_26_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG26_PRI_HINT_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG26_NONE_HINT_26_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG26_NONE_HINT_26_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG26_NONE_HINT_26_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG26_RESETVAL (0x80000000u)

/* pri_hint_reg27 */

#define CSL_CPINTC_PRI_HINT_REG27_PRI_HINT_27_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG27_PRI_HINT_27_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG27_PRI_HINT_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG27_NONE_HINT_27_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG27_NONE_HINT_27_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG27_NONE_HINT_27_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG27_RESETVAL (0x80000000u)

/* pri_hint_reg28 */

#define CSL_CPINTC_PRI_HINT_REG28_PRI_HINT_28_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG28_PRI_HINT_28_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG28_PRI_HINT_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG28_NONE_HINT_28_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG28_NONE_HINT_28_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG28_NONE_HINT_28_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG28_RESETVAL (0x80000000u)

/* pri_hint_reg29 */

#define CSL_CPINTC_PRI_HINT_REG29_PRI_HINT_29_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG29_PRI_HINT_29_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG29_PRI_HINT_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG29_NONE_HINT_29_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG29_NONE_HINT_29_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG29_NONE_HINT_29_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG29_RESETVAL (0x80000000u)

/* pri_hint_reg30 */

#define CSL_CPINTC_PRI_HINT_REG30_PRI_HINT_30_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG30_PRI_HINT_30_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG30_PRI_HINT_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG30_NONE_HINT_30_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG30_NONE_HINT_30_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG30_NONE_HINT_30_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG30_RESETVAL (0x80000000u)

/* pri_hint_reg31 */

#define CSL_CPINTC_PRI_HINT_REG31_PRI_HINT_31_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG31_PRI_HINT_31_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG31_PRI_HINT_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG31_NONE_HINT_31_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG31_NONE_HINT_31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG31_NONE_HINT_31_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG31_RESETVAL (0x80000000u)

/* pri_hint_reg32 */

#define CSL_CPINTC_PRI_HINT_REG32_PRI_HINT_32_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG32_PRI_HINT_32_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG32_PRI_HINT_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG32_NONE_HINT_32_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG32_NONE_HINT_32_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG32_NONE_HINT_32_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG32_RESETVAL (0x80000000u)

/* pri_hint_reg33 */

#define CSL_CPINTC_PRI_HINT_REG33_PRI_HINT_33_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG33_PRI_HINT_33_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG33_PRI_HINT_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG33_NONE_HINT_33_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG33_NONE_HINT_33_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG33_NONE_HINT_33_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG33_RESETVAL (0x80000000u)

/* pri_hint_reg34 */

#define CSL_CPINTC_PRI_HINT_REG34_PRI_HINT_34_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG34_PRI_HINT_34_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG34_PRI_HINT_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG34_NONE_HINT_34_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG34_NONE_HINT_34_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG34_NONE_HINT_34_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG34_RESETVAL (0x80000000u)

/* pri_hint_reg35 */

#define CSL_CPINTC_PRI_HINT_REG35_PRI_HINT_35_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG35_PRI_HINT_35_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG35_PRI_HINT_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG35_NONE_HINT_35_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG35_NONE_HINT_35_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG35_NONE_HINT_35_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG35_RESETVAL (0x80000000u)

/* pri_hint_reg36 */

#define CSL_CPINTC_PRI_HINT_REG36_PRI_HINT_36_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG36_PRI_HINT_36_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG36_PRI_HINT_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG36_NONE_HINT_36_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG36_NONE_HINT_36_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG36_NONE_HINT_36_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG36_RESETVAL (0x80000000u)

/* pri_hint_reg37 */

#define CSL_CPINTC_PRI_HINT_REG37_PRI_HINT_37_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG37_PRI_HINT_37_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG37_PRI_HINT_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG37_NONE_HINT_37_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG37_NONE_HINT_37_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG37_NONE_HINT_37_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG37_RESETVAL (0x80000000u)

/* pri_hint_reg38 */

#define CSL_CPINTC_PRI_HINT_REG38_PRI_HINT_38_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG38_PRI_HINT_38_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG38_PRI_HINT_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG38_NONE_HINT_38_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG38_NONE_HINT_38_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG38_NONE_HINT_38_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG38_RESETVAL (0x80000000u)

/* pri_hint_reg39 */

#define CSL_CPINTC_PRI_HINT_REG39_PRI_HINT_39_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG39_PRI_HINT_39_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG39_PRI_HINT_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG39_NONE_HINT_39_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG39_NONE_HINT_39_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG39_NONE_HINT_39_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG39_RESETVAL (0x80000000u)

/* pri_hint_reg40 */

#define CSL_CPINTC_PRI_HINT_REG40_PRI_HINT_40_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG40_PRI_HINT_40_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG40_PRI_HINT_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG40_NONE_HINT_40_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG40_NONE_HINT_40_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG40_NONE_HINT_40_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG40_RESETVAL (0x80000000u)

/* pri_hint_reg41 */

#define CSL_CPINTC_PRI_HINT_REG41_PRI_HINT_41_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG41_PRI_HINT_41_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG41_PRI_HINT_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG41_NONE_HINT_41_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG41_NONE_HINT_41_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG41_NONE_HINT_41_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG41_RESETVAL (0x80000000u)

/* pri_hint_reg42 */

#define CSL_CPINTC_PRI_HINT_REG42_PRI_HINT_42_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG42_PRI_HINT_42_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG42_PRI_HINT_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG42_NONE_HINT_42_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG42_NONE_HINT_42_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG42_NONE_HINT_42_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG42_RESETVAL (0x80000000u)

/* pri_hint_reg43 */

#define CSL_CPINTC_PRI_HINT_REG43_PRI_HINT_43_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG43_PRI_HINT_43_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG43_PRI_HINT_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG43_NONE_HINT_43_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG43_NONE_HINT_43_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG43_NONE_HINT_43_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG43_RESETVAL (0x80000000u)

/* pri_hint_reg44 */

#define CSL_CPINTC_PRI_HINT_REG44_PRI_HINT_44_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG44_PRI_HINT_44_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG44_PRI_HINT_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG44_NONE_HINT_44_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG44_NONE_HINT_44_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG44_NONE_HINT_44_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG44_RESETVAL (0x80000000u)

/* pri_hint_reg45 */

#define CSL_CPINTC_PRI_HINT_REG45_PRI_HINT_45_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG45_PRI_HINT_45_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG45_PRI_HINT_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG45_NONE_HINT_45_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG45_NONE_HINT_45_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG45_NONE_HINT_45_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG45_RESETVAL (0x80000000u)

/* pri_hint_reg46 */

#define CSL_CPINTC_PRI_HINT_REG46_PRI_HINT_46_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG46_PRI_HINT_46_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG46_PRI_HINT_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG46_NONE_HINT_46_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG46_NONE_HINT_46_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG46_NONE_HINT_46_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG46_RESETVAL (0x80000000u)

/* pri_hint_reg47 */

#define CSL_CPINTC_PRI_HINT_REG47_PRI_HINT_47_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG47_PRI_HINT_47_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG47_PRI_HINT_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG47_NONE_HINT_47_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG47_NONE_HINT_47_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG47_NONE_HINT_47_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG47_RESETVAL (0x80000000u)

/* pri_hint_reg48 */

#define CSL_CPINTC_PRI_HINT_REG48_PRI_HINT_48_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG48_PRI_HINT_48_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG48_PRI_HINT_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG48_NONE_HINT_48_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG48_NONE_HINT_48_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG48_NONE_HINT_48_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG48_RESETVAL (0x80000000u)

/* pri_hint_reg49 */

#define CSL_CPINTC_PRI_HINT_REG49_PRI_HINT_49_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG49_PRI_HINT_49_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG49_PRI_HINT_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG49_NONE_HINT_49_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG49_NONE_HINT_49_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG49_NONE_HINT_49_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG49_RESETVAL (0x80000000u)

/* pri_hint_reg50 */

#define CSL_CPINTC_PRI_HINT_REG50_PRI_HINT_50_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG50_PRI_HINT_50_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG50_PRI_HINT_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG50_NONE_HINT_50_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG50_NONE_HINT_50_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG50_NONE_HINT_50_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG50_RESETVAL (0x80000000u)

/* pri_hint_reg51 */

#define CSL_CPINTC_PRI_HINT_REG51_PRI_HINT_51_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG51_PRI_HINT_51_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG51_PRI_HINT_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG51_NONE_HINT_51_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG51_NONE_HINT_51_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG51_NONE_HINT_51_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG51_RESETVAL (0x80000000u)

/* pri_hint_reg52 */

#define CSL_CPINTC_PRI_HINT_REG52_PRI_HINT_52_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG52_PRI_HINT_52_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG52_PRI_HINT_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG52_NONE_HINT_52_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG52_NONE_HINT_52_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG52_NONE_HINT_52_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG52_RESETVAL (0x80000000u)

/* pri_hint_reg53 */

#define CSL_CPINTC_PRI_HINT_REG53_PRI_HINT_53_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG53_PRI_HINT_53_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG53_PRI_HINT_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG53_NONE_HINT_53_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG53_NONE_HINT_53_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG53_NONE_HINT_53_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG53_RESETVAL (0x80000000u)

/* pri_hint_reg54 */

#define CSL_CPINTC_PRI_HINT_REG54_PRI_HINT_54_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG54_PRI_HINT_54_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG54_PRI_HINT_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG54_NONE_HINT_54_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG54_NONE_HINT_54_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG54_NONE_HINT_54_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG54_RESETVAL (0x80000000u)

/* pri_hint_reg55 */

#define CSL_CPINTC_PRI_HINT_REG55_PRI_HINT_55_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG55_PRI_HINT_55_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG55_PRI_HINT_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG55_NONE_HINT_55_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG55_NONE_HINT_55_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG55_NONE_HINT_55_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG55_RESETVAL (0x80000000u)

/* pri_hint_reg56 */

#define CSL_CPINTC_PRI_HINT_REG56_PRI_HINT_56_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG56_PRI_HINT_56_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG56_PRI_HINT_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG56_NONE_HINT_56_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG56_NONE_HINT_56_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG56_NONE_HINT_56_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG56_RESETVAL (0x80000000u)

/* pri_hint_reg57 */

#define CSL_CPINTC_PRI_HINT_REG57_PRI_HINT_57_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG57_PRI_HINT_57_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG57_PRI_HINT_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG57_NONE_HINT_57_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG57_NONE_HINT_57_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG57_NONE_HINT_57_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG57_RESETVAL (0x80000000u)

/* pri_hint_reg58 */

#define CSL_CPINTC_PRI_HINT_REG58_PRI_HINT_58_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG58_PRI_HINT_58_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG58_PRI_HINT_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG58_NONE_HINT_58_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG58_NONE_HINT_58_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG58_NONE_HINT_58_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG58_RESETVAL (0x80000000u)

/* pri_hint_reg59 */

#define CSL_CPINTC_PRI_HINT_REG59_PRI_HINT_59_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG59_PRI_HINT_59_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG59_PRI_HINT_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG59_NONE_HINT_59_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG59_NONE_HINT_59_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG59_NONE_HINT_59_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG59_RESETVAL (0x80000000u)

/* pri_hint_reg60 */

#define CSL_CPINTC_PRI_HINT_REG60_PRI_HINT_60_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG60_PRI_HINT_60_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG60_PRI_HINT_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG60_NONE_HINT_60_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG60_NONE_HINT_60_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG60_NONE_HINT_60_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG60_RESETVAL (0x80000000u)

/* pri_hint_reg61 */

#define CSL_CPINTC_PRI_HINT_REG61_PRI_HINT_61_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG61_PRI_HINT_61_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG61_PRI_HINT_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG61_NONE_HINT_61_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG61_NONE_HINT_61_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG61_NONE_HINT_61_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG61_RESETVAL (0x80000000u)

/* pri_hint_reg62 */

#define CSL_CPINTC_PRI_HINT_REG62_PRI_HINT_62_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG62_PRI_HINT_62_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG62_PRI_HINT_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG62_NONE_HINT_62_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG62_NONE_HINT_62_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG62_NONE_HINT_62_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG62_RESETVAL (0x80000000u)

/* pri_hint_reg63 */

#define CSL_CPINTC_PRI_HINT_REG63_PRI_HINT_63_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG63_PRI_HINT_63_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG63_PRI_HINT_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG63_NONE_HINT_63_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG63_NONE_HINT_63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG63_NONE_HINT_63_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG63_RESETVAL (0x80000000u)

/* pri_hint_reg64 */

#define CSL_CPINTC_PRI_HINT_REG64_PRI_HINT_64_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG64_PRI_HINT_64_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG64_PRI_HINT_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG64_NONE_HINT_64_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG64_NONE_HINT_64_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG64_NONE_HINT_64_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG64_RESETVAL (0x80000000u)

/* pri_hint_reg65 */

#define CSL_CPINTC_PRI_HINT_REG65_PRI_HINT_65_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG65_PRI_HINT_65_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG65_PRI_HINT_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG65_NONE_HINT_65_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG65_NONE_HINT_65_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG65_NONE_HINT_65_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG65_RESETVAL (0x80000000u)

/* pri_hint_reg66 */

#define CSL_CPINTC_PRI_HINT_REG66_PRI_HINT_66_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG66_PRI_HINT_66_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG66_PRI_HINT_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG66_NONE_HINT_66_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG66_NONE_HINT_66_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG66_NONE_HINT_66_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG66_RESETVAL (0x80000000u)

/* pri_hint_reg67 */

#define CSL_CPINTC_PRI_HINT_REG67_PRI_HINT_67_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG67_PRI_HINT_67_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG67_PRI_HINT_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG67_NONE_HINT_67_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG67_NONE_HINT_67_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG67_NONE_HINT_67_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG67_RESETVAL (0x80000000u)

/* pri_hint_reg68 */

#define CSL_CPINTC_PRI_HINT_REG68_PRI_HINT_68_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG68_PRI_HINT_68_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG68_PRI_HINT_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG68_NONE_HINT_68_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG68_NONE_HINT_68_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG68_NONE_HINT_68_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG68_RESETVAL (0x80000000u)

/* pri_hint_reg69 */

#define CSL_CPINTC_PRI_HINT_REG69_PRI_HINT_69_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG69_PRI_HINT_69_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG69_PRI_HINT_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG69_NONE_HINT_69_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG69_NONE_HINT_69_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG69_NONE_HINT_69_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG69_RESETVAL (0x80000000u)

/* pri_hint_reg70 */

#define CSL_CPINTC_PRI_HINT_REG70_PRI_HINT_70_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG70_PRI_HINT_70_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG70_PRI_HINT_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG70_NONE_HINT_70_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG70_NONE_HINT_70_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG70_NONE_HINT_70_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG70_RESETVAL (0x80000000u)

/* pri_hint_reg71 */

#define CSL_CPINTC_PRI_HINT_REG71_PRI_HINT_71_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG71_PRI_HINT_71_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG71_PRI_HINT_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG71_NONE_HINT_71_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG71_NONE_HINT_71_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG71_NONE_HINT_71_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG71_RESETVAL (0x80000000u)

/* pri_hint_reg72 */

#define CSL_CPINTC_PRI_HINT_REG72_PRI_HINT_72_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG72_PRI_HINT_72_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG72_PRI_HINT_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG72_NONE_HINT_72_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG72_NONE_HINT_72_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG72_NONE_HINT_72_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG72_RESETVAL (0x80000000u)

/* pri_hint_reg73 */

#define CSL_CPINTC_PRI_HINT_REG73_PRI_HINT_73_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG73_PRI_HINT_73_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG73_PRI_HINT_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG73_NONE_HINT_73_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG73_NONE_HINT_73_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG73_NONE_HINT_73_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG73_RESETVAL (0x80000000u)

/* pri_hint_reg74 */

#define CSL_CPINTC_PRI_HINT_REG74_PRI_HINT_74_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG74_PRI_HINT_74_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG74_PRI_HINT_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG74_NONE_HINT_74_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG74_NONE_HINT_74_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG74_NONE_HINT_74_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG74_RESETVAL (0x80000000u)

/* pri_hint_reg75 */

#define CSL_CPINTC_PRI_HINT_REG75_PRI_HINT_75_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG75_PRI_HINT_75_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG75_PRI_HINT_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG75_NONE_HINT_75_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG75_NONE_HINT_75_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG75_NONE_HINT_75_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG75_RESETVAL (0x80000000u)

/* pri_hint_reg76 */

#define CSL_CPINTC_PRI_HINT_REG76_PRI_HINT_76_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG76_PRI_HINT_76_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG76_PRI_HINT_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG76_NONE_HINT_76_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG76_NONE_HINT_76_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG76_NONE_HINT_76_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG76_RESETVAL (0x80000000u)

/* pri_hint_reg77 */

#define CSL_CPINTC_PRI_HINT_REG77_PRI_HINT_77_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG77_PRI_HINT_77_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG77_PRI_HINT_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG77_NONE_HINT_77_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG77_NONE_HINT_77_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG77_NONE_HINT_77_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG77_RESETVAL (0x80000000u)

/* pri_hint_reg78 */

#define CSL_CPINTC_PRI_HINT_REG78_PRI_HINT_78_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG78_PRI_HINT_78_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG78_PRI_HINT_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG78_NONE_HINT_78_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG78_NONE_HINT_78_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG78_NONE_HINT_78_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG78_RESETVAL (0x80000000u)

/* pri_hint_reg79 */

#define CSL_CPINTC_PRI_HINT_REG79_PRI_HINT_79_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG79_PRI_HINT_79_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG79_PRI_HINT_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG79_NONE_HINT_79_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG79_NONE_HINT_79_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG79_NONE_HINT_79_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG79_RESETVAL (0x80000000u)

/* pri_hint_reg80 */

#define CSL_CPINTC_PRI_HINT_REG80_PRI_HINT_80_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG80_PRI_HINT_80_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG80_PRI_HINT_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG80_NONE_HINT_80_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG80_NONE_HINT_80_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG80_NONE_HINT_80_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG80_RESETVAL (0x80000000u)

/* pri_hint_reg81 */

#define CSL_CPINTC_PRI_HINT_REG81_PRI_HINT_81_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG81_PRI_HINT_81_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG81_PRI_HINT_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG81_NONE_HINT_81_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG81_NONE_HINT_81_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG81_NONE_HINT_81_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG81_RESETVAL (0x80000000u)

/* pri_hint_reg82 */

#define CSL_CPINTC_PRI_HINT_REG82_PRI_HINT_82_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG82_PRI_HINT_82_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG82_PRI_HINT_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG82_NONE_HINT_82_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG82_NONE_HINT_82_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG82_NONE_HINT_82_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG82_RESETVAL (0x80000000u)

/* pri_hint_reg83 */

#define CSL_CPINTC_PRI_HINT_REG83_PRI_HINT_83_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG83_PRI_HINT_83_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG83_PRI_HINT_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG83_NONE_HINT_83_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG83_NONE_HINT_83_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG83_NONE_HINT_83_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG83_RESETVAL (0x80000000u)

/* pri_hint_reg84 */

#define CSL_CPINTC_PRI_HINT_REG84_PRI_HINT_84_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG84_PRI_HINT_84_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG84_PRI_HINT_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG84_NONE_HINT_84_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG84_NONE_HINT_84_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG84_NONE_HINT_84_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG84_RESETVAL (0x80000000u)

/* pri_hint_reg85 */

#define CSL_CPINTC_PRI_HINT_REG85_PRI_HINT_85_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG85_PRI_HINT_85_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG85_PRI_HINT_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG85_NONE_HINT_85_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG85_NONE_HINT_85_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG85_NONE_HINT_85_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG85_RESETVAL (0x80000000u)

/* pri_hint_reg86 */

#define CSL_CPINTC_PRI_HINT_REG86_PRI_HINT_86_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG86_PRI_HINT_86_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG86_PRI_HINT_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG86_NONE_HINT_86_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG86_NONE_HINT_86_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG86_NONE_HINT_86_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG86_RESETVAL (0x80000000u)

/* pri_hint_reg87 */

#define CSL_CPINTC_PRI_HINT_REG87_PRI_HINT_87_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG87_PRI_HINT_87_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG87_PRI_HINT_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG87_NONE_HINT_87_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG87_NONE_HINT_87_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG87_NONE_HINT_87_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG87_RESETVAL (0x80000000u)

/* pri_hint_reg88 */

#define CSL_CPINTC_PRI_HINT_REG88_PRI_HINT_88_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG88_PRI_HINT_88_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG88_PRI_HINT_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG88_NONE_HINT_88_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG88_NONE_HINT_88_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG88_NONE_HINT_88_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG88_RESETVAL (0x80000000u)

/* pri_hint_reg89 */

#define CSL_CPINTC_PRI_HINT_REG89_PRI_HINT_89_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG89_PRI_HINT_89_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG89_PRI_HINT_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG89_NONE_HINT_89_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG89_NONE_HINT_89_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG89_NONE_HINT_89_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG89_RESETVAL (0x80000000u)

/* pri_hint_reg90 */

#define CSL_CPINTC_PRI_HINT_REG90_PRI_HINT_90_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG90_PRI_HINT_90_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG90_PRI_HINT_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG90_NONE_HINT_90_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG90_NONE_HINT_90_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG90_NONE_HINT_90_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG90_RESETVAL (0x80000000u)

/* pri_hint_reg91 */

#define CSL_CPINTC_PRI_HINT_REG91_PRI_HINT_91_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG91_PRI_HINT_91_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG91_PRI_HINT_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG91_NONE_HINT_91_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG91_NONE_HINT_91_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG91_NONE_HINT_91_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG91_RESETVAL (0x80000000u)

/* pri_hint_reg92 */

#define CSL_CPINTC_PRI_HINT_REG92_PRI_HINT_92_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG92_PRI_HINT_92_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG92_PRI_HINT_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG92_NONE_HINT_92_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG92_NONE_HINT_92_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG92_NONE_HINT_92_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG92_RESETVAL (0x80000000u)

/* pri_hint_reg93 */

#define CSL_CPINTC_PRI_HINT_REG93_PRI_HINT_93_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG93_PRI_HINT_93_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG93_PRI_HINT_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG93_NONE_HINT_93_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG93_NONE_HINT_93_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG93_NONE_HINT_93_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG93_RESETVAL (0x80000000u)

/* pri_hint_reg94 */

#define CSL_CPINTC_PRI_HINT_REG94_PRI_HINT_94_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG94_PRI_HINT_94_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG94_PRI_HINT_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG94_NONE_HINT_94_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG94_NONE_HINT_94_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG94_NONE_HINT_94_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG94_RESETVAL (0x80000000u)

/* pri_hint_reg95 */

#define CSL_CPINTC_PRI_HINT_REG95_PRI_HINT_95_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG95_PRI_HINT_95_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG95_PRI_HINT_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG95_NONE_HINT_95_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG95_NONE_HINT_95_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG95_NONE_HINT_95_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG95_RESETVAL (0x80000000u)

/* pri_hint_reg96 */

#define CSL_CPINTC_PRI_HINT_REG96_PRI_HINT_96_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG96_PRI_HINT_96_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG96_PRI_HINT_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG96_NONE_HINT_96_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG96_NONE_HINT_96_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG96_NONE_HINT_96_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG96_RESETVAL (0x80000000u)

/* pri_hint_reg97 */

#define CSL_CPINTC_PRI_HINT_REG97_PRI_HINT_97_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG97_PRI_HINT_97_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG97_PRI_HINT_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG97_NONE_HINT_97_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG97_NONE_HINT_97_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG97_NONE_HINT_97_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG97_RESETVAL (0x80000000u)

/* pri_hint_reg98 */

#define CSL_CPINTC_PRI_HINT_REG98_PRI_HINT_98_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG98_PRI_HINT_98_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG98_PRI_HINT_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG98_NONE_HINT_98_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG98_NONE_HINT_98_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG98_NONE_HINT_98_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG98_RESETVAL (0x80000000u)

/* pri_hint_reg99 */

#define CSL_CPINTC_PRI_HINT_REG99_PRI_HINT_99_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG99_PRI_HINT_99_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG99_PRI_HINT_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG99_NONE_HINT_99_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG99_NONE_HINT_99_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG99_NONE_HINT_99_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG99_RESETVAL (0x80000000u)

/* pri_hint_reg100 */

#define CSL_CPINTC_PRI_HINT_REG100_PRI_HINT_100_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG100_PRI_HINT_100_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG100_PRI_HINT_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG100_NONE_HINT_100_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG100_NONE_HINT_100_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG100_NONE_HINT_100_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG100_RESETVAL (0x80000000u)

/* pri_hint_reg101 */

#define CSL_CPINTC_PRI_HINT_REG101_PRI_HINT_101_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG101_PRI_HINT_101_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG101_PRI_HINT_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG101_NONE_HINT_101_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG101_NONE_HINT_101_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG101_NONE_HINT_101_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG101_RESETVAL (0x80000000u)

/* pri_hint_reg102 */

#define CSL_CPINTC_PRI_HINT_REG102_PRI_HINT_102_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG102_PRI_HINT_102_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG102_PRI_HINT_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG102_NONE_HINT_102_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG102_NONE_HINT_102_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG102_NONE_HINT_102_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG102_RESETVAL (0x80000000u)

/* pri_hint_reg103 */

#define CSL_CPINTC_PRI_HINT_REG103_PRI_HINT_103_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG103_PRI_HINT_103_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG103_PRI_HINT_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG103_NONE_HINT_103_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG103_NONE_HINT_103_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG103_NONE_HINT_103_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG103_RESETVAL (0x80000000u)

/* pri_hint_reg104 */

#define CSL_CPINTC_PRI_HINT_REG104_PRI_HINT_104_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG104_PRI_HINT_104_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG104_PRI_HINT_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG104_NONE_HINT_104_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG104_NONE_HINT_104_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG104_NONE_HINT_104_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG104_RESETVAL (0x80000000u)

/* pri_hint_reg105 */

#define CSL_CPINTC_PRI_HINT_REG105_PRI_HINT_105_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG105_PRI_HINT_105_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG105_PRI_HINT_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG105_NONE_HINT_105_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG105_NONE_HINT_105_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG105_NONE_HINT_105_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG105_RESETVAL (0x80000000u)

/* pri_hint_reg106 */

#define CSL_CPINTC_PRI_HINT_REG106_PRI_HINT_106_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG106_PRI_HINT_106_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG106_PRI_HINT_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG106_NONE_HINT_106_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG106_NONE_HINT_106_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG106_NONE_HINT_106_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG106_RESETVAL (0x80000000u)

/* pri_hint_reg107 */

#define CSL_CPINTC_PRI_HINT_REG107_PRI_HINT_107_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG107_PRI_HINT_107_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG107_PRI_HINT_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG107_NONE_HINT_107_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG107_NONE_HINT_107_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG107_NONE_HINT_107_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG107_RESETVAL (0x80000000u)

/* pri_hint_reg108 */

#define CSL_CPINTC_PRI_HINT_REG108_PRI_HINT_108_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG108_PRI_HINT_108_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG108_PRI_HINT_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG108_NONE_HINT_108_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG108_NONE_HINT_108_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG108_NONE_HINT_108_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG108_RESETVAL (0x80000000u)

/* pri_hint_reg109 */

#define CSL_CPINTC_PRI_HINT_REG109_PRI_HINT_109_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG109_PRI_HINT_109_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG109_PRI_HINT_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG109_NONE_HINT_109_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG109_NONE_HINT_109_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG109_NONE_HINT_109_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG109_RESETVAL (0x80000000u)

/* pri_hint_reg110 */

#define CSL_CPINTC_PRI_HINT_REG110_PRI_HINT_110_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG110_PRI_HINT_110_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG110_PRI_HINT_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG110_NONE_HINT_110_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG110_NONE_HINT_110_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG110_NONE_HINT_110_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG110_RESETVAL (0x80000000u)

/* pri_hint_reg111 */

#define CSL_CPINTC_PRI_HINT_REG111_PRI_HINT_111_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG111_PRI_HINT_111_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG111_PRI_HINT_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG111_NONE_HINT_111_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG111_NONE_HINT_111_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG111_NONE_HINT_111_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG111_RESETVAL (0x80000000u)

/* pri_hint_reg112 */

#define CSL_CPINTC_PRI_HINT_REG112_PRI_HINT_112_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG112_PRI_HINT_112_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG112_PRI_HINT_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG112_NONE_HINT_112_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG112_NONE_HINT_112_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG112_NONE_HINT_112_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG112_RESETVAL (0x80000000u)

/* pri_hint_reg113 */

#define CSL_CPINTC_PRI_HINT_REG113_PRI_HINT_113_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG113_PRI_HINT_113_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG113_PRI_HINT_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG113_NONE_HINT_113_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG113_NONE_HINT_113_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG113_NONE_HINT_113_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG113_RESETVAL (0x80000000u)

/* pri_hint_reg114 */

#define CSL_CPINTC_PRI_HINT_REG114_PRI_HINT_114_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG114_PRI_HINT_114_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG114_PRI_HINT_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG114_NONE_HINT_114_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG114_NONE_HINT_114_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG114_NONE_HINT_114_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG114_RESETVAL (0x80000000u)

/* pri_hint_reg115 */

#define CSL_CPINTC_PRI_HINT_REG115_PRI_HINT_115_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG115_PRI_HINT_115_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG115_PRI_HINT_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG115_NONE_HINT_115_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG115_NONE_HINT_115_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG115_NONE_HINT_115_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG115_RESETVAL (0x80000000u)

/* pri_hint_reg116 */

#define CSL_CPINTC_PRI_HINT_REG116_PRI_HINT_116_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG116_PRI_HINT_116_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG116_PRI_HINT_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG116_NONE_HINT_116_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG116_NONE_HINT_116_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG116_NONE_HINT_116_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG116_RESETVAL (0x80000000u)

/* pri_hint_reg117 */

#define CSL_CPINTC_PRI_HINT_REG117_PRI_HINT_117_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG117_PRI_HINT_117_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG117_PRI_HINT_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG117_NONE_HINT_117_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG117_NONE_HINT_117_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG117_NONE_HINT_117_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG117_RESETVAL (0x80000000u)

/* pri_hint_reg118 */

#define CSL_CPINTC_PRI_HINT_REG118_PRI_HINT_118_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG118_PRI_HINT_118_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG118_PRI_HINT_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG118_NONE_HINT_118_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG118_NONE_HINT_118_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG118_NONE_HINT_118_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG118_RESETVAL (0x80000000u)

/* pri_hint_reg119 */

#define CSL_CPINTC_PRI_HINT_REG119_PRI_HINT_119_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG119_PRI_HINT_119_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG119_PRI_HINT_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG119_NONE_HINT_119_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG119_NONE_HINT_119_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG119_NONE_HINT_119_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG119_RESETVAL (0x80000000u)

/* pri_hint_reg120 */

#define CSL_CPINTC_PRI_HINT_REG120_PRI_HINT_120_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG120_PRI_HINT_120_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG120_PRI_HINT_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG120_NONE_HINT_120_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG120_NONE_HINT_120_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG120_NONE_HINT_120_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG120_RESETVAL (0x80000000u)

/* pri_hint_reg121 */

#define CSL_CPINTC_PRI_HINT_REG121_PRI_HINT_121_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG121_PRI_HINT_121_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG121_PRI_HINT_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG121_NONE_HINT_121_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG121_NONE_HINT_121_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG121_NONE_HINT_121_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG121_RESETVAL (0x80000000u)

/* pri_hint_reg122 */

#define CSL_CPINTC_PRI_HINT_REG122_PRI_HINT_122_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG122_PRI_HINT_122_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG122_PRI_HINT_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG122_NONE_HINT_122_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG122_NONE_HINT_122_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG122_NONE_HINT_122_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG122_RESETVAL (0x80000000u)

/* pri_hint_reg123 */

#define CSL_CPINTC_PRI_HINT_REG123_PRI_HINT_123_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG123_PRI_HINT_123_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG123_PRI_HINT_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG123_NONE_HINT_123_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG123_NONE_HINT_123_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG123_NONE_HINT_123_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG123_RESETVAL (0x80000000u)

/* pri_hint_reg124 */

#define CSL_CPINTC_PRI_HINT_REG124_PRI_HINT_124_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG124_PRI_HINT_124_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG124_PRI_HINT_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG124_NONE_HINT_124_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG124_NONE_HINT_124_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG124_NONE_HINT_124_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG124_RESETVAL (0x80000000u)

/* pri_hint_reg125 */

#define CSL_CPINTC_PRI_HINT_REG125_PRI_HINT_125_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG125_PRI_HINT_125_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG125_PRI_HINT_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG125_NONE_HINT_125_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG125_NONE_HINT_125_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG125_NONE_HINT_125_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG125_RESETVAL (0x80000000u)

/* pri_hint_reg126 */

#define CSL_CPINTC_PRI_HINT_REG126_PRI_HINT_126_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG126_PRI_HINT_126_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG126_PRI_HINT_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG126_NONE_HINT_126_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG126_NONE_HINT_126_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG126_NONE_HINT_126_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG126_RESETVAL (0x80000000u)

/* pri_hint_reg127 */

#define CSL_CPINTC_PRI_HINT_REG127_PRI_HINT_127_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG127_PRI_HINT_127_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG127_PRI_HINT_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG127_NONE_HINT_127_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG127_NONE_HINT_127_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG127_NONE_HINT_127_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG127_RESETVAL (0x80000000u)

/* pri_hint_reg128 */

#define CSL_CPINTC_PRI_HINT_REG128_PRI_HINT_128_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG128_PRI_HINT_128_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG128_PRI_HINT_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG128_NONE_HINT_128_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG128_NONE_HINT_128_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG128_NONE_HINT_128_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG128_RESETVAL (0x80000000u)

/* pri_hint_reg129 */

#define CSL_CPINTC_PRI_HINT_REG129_PRI_HINT_129_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG129_PRI_HINT_129_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG129_PRI_HINT_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG129_NONE_HINT_129_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG129_NONE_HINT_129_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG129_NONE_HINT_129_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG129_RESETVAL (0x80000000u)

/* pri_hint_reg130 */

#define CSL_CPINTC_PRI_HINT_REG130_PRI_HINT_130_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG130_PRI_HINT_130_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG130_PRI_HINT_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG130_NONE_HINT_130_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG130_NONE_HINT_130_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG130_NONE_HINT_130_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG130_RESETVAL (0x80000000u)

/* pri_hint_reg131 */

#define CSL_CPINTC_PRI_HINT_REG131_PRI_HINT_131_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG131_PRI_HINT_131_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG131_PRI_HINT_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG131_NONE_HINT_131_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG131_NONE_HINT_131_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG131_NONE_HINT_131_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG131_RESETVAL (0x80000000u)

/* pri_hint_reg132 */

#define CSL_CPINTC_PRI_HINT_REG132_PRI_HINT_132_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG132_PRI_HINT_132_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG132_PRI_HINT_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG132_NONE_HINT_132_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG132_NONE_HINT_132_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG132_NONE_HINT_132_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG132_RESETVAL (0x80000000u)

/* pri_hint_reg133 */

#define CSL_CPINTC_PRI_HINT_REG133_PRI_HINT_133_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG133_PRI_HINT_133_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG133_PRI_HINT_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG133_NONE_HINT_133_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG133_NONE_HINT_133_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG133_NONE_HINT_133_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG133_RESETVAL (0x80000000u)

/* pri_hint_reg134 */

#define CSL_CPINTC_PRI_HINT_REG134_PRI_HINT_134_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG134_PRI_HINT_134_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG134_PRI_HINT_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG134_NONE_HINT_134_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG134_NONE_HINT_134_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG134_NONE_HINT_134_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG134_RESETVAL (0x80000000u)

/* pri_hint_reg135 */

#define CSL_CPINTC_PRI_HINT_REG135_PRI_HINT_135_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG135_PRI_HINT_135_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG135_PRI_HINT_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG135_NONE_HINT_135_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG135_NONE_HINT_135_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG135_NONE_HINT_135_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG135_RESETVAL (0x80000000u)

/* pri_hint_reg136 */

#define CSL_CPINTC_PRI_HINT_REG136_PRI_HINT_136_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG136_PRI_HINT_136_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG136_PRI_HINT_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG136_NONE_HINT_136_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG136_NONE_HINT_136_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG136_NONE_HINT_136_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG136_RESETVAL (0x80000000u)

/* pri_hint_reg137 */

#define CSL_CPINTC_PRI_HINT_REG137_PRI_HINT_137_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG137_PRI_HINT_137_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG137_PRI_HINT_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG137_NONE_HINT_137_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG137_NONE_HINT_137_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG137_NONE_HINT_137_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG137_RESETVAL (0x80000000u)

/* pri_hint_reg138 */

#define CSL_CPINTC_PRI_HINT_REG138_PRI_HINT_138_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG138_PRI_HINT_138_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG138_PRI_HINT_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG138_NONE_HINT_138_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG138_NONE_HINT_138_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG138_NONE_HINT_138_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG138_RESETVAL (0x80000000u)

/* pri_hint_reg139 */

#define CSL_CPINTC_PRI_HINT_REG139_PRI_HINT_139_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG139_PRI_HINT_139_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG139_PRI_HINT_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG139_NONE_HINT_139_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG139_NONE_HINT_139_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG139_NONE_HINT_139_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG139_RESETVAL (0x80000000u)

/* pri_hint_reg140 */

#define CSL_CPINTC_PRI_HINT_REG140_PRI_HINT_140_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG140_PRI_HINT_140_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG140_PRI_HINT_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG140_NONE_HINT_140_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG140_NONE_HINT_140_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG140_NONE_HINT_140_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG140_RESETVAL (0x80000000u)

/* pri_hint_reg141 */

#define CSL_CPINTC_PRI_HINT_REG141_PRI_HINT_141_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG141_PRI_HINT_141_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG141_PRI_HINT_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG141_NONE_HINT_141_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG141_NONE_HINT_141_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG141_NONE_HINT_141_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG141_RESETVAL (0x80000000u)

/* pri_hint_reg142 */

#define CSL_CPINTC_PRI_HINT_REG142_PRI_HINT_142_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG142_PRI_HINT_142_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG142_PRI_HINT_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG142_NONE_HINT_142_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG142_NONE_HINT_142_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG142_NONE_HINT_142_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG142_RESETVAL (0x80000000u)

/* pri_hint_reg143 */

#define CSL_CPINTC_PRI_HINT_REG143_PRI_HINT_143_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG143_PRI_HINT_143_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG143_PRI_HINT_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG143_NONE_HINT_143_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG143_NONE_HINT_143_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG143_NONE_HINT_143_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG143_RESETVAL (0x80000000u)

/* pri_hint_reg144 */

#define CSL_CPINTC_PRI_HINT_REG144_PRI_HINT_144_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG144_PRI_HINT_144_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG144_PRI_HINT_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG144_NONE_HINT_144_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG144_NONE_HINT_144_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG144_NONE_HINT_144_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG144_RESETVAL (0x80000000u)

/* pri_hint_reg145 */

#define CSL_CPINTC_PRI_HINT_REG145_PRI_HINT_145_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG145_PRI_HINT_145_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG145_PRI_HINT_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG145_NONE_HINT_145_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG145_NONE_HINT_145_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG145_NONE_HINT_145_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG145_RESETVAL (0x80000000u)

/* pri_hint_reg146 */

#define CSL_CPINTC_PRI_HINT_REG146_PRI_HINT_146_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG146_PRI_HINT_146_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG146_PRI_HINT_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG146_NONE_HINT_146_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG146_NONE_HINT_146_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG146_NONE_HINT_146_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG146_RESETVAL (0x80000000u)

/* pri_hint_reg147 */

#define CSL_CPINTC_PRI_HINT_REG147_PRI_HINT_147_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG147_PRI_HINT_147_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG147_PRI_HINT_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG147_NONE_HINT_147_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG147_NONE_HINT_147_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG147_NONE_HINT_147_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG147_RESETVAL (0x80000000u)

/* pri_hint_reg148 */

#define CSL_CPINTC_PRI_HINT_REG148_PRI_HINT_148_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG148_PRI_HINT_148_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG148_PRI_HINT_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG148_NONE_HINT_148_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG148_NONE_HINT_148_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG148_NONE_HINT_148_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG148_RESETVAL (0x80000000u)

/* pri_hint_reg149 */

#define CSL_CPINTC_PRI_HINT_REG149_PRI_HINT_149_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG149_PRI_HINT_149_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG149_PRI_HINT_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG149_NONE_HINT_149_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG149_NONE_HINT_149_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG149_NONE_HINT_149_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG149_RESETVAL (0x80000000u)

/* pri_hint_reg150 */

#define CSL_CPINTC_PRI_HINT_REG150_PRI_HINT_150_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG150_PRI_HINT_150_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG150_PRI_HINT_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG150_NONE_HINT_150_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG150_NONE_HINT_150_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG150_NONE_HINT_150_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG150_RESETVAL (0x80000000u)

/* pri_hint_reg151 */

#define CSL_CPINTC_PRI_HINT_REG151_PRI_HINT_151_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG151_PRI_HINT_151_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG151_PRI_HINT_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG151_NONE_HINT_151_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG151_NONE_HINT_151_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG151_NONE_HINT_151_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG151_RESETVAL (0x80000000u)

/* pri_hint_reg152 */

#define CSL_CPINTC_PRI_HINT_REG152_PRI_HINT_152_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG152_PRI_HINT_152_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG152_PRI_HINT_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG152_NONE_HINT_152_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG152_NONE_HINT_152_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG152_NONE_HINT_152_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG152_RESETVAL (0x80000000u)

/* pri_hint_reg153 */

#define CSL_CPINTC_PRI_HINT_REG153_PRI_HINT_153_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG153_PRI_HINT_153_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG153_PRI_HINT_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG153_NONE_HINT_153_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG153_NONE_HINT_153_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG153_NONE_HINT_153_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG153_RESETVAL (0x80000000u)

/* pri_hint_reg154 */

#define CSL_CPINTC_PRI_HINT_REG154_PRI_HINT_154_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG154_PRI_HINT_154_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG154_PRI_HINT_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG154_NONE_HINT_154_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG154_NONE_HINT_154_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG154_NONE_HINT_154_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG154_RESETVAL (0x80000000u)

/* pri_hint_reg155 */

#define CSL_CPINTC_PRI_HINT_REG155_PRI_HINT_155_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG155_PRI_HINT_155_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG155_PRI_HINT_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG155_NONE_HINT_155_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG155_NONE_HINT_155_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG155_NONE_HINT_155_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG155_RESETVAL (0x80000000u)

/* pri_hint_reg156 */

#define CSL_CPINTC_PRI_HINT_REG156_PRI_HINT_156_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG156_PRI_HINT_156_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG156_PRI_HINT_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG156_NONE_HINT_156_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG156_NONE_HINT_156_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG156_NONE_HINT_156_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG156_RESETVAL (0x80000000u)

/* pri_hint_reg157 */

#define CSL_CPINTC_PRI_HINT_REG157_PRI_HINT_157_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG157_PRI_HINT_157_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG157_PRI_HINT_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG157_NONE_HINT_157_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG157_NONE_HINT_157_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG157_NONE_HINT_157_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG157_RESETVAL (0x80000000u)

/* pri_hint_reg158 */

#define CSL_CPINTC_PRI_HINT_REG158_PRI_HINT_158_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG158_PRI_HINT_158_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG158_PRI_HINT_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG158_NONE_HINT_158_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG158_NONE_HINT_158_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG158_NONE_HINT_158_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG158_RESETVAL (0x80000000u)

/* pri_hint_reg159 */

#define CSL_CPINTC_PRI_HINT_REG159_PRI_HINT_159_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG159_PRI_HINT_159_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG159_PRI_HINT_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG159_NONE_HINT_159_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG159_NONE_HINT_159_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG159_NONE_HINT_159_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG159_RESETVAL (0x80000000u)

/* pri_hint_reg160 */

#define CSL_CPINTC_PRI_HINT_REG160_PRI_HINT_160_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG160_PRI_HINT_160_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG160_PRI_HINT_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG160_NONE_HINT_160_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG160_NONE_HINT_160_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG160_NONE_HINT_160_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG160_RESETVAL (0x80000000u)

/* pri_hint_reg161 */

#define CSL_CPINTC_PRI_HINT_REG161_PRI_HINT_161_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG161_PRI_HINT_161_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG161_PRI_HINT_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG161_NONE_HINT_161_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG161_NONE_HINT_161_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG161_NONE_HINT_161_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG161_RESETVAL (0x80000000u)

/* pri_hint_reg162 */

#define CSL_CPINTC_PRI_HINT_REG162_PRI_HINT_162_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG162_PRI_HINT_162_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG162_PRI_HINT_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG162_NONE_HINT_162_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG162_NONE_HINT_162_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG162_NONE_HINT_162_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG162_RESETVAL (0x80000000u)

/* pri_hint_reg163 */

#define CSL_CPINTC_PRI_HINT_REG163_PRI_HINT_163_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG163_PRI_HINT_163_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG163_PRI_HINT_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG163_NONE_HINT_163_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG163_NONE_HINT_163_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG163_NONE_HINT_163_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG163_RESETVAL (0x80000000u)

/* pri_hint_reg164 */

#define CSL_CPINTC_PRI_HINT_REG164_PRI_HINT_164_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG164_PRI_HINT_164_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG164_PRI_HINT_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG164_NONE_HINT_164_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG164_NONE_HINT_164_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG164_NONE_HINT_164_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG164_RESETVAL (0x80000000u)

/* pri_hint_reg165 */

#define CSL_CPINTC_PRI_HINT_REG165_PRI_HINT_165_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG165_PRI_HINT_165_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG165_PRI_HINT_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG165_NONE_HINT_165_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG165_NONE_HINT_165_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG165_NONE_HINT_165_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG165_RESETVAL (0x80000000u)

/* pri_hint_reg166 */

#define CSL_CPINTC_PRI_HINT_REG166_PRI_HINT_166_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG166_PRI_HINT_166_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG166_PRI_HINT_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG166_NONE_HINT_166_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG166_NONE_HINT_166_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG166_NONE_HINT_166_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG166_RESETVAL (0x80000000u)

/* pri_hint_reg167 */

#define CSL_CPINTC_PRI_HINT_REG167_PRI_HINT_167_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG167_PRI_HINT_167_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG167_PRI_HINT_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG167_NONE_HINT_167_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG167_NONE_HINT_167_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG167_NONE_HINT_167_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG167_RESETVAL (0x80000000u)

/* pri_hint_reg168 */

#define CSL_CPINTC_PRI_HINT_REG168_PRI_HINT_168_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG168_PRI_HINT_168_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG168_PRI_HINT_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG168_NONE_HINT_168_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG168_NONE_HINT_168_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG168_NONE_HINT_168_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG168_RESETVAL (0x80000000u)

/* pri_hint_reg169 */

#define CSL_CPINTC_PRI_HINT_REG169_PRI_HINT_169_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG169_PRI_HINT_169_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG169_PRI_HINT_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG169_NONE_HINT_169_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG169_NONE_HINT_169_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG169_NONE_HINT_169_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG169_RESETVAL (0x80000000u)

/* pri_hint_reg170 */

#define CSL_CPINTC_PRI_HINT_REG170_PRI_HINT_170_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG170_PRI_HINT_170_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG170_PRI_HINT_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG170_NONE_HINT_170_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG170_NONE_HINT_170_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG170_NONE_HINT_170_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG170_RESETVAL (0x80000000u)

/* pri_hint_reg171 */

#define CSL_CPINTC_PRI_HINT_REG171_PRI_HINT_171_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG171_PRI_HINT_171_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG171_PRI_HINT_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG171_NONE_HINT_171_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG171_NONE_HINT_171_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG171_NONE_HINT_171_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG171_RESETVAL (0x80000000u)

/* pri_hint_reg172 */

#define CSL_CPINTC_PRI_HINT_REG172_PRI_HINT_172_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG172_PRI_HINT_172_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG172_PRI_HINT_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG172_NONE_HINT_172_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG172_NONE_HINT_172_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG172_NONE_HINT_172_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG172_RESETVAL (0x80000000u)

/* pri_hint_reg173 */

#define CSL_CPINTC_PRI_HINT_REG173_PRI_HINT_173_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG173_PRI_HINT_173_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG173_PRI_HINT_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG173_NONE_HINT_173_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG173_NONE_HINT_173_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG173_NONE_HINT_173_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG173_RESETVAL (0x80000000u)

/* pri_hint_reg174 */

#define CSL_CPINTC_PRI_HINT_REG174_PRI_HINT_174_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG174_PRI_HINT_174_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG174_PRI_HINT_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG174_NONE_HINT_174_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG174_NONE_HINT_174_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG174_NONE_HINT_174_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG174_RESETVAL (0x80000000u)

/* pri_hint_reg175 */

#define CSL_CPINTC_PRI_HINT_REG175_PRI_HINT_175_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG175_PRI_HINT_175_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG175_PRI_HINT_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG175_NONE_HINT_175_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG175_NONE_HINT_175_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG175_NONE_HINT_175_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG175_RESETVAL (0x80000000u)

/* pri_hint_reg176 */

#define CSL_CPINTC_PRI_HINT_REG176_PRI_HINT_176_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG176_PRI_HINT_176_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG176_PRI_HINT_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG176_NONE_HINT_176_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG176_NONE_HINT_176_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG176_NONE_HINT_176_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG176_RESETVAL (0x80000000u)

/* pri_hint_reg177 */

#define CSL_CPINTC_PRI_HINT_REG177_PRI_HINT_177_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG177_PRI_HINT_177_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG177_PRI_HINT_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG177_NONE_HINT_177_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG177_NONE_HINT_177_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG177_NONE_HINT_177_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG177_RESETVAL (0x80000000u)

/* pri_hint_reg178 */

#define CSL_CPINTC_PRI_HINT_REG178_PRI_HINT_178_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG178_PRI_HINT_178_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG178_PRI_HINT_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG178_NONE_HINT_178_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG178_NONE_HINT_178_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG178_NONE_HINT_178_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG178_RESETVAL (0x80000000u)

/* pri_hint_reg179 */

#define CSL_CPINTC_PRI_HINT_REG179_PRI_HINT_179_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG179_PRI_HINT_179_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG179_PRI_HINT_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG179_NONE_HINT_179_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG179_NONE_HINT_179_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG179_NONE_HINT_179_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG179_RESETVAL (0x80000000u)

/* pri_hint_reg180 */

#define CSL_CPINTC_PRI_HINT_REG180_PRI_HINT_180_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG180_PRI_HINT_180_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG180_PRI_HINT_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG180_NONE_HINT_180_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG180_NONE_HINT_180_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG180_NONE_HINT_180_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG180_RESETVAL (0x80000000u)

/* pri_hint_reg181 */

#define CSL_CPINTC_PRI_HINT_REG181_PRI_HINT_181_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG181_PRI_HINT_181_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG181_PRI_HINT_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG181_NONE_HINT_181_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG181_NONE_HINT_181_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG181_NONE_HINT_181_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG181_RESETVAL (0x80000000u)

/* pri_hint_reg182 */

#define CSL_CPINTC_PRI_HINT_REG182_PRI_HINT_182_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG182_PRI_HINT_182_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG182_PRI_HINT_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG182_NONE_HINT_182_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG182_NONE_HINT_182_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG182_NONE_HINT_182_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG182_RESETVAL (0x80000000u)

/* pri_hint_reg183 */

#define CSL_CPINTC_PRI_HINT_REG183_PRI_HINT_183_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG183_PRI_HINT_183_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG183_PRI_HINT_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG183_NONE_HINT_183_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG183_NONE_HINT_183_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG183_NONE_HINT_183_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG183_RESETVAL (0x80000000u)

/* pri_hint_reg184 */

#define CSL_CPINTC_PRI_HINT_REG184_PRI_HINT_184_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG184_PRI_HINT_184_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG184_PRI_HINT_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG184_NONE_HINT_184_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG184_NONE_HINT_184_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG184_NONE_HINT_184_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG184_RESETVAL (0x80000000u)

/* pri_hint_reg185 */

#define CSL_CPINTC_PRI_HINT_REG185_PRI_HINT_185_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG185_PRI_HINT_185_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG185_PRI_HINT_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG185_NONE_HINT_185_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG185_NONE_HINT_185_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG185_NONE_HINT_185_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG185_RESETVAL (0x80000000u)

/* pri_hint_reg186 */

#define CSL_CPINTC_PRI_HINT_REG186_PRI_HINT_186_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG186_PRI_HINT_186_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG186_PRI_HINT_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG186_NONE_HINT_186_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG186_NONE_HINT_186_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG186_NONE_HINT_186_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG186_RESETVAL (0x80000000u)

/* pri_hint_reg187 */

#define CSL_CPINTC_PRI_HINT_REG187_PRI_HINT_187_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG187_PRI_HINT_187_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG187_PRI_HINT_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG187_NONE_HINT_187_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG187_NONE_HINT_187_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG187_NONE_HINT_187_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG187_RESETVAL (0x80000000u)

/* pri_hint_reg188 */

#define CSL_CPINTC_PRI_HINT_REG188_PRI_HINT_188_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG188_PRI_HINT_188_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG188_PRI_HINT_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG188_NONE_HINT_188_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG188_NONE_HINT_188_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG188_NONE_HINT_188_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG188_RESETVAL (0x80000000u)

/* pri_hint_reg189 */

#define CSL_CPINTC_PRI_HINT_REG189_PRI_HINT_189_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG189_PRI_HINT_189_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG189_PRI_HINT_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG189_NONE_HINT_189_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG189_NONE_HINT_189_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG189_NONE_HINT_189_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG189_RESETVAL (0x80000000u)

/* pri_hint_reg190 */

#define CSL_CPINTC_PRI_HINT_REG190_PRI_HINT_190_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG190_PRI_HINT_190_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG190_PRI_HINT_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG190_NONE_HINT_190_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG190_NONE_HINT_190_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG190_NONE_HINT_190_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG190_RESETVAL (0x80000000u)

/* pri_hint_reg191 */

#define CSL_CPINTC_PRI_HINT_REG191_PRI_HINT_191_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG191_PRI_HINT_191_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG191_PRI_HINT_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG191_NONE_HINT_191_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG191_NONE_HINT_191_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG191_NONE_HINT_191_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG191_RESETVAL (0x80000000u)

/* pri_hint_reg192 */

#define CSL_CPINTC_PRI_HINT_REG192_PRI_HINT_192_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG192_PRI_HINT_192_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG192_PRI_HINT_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG192_NONE_HINT_192_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG192_NONE_HINT_192_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG192_NONE_HINT_192_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG192_RESETVAL (0x80000000u)

/* pri_hint_reg193 */

#define CSL_CPINTC_PRI_HINT_REG193_PRI_HINT_193_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG193_PRI_HINT_193_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG193_PRI_HINT_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG193_NONE_HINT_193_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG193_NONE_HINT_193_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG193_NONE_HINT_193_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG193_RESETVAL (0x80000000u)

/* pri_hint_reg194 */

#define CSL_CPINTC_PRI_HINT_REG194_PRI_HINT_194_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG194_PRI_HINT_194_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG194_PRI_HINT_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG194_NONE_HINT_194_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG194_NONE_HINT_194_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG194_NONE_HINT_194_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG194_RESETVAL (0x80000000u)

/* pri_hint_reg195 */

#define CSL_CPINTC_PRI_HINT_REG195_PRI_HINT_195_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG195_PRI_HINT_195_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG195_PRI_HINT_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG195_NONE_HINT_195_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG195_NONE_HINT_195_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG195_NONE_HINT_195_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG195_RESETVAL (0x80000000u)

/* pri_hint_reg196 */

#define CSL_CPINTC_PRI_HINT_REG196_PRI_HINT_196_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG196_PRI_HINT_196_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG196_PRI_HINT_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG196_NONE_HINT_196_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG196_NONE_HINT_196_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG196_NONE_HINT_196_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG196_RESETVAL (0x80000000u)

/* pri_hint_reg197 */

#define CSL_CPINTC_PRI_HINT_REG197_PRI_HINT_197_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG197_PRI_HINT_197_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG197_PRI_HINT_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG197_NONE_HINT_197_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG197_NONE_HINT_197_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG197_NONE_HINT_197_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG197_RESETVAL (0x80000000u)

/* pri_hint_reg198 */

#define CSL_CPINTC_PRI_HINT_REG198_PRI_HINT_198_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG198_PRI_HINT_198_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG198_PRI_HINT_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG198_NONE_HINT_198_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG198_NONE_HINT_198_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG198_NONE_HINT_198_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG198_RESETVAL (0x80000000u)

/* pri_hint_reg199 */

#define CSL_CPINTC_PRI_HINT_REG199_PRI_HINT_199_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG199_PRI_HINT_199_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG199_PRI_HINT_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG199_NONE_HINT_199_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG199_NONE_HINT_199_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG199_NONE_HINT_199_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG199_RESETVAL (0x80000000u)

/* pri_hint_reg200 */

#define CSL_CPINTC_PRI_HINT_REG200_PRI_HINT_200_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG200_PRI_HINT_200_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG200_PRI_HINT_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG200_NONE_HINT_200_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG200_NONE_HINT_200_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG200_NONE_HINT_200_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG200_RESETVAL (0x80000000u)

/* pri_hint_reg201 */

#define CSL_CPINTC_PRI_HINT_REG201_PRI_HINT_201_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG201_PRI_HINT_201_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG201_PRI_HINT_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG201_NONE_HINT_201_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG201_NONE_HINT_201_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG201_NONE_HINT_201_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG201_RESETVAL (0x80000000u)

/* pri_hint_reg202 */

#define CSL_CPINTC_PRI_HINT_REG202_PRI_HINT_202_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG202_PRI_HINT_202_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG202_PRI_HINT_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG202_NONE_HINT_202_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG202_NONE_HINT_202_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG202_NONE_HINT_202_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG202_RESETVAL (0x80000000u)

/* pri_hint_reg203 */

#define CSL_CPINTC_PRI_HINT_REG203_PRI_HINT_203_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG203_PRI_HINT_203_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG203_PRI_HINT_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG203_NONE_HINT_203_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG203_NONE_HINT_203_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG203_NONE_HINT_203_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG203_RESETVAL (0x80000000u)

/* pri_hint_reg204 */

#define CSL_CPINTC_PRI_HINT_REG204_PRI_HINT_204_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG204_PRI_HINT_204_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG204_PRI_HINT_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG204_NONE_HINT_204_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG204_NONE_HINT_204_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG204_NONE_HINT_204_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG204_RESETVAL (0x80000000u)

/* pri_hint_reg205 */

#define CSL_CPINTC_PRI_HINT_REG205_PRI_HINT_205_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG205_PRI_HINT_205_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG205_PRI_HINT_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG205_NONE_HINT_205_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG205_NONE_HINT_205_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG205_NONE_HINT_205_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG205_RESETVAL (0x80000000u)

/* pri_hint_reg206 */

#define CSL_CPINTC_PRI_HINT_REG206_PRI_HINT_206_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG206_PRI_HINT_206_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG206_PRI_HINT_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG206_NONE_HINT_206_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG206_NONE_HINT_206_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG206_NONE_HINT_206_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG206_RESETVAL (0x80000000u)

/* pri_hint_reg207 */

#define CSL_CPINTC_PRI_HINT_REG207_PRI_HINT_207_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG207_PRI_HINT_207_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG207_PRI_HINT_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG207_NONE_HINT_207_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG207_NONE_HINT_207_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG207_NONE_HINT_207_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG207_RESETVAL (0x80000000u)

/* pri_hint_reg208 */

#define CSL_CPINTC_PRI_HINT_REG208_PRI_HINT_208_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG208_PRI_HINT_208_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG208_PRI_HINT_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG208_NONE_HINT_208_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG208_NONE_HINT_208_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG208_NONE_HINT_208_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG208_RESETVAL (0x80000000u)

/* pri_hint_reg209 */

#define CSL_CPINTC_PRI_HINT_REG209_PRI_HINT_209_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG209_PRI_HINT_209_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG209_PRI_HINT_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG209_NONE_HINT_209_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG209_NONE_HINT_209_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG209_NONE_HINT_209_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG209_RESETVAL (0x80000000u)

/* pri_hint_reg210 */

#define CSL_CPINTC_PRI_HINT_REG210_PRI_HINT_210_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG210_PRI_HINT_210_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG210_PRI_HINT_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG210_NONE_HINT_210_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG210_NONE_HINT_210_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG210_NONE_HINT_210_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG210_RESETVAL (0x80000000u)

/* pri_hint_reg211 */

#define CSL_CPINTC_PRI_HINT_REG211_PRI_HINT_211_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG211_PRI_HINT_211_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG211_PRI_HINT_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG211_NONE_HINT_211_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG211_NONE_HINT_211_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG211_NONE_HINT_211_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG211_RESETVAL (0x80000000u)

/* pri_hint_reg212 */

#define CSL_CPINTC_PRI_HINT_REG212_PRI_HINT_212_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG212_PRI_HINT_212_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG212_PRI_HINT_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG212_NONE_HINT_212_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG212_NONE_HINT_212_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG212_NONE_HINT_212_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG212_RESETVAL (0x80000000u)

/* pri_hint_reg213 */

#define CSL_CPINTC_PRI_HINT_REG213_PRI_HINT_213_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG213_PRI_HINT_213_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG213_PRI_HINT_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG213_NONE_HINT_213_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG213_NONE_HINT_213_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG213_NONE_HINT_213_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG213_RESETVAL (0x80000000u)

/* pri_hint_reg214 */

#define CSL_CPINTC_PRI_HINT_REG214_PRI_HINT_214_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG214_PRI_HINT_214_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG214_PRI_HINT_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG214_NONE_HINT_214_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG214_NONE_HINT_214_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG214_NONE_HINT_214_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG214_RESETVAL (0x80000000u)

/* pri_hint_reg215 */

#define CSL_CPINTC_PRI_HINT_REG215_PRI_HINT_215_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG215_PRI_HINT_215_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG215_PRI_HINT_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG215_NONE_HINT_215_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG215_NONE_HINT_215_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG215_NONE_HINT_215_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG215_RESETVAL (0x80000000u)

/* pri_hint_reg216 */

#define CSL_CPINTC_PRI_HINT_REG216_PRI_HINT_216_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG216_PRI_HINT_216_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG216_PRI_HINT_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG216_NONE_HINT_216_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG216_NONE_HINT_216_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG216_NONE_HINT_216_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG216_RESETVAL (0x80000000u)

/* pri_hint_reg217 */

#define CSL_CPINTC_PRI_HINT_REG217_PRI_HINT_217_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG217_PRI_HINT_217_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG217_PRI_HINT_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG217_NONE_HINT_217_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG217_NONE_HINT_217_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG217_NONE_HINT_217_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG217_RESETVAL (0x80000000u)

/* pri_hint_reg218 */

#define CSL_CPINTC_PRI_HINT_REG218_PRI_HINT_218_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG218_PRI_HINT_218_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG218_PRI_HINT_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG218_NONE_HINT_218_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG218_NONE_HINT_218_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG218_NONE_HINT_218_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG218_RESETVAL (0x80000000u)

/* pri_hint_reg219 */

#define CSL_CPINTC_PRI_HINT_REG219_PRI_HINT_219_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG219_PRI_HINT_219_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG219_PRI_HINT_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG219_NONE_HINT_219_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG219_NONE_HINT_219_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG219_NONE_HINT_219_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG219_RESETVAL (0x80000000u)

/* pri_hint_reg220 */

#define CSL_CPINTC_PRI_HINT_REG220_PRI_HINT_220_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG220_PRI_HINT_220_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG220_PRI_HINT_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG220_NONE_HINT_220_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG220_NONE_HINT_220_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG220_NONE_HINT_220_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG220_RESETVAL (0x80000000u)

/* pri_hint_reg221 */

#define CSL_CPINTC_PRI_HINT_REG221_PRI_HINT_221_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG221_PRI_HINT_221_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG221_PRI_HINT_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG221_NONE_HINT_221_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG221_NONE_HINT_221_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG221_NONE_HINT_221_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG221_RESETVAL (0x80000000u)

/* pri_hint_reg222 */

#define CSL_CPINTC_PRI_HINT_REG222_PRI_HINT_222_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG222_PRI_HINT_222_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG222_PRI_HINT_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG222_NONE_HINT_222_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG222_NONE_HINT_222_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG222_NONE_HINT_222_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG222_RESETVAL (0x80000000u)

/* pri_hint_reg223 */

#define CSL_CPINTC_PRI_HINT_REG223_PRI_HINT_223_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG223_PRI_HINT_223_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG223_PRI_HINT_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG223_NONE_HINT_223_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG223_NONE_HINT_223_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG223_NONE_HINT_223_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG223_RESETVAL (0x80000000u)

/* pri_hint_reg224 */

#define CSL_CPINTC_PRI_HINT_REG224_PRI_HINT_224_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG224_PRI_HINT_224_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG224_PRI_HINT_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG224_NONE_HINT_224_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG224_NONE_HINT_224_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG224_NONE_HINT_224_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG224_RESETVAL (0x80000000u)

/* pri_hint_reg225 */

#define CSL_CPINTC_PRI_HINT_REG225_PRI_HINT_225_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG225_PRI_HINT_225_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG225_PRI_HINT_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG225_NONE_HINT_225_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG225_NONE_HINT_225_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG225_NONE_HINT_225_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG225_RESETVAL (0x80000000u)

/* pri_hint_reg226 */

#define CSL_CPINTC_PRI_HINT_REG226_PRI_HINT_226_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG226_PRI_HINT_226_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG226_PRI_HINT_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG226_NONE_HINT_226_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG226_NONE_HINT_226_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG226_NONE_HINT_226_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG226_RESETVAL (0x80000000u)

/* pri_hint_reg227 */

#define CSL_CPINTC_PRI_HINT_REG227_PRI_HINT_227_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG227_PRI_HINT_227_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG227_PRI_HINT_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG227_NONE_HINT_227_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG227_NONE_HINT_227_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG227_NONE_HINT_227_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG227_RESETVAL (0x80000000u)

/* pri_hint_reg228 */

#define CSL_CPINTC_PRI_HINT_REG228_PRI_HINT_228_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG228_PRI_HINT_228_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG228_PRI_HINT_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG228_NONE_HINT_228_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG228_NONE_HINT_228_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG228_NONE_HINT_228_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG228_RESETVAL (0x80000000u)

/* pri_hint_reg229 */

#define CSL_CPINTC_PRI_HINT_REG229_PRI_HINT_229_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG229_PRI_HINT_229_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG229_PRI_HINT_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG229_NONE_HINT_229_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG229_NONE_HINT_229_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG229_NONE_HINT_229_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG229_RESETVAL (0x80000000u)

/* pri_hint_reg230 */

#define CSL_CPINTC_PRI_HINT_REG230_PRI_HINT_230_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG230_PRI_HINT_230_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG230_PRI_HINT_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG230_NONE_HINT_230_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG230_NONE_HINT_230_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG230_NONE_HINT_230_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG230_RESETVAL (0x80000000u)

/* pri_hint_reg231 */

#define CSL_CPINTC_PRI_HINT_REG231_PRI_HINT_231_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG231_PRI_HINT_231_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG231_PRI_HINT_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG231_NONE_HINT_231_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG231_NONE_HINT_231_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG231_NONE_HINT_231_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG231_RESETVAL (0x80000000u)

/* pri_hint_reg232 */

#define CSL_CPINTC_PRI_HINT_REG232_PRI_HINT_232_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG232_PRI_HINT_232_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG232_PRI_HINT_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG232_NONE_HINT_232_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG232_NONE_HINT_232_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG232_NONE_HINT_232_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG232_RESETVAL (0x80000000u)

/* pri_hint_reg233 */

#define CSL_CPINTC_PRI_HINT_REG233_PRI_HINT_233_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG233_PRI_HINT_233_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG233_PRI_HINT_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG233_NONE_HINT_233_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG233_NONE_HINT_233_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG233_NONE_HINT_233_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG233_RESETVAL (0x80000000u)

/* pri_hint_reg234 */

#define CSL_CPINTC_PRI_HINT_REG234_PRI_HINT_234_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG234_PRI_HINT_234_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG234_PRI_HINT_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG234_NONE_HINT_234_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG234_NONE_HINT_234_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG234_NONE_HINT_234_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG234_RESETVAL (0x80000000u)

/* pri_hint_reg235 */

#define CSL_CPINTC_PRI_HINT_REG235_PRI_HINT_235_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG235_PRI_HINT_235_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG235_PRI_HINT_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG235_NONE_HINT_235_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG235_NONE_HINT_235_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG235_NONE_HINT_235_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG235_RESETVAL (0x80000000u)

/* pri_hint_reg236 */

#define CSL_CPINTC_PRI_HINT_REG236_PRI_HINT_236_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG236_PRI_HINT_236_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG236_PRI_HINT_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG236_NONE_HINT_236_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG236_NONE_HINT_236_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG236_NONE_HINT_236_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG236_RESETVAL (0x80000000u)

/* pri_hint_reg237 */

#define CSL_CPINTC_PRI_HINT_REG237_PRI_HINT_237_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG237_PRI_HINT_237_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG237_PRI_HINT_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG237_NONE_HINT_237_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG237_NONE_HINT_237_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG237_NONE_HINT_237_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG237_RESETVAL (0x80000000u)

/* pri_hint_reg238 */

#define CSL_CPINTC_PRI_HINT_REG238_PRI_HINT_238_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG238_PRI_HINT_238_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG238_PRI_HINT_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG238_NONE_HINT_238_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG238_NONE_HINT_238_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG238_NONE_HINT_238_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG238_RESETVAL (0x80000000u)

/* pri_hint_reg239 */

#define CSL_CPINTC_PRI_HINT_REG239_PRI_HINT_239_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG239_PRI_HINT_239_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG239_PRI_HINT_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG239_NONE_HINT_239_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG239_NONE_HINT_239_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG239_NONE_HINT_239_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG239_RESETVAL (0x80000000u)

/* pri_hint_reg240 */

#define CSL_CPINTC_PRI_HINT_REG240_PRI_HINT_240_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG240_PRI_HINT_240_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG240_PRI_HINT_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG240_NONE_HINT_240_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG240_NONE_HINT_240_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG240_NONE_HINT_240_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG240_RESETVAL (0x80000000u)

/* pri_hint_reg241 */

#define CSL_CPINTC_PRI_HINT_REG241_PRI_HINT_241_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG241_PRI_HINT_241_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG241_PRI_HINT_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG241_NONE_HINT_241_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG241_NONE_HINT_241_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG241_NONE_HINT_241_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG241_RESETVAL (0x80000000u)

/* pri_hint_reg242 */

#define CSL_CPINTC_PRI_HINT_REG242_PRI_HINT_242_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG242_PRI_HINT_242_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG242_PRI_HINT_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG242_NONE_HINT_242_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG242_NONE_HINT_242_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG242_NONE_HINT_242_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG242_RESETVAL (0x80000000u)

/* pri_hint_reg243 */

#define CSL_CPINTC_PRI_HINT_REG243_PRI_HINT_243_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG243_PRI_HINT_243_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG243_PRI_HINT_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG243_NONE_HINT_243_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG243_NONE_HINT_243_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG243_NONE_HINT_243_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG243_RESETVAL (0x80000000u)

/* pri_hint_reg244 */

#define CSL_CPINTC_PRI_HINT_REG244_PRI_HINT_244_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG244_PRI_HINT_244_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG244_PRI_HINT_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG244_NONE_HINT_244_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG244_NONE_HINT_244_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG244_NONE_HINT_244_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG244_RESETVAL (0x80000000u)

/* pri_hint_reg245 */

#define CSL_CPINTC_PRI_HINT_REG245_PRI_HINT_245_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG245_PRI_HINT_245_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG245_PRI_HINT_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG245_NONE_HINT_245_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG245_NONE_HINT_245_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG245_NONE_HINT_245_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG245_RESETVAL (0x80000000u)

/* pri_hint_reg246 */

#define CSL_CPINTC_PRI_HINT_REG246_PRI_HINT_246_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG246_PRI_HINT_246_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG246_PRI_HINT_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG246_NONE_HINT_246_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG246_NONE_HINT_246_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG246_NONE_HINT_246_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG246_RESETVAL (0x80000000u)

/* pri_hint_reg247 */

#define CSL_CPINTC_PRI_HINT_REG247_PRI_HINT_247_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG247_PRI_HINT_247_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG247_PRI_HINT_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG247_NONE_HINT_247_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG247_NONE_HINT_247_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG247_NONE_HINT_247_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG247_RESETVAL (0x80000000u)

/* pri_hint_reg248 */

#define CSL_CPINTC_PRI_HINT_REG248_PRI_HINT_248_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG248_PRI_HINT_248_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG248_PRI_HINT_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG248_NONE_HINT_248_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG248_NONE_HINT_248_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG248_NONE_HINT_248_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG248_RESETVAL (0x80000000u)

/* pri_hint_reg249 */

#define CSL_CPINTC_PRI_HINT_REG249_PRI_HINT_249_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG249_PRI_HINT_249_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG249_PRI_HINT_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG249_NONE_HINT_249_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG249_NONE_HINT_249_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG249_NONE_HINT_249_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG249_RESETVAL (0x80000000u)

/* pri_hint_reg250 */

#define CSL_CPINTC_PRI_HINT_REG250_PRI_HINT_250_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG250_PRI_HINT_250_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG250_PRI_HINT_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG250_NONE_HINT_250_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG250_NONE_HINT_250_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG250_NONE_HINT_250_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG250_RESETVAL (0x80000000u)

/* pri_hint_reg251 */

#define CSL_CPINTC_PRI_HINT_REG251_PRI_HINT_251_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG251_PRI_HINT_251_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG251_PRI_HINT_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG251_NONE_HINT_251_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG251_NONE_HINT_251_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG251_NONE_HINT_251_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG251_RESETVAL (0x80000000u)

/* pri_hint_reg252 */

#define CSL_CPINTC_PRI_HINT_REG252_PRI_HINT_252_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG252_PRI_HINT_252_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG252_PRI_HINT_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG252_NONE_HINT_252_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG252_NONE_HINT_252_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG252_NONE_HINT_252_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG252_RESETVAL (0x80000000u)

/* pri_hint_reg253 */

#define CSL_CPINTC_PRI_HINT_REG253_PRI_HINT_253_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG253_PRI_HINT_253_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG253_PRI_HINT_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG253_NONE_HINT_253_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG253_NONE_HINT_253_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG253_NONE_HINT_253_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG253_RESETVAL (0x80000000u)

/* pri_hint_reg254 */

#define CSL_CPINTC_PRI_HINT_REG254_PRI_HINT_254_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG254_PRI_HINT_254_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG254_PRI_HINT_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG254_NONE_HINT_254_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG254_NONE_HINT_254_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG254_NONE_HINT_254_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG254_RESETVAL (0x80000000u)

/* pri_hint_reg255 */

#define CSL_CPINTC_PRI_HINT_REG255_PRI_HINT_255_MASK (0x000003FFu)
#define CSL_CPINTC_PRI_HINT_REG255_PRI_HINT_255_SHIFT (0x00000000u)
#define CSL_CPINTC_PRI_HINT_REG255_PRI_HINT_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_PRI_HINT_REG255_NONE_HINT_255_MASK (0x80000000u)
#define CSL_CPINTC_PRI_HINT_REG255_NONE_HINT_255_SHIFT (0x0000001Fu)
#define CSL_CPINTC_PRI_HINT_REG255_NONE_HINT_255_RESETVAL (0x00000001u)

#define CSL_CPINTC_PRI_HINT_REG255_RESETVAL (0x80000000u)

/* polarity_reg0 */

#define CSL_CPINTC_POLARITY_REG0_POLARITY_0_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_0_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_1_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_1_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_2_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_2_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_3_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_3_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_4_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_4_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_5_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_5_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_6_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_6_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_7_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_7_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_8_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_8_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_9_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_9_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_10_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_10_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_11_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_11_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_12_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_12_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_13_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_13_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_14_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_14_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_15_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_15_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_16_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_16_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_17_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_17_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_18_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_18_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_19_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_19_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_20_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_20_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_21_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_21_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_22_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_22_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_23_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_23_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_24_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_24_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_25_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_25_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_26_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_26_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_27_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_27_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_28_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_28_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_29_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_29_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_30_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_30_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_POLARITY_31_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG0_POLARITY_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG0_RESETVAL (0x00000000u)

/* polarity_reg1 */

#define CSL_CPINTC_POLARITY_REG1_POLARITY_32_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_32_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_33_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_33_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_34_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_34_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_35_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_35_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_36_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_36_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_37_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_37_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_38_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_38_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_39_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_39_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_40_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_40_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_41_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_41_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_42_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_42_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_43_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_43_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_44_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_44_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_45_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_45_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_46_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_46_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_47_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_47_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_48_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_48_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_49_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_49_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_50_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_50_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_51_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_51_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_52_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_52_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_53_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_53_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_54_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_54_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_55_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_55_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_56_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_56_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_57_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_57_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_58_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_58_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_59_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_59_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_60_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_60_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_61_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_61_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_62_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_62_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_POLARITY_63_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG1_POLARITY_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG1_RESETVAL (0x00000000u)

/* polarity_reg2 */

#define CSL_CPINTC_POLARITY_REG2_POLARITY_64_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_64_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_65_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_65_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_66_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_66_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_67_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_67_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_68_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_68_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_69_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_69_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_70_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_70_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_71_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_71_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_72_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_72_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_73_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_73_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_74_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_74_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_75_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_75_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_76_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_76_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_77_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_77_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_78_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_78_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_79_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_79_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_80_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_80_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_81_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_81_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_82_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_82_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_83_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_83_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_84_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_84_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_85_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_85_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_86_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_86_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_87_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_87_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_88_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_88_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_89_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_89_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_90_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_90_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_91_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_91_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_92_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_92_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_93_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_93_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_94_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_94_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_POLARITY_95_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_95_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG2_POLARITY_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG2_RESETVAL (0x00000000u)

/* polarity_reg3 */

#define CSL_CPINTC_POLARITY_REG3_POLARITY_96_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_96_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_97_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_97_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_98_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_98_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_99_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_99_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_100_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_100_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_101_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_101_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_102_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_102_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_103_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_103_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_104_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_104_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_105_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_105_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_106_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_106_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_107_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_107_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_108_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_108_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_109_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_109_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_110_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_110_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_111_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_111_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_112_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_112_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_113_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_113_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_114_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_114_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_115_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_115_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_116_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_116_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_117_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_117_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_118_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_118_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_119_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_119_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_120_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_120_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_121_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_121_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_122_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_122_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_123_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_123_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_124_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_124_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_125_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_125_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_126_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_126_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_POLARITY_127_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_127_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG3_POLARITY_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG3_RESETVAL (0x00000000u)

/* polarity_reg4 */

#define CSL_CPINTC_POLARITY_REG4_POLARITY_128_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_128_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_129_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_129_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_130_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_130_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_131_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_131_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_132_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_132_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_133_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_133_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_134_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_134_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_135_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_135_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_136_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_136_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_137_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_137_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_138_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_138_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_139_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_139_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_140_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_140_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_141_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_141_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_142_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_142_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_143_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_143_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_144_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_144_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_145_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_145_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_146_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_146_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_147_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_147_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_148_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_148_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_149_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_149_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_150_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_150_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_151_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_151_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_152_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_152_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_153_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_153_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_154_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_154_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_155_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_155_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_156_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_156_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_157_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_157_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_158_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_158_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_POLARITY_159_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_159_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG4_POLARITY_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG4_RESETVAL (0x00000000u)

/* polarity_reg5 */

#define CSL_CPINTC_POLARITY_REG5_POLARITY_160_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_160_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_161_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_161_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_162_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_162_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_163_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_163_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_164_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_164_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_165_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_165_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_166_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_166_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_167_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_167_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_168_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_168_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_169_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_169_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_170_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_170_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_171_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_171_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_172_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_172_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_173_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_173_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_174_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_174_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_175_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_175_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_176_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_176_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_177_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_177_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_178_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_178_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_179_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_179_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_180_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_180_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_181_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_181_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_182_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_182_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_183_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_183_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_184_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_184_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_185_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_185_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_186_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_186_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_187_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_187_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_188_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_188_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_189_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_189_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_190_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_190_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_POLARITY_191_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_191_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG5_POLARITY_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG5_RESETVAL (0x00000000u)

/* polarity_reg6 */

#define CSL_CPINTC_POLARITY_REG6_POLARITY_192_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_192_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_193_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_193_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_194_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_194_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_195_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_195_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_196_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_196_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_197_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_197_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_198_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_198_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_199_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_199_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_200_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_200_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_201_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_201_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_202_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_202_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_203_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_203_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_204_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_204_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_205_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_205_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_206_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_206_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_207_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_207_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_208_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_208_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_209_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_209_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_210_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_210_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_211_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_211_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_212_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_212_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_213_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_213_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_214_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_214_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_215_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_215_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_216_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_216_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_217_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_217_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_218_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_218_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_219_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_219_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_220_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_220_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_221_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_221_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_222_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_222_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_POLARITY_223_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_223_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG6_POLARITY_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG6_RESETVAL (0x00000000u)

/* polarity_reg7 */

#define CSL_CPINTC_POLARITY_REG7_POLARITY_224_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_224_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_225_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_225_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_226_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_226_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_227_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_227_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_228_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_228_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_229_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_229_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_230_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_230_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_231_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_231_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_232_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_232_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_233_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_233_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_234_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_234_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_235_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_235_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_236_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_236_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_237_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_237_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_238_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_238_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_239_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_239_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_240_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_240_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_241_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_241_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_242_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_242_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_243_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_243_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_244_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_244_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_245_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_245_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_246_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_246_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_247_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_247_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_248_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_248_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_249_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_249_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_250_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_250_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_251_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_251_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_252_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_252_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_253_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_253_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_254_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_254_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_POLARITY_255_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_255_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG7_POLARITY_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG7_RESETVAL (0x00000000u)

/* polarity_reg8 */

#define CSL_CPINTC_POLARITY_REG8_POLARITY_256_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_256_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_256_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_257_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_257_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_257_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_258_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_258_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_258_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_259_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_259_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_259_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_260_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_260_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_260_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_261_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_261_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_261_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_262_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_262_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_262_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_263_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_263_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_263_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_264_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_264_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_264_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_265_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_265_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_265_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_266_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_266_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_266_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_267_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_267_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_267_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_268_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_268_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_268_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_269_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_269_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_269_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_270_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_270_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_270_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_271_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_271_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_271_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_272_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_272_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_272_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_273_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_273_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_273_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_274_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_274_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_274_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_275_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_275_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_275_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_276_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_276_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_276_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_277_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_277_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_277_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_278_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_278_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_278_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_279_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_279_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_279_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_280_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_280_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_280_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_281_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_281_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_281_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_282_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_282_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_282_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_283_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_283_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_283_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_284_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_284_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_284_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_285_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_285_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_285_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_286_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_286_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_286_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_POLARITY_287_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_287_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG8_POLARITY_287_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG8_RESETVAL (0x00000000u)

/* polarity_reg9 */

#define CSL_CPINTC_POLARITY_REG9_POLARITY_288_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_288_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_288_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_289_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_289_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_289_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_290_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_290_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_290_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_291_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_291_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_291_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_292_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_292_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_292_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_293_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_293_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_293_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_294_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_294_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_294_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_295_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_295_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_295_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_296_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_296_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_296_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_297_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_297_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_297_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_298_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_298_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_298_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_299_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_299_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_299_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_300_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_300_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_300_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_301_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_301_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_301_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_302_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_302_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_302_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_303_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_303_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_303_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_304_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_304_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_304_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_305_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_305_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_305_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_306_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_306_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_306_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_307_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_307_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_307_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_308_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_308_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_308_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_309_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_309_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_309_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_310_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_310_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_310_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_311_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_311_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_311_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_312_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_312_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_312_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_313_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_313_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_313_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_314_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_314_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_314_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_315_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_315_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_315_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_316_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_316_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_316_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_317_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_317_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_317_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_318_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_318_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_318_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_POLARITY_319_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_319_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG9_POLARITY_319_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG9_RESETVAL (0x00000000u)

/* polarity_reg10 */

#define CSL_CPINTC_POLARITY_REG10_POLARITY_320_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_320_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_320_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_321_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_321_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_321_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_322_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_322_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_322_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_323_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_323_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_323_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_324_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_324_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_324_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_325_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_325_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_325_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_326_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_326_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_326_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_327_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_327_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_327_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_328_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_328_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_328_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_329_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_329_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_329_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_330_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_330_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_330_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_331_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_331_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_331_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_332_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_332_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_332_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_333_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_333_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_333_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_334_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_334_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_334_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_335_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_335_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_335_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_336_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_336_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_336_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_337_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_337_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_337_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_338_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_338_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_338_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_339_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_339_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_339_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_340_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_340_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_340_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_341_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_341_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_341_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_342_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_342_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_342_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_343_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_343_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_343_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_344_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_344_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_344_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_345_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_345_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_345_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_346_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_346_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_346_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_347_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_347_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_347_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_348_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_348_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_348_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_349_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_349_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_349_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_350_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_350_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_350_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_POLARITY_351_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_351_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG10_POLARITY_351_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG10_RESETVAL (0x00000000u)

/* polarity_reg11 */

#define CSL_CPINTC_POLARITY_REG11_POLARITY_352_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_352_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_352_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_353_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_353_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_353_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_354_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_354_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_354_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_355_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_355_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_355_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_356_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_356_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_356_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_357_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_357_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_357_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_358_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_358_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_358_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_359_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_359_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_359_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_360_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_360_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_360_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_361_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_361_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_361_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_362_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_362_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_362_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_363_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_363_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_363_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_364_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_364_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_364_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_365_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_365_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_365_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_366_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_366_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_366_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_367_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_367_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_367_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_368_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_368_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_368_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_369_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_369_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_369_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_370_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_370_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_370_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_371_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_371_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_371_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_372_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_372_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_372_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_373_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_373_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_373_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_374_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_374_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_374_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_375_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_375_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_375_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_376_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_376_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_376_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_377_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_377_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_377_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_378_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_378_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_378_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_379_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_379_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_379_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_380_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_380_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_380_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_381_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_381_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_381_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_382_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_382_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_382_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_POLARITY_383_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_383_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG11_POLARITY_383_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG11_RESETVAL (0x00000000u)

/* polarity_reg12 */

#define CSL_CPINTC_POLARITY_REG12_POLARITY_384_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_384_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_384_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_385_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_385_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_385_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_386_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_386_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_386_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_387_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_387_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_387_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_388_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_388_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_388_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_389_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_389_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_389_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_390_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_390_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_390_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_391_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_391_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_391_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_392_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_392_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_392_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_393_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_393_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_393_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_394_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_394_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_394_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_395_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_395_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_395_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_396_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_396_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_396_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_397_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_397_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_397_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_398_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_398_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_398_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_399_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_399_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_399_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_400_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_400_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_400_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_401_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_401_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_401_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_402_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_402_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_402_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_403_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_403_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_403_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_404_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_404_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_404_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_405_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_405_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_405_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_406_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_406_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_406_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_407_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_407_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_407_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_408_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_408_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_408_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_409_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_409_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_409_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_410_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_410_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_410_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_411_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_411_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_411_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_412_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_412_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_412_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_413_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_413_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_413_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_414_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_414_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_414_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_POLARITY_415_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_415_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG12_POLARITY_415_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG12_RESETVAL (0x00000000u)

/* polarity_reg13 */

#define CSL_CPINTC_POLARITY_REG13_POLARITY_416_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_416_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_416_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_417_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_417_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_417_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_418_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_418_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_418_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_419_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_419_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_419_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_420_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_420_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_420_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_421_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_421_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_421_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_422_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_422_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_422_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_423_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_423_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_423_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_424_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_424_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_424_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_425_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_425_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_425_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_426_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_426_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_426_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_427_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_427_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_427_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_428_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_428_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_428_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_429_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_429_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_429_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_430_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_430_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_430_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_431_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_431_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_431_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_432_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_432_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_432_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_433_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_433_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_433_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_434_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_434_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_434_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_435_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_435_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_435_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_436_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_436_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_436_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_437_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_437_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_437_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_438_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_438_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_438_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_439_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_439_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_439_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_440_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_440_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_440_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_441_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_441_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_441_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_442_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_442_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_442_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_443_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_443_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_443_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_444_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_444_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_444_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_445_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_445_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_445_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_446_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_446_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_446_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_POLARITY_447_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_447_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG13_POLARITY_447_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG13_RESETVAL (0x00000000u)

/* polarity_reg14 */

#define CSL_CPINTC_POLARITY_REG14_POLARITY_448_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_448_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_448_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_449_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_449_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_449_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_450_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_450_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_450_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_451_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_451_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_451_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_452_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_452_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_452_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_453_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_453_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_453_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_454_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_454_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_454_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_455_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_455_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_455_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_456_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_456_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_456_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_457_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_457_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_457_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_458_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_458_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_458_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_459_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_459_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_459_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_460_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_460_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_460_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_461_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_461_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_461_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_462_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_462_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_462_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_463_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_463_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_463_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_464_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_464_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_464_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_465_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_465_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_465_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_466_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_466_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_466_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_467_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_467_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_467_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_468_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_468_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_468_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_469_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_469_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_469_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_470_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_470_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_470_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_471_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_471_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_471_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_472_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_472_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_472_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_473_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_473_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_473_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_474_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_474_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_474_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_475_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_475_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_475_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_476_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_476_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_476_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_477_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_477_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_477_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_478_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_478_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_478_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_POLARITY_479_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_479_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG14_POLARITY_479_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG14_RESETVAL (0x00000000u)

/* polarity_reg15 */

#define CSL_CPINTC_POLARITY_REG15_POLARITY_480_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_480_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_480_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_481_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_481_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_481_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_482_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_482_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_482_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_483_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_483_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_483_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_484_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_484_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_484_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_485_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_485_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_485_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_486_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_486_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_486_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_487_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_487_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_487_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_488_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_488_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_488_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_489_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_489_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_489_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_490_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_490_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_490_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_491_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_491_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_491_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_492_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_492_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_492_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_493_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_493_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_493_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_494_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_494_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_494_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_495_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_495_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_495_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_496_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_496_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_496_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_497_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_497_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_497_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_498_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_498_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_498_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_499_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_499_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_499_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_500_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_500_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_500_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_501_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_501_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_501_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_502_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_502_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_502_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_503_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_503_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_503_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_504_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_504_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_504_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_505_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_505_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_505_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_506_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_506_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_506_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_507_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_507_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_507_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_508_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_508_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_508_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_509_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_509_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_509_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_510_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_510_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_510_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_POLARITY_511_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_511_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG15_POLARITY_511_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG15_RESETVAL (0x00000000u)

/* polarity_reg16 */

#define CSL_CPINTC_POLARITY_REG16_POLARITY_512_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_512_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_512_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_513_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_513_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_513_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_514_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_514_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_514_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_515_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_515_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_515_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_516_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_516_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_516_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_517_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_517_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_517_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_518_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_518_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_518_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_519_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_519_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_519_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_520_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_520_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_520_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_521_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_521_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_521_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_522_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_522_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_522_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_523_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_523_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_523_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_524_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_524_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_524_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_525_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_525_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_525_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_526_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_526_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_526_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_527_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_527_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_527_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_528_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_528_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_528_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_529_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_529_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_529_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_530_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_530_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_530_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_531_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_531_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_531_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_532_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_532_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_532_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_533_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_533_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_533_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_534_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_534_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_534_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_535_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_535_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_535_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_536_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_536_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_536_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_537_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_537_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_537_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_538_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_538_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_538_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_539_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_539_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_539_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_540_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_540_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_540_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_541_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_541_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_541_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_542_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_542_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_542_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_POLARITY_543_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_543_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG16_POLARITY_543_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG16_RESETVAL (0x00000000u)

/* polarity_reg17 */

#define CSL_CPINTC_POLARITY_REG17_POLARITY_544_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_544_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_544_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_545_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_545_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_545_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_546_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_546_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_546_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_547_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_547_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_547_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_548_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_548_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_548_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_549_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_549_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_549_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_550_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_550_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_550_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_551_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_551_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_551_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_552_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_552_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_552_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_553_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_553_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_553_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_554_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_554_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_554_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_555_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_555_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_555_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_556_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_556_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_556_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_557_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_557_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_557_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_558_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_558_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_558_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_559_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_559_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_559_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_560_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_560_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_560_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_561_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_561_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_561_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_562_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_562_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_562_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_563_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_563_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_563_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_564_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_564_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_564_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_565_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_565_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_565_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_566_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_566_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_566_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_567_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_567_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_567_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_568_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_568_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_568_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_569_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_569_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_569_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_570_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_570_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_570_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_571_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_571_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_571_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_572_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_572_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_572_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_573_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_573_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_573_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_574_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_574_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_574_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_POLARITY_575_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_575_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG17_POLARITY_575_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG17_RESETVAL (0x00000000u)

/* polarity_reg18 */

#define CSL_CPINTC_POLARITY_REG18_POLARITY_576_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_576_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_576_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_577_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_577_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_577_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_578_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_578_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_578_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_579_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_579_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_579_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_580_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_580_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_580_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_581_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_581_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_581_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_582_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_582_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_582_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_583_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_583_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_583_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_584_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_584_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_584_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_585_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_585_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_585_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_586_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_586_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_586_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_587_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_587_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_587_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_588_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_588_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_588_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_589_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_589_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_589_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_590_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_590_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_590_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_591_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_591_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_591_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_592_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_592_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_592_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_593_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_593_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_593_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_594_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_594_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_594_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_595_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_595_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_595_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_596_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_596_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_596_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_597_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_597_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_597_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_598_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_598_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_598_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_599_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_599_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_599_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_600_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_600_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_600_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_601_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_601_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_601_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_602_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_602_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_602_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_603_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_603_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_603_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_604_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_604_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_604_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_605_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_605_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_605_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_606_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_606_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_606_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_POLARITY_607_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_607_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG18_POLARITY_607_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG18_RESETVAL (0x00000000u)

/* polarity_reg19 */

#define CSL_CPINTC_POLARITY_REG19_POLARITY_608_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_608_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_608_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_609_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_609_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_609_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_610_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_610_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_610_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_611_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_611_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_611_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_612_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_612_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_612_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_613_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_613_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_613_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_614_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_614_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_614_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_615_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_615_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_615_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_616_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_616_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_616_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_617_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_617_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_617_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_618_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_618_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_618_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_619_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_619_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_619_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_620_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_620_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_620_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_621_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_621_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_621_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_622_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_622_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_622_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_623_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_623_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_623_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_624_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_624_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_624_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_625_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_625_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_625_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_626_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_626_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_626_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_627_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_627_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_627_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_628_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_628_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_628_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_629_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_629_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_629_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_630_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_630_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_630_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_631_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_631_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_631_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_632_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_632_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_632_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_633_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_633_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_633_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_634_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_634_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_634_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_635_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_635_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_635_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_636_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_636_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_636_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_637_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_637_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_637_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_638_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_638_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_638_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_POLARITY_639_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_639_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG19_POLARITY_639_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG19_RESETVAL (0x00000000u)

/* polarity_reg20 */

#define CSL_CPINTC_POLARITY_REG20_POLARITY_640_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_640_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_640_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_641_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_641_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_641_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_642_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_642_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_642_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_643_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_643_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_643_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_644_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_644_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_644_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_645_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_645_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_645_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_646_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_646_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_646_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_647_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_647_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_647_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_648_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_648_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_648_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_649_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_649_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_649_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_650_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_650_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_650_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_651_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_651_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_651_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_652_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_652_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_652_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_653_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_653_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_653_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_654_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_654_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_654_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_655_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_655_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_655_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_656_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_656_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_656_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_657_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_657_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_657_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_658_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_658_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_658_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_659_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_659_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_659_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_660_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_660_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_660_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_661_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_661_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_661_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_662_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_662_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_662_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_663_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_663_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_663_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_664_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_664_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_664_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_665_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_665_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_665_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_666_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_666_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_666_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_667_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_667_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_667_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_668_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_668_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_668_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_669_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_669_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_669_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_670_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_670_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_670_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_POLARITY_671_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_671_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG20_POLARITY_671_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG20_RESETVAL (0x00000000u)

/* polarity_reg21 */

#define CSL_CPINTC_POLARITY_REG21_POLARITY_672_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_672_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_672_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_673_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_673_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_673_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_674_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_674_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_674_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_675_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_675_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_675_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_676_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_676_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_676_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_677_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_677_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_677_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_678_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_678_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_678_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_679_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_679_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_679_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_680_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_680_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_680_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_681_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_681_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_681_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_682_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_682_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_682_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_683_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_683_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_683_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_684_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_684_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_684_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_685_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_685_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_685_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_686_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_686_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_686_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_687_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_687_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_687_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_688_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_688_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_688_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_689_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_689_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_689_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_690_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_690_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_690_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_691_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_691_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_691_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_692_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_692_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_692_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_693_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_693_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_693_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_694_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_694_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_694_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_695_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_695_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_695_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_696_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_696_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_696_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_697_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_697_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_697_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_698_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_698_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_698_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_699_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_699_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_699_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_700_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_700_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_700_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_701_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_701_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_701_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_702_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_702_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_702_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_POLARITY_703_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_703_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG21_POLARITY_703_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG21_RESETVAL (0x00000000u)

/* polarity_reg22 */

#define CSL_CPINTC_POLARITY_REG22_POLARITY_704_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_704_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_704_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_705_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_705_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_705_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_706_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_706_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_706_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_707_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_707_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_707_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_708_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_708_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_708_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_709_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_709_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_709_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_710_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_710_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_710_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_711_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_711_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_711_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_712_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_712_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_712_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_713_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_713_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_713_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_714_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_714_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_714_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_715_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_715_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_715_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_716_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_716_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_716_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_717_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_717_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_717_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_718_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_718_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_718_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_719_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_719_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_719_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_720_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_720_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_720_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_721_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_721_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_721_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_722_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_722_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_722_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_723_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_723_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_723_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_724_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_724_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_724_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_725_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_725_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_725_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_726_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_726_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_726_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_727_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_727_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_727_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_728_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_728_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_728_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_729_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_729_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_729_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_730_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_730_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_730_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_731_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_731_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_731_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_732_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_732_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_732_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_733_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_733_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_733_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_734_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_734_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_734_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_POLARITY_735_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_735_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG22_POLARITY_735_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG22_RESETVAL (0x00000000u)

/* polarity_reg23 */

#define CSL_CPINTC_POLARITY_REG23_POLARITY_736_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_736_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_736_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_737_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_737_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_737_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_738_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_738_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_738_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_739_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_739_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_739_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_740_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_740_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_740_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_741_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_741_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_741_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_742_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_742_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_742_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_743_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_743_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_743_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_744_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_744_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_744_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_745_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_745_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_745_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_746_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_746_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_746_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_747_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_747_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_747_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_748_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_748_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_748_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_749_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_749_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_749_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_750_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_750_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_750_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_751_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_751_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_751_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_752_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_752_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_752_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_753_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_753_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_753_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_754_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_754_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_754_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_755_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_755_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_755_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_756_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_756_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_756_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_757_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_757_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_757_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_758_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_758_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_758_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_759_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_759_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_759_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_760_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_760_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_760_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_761_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_761_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_761_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_762_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_762_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_762_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_763_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_763_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_763_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_764_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_764_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_764_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_765_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_765_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_765_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_766_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_766_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_766_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_POLARITY_767_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_767_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG23_POLARITY_767_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG23_RESETVAL (0x00000000u)

/* polarity_reg24 */

#define CSL_CPINTC_POLARITY_REG24_POLARITY_768_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_768_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_768_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_769_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_769_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_769_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_770_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_770_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_770_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_771_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_771_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_771_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_772_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_772_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_772_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_773_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_773_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_773_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_774_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_774_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_774_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_775_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_775_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_775_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_776_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_776_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_776_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_777_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_777_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_777_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_778_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_778_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_778_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_779_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_779_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_779_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_780_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_780_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_780_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_781_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_781_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_781_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_782_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_782_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_782_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_783_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_783_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_783_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_784_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_784_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_784_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_785_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_785_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_785_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_786_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_786_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_786_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_787_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_787_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_787_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_788_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_788_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_788_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_789_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_789_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_789_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_790_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_790_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_790_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_791_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_791_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_791_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_792_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_792_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_792_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_793_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_793_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_793_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_794_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_794_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_794_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_795_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_795_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_795_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_796_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_796_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_796_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_797_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_797_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_797_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_798_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_798_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_798_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_POLARITY_799_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_799_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG24_POLARITY_799_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG24_RESETVAL (0x00000000u)

/* polarity_reg25 */

#define CSL_CPINTC_POLARITY_REG25_POLARITY_800_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_800_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_800_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_801_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_801_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_801_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_802_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_802_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_802_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_803_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_803_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_803_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_804_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_804_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_804_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_805_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_805_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_805_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_806_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_806_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_806_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_807_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_807_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_807_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_808_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_808_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_808_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_809_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_809_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_809_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_810_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_810_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_810_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_811_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_811_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_811_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_812_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_812_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_812_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_813_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_813_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_813_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_814_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_814_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_814_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_815_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_815_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_815_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_816_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_816_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_816_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_817_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_817_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_817_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_818_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_818_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_818_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_819_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_819_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_819_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_820_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_820_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_820_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_821_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_821_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_821_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_822_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_822_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_822_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_823_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_823_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_823_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_824_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_824_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_824_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_825_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_825_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_825_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_826_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_826_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_826_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_827_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_827_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_827_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_828_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_828_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_828_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_829_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_829_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_829_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_830_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_830_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_830_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_POLARITY_831_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_831_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG25_POLARITY_831_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG25_RESETVAL (0x00000000u)

/* polarity_reg26 */

#define CSL_CPINTC_POLARITY_REG26_POLARITY_832_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_832_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_832_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_833_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_833_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_833_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_834_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_834_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_834_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_835_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_835_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_835_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_836_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_836_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_836_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_837_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_837_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_837_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_838_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_838_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_838_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_839_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_839_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_839_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_840_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_840_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_840_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_841_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_841_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_841_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_842_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_842_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_842_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_843_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_843_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_843_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_844_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_844_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_844_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_845_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_845_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_845_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_846_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_846_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_846_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_847_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_847_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_847_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_848_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_848_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_848_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_849_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_849_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_849_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_850_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_850_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_850_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_851_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_851_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_851_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_852_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_852_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_852_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_853_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_853_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_853_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_854_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_854_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_854_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_855_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_855_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_855_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_856_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_856_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_856_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_857_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_857_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_857_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_858_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_858_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_858_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_859_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_859_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_859_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_860_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_860_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_860_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_861_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_861_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_861_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_862_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_862_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_862_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_POLARITY_863_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_863_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG26_POLARITY_863_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG26_RESETVAL (0x00000000u)

/* polarity_reg27 */

#define CSL_CPINTC_POLARITY_REG27_POLARITY_864_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_864_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_864_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_865_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_865_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_865_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_866_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_866_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_866_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_867_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_867_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_867_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_868_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_868_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_868_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_869_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_869_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_869_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_870_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_870_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_870_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_871_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_871_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_871_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_872_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_872_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_872_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_873_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_873_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_873_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_874_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_874_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_874_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_875_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_875_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_875_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_876_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_876_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_876_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_877_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_877_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_877_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_878_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_878_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_878_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_879_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_879_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_879_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_880_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_880_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_880_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_881_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_881_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_881_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_882_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_882_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_882_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_883_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_883_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_883_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_884_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_884_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_884_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_885_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_885_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_885_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_886_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_886_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_886_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_887_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_887_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_887_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_888_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_888_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_888_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_889_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_889_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_889_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_890_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_890_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_890_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_891_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_891_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_891_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_892_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_892_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_892_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_893_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_893_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_893_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_894_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_894_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_894_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_POLARITY_895_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_895_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG27_POLARITY_895_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG27_RESETVAL (0x00000000u)

/* polarity_reg28 */

#define CSL_CPINTC_POLARITY_REG28_POLARITY_896_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_896_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_896_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_897_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_897_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_897_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_898_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_898_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_898_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_899_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_899_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_899_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_900_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_900_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_900_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_901_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_901_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_901_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_902_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_902_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_902_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_903_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_903_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_903_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_904_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_904_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_904_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_905_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_905_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_905_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_906_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_906_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_906_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_907_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_907_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_907_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_908_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_908_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_908_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_909_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_909_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_909_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_910_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_910_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_910_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_911_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_911_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_911_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_912_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_912_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_912_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_913_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_913_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_913_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_914_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_914_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_914_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_915_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_915_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_915_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_916_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_916_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_916_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_917_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_917_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_917_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_918_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_918_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_918_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_919_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_919_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_919_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_920_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_920_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_920_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_921_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_921_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_921_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_922_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_922_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_922_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_923_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_923_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_923_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_924_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_924_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_924_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_925_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_925_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_925_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_926_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_926_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_926_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_POLARITY_927_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_927_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG28_POLARITY_927_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG28_RESETVAL (0x00000000u)

/* polarity_reg29 */

#define CSL_CPINTC_POLARITY_REG29_POLARITY_928_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_928_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_928_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_929_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_929_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_929_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_930_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_930_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_930_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_931_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_931_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_931_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_932_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_932_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_932_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_933_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_933_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_933_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_934_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_934_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_934_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_935_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_935_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_935_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_936_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_936_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_936_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_937_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_937_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_937_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_938_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_938_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_938_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_939_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_939_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_939_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_940_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_940_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_940_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_941_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_941_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_941_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_942_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_942_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_942_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_943_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_943_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_943_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_944_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_944_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_944_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_945_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_945_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_945_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_946_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_946_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_946_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_947_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_947_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_947_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_948_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_948_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_948_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_949_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_949_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_949_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_950_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_950_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_950_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_951_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_951_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_951_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_952_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_952_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_952_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_953_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_953_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_953_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_954_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_954_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_954_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_955_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_955_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_955_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_956_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_956_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_956_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_957_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_957_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_957_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_958_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_958_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_958_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_POLARITY_959_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_959_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG29_POLARITY_959_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG29_RESETVAL (0x00000000u)

/* polarity_reg30 */

#define CSL_CPINTC_POLARITY_REG30_POLARITY_960_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_960_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_960_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_961_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_961_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_961_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_962_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_962_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_962_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_963_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_963_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_963_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_964_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_964_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_964_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_965_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_965_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_965_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_966_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_966_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_966_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_967_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_967_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_967_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_968_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_968_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_968_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_969_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_969_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_969_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_970_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_970_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_970_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_971_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_971_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_971_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_972_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_972_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_972_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_973_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_973_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_973_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_974_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_974_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_974_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_975_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_975_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_975_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_976_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_976_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_976_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_977_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_977_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_977_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_978_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_978_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_978_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_979_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_979_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_979_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_980_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_980_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_980_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_981_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_981_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_981_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_982_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_982_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_982_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_983_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_983_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_983_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_984_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_984_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_984_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_985_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_985_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_985_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_986_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_986_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_986_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_987_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_987_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_987_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_988_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_988_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_988_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_989_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_989_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_989_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_990_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_990_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_990_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_POLARITY_991_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_991_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG30_POLARITY_991_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG30_RESETVAL (0x00000000u)

/* polarity_reg31 */

#define CSL_CPINTC_POLARITY_REG31_POLARITY_992_MASK (0x00000001u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_992_SHIFT (0x00000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_992_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_993_MASK (0x00000002u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_993_SHIFT (0x00000001u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_993_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_994_MASK (0x00000004u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_994_SHIFT (0x00000002u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_994_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_995_MASK (0x00000008u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_995_SHIFT (0x00000003u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_995_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_996_MASK (0x00000010u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_996_SHIFT (0x00000004u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_996_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_997_MASK (0x00000020u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_997_SHIFT (0x00000005u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_997_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_998_MASK (0x00000040u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_998_SHIFT (0x00000006u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_998_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_999_MASK (0x00000080u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_999_SHIFT (0x00000007u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_999_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1000_MASK (0x00000100u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1000_SHIFT (0x00000008u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1000_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1001_MASK (0x00000200u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1001_SHIFT (0x00000009u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1001_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1002_MASK (0x00000400u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1002_SHIFT (0x0000000Au)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1002_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1003_MASK (0x00000800u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1003_SHIFT (0x0000000Bu)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1003_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1004_MASK (0x00001000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1004_SHIFT (0x0000000Cu)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1004_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1005_MASK (0x00002000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1005_SHIFT (0x0000000Du)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1005_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1006_MASK (0x00004000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1006_SHIFT (0x0000000Eu)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1006_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1007_MASK (0x00008000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1007_SHIFT (0x0000000Fu)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1007_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1008_MASK (0x00010000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1008_SHIFT (0x00000010u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1008_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1009_MASK (0x00020000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1009_SHIFT (0x00000011u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1009_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1010_MASK (0x00040000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1010_SHIFT (0x00000012u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1010_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1011_MASK (0x00080000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1011_SHIFT (0x00000013u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1011_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1012_MASK (0x00100000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1012_SHIFT (0x00000014u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1012_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1013_MASK (0x00200000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1013_SHIFT (0x00000015u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1013_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1014_MASK (0x00400000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1014_SHIFT (0x00000016u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1014_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1015_MASK (0x00800000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1015_SHIFT (0x00000017u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1015_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1016_MASK (0x01000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1016_SHIFT (0x00000018u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1016_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1017_MASK (0x02000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1017_SHIFT (0x00000019u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1017_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1018_MASK (0x04000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1018_SHIFT (0x0000001Au)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1018_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1019_MASK (0x08000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1019_SHIFT (0x0000001Bu)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1019_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1020_MASK (0x10000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1020_SHIFT (0x0000001Cu)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1020_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1021_MASK (0x20000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1021_SHIFT (0x0000001Du)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1021_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1022_MASK (0x40000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1022_SHIFT (0x0000001Eu)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1022_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_POLARITY_1023_MASK (0x80000000u)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1023_SHIFT (0x0000001Fu)
#define CSL_CPINTC_POLARITY_REG31_POLARITY_1023_RESETVAL (0x00000000u)

#define CSL_CPINTC_POLARITY_REG31_RESETVAL (0x00000000u)

/* type_reg0 */

#define CSL_CPINTC_TYPE_REG0_TYPE_0_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG0_TYPE_0_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_1_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG0_TYPE_1_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG0_TYPE_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_2_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG0_TYPE_2_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG0_TYPE_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_3_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG0_TYPE_3_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG0_TYPE_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_4_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG0_TYPE_4_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG0_TYPE_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_5_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG0_TYPE_5_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG0_TYPE_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_6_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG0_TYPE_6_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG0_TYPE_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_7_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG0_TYPE_7_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG0_TYPE_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_8_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG0_TYPE_8_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG0_TYPE_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_9_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG0_TYPE_9_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG0_TYPE_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_10_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG0_TYPE_10_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG0_TYPE_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_11_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG0_TYPE_11_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG0_TYPE_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_12_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_12_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG0_TYPE_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_13_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_13_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG0_TYPE_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_14_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_14_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG0_TYPE_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_15_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_15_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG0_TYPE_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_16_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_16_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG0_TYPE_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_17_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_17_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG0_TYPE_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_18_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_18_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG0_TYPE_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_19_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_19_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG0_TYPE_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_20_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_20_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG0_TYPE_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_21_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_21_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG0_TYPE_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_22_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_22_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG0_TYPE_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_23_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_23_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG0_TYPE_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_24_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_24_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG0_TYPE_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_25_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_25_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG0_TYPE_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_26_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_26_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG0_TYPE_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_27_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_27_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG0_TYPE_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_28_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_28_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG0_TYPE_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_29_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_29_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG0_TYPE_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_30_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_30_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG0_TYPE_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_TYPE_31_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG0_TYPE_31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG0_TYPE_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG0_RESETVAL    (0x00000000u)

/* type_reg1 */

#define CSL_CPINTC_TYPE_REG1_TYPE_32_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG1_TYPE_32_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_33_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG1_TYPE_33_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG1_TYPE_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_34_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG1_TYPE_34_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG1_TYPE_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_35_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG1_TYPE_35_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG1_TYPE_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_36_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG1_TYPE_36_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG1_TYPE_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_37_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG1_TYPE_37_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG1_TYPE_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_38_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG1_TYPE_38_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG1_TYPE_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_39_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG1_TYPE_39_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG1_TYPE_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_40_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG1_TYPE_40_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG1_TYPE_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_41_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG1_TYPE_41_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG1_TYPE_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_42_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG1_TYPE_42_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG1_TYPE_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_43_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG1_TYPE_43_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG1_TYPE_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_44_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_44_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG1_TYPE_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_45_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_45_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG1_TYPE_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_46_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_46_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG1_TYPE_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_47_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_47_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG1_TYPE_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_48_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_48_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG1_TYPE_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_49_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_49_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG1_TYPE_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_50_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_50_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG1_TYPE_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_51_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_51_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG1_TYPE_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_52_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_52_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG1_TYPE_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_53_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_53_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG1_TYPE_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_54_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_54_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG1_TYPE_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_55_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_55_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG1_TYPE_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_56_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_56_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG1_TYPE_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_57_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_57_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG1_TYPE_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_58_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_58_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG1_TYPE_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_59_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_59_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG1_TYPE_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_60_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_60_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG1_TYPE_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_61_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_61_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG1_TYPE_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_62_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_62_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG1_TYPE_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_TYPE_63_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG1_TYPE_63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG1_TYPE_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG1_RESETVAL    (0x00000000u)

/* type_reg2 */

#define CSL_CPINTC_TYPE_REG2_TYPE_64_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG2_TYPE_64_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_65_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG2_TYPE_65_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG2_TYPE_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_66_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG2_TYPE_66_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG2_TYPE_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_67_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG2_TYPE_67_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG2_TYPE_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_68_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG2_TYPE_68_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG2_TYPE_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_69_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG2_TYPE_69_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG2_TYPE_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_70_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG2_TYPE_70_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG2_TYPE_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_71_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG2_TYPE_71_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG2_TYPE_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_72_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG2_TYPE_72_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG2_TYPE_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_73_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG2_TYPE_73_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG2_TYPE_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_74_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG2_TYPE_74_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG2_TYPE_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_75_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG2_TYPE_75_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG2_TYPE_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_76_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_76_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG2_TYPE_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_77_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_77_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG2_TYPE_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_78_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_78_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG2_TYPE_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_79_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_79_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG2_TYPE_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_80_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_80_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG2_TYPE_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_81_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_81_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG2_TYPE_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_82_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_82_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG2_TYPE_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_83_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_83_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG2_TYPE_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_84_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_84_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG2_TYPE_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_85_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_85_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG2_TYPE_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_86_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_86_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG2_TYPE_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_87_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_87_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG2_TYPE_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_88_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_88_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG2_TYPE_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_89_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_89_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG2_TYPE_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_90_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_90_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG2_TYPE_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_91_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_91_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG2_TYPE_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_92_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_92_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG2_TYPE_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_93_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_93_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG2_TYPE_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_94_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_94_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG2_TYPE_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_TYPE_95_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG2_TYPE_95_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG2_TYPE_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG2_RESETVAL    (0x00000000u)

/* type_reg3 */

#define CSL_CPINTC_TYPE_REG3_TYPE_96_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG3_TYPE_96_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_97_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG3_TYPE_97_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG3_TYPE_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_98_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG3_TYPE_98_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG3_TYPE_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_99_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG3_TYPE_99_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG3_TYPE_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_100_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG3_TYPE_100_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG3_TYPE_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_101_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG3_TYPE_101_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG3_TYPE_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_102_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG3_TYPE_102_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG3_TYPE_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_103_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG3_TYPE_103_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG3_TYPE_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_104_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG3_TYPE_104_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG3_TYPE_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_105_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG3_TYPE_105_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG3_TYPE_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_106_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG3_TYPE_106_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG3_TYPE_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_107_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG3_TYPE_107_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG3_TYPE_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_108_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_108_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG3_TYPE_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_109_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_109_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG3_TYPE_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_110_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_110_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG3_TYPE_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_111_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_111_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG3_TYPE_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_112_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_112_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG3_TYPE_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_113_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_113_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG3_TYPE_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_114_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_114_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG3_TYPE_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_115_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_115_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG3_TYPE_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_116_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_116_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG3_TYPE_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_117_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_117_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG3_TYPE_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_118_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_118_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG3_TYPE_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_119_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_119_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG3_TYPE_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_120_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_120_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG3_TYPE_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_121_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_121_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG3_TYPE_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_122_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_122_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG3_TYPE_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_123_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_123_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG3_TYPE_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_124_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_124_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG3_TYPE_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_125_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_125_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG3_TYPE_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_126_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_126_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG3_TYPE_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_TYPE_127_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG3_TYPE_127_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG3_TYPE_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG3_RESETVAL    (0x00000000u)

/* type_reg4 */

#define CSL_CPINTC_TYPE_REG4_TYPE_128_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG4_TYPE_128_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_129_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG4_TYPE_129_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG4_TYPE_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_130_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG4_TYPE_130_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG4_TYPE_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_131_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG4_TYPE_131_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG4_TYPE_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_132_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG4_TYPE_132_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG4_TYPE_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_133_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG4_TYPE_133_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG4_TYPE_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_134_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG4_TYPE_134_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG4_TYPE_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_135_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG4_TYPE_135_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG4_TYPE_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_136_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG4_TYPE_136_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG4_TYPE_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_137_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG4_TYPE_137_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG4_TYPE_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_138_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG4_TYPE_138_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG4_TYPE_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_139_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG4_TYPE_139_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG4_TYPE_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_140_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_140_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG4_TYPE_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_141_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_141_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG4_TYPE_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_142_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_142_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG4_TYPE_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_143_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_143_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG4_TYPE_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_144_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_144_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG4_TYPE_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_145_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_145_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG4_TYPE_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_146_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_146_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG4_TYPE_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_147_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_147_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG4_TYPE_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_148_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_148_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG4_TYPE_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_149_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_149_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG4_TYPE_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_150_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_150_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG4_TYPE_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_151_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_151_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG4_TYPE_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_152_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_152_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG4_TYPE_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_153_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_153_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG4_TYPE_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_154_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_154_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG4_TYPE_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_155_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_155_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG4_TYPE_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_156_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_156_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG4_TYPE_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_157_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_157_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG4_TYPE_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_158_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_158_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG4_TYPE_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_TYPE_159_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG4_TYPE_159_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG4_TYPE_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG4_RESETVAL    (0x00000000u)

/* type_reg5 */

#define CSL_CPINTC_TYPE_REG5_TYPE_160_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG5_TYPE_160_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_161_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG5_TYPE_161_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG5_TYPE_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_162_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG5_TYPE_162_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG5_TYPE_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_163_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG5_TYPE_163_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG5_TYPE_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_164_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG5_TYPE_164_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG5_TYPE_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_165_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG5_TYPE_165_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG5_TYPE_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_166_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG5_TYPE_166_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG5_TYPE_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_167_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG5_TYPE_167_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG5_TYPE_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_168_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG5_TYPE_168_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG5_TYPE_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_169_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG5_TYPE_169_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG5_TYPE_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_170_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG5_TYPE_170_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG5_TYPE_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_171_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG5_TYPE_171_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG5_TYPE_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_172_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_172_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG5_TYPE_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_173_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_173_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG5_TYPE_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_174_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_174_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG5_TYPE_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_175_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_175_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG5_TYPE_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_176_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_176_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG5_TYPE_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_177_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_177_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG5_TYPE_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_178_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_178_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG5_TYPE_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_179_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_179_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG5_TYPE_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_180_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_180_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG5_TYPE_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_181_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_181_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG5_TYPE_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_182_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_182_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG5_TYPE_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_183_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_183_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG5_TYPE_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_184_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_184_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG5_TYPE_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_185_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_185_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG5_TYPE_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_186_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_186_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG5_TYPE_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_187_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_187_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG5_TYPE_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_188_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_188_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG5_TYPE_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_189_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_189_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG5_TYPE_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_190_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_190_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG5_TYPE_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_TYPE_191_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG5_TYPE_191_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG5_TYPE_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG5_RESETVAL    (0x00000000u)

/* type_reg6 */

#define CSL_CPINTC_TYPE_REG6_TYPE_192_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG6_TYPE_192_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_193_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG6_TYPE_193_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG6_TYPE_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_194_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG6_TYPE_194_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG6_TYPE_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_195_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG6_TYPE_195_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG6_TYPE_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_196_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG6_TYPE_196_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG6_TYPE_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_197_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG6_TYPE_197_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG6_TYPE_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_198_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG6_TYPE_198_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG6_TYPE_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_199_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG6_TYPE_199_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG6_TYPE_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_200_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG6_TYPE_200_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG6_TYPE_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_201_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG6_TYPE_201_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG6_TYPE_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_202_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG6_TYPE_202_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG6_TYPE_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_203_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG6_TYPE_203_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG6_TYPE_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_204_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_204_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG6_TYPE_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_205_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_205_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG6_TYPE_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_206_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_206_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG6_TYPE_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_207_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_207_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG6_TYPE_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_208_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_208_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG6_TYPE_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_209_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_209_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG6_TYPE_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_210_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_210_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG6_TYPE_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_211_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_211_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG6_TYPE_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_212_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_212_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG6_TYPE_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_213_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_213_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG6_TYPE_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_214_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_214_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG6_TYPE_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_215_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_215_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG6_TYPE_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_216_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_216_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG6_TYPE_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_217_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_217_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG6_TYPE_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_218_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_218_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG6_TYPE_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_219_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_219_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG6_TYPE_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_220_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_220_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG6_TYPE_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_221_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_221_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG6_TYPE_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_222_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_222_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG6_TYPE_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_TYPE_223_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG6_TYPE_223_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG6_TYPE_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG6_RESETVAL    (0x00000000u)

/* type_reg7 */

#define CSL_CPINTC_TYPE_REG7_TYPE_224_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG7_TYPE_224_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_225_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG7_TYPE_225_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG7_TYPE_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_226_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG7_TYPE_226_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG7_TYPE_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_227_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG7_TYPE_227_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG7_TYPE_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_228_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG7_TYPE_228_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG7_TYPE_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_229_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG7_TYPE_229_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG7_TYPE_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_230_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG7_TYPE_230_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG7_TYPE_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_231_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG7_TYPE_231_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG7_TYPE_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_232_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG7_TYPE_232_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG7_TYPE_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_233_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG7_TYPE_233_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG7_TYPE_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_234_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG7_TYPE_234_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG7_TYPE_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_235_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG7_TYPE_235_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG7_TYPE_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_236_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_236_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG7_TYPE_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_237_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_237_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG7_TYPE_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_238_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_238_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG7_TYPE_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_239_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_239_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG7_TYPE_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_240_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_240_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG7_TYPE_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_241_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_241_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG7_TYPE_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_242_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_242_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG7_TYPE_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_243_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_243_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG7_TYPE_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_244_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_244_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG7_TYPE_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_245_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_245_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG7_TYPE_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_246_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_246_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG7_TYPE_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_247_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_247_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG7_TYPE_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_248_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_248_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG7_TYPE_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_249_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_249_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG7_TYPE_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_250_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_250_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG7_TYPE_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_251_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_251_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG7_TYPE_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_252_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_252_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG7_TYPE_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_253_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_253_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG7_TYPE_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_254_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_254_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG7_TYPE_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_TYPE_255_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG7_TYPE_255_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG7_TYPE_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG7_RESETVAL    (0x00000000u)

/* type_reg8 */

#define CSL_CPINTC_TYPE_REG8_TYPE_256_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG8_TYPE_256_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_256_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_257_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG8_TYPE_257_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG8_TYPE_257_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_258_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG8_TYPE_258_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG8_TYPE_258_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_259_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG8_TYPE_259_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG8_TYPE_259_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_260_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG8_TYPE_260_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG8_TYPE_260_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_261_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG8_TYPE_261_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG8_TYPE_261_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_262_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG8_TYPE_262_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG8_TYPE_262_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_263_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG8_TYPE_263_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG8_TYPE_263_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_264_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG8_TYPE_264_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG8_TYPE_264_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_265_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG8_TYPE_265_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG8_TYPE_265_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_266_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG8_TYPE_266_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG8_TYPE_266_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_267_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG8_TYPE_267_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG8_TYPE_267_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_268_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_268_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG8_TYPE_268_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_269_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_269_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG8_TYPE_269_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_270_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_270_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG8_TYPE_270_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_271_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_271_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG8_TYPE_271_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_272_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_272_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG8_TYPE_272_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_273_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_273_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG8_TYPE_273_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_274_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_274_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG8_TYPE_274_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_275_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_275_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG8_TYPE_275_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_276_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_276_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG8_TYPE_276_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_277_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_277_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG8_TYPE_277_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_278_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_278_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG8_TYPE_278_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_279_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_279_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG8_TYPE_279_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_280_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_280_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG8_TYPE_280_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_281_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_281_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG8_TYPE_281_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_282_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_282_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG8_TYPE_282_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_283_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_283_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG8_TYPE_283_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_284_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_284_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG8_TYPE_284_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_285_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_285_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG8_TYPE_285_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_286_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_286_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG8_TYPE_286_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_TYPE_287_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG8_TYPE_287_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG8_TYPE_287_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG8_RESETVAL    (0x00000000u)

/* type_reg9 */

#define CSL_CPINTC_TYPE_REG9_TYPE_288_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG9_TYPE_288_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_288_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_289_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG9_TYPE_289_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG9_TYPE_289_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_290_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG9_TYPE_290_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG9_TYPE_290_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_291_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG9_TYPE_291_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG9_TYPE_291_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_292_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG9_TYPE_292_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG9_TYPE_292_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_293_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG9_TYPE_293_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG9_TYPE_293_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_294_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG9_TYPE_294_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG9_TYPE_294_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_295_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG9_TYPE_295_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG9_TYPE_295_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_296_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG9_TYPE_296_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG9_TYPE_296_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_297_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG9_TYPE_297_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG9_TYPE_297_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_298_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG9_TYPE_298_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG9_TYPE_298_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_299_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG9_TYPE_299_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG9_TYPE_299_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_300_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_300_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG9_TYPE_300_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_301_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_301_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG9_TYPE_301_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_302_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_302_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG9_TYPE_302_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_303_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_303_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG9_TYPE_303_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_304_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_304_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG9_TYPE_304_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_305_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_305_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG9_TYPE_305_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_306_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_306_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG9_TYPE_306_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_307_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_307_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG9_TYPE_307_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_308_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_308_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG9_TYPE_308_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_309_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_309_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG9_TYPE_309_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_310_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_310_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG9_TYPE_310_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_311_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_311_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG9_TYPE_311_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_312_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_312_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG9_TYPE_312_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_313_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_313_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG9_TYPE_313_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_314_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_314_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG9_TYPE_314_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_315_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_315_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG9_TYPE_315_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_316_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_316_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG9_TYPE_316_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_317_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_317_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG9_TYPE_317_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_318_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_318_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG9_TYPE_318_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_TYPE_319_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG9_TYPE_319_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG9_TYPE_319_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG9_RESETVAL    (0x00000000u)

/* type_reg10 */

#define CSL_CPINTC_TYPE_REG10_TYPE_320_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG10_TYPE_320_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_320_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_321_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG10_TYPE_321_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG10_TYPE_321_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_322_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG10_TYPE_322_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG10_TYPE_322_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_323_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG10_TYPE_323_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG10_TYPE_323_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_324_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG10_TYPE_324_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG10_TYPE_324_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_325_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG10_TYPE_325_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG10_TYPE_325_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_326_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG10_TYPE_326_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG10_TYPE_326_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_327_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG10_TYPE_327_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG10_TYPE_327_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_328_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG10_TYPE_328_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG10_TYPE_328_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_329_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG10_TYPE_329_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG10_TYPE_329_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_330_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG10_TYPE_330_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG10_TYPE_330_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_331_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG10_TYPE_331_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG10_TYPE_331_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_332_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_332_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG10_TYPE_332_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_333_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_333_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG10_TYPE_333_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_334_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_334_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG10_TYPE_334_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_335_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_335_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG10_TYPE_335_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_336_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_336_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG10_TYPE_336_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_337_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_337_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG10_TYPE_337_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_338_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_338_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG10_TYPE_338_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_339_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_339_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG10_TYPE_339_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_340_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_340_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG10_TYPE_340_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_341_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_341_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG10_TYPE_341_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_342_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_342_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG10_TYPE_342_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_343_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_343_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG10_TYPE_343_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_344_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_344_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG10_TYPE_344_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_345_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_345_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG10_TYPE_345_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_346_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_346_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG10_TYPE_346_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_347_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_347_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG10_TYPE_347_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_348_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_348_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG10_TYPE_348_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_349_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_349_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG10_TYPE_349_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_350_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_350_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG10_TYPE_350_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_TYPE_351_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG10_TYPE_351_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG10_TYPE_351_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG10_RESETVAL   (0x00000000u)

/* type_reg11 */

#define CSL_CPINTC_TYPE_REG11_TYPE_352_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG11_TYPE_352_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_352_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_353_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG11_TYPE_353_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG11_TYPE_353_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_354_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG11_TYPE_354_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG11_TYPE_354_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_355_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG11_TYPE_355_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG11_TYPE_355_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_356_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG11_TYPE_356_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG11_TYPE_356_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_357_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG11_TYPE_357_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG11_TYPE_357_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_358_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG11_TYPE_358_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG11_TYPE_358_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_359_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG11_TYPE_359_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG11_TYPE_359_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_360_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG11_TYPE_360_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG11_TYPE_360_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_361_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG11_TYPE_361_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG11_TYPE_361_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_362_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG11_TYPE_362_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG11_TYPE_362_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_363_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG11_TYPE_363_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG11_TYPE_363_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_364_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_364_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG11_TYPE_364_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_365_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_365_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG11_TYPE_365_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_366_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_366_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG11_TYPE_366_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_367_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_367_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG11_TYPE_367_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_368_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_368_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG11_TYPE_368_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_369_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_369_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG11_TYPE_369_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_370_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_370_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG11_TYPE_370_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_371_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_371_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG11_TYPE_371_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_372_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_372_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG11_TYPE_372_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_373_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_373_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG11_TYPE_373_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_374_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_374_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG11_TYPE_374_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_375_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_375_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG11_TYPE_375_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_376_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_376_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG11_TYPE_376_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_377_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_377_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG11_TYPE_377_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_378_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_378_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG11_TYPE_378_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_379_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_379_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG11_TYPE_379_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_380_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_380_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG11_TYPE_380_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_381_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_381_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG11_TYPE_381_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_382_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_382_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG11_TYPE_382_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_TYPE_383_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG11_TYPE_383_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG11_TYPE_383_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG11_RESETVAL   (0x00000000u)

/* type_reg12 */

#define CSL_CPINTC_TYPE_REG12_TYPE_384_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG12_TYPE_384_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_384_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_385_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG12_TYPE_385_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG12_TYPE_385_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_386_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG12_TYPE_386_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG12_TYPE_386_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_387_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG12_TYPE_387_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG12_TYPE_387_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_388_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG12_TYPE_388_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG12_TYPE_388_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_389_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG12_TYPE_389_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG12_TYPE_389_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_390_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG12_TYPE_390_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG12_TYPE_390_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_391_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG12_TYPE_391_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG12_TYPE_391_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_392_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG12_TYPE_392_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG12_TYPE_392_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_393_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG12_TYPE_393_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG12_TYPE_393_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_394_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG12_TYPE_394_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG12_TYPE_394_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_395_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG12_TYPE_395_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG12_TYPE_395_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_396_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_396_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG12_TYPE_396_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_397_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_397_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG12_TYPE_397_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_398_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_398_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG12_TYPE_398_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_399_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_399_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG12_TYPE_399_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_400_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_400_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG12_TYPE_400_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_401_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_401_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG12_TYPE_401_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_402_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_402_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG12_TYPE_402_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_403_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_403_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG12_TYPE_403_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_404_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_404_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG12_TYPE_404_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_405_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_405_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG12_TYPE_405_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_406_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_406_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG12_TYPE_406_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_407_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_407_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG12_TYPE_407_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_408_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_408_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG12_TYPE_408_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_409_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_409_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG12_TYPE_409_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_410_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_410_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG12_TYPE_410_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_411_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_411_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG12_TYPE_411_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_412_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_412_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG12_TYPE_412_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_413_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_413_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG12_TYPE_413_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_414_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_414_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG12_TYPE_414_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_TYPE_415_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG12_TYPE_415_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG12_TYPE_415_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG12_RESETVAL   (0x00000000u)

/* type_reg13 */

#define CSL_CPINTC_TYPE_REG13_TYPE_416_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG13_TYPE_416_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_416_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_417_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG13_TYPE_417_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG13_TYPE_417_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_418_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG13_TYPE_418_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG13_TYPE_418_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_419_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG13_TYPE_419_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG13_TYPE_419_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_420_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG13_TYPE_420_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG13_TYPE_420_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_421_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG13_TYPE_421_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG13_TYPE_421_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_422_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG13_TYPE_422_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG13_TYPE_422_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_423_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG13_TYPE_423_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG13_TYPE_423_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_424_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG13_TYPE_424_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG13_TYPE_424_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_425_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG13_TYPE_425_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG13_TYPE_425_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_426_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG13_TYPE_426_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG13_TYPE_426_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_427_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG13_TYPE_427_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG13_TYPE_427_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_428_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_428_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG13_TYPE_428_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_429_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_429_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG13_TYPE_429_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_430_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_430_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG13_TYPE_430_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_431_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_431_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG13_TYPE_431_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_432_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_432_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG13_TYPE_432_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_433_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_433_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG13_TYPE_433_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_434_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_434_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG13_TYPE_434_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_435_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_435_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG13_TYPE_435_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_436_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_436_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG13_TYPE_436_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_437_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_437_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG13_TYPE_437_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_438_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_438_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG13_TYPE_438_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_439_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_439_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG13_TYPE_439_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_440_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_440_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG13_TYPE_440_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_441_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_441_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG13_TYPE_441_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_442_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_442_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG13_TYPE_442_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_443_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_443_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG13_TYPE_443_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_444_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_444_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG13_TYPE_444_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_445_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_445_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG13_TYPE_445_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_446_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_446_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG13_TYPE_446_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_TYPE_447_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG13_TYPE_447_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG13_TYPE_447_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG13_RESETVAL   (0x00000000u)

/* type_reg14 */

#define CSL_CPINTC_TYPE_REG14_TYPE_448_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG14_TYPE_448_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_448_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_449_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG14_TYPE_449_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG14_TYPE_449_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_450_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG14_TYPE_450_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG14_TYPE_450_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_451_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG14_TYPE_451_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG14_TYPE_451_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_452_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG14_TYPE_452_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG14_TYPE_452_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_453_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG14_TYPE_453_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG14_TYPE_453_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_454_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG14_TYPE_454_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG14_TYPE_454_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_455_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG14_TYPE_455_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG14_TYPE_455_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_456_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG14_TYPE_456_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG14_TYPE_456_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_457_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG14_TYPE_457_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG14_TYPE_457_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_458_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG14_TYPE_458_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG14_TYPE_458_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_459_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG14_TYPE_459_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG14_TYPE_459_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_460_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_460_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG14_TYPE_460_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_461_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_461_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG14_TYPE_461_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_462_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_462_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG14_TYPE_462_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_463_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_463_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG14_TYPE_463_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_464_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_464_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG14_TYPE_464_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_465_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_465_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG14_TYPE_465_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_466_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_466_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG14_TYPE_466_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_467_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_467_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG14_TYPE_467_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_468_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_468_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG14_TYPE_468_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_469_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_469_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG14_TYPE_469_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_470_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_470_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG14_TYPE_470_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_471_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_471_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG14_TYPE_471_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_472_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_472_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG14_TYPE_472_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_473_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_473_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG14_TYPE_473_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_474_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_474_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG14_TYPE_474_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_475_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_475_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG14_TYPE_475_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_476_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_476_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG14_TYPE_476_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_477_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_477_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG14_TYPE_477_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_478_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_478_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG14_TYPE_478_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_TYPE_479_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG14_TYPE_479_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG14_TYPE_479_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG14_RESETVAL   (0x00000000u)

/* type_reg15 */

#define CSL_CPINTC_TYPE_REG15_TYPE_480_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG15_TYPE_480_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_480_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_481_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG15_TYPE_481_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG15_TYPE_481_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_482_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG15_TYPE_482_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG15_TYPE_482_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_483_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG15_TYPE_483_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG15_TYPE_483_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_484_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG15_TYPE_484_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG15_TYPE_484_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_485_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG15_TYPE_485_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG15_TYPE_485_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_486_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG15_TYPE_486_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG15_TYPE_486_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_487_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG15_TYPE_487_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG15_TYPE_487_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_488_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG15_TYPE_488_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG15_TYPE_488_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_489_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG15_TYPE_489_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG15_TYPE_489_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_490_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG15_TYPE_490_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG15_TYPE_490_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_491_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG15_TYPE_491_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG15_TYPE_491_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_492_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_492_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG15_TYPE_492_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_493_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_493_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG15_TYPE_493_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_494_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_494_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG15_TYPE_494_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_495_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_495_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG15_TYPE_495_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_496_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_496_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG15_TYPE_496_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_497_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_497_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG15_TYPE_497_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_498_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_498_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG15_TYPE_498_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_499_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_499_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG15_TYPE_499_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_500_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_500_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG15_TYPE_500_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_501_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_501_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG15_TYPE_501_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_502_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_502_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG15_TYPE_502_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_503_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_503_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG15_TYPE_503_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_504_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_504_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG15_TYPE_504_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_505_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_505_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG15_TYPE_505_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_506_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_506_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG15_TYPE_506_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_507_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_507_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG15_TYPE_507_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_508_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_508_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG15_TYPE_508_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_509_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_509_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG15_TYPE_509_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_510_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_510_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG15_TYPE_510_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_TYPE_511_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG15_TYPE_511_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG15_TYPE_511_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG15_RESETVAL   (0x00000000u)

/* type_reg16 */

#define CSL_CPINTC_TYPE_REG16_TYPE_512_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG16_TYPE_512_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_512_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_513_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG16_TYPE_513_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG16_TYPE_513_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_514_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG16_TYPE_514_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG16_TYPE_514_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_515_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG16_TYPE_515_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG16_TYPE_515_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_516_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG16_TYPE_516_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG16_TYPE_516_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_517_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG16_TYPE_517_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG16_TYPE_517_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_518_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG16_TYPE_518_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG16_TYPE_518_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_519_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG16_TYPE_519_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG16_TYPE_519_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_520_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG16_TYPE_520_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG16_TYPE_520_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_521_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG16_TYPE_521_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG16_TYPE_521_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_522_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG16_TYPE_522_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG16_TYPE_522_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_523_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG16_TYPE_523_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG16_TYPE_523_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_524_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_524_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG16_TYPE_524_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_525_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_525_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG16_TYPE_525_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_526_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_526_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG16_TYPE_526_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_527_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_527_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG16_TYPE_527_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_528_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_528_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG16_TYPE_528_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_529_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_529_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG16_TYPE_529_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_530_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_530_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG16_TYPE_530_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_531_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_531_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG16_TYPE_531_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_532_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_532_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG16_TYPE_532_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_533_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_533_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG16_TYPE_533_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_534_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_534_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG16_TYPE_534_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_535_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_535_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG16_TYPE_535_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_536_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_536_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG16_TYPE_536_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_537_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_537_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG16_TYPE_537_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_538_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_538_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG16_TYPE_538_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_539_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_539_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG16_TYPE_539_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_540_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_540_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG16_TYPE_540_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_541_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_541_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG16_TYPE_541_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_542_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_542_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG16_TYPE_542_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_TYPE_543_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG16_TYPE_543_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG16_TYPE_543_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG16_RESETVAL   (0x00000000u)

/* type_reg17 */

#define CSL_CPINTC_TYPE_REG17_TYPE_544_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG17_TYPE_544_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_544_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_545_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG17_TYPE_545_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG17_TYPE_545_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_546_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG17_TYPE_546_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG17_TYPE_546_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_547_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG17_TYPE_547_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG17_TYPE_547_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_548_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG17_TYPE_548_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG17_TYPE_548_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_549_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG17_TYPE_549_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG17_TYPE_549_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_550_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG17_TYPE_550_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG17_TYPE_550_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_551_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG17_TYPE_551_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG17_TYPE_551_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_552_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG17_TYPE_552_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG17_TYPE_552_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_553_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG17_TYPE_553_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG17_TYPE_553_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_554_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG17_TYPE_554_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG17_TYPE_554_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_555_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG17_TYPE_555_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG17_TYPE_555_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_556_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_556_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG17_TYPE_556_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_557_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_557_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG17_TYPE_557_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_558_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_558_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG17_TYPE_558_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_559_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_559_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG17_TYPE_559_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_560_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_560_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG17_TYPE_560_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_561_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_561_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG17_TYPE_561_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_562_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_562_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG17_TYPE_562_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_563_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_563_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG17_TYPE_563_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_564_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_564_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG17_TYPE_564_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_565_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_565_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG17_TYPE_565_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_566_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_566_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG17_TYPE_566_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_567_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_567_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG17_TYPE_567_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_568_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_568_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG17_TYPE_568_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_569_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_569_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG17_TYPE_569_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_570_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_570_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG17_TYPE_570_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_571_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_571_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG17_TYPE_571_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_572_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_572_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG17_TYPE_572_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_573_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_573_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG17_TYPE_573_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_574_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_574_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG17_TYPE_574_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_TYPE_575_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG17_TYPE_575_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG17_TYPE_575_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG17_RESETVAL   (0x00000000u)

/* type_reg18 */

#define CSL_CPINTC_TYPE_REG18_TYPE_576_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG18_TYPE_576_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_576_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_577_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG18_TYPE_577_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG18_TYPE_577_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_578_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG18_TYPE_578_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG18_TYPE_578_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_579_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG18_TYPE_579_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG18_TYPE_579_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_580_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG18_TYPE_580_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG18_TYPE_580_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_581_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG18_TYPE_581_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG18_TYPE_581_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_582_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG18_TYPE_582_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG18_TYPE_582_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_583_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG18_TYPE_583_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG18_TYPE_583_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_584_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG18_TYPE_584_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG18_TYPE_584_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_585_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG18_TYPE_585_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG18_TYPE_585_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_586_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG18_TYPE_586_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG18_TYPE_586_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_587_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG18_TYPE_587_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG18_TYPE_587_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_588_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_588_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG18_TYPE_588_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_589_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_589_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG18_TYPE_589_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_590_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_590_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG18_TYPE_590_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_591_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_591_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG18_TYPE_591_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_592_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_592_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG18_TYPE_592_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_593_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_593_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG18_TYPE_593_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_594_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_594_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG18_TYPE_594_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_595_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_595_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG18_TYPE_595_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_596_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_596_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG18_TYPE_596_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_597_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_597_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG18_TYPE_597_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_598_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_598_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG18_TYPE_598_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_599_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_599_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG18_TYPE_599_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_600_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_600_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG18_TYPE_600_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_601_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_601_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG18_TYPE_601_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_602_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_602_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG18_TYPE_602_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_603_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_603_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG18_TYPE_603_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_604_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_604_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG18_TYPE_604_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_605_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_605_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG18_TYPE_605_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_606_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_606_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG18_TYPE_606_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_TYPE_607_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG18_TYPE_607_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG18_TYPE_607_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG18_RESETVAL   (0x00000000u)

/* type_reg19 */

#define CSL_CPINTC_TYPE_REG19_TYPE_608_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG19_TYPE_608_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_608_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_609_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG19_TYPE_609_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG19_TYPE_609_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_610_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG19_TYPE_610_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG19_TYPE_610_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_611_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG19_TYPE_611_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG19_TYPE_611_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_612_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG19_TYPE_612_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG19_TYPE_612_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_613_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG19_TYPE_613_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG19_TYPE_613_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_614_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG19_TYPE_614_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG19_TYPE_614_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_615_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG19_TYPE_615_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG19_TYPE_615_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_616_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG19_TYPE_616_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG19_TYPE_616_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_617_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG19_TYPE_617_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG19_TYPE_617_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_618_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG19_TYPE_618_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG19_TYPE_618_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_619_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG19_TYPE_619_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG19_TYPE_619_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_620_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_620_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG19_TYPE_620_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_621_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_621_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG19_TYPE_621_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_622_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_622_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG19_TYPE_622_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_623_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_623_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG19_TYPE_623_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_624_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_624_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG19_TYPE_624_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_625_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_625_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG19_TYPE_625_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_626_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_626_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG19_TYPE_626_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_627_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_627_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG19_TYPE_627_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_628_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_628_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG19_TYPE_628_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_629_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_629_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG19_TYPE_629_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_630_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_630_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG19_TYPE_630_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_631_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_631_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG19_TYPE_631_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_632_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_632_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG19_TYPE_632_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_633_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_633_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG19_TYPE_633_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_634_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_634_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG19_TYPE_634_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_635_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_635_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG19_TYPE_635_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_636_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_636_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG19_TYPE_636_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_637_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_637_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG19_TYPE_637_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_638_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_638_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG19_TYPE_638_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_TYPE_639_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG19_TYPE_639_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG19_TYPE_639_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG19_RESETVAL   (0x00000000u)

/* type_reg20 */

#define CSL_CPINTC_TYPE_REG20_TYPE_640_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG20_TYPE_640_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_640_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_641_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG20_TYPE_641_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG20_TYPE_641_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_642_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG20_TYPE_642_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG20_TYPE_642_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_643_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG20_TYPE_643_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG20_TYPE_643_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_644_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG20_TYPE_644_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG20_TYPE_644_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_645_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG20_TYPE_645_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG20_TYPE_645_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_646_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG20_TYPE_646_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG20_TYPE_646_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_647_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG20_TYPE_647_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG20_TYPE_647_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_648_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG20_TYPE_648_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG20_TYPE_648_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_649_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG20_TYPE_649_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG20_TYPE_649_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_650_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG20_TYPE_650_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG20_TYPE_650_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_651_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG20_TYPE_651_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG20_TYPE_651_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_652_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_652_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG20_TYPE_652_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_653_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_653_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG20_TYPE_653_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_654_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_654_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG20_TYPE_654_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_655_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_655_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG20_TYPE_655_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_656_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_656_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG20_TYPE_656_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_657_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_657_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG20_TYPE_657_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_658_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_658_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG20_TYPE_658_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_659_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_659_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG20_TYPE_659_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_660_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_660_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG20_TYPE_660_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_661_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_661_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG20_TYPE_661_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_662_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_662_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG20_TYPE_662_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_663_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_663_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG20_TYPE_663_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_664_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_664_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG20_TYPE_664_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_665_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_665_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG20_TYPE_665_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_666_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_666_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG20_TYPE_666_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_667_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_667_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG20_TYPE_667_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_668_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_668_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG20_TYPE_668_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_669_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_669_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG20_TYPE_669_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_670_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_670_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG20_TYPE_670_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_TYPE_671_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG20_TYPE_671_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG20_TYPE_671_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG20_RESETVAL   (0x00000000u)

/* type_reg21 */

#define CSL_CPINTC_TYPE_REG21_TYPE_672_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG21_TYPE_672_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_672_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_673_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG21_TYPE_673_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG21_TYPE_673_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_674_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG21_TYPE_674_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG21_TYPE_674_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_675_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG21_TYPE_675_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG21_TYPE_675_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_676_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG21_TYPE_676_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG21_TYPE_676_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_677_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG21_TYPE_677_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG21_TYPE_677_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_678_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG21_TYPE_678_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG21_TYPE_678_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_679_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG21_TYPE_679_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG21_TYPE_679_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_680_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG21_TYPE_680_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG21_TYPE_680_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_681_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG21_TYPE_681_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG21_TYPE_681_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_682_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG21_TYPE_682_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG21_TYPE_682_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_683_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG21_TYPE_683_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG21_TYPE_683_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_684_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_684_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG21_TYPE_684_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_685_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_685_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG21_TYPE_685_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_686_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_686_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG21_TYPE_686_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_687_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_687_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG21_TYPE_687_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_688_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_688_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG21_TYPE_688_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_689_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_689_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG21_TYPE_689_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_690_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_690_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG21_TYPE_690_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_691_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_691_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG21_TYPE_691_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_692_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_692_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG21_TYPE_692_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_693_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_693_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG21_TYPE_693_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_694_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_694_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG21_TYPE_694_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_695_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_695_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG21_TYPE_695_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_696_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_696_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG21_TYPE_696_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_697_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_697_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG21_TYPE_697_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_698_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_698_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG21_TYPE_698_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_699_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_699_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG21_TYPE_699_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_700_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_700_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG21_TYPE_700_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_701_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_701_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG21_TYPE_701_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_702_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_702_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG21_TYPE_702_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_TYPE_703_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG21_TYPE_703_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG21_TYPE_703_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG21_RESETVAL   (0x00000000u)

/* type_reg22 */

#define CSL_CPINTC_TYPE_REG22_TYPE_704_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG22_TYPE_704_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_704_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_705_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG22_TYPE_705_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG22_TYPE_705_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_706_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG22_TYPE_706_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG22_TYPE_706_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_707_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG22_TYPE_707_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG22_TYPE_707_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_708_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG22_TYPE_708_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG22_TYPE_708_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_709_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG22_TYPE_709_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG22_TYPE_709_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_710_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG22_TYPE_710_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG22_TYPE_710_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_711_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG22_TYPE_711_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG22_TYPE_711_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_712_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG22_TYPE_712_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG22_TYPE_712_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_713_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG22_TYPE_713_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG22_TYPE_713_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_714_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG22_TYPE_714_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG22_TYPE_714_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_715_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG22_TYPE_715_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG22_TYPE_715_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_716_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_716_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG22_TYPE_716_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_717_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_717_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG22_TYPE_717_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_718_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_718_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG22_TYPE_718_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_719_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_719_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG22_TYPE_719_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_720_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_720_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG22_TYPE_720_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_721_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_721_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG22_TYPE_721_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_722_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_722_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG22_TYPE_722_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_723_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_723_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG22_TYPE_723_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_724_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_724_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG22_TYPE_724_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_725_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_725_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG22_TYPE_725_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_726_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_726_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG22_TYPE_726_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_727_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_727_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG22_TYPE_727_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_728_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_728_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG22_TYPE_728_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_729_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_729_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG22_TYPE_729_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_730_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_730_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG22_TYPE_730_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_731_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_731_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG22_TYPE_731_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_732_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_732_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG22_TYPE_732_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_733_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_733_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG22_TYPE_733_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_734_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_734_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG22_TYPE_734_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_TYPE_735_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG22_TYPE_735_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG22_TYPE_735_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG22_RESETVAL   (0x00000000u)

/* type_reg23 */

#define CSL_CPINTC_TYPE_REG23_TYPE_736_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG23_TYPE_736_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_736_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_737_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG23_TYPE_737_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG23_TYPE_737_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_738_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG23_TYPE_738_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG23_TYPE_738_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_739_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG23_TYPE_739_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG23_TYPE_739_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_740_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG23_TYPE_740_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG23_TYPE_740_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_741_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG23_TYPE_741_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG23_TYPE_741_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_742_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG23_TYPE_742_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG23_TYPE_742_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_743_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG23_TYPE_743_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG23_TYPE_743_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_744_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG23_TYPE_744_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG23_TYPE_744_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_745_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG23_TYPE_745_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG23_TYPE_745_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_746_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG23_TYPE_746_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG23_TYPE_746_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_747_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG23_TYPE_747_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG23_TYPE_747_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_748_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_748_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG23_TYPE_748_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_749_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_749_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG23_TYPE_749_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_750_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_750_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG23_TYPE_750_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_751_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_751_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG23_TYPE_751_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_752_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_752_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG23_TYPE_752_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_753_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_753_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG23_TYPE_753_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_754_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_754_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG23_TYPE_754_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_755_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_755_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG23_TYPE_755_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_756_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_756_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG23_TYPE_756_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_757_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_757_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG23_TYPE_757_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_758_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_758_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG23_TYPE_758_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_759_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_759_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG23_TYPE_759_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_760_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_760_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG23_TYPE_760_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_761_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_761_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG23_TYPE_761_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_762_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_762_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG23_TYPE_762_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_763_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_763_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG23_TYPE_763_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_764_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_764_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG23_TYPE_764_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_765_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_765_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG23_TYPE_765_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_766_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_766_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG23_TYPE_766_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_TYPE_767_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG23_TYPE_767_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG23_TYPE_767_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG23_RESETVAL   (0x00000000u)

/* type_reg24 */

#define CSL_CPINTC_TYPE_REG24_TYPE_768_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG24_TYPE_768_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_768_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_769_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG24_TYPE_769_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG24_TYPE_769_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_770_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG24_TYPE_770_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG24_TYPE_770_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_771_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG24_TYPE_771_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG24_TYPE_771_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_772_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG24_TYPE_772_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG24_TYPE_772_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_773_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG24_TYPE_773_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG24_TYPE_773_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_774_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG24_TYPE_774_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG24_TYPE_774_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_775_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG24_TYPE_775_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG24_TYPE_775_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_776_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG24_TYPE_776_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG24_TYPE_776_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_777_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG24_TYPE_777_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG24_TYPE_777_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_778_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG24_TYPE_778_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG24_TYPE_778_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_779_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG24_TYPE_779_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG24_TYPE_779_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_780_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_780_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG24_TYPE_780_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_781_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_781_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG24_TYPE_781_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_782_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_782_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG24_TYPE_782_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_783_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_783_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG24_TYPE_783_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_784_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_784_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG24_TYPE_784_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_785_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_785_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG24_TYPE_785_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_786_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_786_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG24_TYPE_786_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_787_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_787_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG24_TYPE_787_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_788_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_788_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG24_TYPE_788_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_789_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_789_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG24_TYPE_789_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_790_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_790_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG24_TYPE_790_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_791_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_791_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG24_TYPE_791_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_792_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_792_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG24_TYPE_792_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_793_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_793_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG24_TYPE_793_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_794_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_794_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG24_TYPE_794_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_795_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_795_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG24_TYPE_795_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_796_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_796_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG24_TYPE_796_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_797_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_797_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG24_TYPE_797_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_798_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_798_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG24_TYPE_798_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_TYPE_799_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG24_TYPE_799_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG24_TYPE_799_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG24_RESETVAL   (0x00000000u)

/* type_reg25 */

#define CSL_CPINTC_TYPE_REG25_TYPE_800_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG25_TYPE_800_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_800_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_801_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG25_TYPE_801_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG25_TYPE_801_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_802_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG25_TYPE_802_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG25_TYPE_802_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_803_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG25_TYPE_803_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG25_TYPE_803_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_804_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG25_TYPE_804_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG25_TYPE_804_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_805_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG25_TYPE_805_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG25_TYPE_805_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_806_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG25_TYPE_806_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG25_TYPE_806_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_807_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG25_TYPE_807_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG25_TYPE_807_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_808_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG25_TYPE_808_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG25_TYPE_808_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_809_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG25_TYPE_809_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG25_TYPE_809_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_810_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG25_TYPE_810_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG25_TYPE_810_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_811_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG25_TYPE_811_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG25_TYPE_811_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_812_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_812_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG25_TYPE_812_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_813_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_813_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG25_TYPE_813_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_814_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_814_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG25_TYPE_814_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_815_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_815_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG25_TYPE_815_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_816_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_816_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG25_TYPE_816_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_817_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_817_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG25_TYPE_817_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_818_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_818_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG25_TYPE_818_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_819_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_819_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG25_TYPE_819_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_820_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_820_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG25_TYPE_820_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_821_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_821_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG25_TYPE_821_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_822_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_822_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG25_TYPE_822_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_823_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_823_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG25_TYPE_823_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_824_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_824_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG25_TYPE_824_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_825_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_825_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG25_TYPE_825_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_826_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_826_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG25_TYPE_826_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_827_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_827_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG25_TYPE_827_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_828_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_828_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG25_TYPE_828_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_829_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_829_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG25_TYPE_829_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_830_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_830_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG25_TYPE_830_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_TYPE_831_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG25_TYPE_831_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG25_TYPE_831_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG25_RESETVAL   (0x00000000u)

/* type_reg26 */

#define CSL_CPINTC_TYPE_REG26_TYPE_832_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG26_TYPE_832_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_832_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_833_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG26_TYPE_833_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG26_TYPE_833_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_834_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG26_TYPE_834_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG26_TYPE_834_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_835_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG26_TYPE_835_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG26_TYPE_835_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_836_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG26_TYPE_836_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG26_TYPE_836_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_837_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG26_TYPE_837_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG26_TYPE_837_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_838_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG26_TYPE_838_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG26_TYPE_838_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_839_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG26_TYPE_839_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG26_TYPE_839_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_840_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG26_TYPE_840_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG26_TYPE_840_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_841_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG26_TYPE_841_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG26_TYPE_841_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_842_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG26_TYPE_842_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG26_TYPE_842_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_843_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG26_TYPE_843_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG26_TYPE_843_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_844_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_844_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG26_TYPE_844_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_845_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_845_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG26_TYPE_845_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_846_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_846_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG26_TYPE_846_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_847_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_847_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG26_TYPE_847_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_848_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_848_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG26_TYPE_848_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_849_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_849_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG26_TYPE_849_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_850_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_850_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG26_TYPE_850_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_851_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_851_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG26_TYPE_851_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_852_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_852_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG26_TYPE_852_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_853_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_853_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG26_TYPE_853_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_854_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_854_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG26_TYPE_854_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_855_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_855_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG26_TYPE_855_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_856_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_856_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG26_TYPE_856_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_857_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_857_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG26_TYPE_857_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_858_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_858_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG26_TYPE_858_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_859_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_859_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG26_TYPE_859_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_860_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_860_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG26_TYPE_860_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_861_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_861_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG26_TYPE_861_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_862_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_862_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG26_TYPE_862_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_TYPE_863_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG26_TYPE_863_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG26_TYPE_863_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG26_RESETVAL   (0x00000000u)

/* type_reg27 */

#define CSL_CPINTC_TYPE_REG27_TYPE_864_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG27_TYPE_864_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_864_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_865_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG27_TYPE_865_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG27_TYPE_865_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_866_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG27_TYPE_866_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG27_TYPE_866_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_867_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG27_TYPE_867_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG27_TYPE_867_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_868_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG27_TYPE_868_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG27_TYPE_868_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_869_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG27_TYPE_869_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG27_TYPE_869_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_870_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG27_TYPE_870_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG27_TYPE_870_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_871_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG27_TYPE_871_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG27_TYPE_871_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_872_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG27_TYPE_872_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG27_TYPE_872_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_873_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG27_TYPE_873_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG27_TYPE_873_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_874_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG27_TYPE_874_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG27_TYPE_874_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_875_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG27_TYPE_875_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG27_TYPE_875_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_876_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_876_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG27_TYPE_876_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_877_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_877_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG27_TYPE_877_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_878_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_878_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG27_TYPE_878_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_879_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_879_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG27_TYPE_879_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_880_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_880_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG27_TYPE_880_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_881_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_881_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG27_TYPE_881_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_882_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_882_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG27_TYPE_882_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_883_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_883_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG27_TYPE_883_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_884_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_884_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG27_TYPE_884_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_885_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_885_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG27_TYPE_885_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_886_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_886_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG27_TYPE_886_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_887_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_887_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG27_TYPE_887_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_888_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_888_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG27_TYPE_888_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_889_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_889_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG27_TYPE_889_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_890_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_890_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG27_TYPE_890_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_891_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_891_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG27_TYPE_891_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_892_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_892_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG27_TYPE_892_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_893_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_893_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG27_TYPE_893_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_894_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_894_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG27_TYPE_894_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_TYPE_895_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG27_TYPE_895_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG27_TYPE_895_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG27_RESETVAL   (0x00000000u)

/* type_reg28 */

#define CSL_CPINTC_TYPE_REG28_TYPE_896_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG28_TYPE_896_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_896_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_897_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG28_TYPE_897_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG28_TYPE_897_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_898_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG28_TYPE_898_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG28_TYPE_898_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_899_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG28_TYPE_899_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG28_TYPE_899_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_900_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG28_TYPE_900_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG28_TYPE_900_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_901_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG28_TYPE_901_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG28_TYPE_901_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_902_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG28_TYPE_902_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG28_TYPE_902_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_903_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG28_TYPE_903_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG28_TYPE_903_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_904_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG28_TYPE_904_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG28_TYPE_904_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_905_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG28_TYPE_905_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG28_TYPE_905_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_906_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG28_TYPE_906_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG28_TYPE_906_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_907_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG28_TYPE_907_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG28_TYPE_907_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_908_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_908_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG28_TYPE_908_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_909_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_909_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG28_TYPE_909_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_910_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_910_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG28_TYPE_910_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_911_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_911_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG28_TYPE_911_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_912_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_912_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG28_TYPE_912_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_913_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_913_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG28_TYPE_913_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_914_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_914_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG28_TYPE_914_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_915_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_915_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG28_TYPE_915_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_916_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_916_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG28_TYPE_916_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_917_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_917_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG28_TYPE_917_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_918_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_918_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG28_TYPE_918_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_919_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_919_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG28_TYPE_919_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_920_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_920_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG28_TYPE_920_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_921_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_921_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG28_TYPE_921_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_922_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_922_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG28_TYPE_922_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_923_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_923_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG28_TYPE_923_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_924_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_924_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG28_TYPE_924_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_925_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_925_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG28_TYPE_925_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_926_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_926_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG28_TYPE_926_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_TYPE_927_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG28_TYPE_927_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG28_TYPE_927_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG28_RESETVAL   (0x00000000u)

/* type_reg29 */

#define CSL_CPINTC_TYPE_REG29_TYPE_928_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG29_TYPE_928_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_928_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_929_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG29_TYPE_929_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG29_TYPE_929_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_930_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG29_TYPE_930_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG29_TYPE_930_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_931_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG29_TYPE_931_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG29_TYPE_931_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_932_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG29_TYPE_932_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG29_TYPE_932_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_933_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG29_TYPE_933_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG29_TYPE_933_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_934_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG29_TYPE_934_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG29_TYPE_934_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_935_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG29_TYPE_935_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG29_TYPE_935_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_936_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG29_TYPE_936_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG29_TYPE_936_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_937_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG29_TYPE_937_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG29_TYPE_937_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_938_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG29_TYPE_938_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG29_TYPE_938_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_939_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG29_TYPE_939_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG29_TYPE_939_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_940_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_940_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG29_TYPE_940_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_941_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_941_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG29_TYPE_941_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_942_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_942_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG29_TYPE_942_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_943_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_943_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG29_TYPE_943_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_944_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_944_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG29_TYPE_944_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_945_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_945_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG29_TYPE_945_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_946_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_946_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG29_TYPE_946_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_947_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_947_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG29_TYPE_947_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_948_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_948_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG29_TYPE_948_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_949_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_949_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG29_TYPE_949_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_950_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_950_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG29_TYPE_950_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_951_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_951_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG29_TYPE_951_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_952_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_952_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG29_TYPE_952_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_953_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_953_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG29_TYPE_953_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_954_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_954_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG29_TYPE_954_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_955_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_955_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG29_TYPE_955_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_956_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_956_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG29_TYPE_956_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_957_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_957_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG29_TYPE_957_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_958_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_958_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG29_TYPE_958_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_TYPE_959_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG29_TYPE_959_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG29_TYPE_959_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG29_RESETVAL   (0x00000000u)

/* type_reg30 */

#define CSL_CPINTC_TYPE_REG30_TYPE_960_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG30_TYPE_960_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_960_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_961_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG30_TYPE_961_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG30_TYPE_961_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_962_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG30_TYPE_962_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG30_TYPE_962_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_963_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG30_TYPE_963_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG30_TYPE_963_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_964_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG30_TYPE_964_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG30_TYPE_964_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_965_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG30_TYPE_965_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG30_TYPE_965_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_966_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG30_TYPE_966_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG30_TYPE_966_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_967_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG30_TYPE_967_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG30_TYPE_967_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_968_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG30_TYPE_968_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG30_TYPE_968_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_969_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG30_TYPE_969_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG30_TYPE_969_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_970_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG30_TYPE_970_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG30_TYPE_970_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_971_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG30_TYPE_971_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG30_TYPE_971_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_972_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_972_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG30_TYPE_972_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_973_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_973_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG30_TYPE_973_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_974_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_974_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG30_TYPE_974_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_975_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_975_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG30_TYPE_975_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_976_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_976_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG30_TYPE_976_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_977_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_977_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG30_TYPE_977_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_978_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_978_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG30_TYPE_978_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_979_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_979_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG30_TYPE_979_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_980_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_980_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG30_TYPE_980_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_981_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_981_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG30_TYPE_981_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_982_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_982_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG30_TYPE_982_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_983_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_983_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG30_TYPE_983_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_984_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_984_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG30_TYPE_984_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_985_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_985_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG30_TYPE_985_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_986_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_986_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG30_TYPE_986_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_987_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_987_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG30_TYPE_987_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_988_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_988_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG30_TYPE_988_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_989_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_989_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG30_TYPE_989_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_990_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_990_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG30_TYPE_990_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_TYPE_991_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG30_TYPE_991_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG30_TYPE_991_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG30_RESETVAL   (0x00000000u)

/* type_reg31 */

#define CSL_CPINTC_TYPE_REG31_TYPE_992_MASK (0x00000001u)
#define CSL_CPINTC_TYPE_REG31_TYPE_992_SHIFT (0x00000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_992_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_993_MASK (0x00000002u)
#define CSL_CPINTC_TYPE_REG31_TYPE_993_SHIFT (0x00000001u)
#define CSL_CPINTC_TYPE_REG31_TYPE_993_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_994_MASK (0x00000004u)
#define CSL_CPINTC_TYPE_REG31_TYPE_994_SHIFT (0x00000002u)
#define CSL_CPINTC_TYPE_REG31_TYPE_994_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_995_MASK (0x00000008u)
#define CSL_CPINTC_TYPE_REG31_TYPE_995_SHIFT (0x00000003u)
#define CSL_CPINTC_TYPE_REG31_TYPE_995_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_996_MASK (0x00000010u)
#define CSL_CPINTC_TYPE_REG31_TYPE_996_SHIFT (0x00000004u)
#define CSL_CPINTC_TYPE_REG31_TYPE_996_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_997_MASK (0x00000020u)
#define CSL_CPINTC_TYPE_REG31_TYPE_997_SHIFT (0x00000005u)
#define CSL_CPINTC_TYPE_REG31_TYPE_997_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_998_MASK (0x00000040u)
#define CSL_CPINTC_TYPE_REG31_TYPE_998_SHIFT (0x00000006u)
#define CSL_CPINTC_TYPE_REG31_TYPE_998_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_999_MASK (0x00000080u)
#define CSL_CPINTC_TYPE_REG31_TYPE_999_SHIFT (0x00000007u)
#define CSL_CPINTC_TYPE_REG31_TYPE_999_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1000_MASK (0x00000100u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1000_SHIFT (0x00000008u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1000_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1001_MASK (0x00000200u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1001_SHIFT (0x00000009u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1001_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1002_MASK (0x00000400u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1002_SHIFT (0x0000000Au)
#define CSL_CPINTC_TYPE_REG31_TYPE_1002_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1003_MASK (0x00000800u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1003_SHIFT (0x0000000Bu)
#define CSL_CPINTC_TYPE_REG31_TYPE_1003_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1004_MASK (0x00001000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1004_SHIFT (0x0000000Cu)
#define CSL_CPINTC_TYPE_REG31_TYPE_1004_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1005_MASK (0x00002000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1005_SHIFT (0x0000000Du)
#define CSL_CPINTC_TYPE_REG31_TYPE_1005_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1006_MASK (0x00004000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1006_SHIFT (0x0000000Eu)
#define CSL_CPINTC_TYPE_REG31_TYPE_1006_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1007_MASK (0x00008000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1007_SHIFT (0x0000000Fu)
#define CSL_CPINTC_TYPE_REG31_TYPE_1007_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1008_MASK (0x00010000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1008_SHIFT (0x00000010u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1008_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1009_MASK (0x00020000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1009_SHIFT (0x00000011u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1009_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1010_MASK (0x00040000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1010_SHIFT (0x00000012u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1010_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1011_MASK (0x00080000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1011_SHIFT (0x00000013u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1011_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1012_MASK (0x00100000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1012_SHIFT (0x00000014u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1012_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1013_MASK (0x00200000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1013_SHIFT (0x00000015u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1013_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1014_MASK (0x00400000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1014_SHIFT (0x00000016u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1014_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1015_MASK (0x00800000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1015_SHIFT (0x00000017u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1015_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1016_MASK (0x01000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1016_SHIFT (0x00000018u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1016_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1017_MASK (0x02000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1017_SHIFT (0x00000019u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1017_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1018_MASK (0x04000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1018_SHIFT (0x0000001Au)
#define CSL_CPINTC_TYPE_REG31_TYPE_1018_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1019_MASK (0x08000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1019_SHIFT (0x0000001Bu)
#define CSL_CPINTC_TYPE_REG31_TYPE_1019_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1020_MASK (0x10000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1020_SHIFT (0x0000001Cu)
#define CSL_CPINTC_TYPE_REG31_TYPE_1020_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1021_MASK (0x20000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1021_SHIFT (0x0000001Du)
#define CSL_CPINTC_TYPE_REG31_TYPE_1021_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1022_MASK (0x40000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1022_SHIFT (0x0000001Eu)
#define CSL_CPINTC_TYPE_REG31_TYPE_1022_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_TYPE_1023_MASK (0x80000000u)
#define CSL_CPINTC_TYPE_REG31_TYPE_1023_SHIFT (0x0000001Fu)
#define CSL_CPINTC_TYPE_REG31_TYPE_1023_RESETVAL (0x00000000u)

#define CSL_CPINTC_TYPE_REG31_RESETVAL   (0x00000000u)

/* dbg_select_reg0 */

#define CSL_CPINTC_DBG_SELECT_REG0_DBG_ENABLE0_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG0_DBG_ENABLE0_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG0_DBG_ENABLE0_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG0_DBG_SELECT0_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG0_DBG_SELECT0_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG0_DBG_SELECT0_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG0_RESETVAL (0x00000000u)

/* dbg_select_reg1 */

#define CSL_CPINTC_DBG_SELECT_REG1_DBG_ENABLE1_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG1_DBG_ENABLE1_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG1_DBG_ENABLE1_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG1_DBG_SELECT1_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG1_DBG_SELECT1_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG1_DBG_SELECT1_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG1_RESETVAL (0x00000000u)

/* dbg_select_reg2 */

#define CSL_CPINTC_DBG_SELECT_REG2_DBG_ENABLE2_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG2_DBG_ENABLE2_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG2_DBG_ENABLE2_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG2_DBG_SELECT2_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG2_DBG_SELECT2_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG2_DBG_SELECT2_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG2_RESETVAL (0x00000000u)

/* dbg_select_reg3 */

#define CSL_CPINTC_DBG_SELECT_REG3_DBG_ENABLE3_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG3_DBG_ENABLE3_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG3_DBG_ENABLE3_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG3_DBG_SELECT3_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG3_DBG_SELECT3_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG3_DBG_SELECT3_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG3_RESETVAL (0x00000000u)

/* dbg_select_reg4 */

#define CSL_CPINTC_DBG_SELECT_REG4_DBG_ENABLE4_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG4_DBG_ENABLE4_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG4_DBG_ENABLE4_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG4_DBG_SELECT4_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG4_DBG_SELECT4_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG4_DBG_SELECT4_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG4_RESETVAL (0x00000000u)

/* dbg_select_reg5 */

#define CSL_CPINTC_DBG_SELECT_REG5_DBG_ENABLE5_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG5_DBG_ENABLE5_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG5_DBG_ENABLE5_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG5_DBG_SELECT5_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG5_DBG_SELECT5_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG5_DBG_SELECT5_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG5_RESETVAL (0x00000000u)

/* dbg_select_reg6 */

#define CSL_CPINTC_DBG_SELECT_REG6_DBG_ENABLE6_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG6_DBG_ENABLE6_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG6_DBG_ENABLE6_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG6_DBG_SELECT6_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG6_DBG_SELECT6_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG6_DBG_SELECT6_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG6_RESETVAL (0x00000000u)

/* dbg_select_reg7 */

#define CSL_CPINTC_DBG_SELECT_REG7_DBG_ENABLE7_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG7_DBG_ENABLE7_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG7_DBG_ENABLE7_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG7_DBG_SELECT7_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG7_DBG_SELECT7_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG7_DBG_SELECT7_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG7_RESETVAL (0x00000000u)

/* dbg_select_reg8 */

#define CSL_CPINTC_DBG_SELECT_REG8_DBG_ENABLE8_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG8_DBG_ENABLE8_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG8_DBG_ENABLE8_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG8_DBG_SELECT8_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG8_DBG_SELECT8_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG8_DBG_SELECT8_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG8_RESETVAL (0x00000000u)

/* dbg_select_reg9 */

#define CSL_CPINTC_DBG_SELECT_REG9_DBG_ENABLE9_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG9_DBG_ENABLE9_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG9_DBG_ENABLE9_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG9_DBG_SELECT9_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG9_DBG_SELECT9_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG9_DBG_SELECT9_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG9_RESETVAL (0x00000000u)

/* dbg_select_reg10 */

#define CSL_CPINTC_DBG_SELECT_REG10_DBG_ENABLE10_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG10_DBG_ENABLE10_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG10_DBG_ENABLE10_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG10_DBG_SELECT10_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG10_DBG_SELECT10_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG10_DBG_SELECT10_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG10_RESETVAL (0x00000000u)

/* dbg_select_reg11 */

#define CSL_CPINTC_DBG_SELECT_REG11_DBG_ENABLE11_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG11_DBG_ENABLE11_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG11_DBG_ENABLE11_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG11_DBG_SELECT11_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG11_DBG_SELECT11_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG11_DBG_SELECT11_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG11_RESETVAL (0x00000000u)

/* dbg_select_reg12 */

#define CSL_CPINTC_DBG_SELECT_REG12_DBG_ENABLE12_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG12_DBG_ENABLE12_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG12_DBG_ENABLE12_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG12_DBG_SELECT12_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG12_DBG_SELECT12_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG12_DBG_SELECT12_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG12_RESETVAL (0x00000000u)

/* dbg_select_reg13 */

#define CSL_CPINTC_DBG_SELECT_REG13_DBG_ENABLE13_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG13_DBG_ENABLE13_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG13_DBG_ENABLE13_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG13_DBG_SELECT13_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG13_DBG_SELECT13_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG13_DBG_SELECT13_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG13_RESETVAL (0x00000000u)

/* dbg_select_reg14 */

#define CSL_CPINTC_DBG_SELECT_REG14_DBG_ENABLE14_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG14_DBG_ENABLE14_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG14_DBG_ENABLE14_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG14_DBG_SELECT14_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG14_DBG_SELECT14_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG14_DBG_SELECT14_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG14_RESETVAL (0x00000000u)

/* dbg_select_reg15 */

#define CSL_CPINTC_DBG_SELECT_REG15_DBG_ENABLE15_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG15_DBG_ENABLE15_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG15_DBG_ENABLE15_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG15_DBG_SELECT15_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG15_DBG_SELECT15_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG15_DBG_SELECT15_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG15_RESETVAL (0x00000000u)

/* dbg_select_reg16 */

#define CSL_CPINTC_DBG_SELECT_REG16_DBG_ENABLE16_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG16_DBG_ENABLE16_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG16_DBG_ENABLE16_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG16_DBG_SELECT16_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG16_DBG_SELECT16_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG16_DBG_SELECT16_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG16_RESETVAL (0x00000000u)

/* dbg_select_reg17 */

#define CSL_CPINTC_DBG_SELECT_REG17_DBG_ENABLE17_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG17_DBG_ENABLE17_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG17_DBG_ENABLE17_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG17_DBG_SELECT17_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG17_DBG_SELECT17_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG17_DBG_SELECT17_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG17_RESETVAL (0x00000000u)

/* dbg_select_reg18 */

#define CSL_CPINTC_DBG_SELECT_REG18_DBG_ENABLE18_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG18_DBG_ENABLE18_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG18_DBG_ENABLE18_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG18_DBG_SELECT18_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG18_DBG_SELECT18_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG18_DBG_SELECT18_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG18_RESETVAL (0x00000000u)

/* dbg_select_reg19 */

#define CSL_CPINTC_DBG_SELECT_REG19_DBG_ENABLE19_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG19_DBG_ENABLE19_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG19_DBG_ENABLE19_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG19_DBG_SELECT19_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG19_DBG_SELECT19_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG19_DBG_SELECT19_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG19_RESETVAL (0x00000000u)

/* dbg_select_reg20 */

#define CSL_CPINTC_DBG_SELECT_REG20_DBG_ENABLE20_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG20_DBG_ENABLE20_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG20_DBG_ENABLE20_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG20_DBG_SELECT20_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG20_DBG_SELECT20_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG20_DBG_SELECT20_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG20_RESETVAL (0x00000000u)

/* dbg_select_reg21 */

#define CSL_CPINTC_DBG_SELECT_REG21_DBG_ENABLE21_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG21_DBG_ENABLE21_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG21_DBG_ENABLE21_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG21_DBG_SELECT21_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG21_DBG_SELECT21_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG21_DBG_SELECT21_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG21_RESETVAL (0x00000000u)

/* dbg_select_reg22 */

#define CSL_CPINTC_DBG_SELECT_REG22_DBG_ENABLE22_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG22_DBG_ENABLE22_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG22_DBG_ENABLE22_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG22_DBG_SELECT22_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG22_DBG_SELECT22_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG22_DBG_SELECT22_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG22_RESETVAL (0x00000000u)

/* dbg_select_reg23 */

#define CSL_CPINTC_DBG_SELECT_REG23_DBG_ENABLE23_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG23_DBG_ENABLE23_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG23_DBG_ENABLE23_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG23_DBG_SELECT23_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG23_DBG_SELECT23_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG23_DBG_SELECT23_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG23_RESETVAL (0x00000000u)

/* dbg_select_reg24 */

#define CSL_CPINTC_DBG_SELECT_REG24_DBG_ENABLE24_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG24_DBG_ENABLE24_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG24_DBG_ENABLE24_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG24_DBG_SELECT24_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG24_DBG_SELECT24_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG24_DBG_SELECT24_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG24_RESETVAL (0x00000000u)

/* dbg_select_reg25 */

#define CSL_CPINTC_DBG_SELECT_REG25_DBG_ENABLE25_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG25_DBG_ENABLE25_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG25_DBG_ENABLE25_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG25_DBG_SELECT25_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG25_DBG_SELECT25_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG25_DBG_SELECT25_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG25_RESETVAL (0x00000000u)

/* dbg_select_reg26 */

#define CSL_CPINTC_DBG_SELECT_REG26_DBG_ENABLE26_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG26_DBG_ENABLE26_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG26_DBG_ENABLE26_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG26_DBG_SELECT26_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG26_DBG_SELECT26_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG26_DBG_SELECT26_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG26_RESETVAL (0x00000000u)

/* dbg_select_reg27 */

#define CSL_CPINTC_DBG_SELECT_REG27_DBG_ENABLE27_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG27_DBG_ENABLE27_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG27_DBG_ENABLE27_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG27_DBG_SELECT27_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG27_DBG_SELECT27_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG27_DBG_SELECT27_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG27_RESETVAL (0x00000000u)

/* dbg_select_reg28 */

#define CSL_CPINTC_DBG_SELECT_REG28_DBG_ENABLE28_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG28_DBG_ENABLE28_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG28_DBG_ENABLE28_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG28_DBG_SELECT28_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG28_DBG_SELECT28_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG28_DBG_SELECT28_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG28_RESETVAL (0x00000000u)

/* dbg_select_reg29 */

#define CSL_CPINTC_DBG_SELECT_REG29_DBG_ENABLE29_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG29_DBG_ENABLE29_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG29_DBG_ENABLE29_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG29_DBG_SELECT29_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG29_DBG_SELECT29_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG29_DBG_SELECT29_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG29_RESETVAL (0x00000000u)

/* dbg_select_reg30 */

#define CSL_CPINTC_DBG_SELECT_REG30_DBG_ENABLE30_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG30_DBG_ENABLE30_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG30_DBG_ENABLE30_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG30_DBG_SELECT30_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG30_DBG_SELECT30_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG30_DBG_SELECT30_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG30_RESETVAL (0x00000000u)

/* dbg_select_reg31 */

#define CSL_CPINTC_DBG_SELECT_REG31_DBG_ENABLE31_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG31_DBG_ENABLE31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG31_DBG_ENABLE31_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG31_DBG_SELECT31_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG31_DBG_SELECT31_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG31_DBG_SELECT31_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG31_RESETVAL (0x00000000u)

/* dbg_select_reg32 */

#define CSL_CPINTC_DBG_SELECT_REG32_DBG_ENABLE32_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG32_DBG_ENABLE32_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG32_DBG_ENABLE32_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG32_DBG_SELECT32_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG32_DBG_SELECT32_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG32_DBG_SELECT32_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG32_RESETVAL (0x00000000u)

/* dbg_select_reg33 */

#define CSL_CPINTC_DBG_SELECT_REG33_DBG_ENABLE33_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG33_DBG_ENABLE33_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG33_DBG_ENABLE33_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG33_DBG_SELECT33_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG33_DBG_SELECT33_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG33_DBG_SELECT33_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG33_RESETVAL (0x00000000u)

/* dbg_select_reg34 */

#define CSL_CPINTC_DBG_SELECT_REG34_DBG_ENABLE34_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG34_DBG_ENABLE34_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG34_DBG_ENABLE34_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG34_DBG_SELECT34_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG34_DBG_SELECT34_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG34_DBG_SELECT34_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG34_RESETVAL (0x00000000u)

/* dbg_select_reg35 */

#define CSL_CPINTC_DBG_SELECT_REG35_DBG_ENABLE35_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG35_DBG_ENABLE35_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG35_DBG_ENABLE35_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG35_DBG_SELECT35_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG35_DBG_SELECT35_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG35_DBG_SELECT35_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG35_RESETVAL (0x00000000u)

/* dbg_select_reg36 */

#define CSL_CPINTC_DBG_SELECT_REG36_DBG_ENABLE36_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG36_DBG_ENABLE36_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG36_DBG_ENABLE36_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG36_DBG_SELECT36_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG36_DBG_SELECT36_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG36_DBG_SELECT36_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG36_RESETVAL (0x00000000u)

/* dbg_select_reg37 */

#define CSL_CPINTC_DBG_SELECT_REG37_DBG_ENABLE37_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG37_DBG_ENABLE37_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG37_DBG_ENABLE37_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG37_DBG_SELECT37_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG37_DBG_SELECT37_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG37_DBG_SELECT37_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG37_RESETVAL (0x00000000u)

/* dbg_select_reg38 */

#define CSL_CPINTC_DBG_SELECT_REG38_DBG_ENABLE38_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG38_DBG_ENABLE38_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG38_DBG_ENABLE38_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG38_DBG_SELECT38_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG38_DBG_SELECT38_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG38_DBG_SELECT38_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG38_RESETVAL (0x00000000u)

/* dbg_select_reg39 */

#define CSL_CPINTC_DBG_SELECT_REG39_DBG_ENABLE39_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG39_DBG_ENABLE39_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG39_DBG_ENABLE39_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG39_DBG_SELECT39_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG39_DBG_SELECT39_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG39_DBG_SELECT39_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG39_RESETVAL (0x00000000u)

/* dbg_select_reg40 */

#define CSL_CPINTC_DBG_SELECT_REG40_DBG_ENABLE40_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG40_DBG_ENABLE40_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG40_DBG_ENABLE40_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG40_DBG_SELECT40_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG40_DBG_SELECT40_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG40_DBG_SELECT40_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG40_RESETVAL (0x00000000u)

/* dbg_select_reg41 */

#define CSL_CPINTC_DBG_SELECT_REG41_DBG_ENABLE41_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG41_DBG_ENABLE41_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG41_DBG_ENABLE41_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG41_DBG_SELECT41_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG41_DBG_SELECT41_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG41_DBG_SELECT41_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG41_RESETVAL (0x00000000u)

/* dbg_select_reg42 */

#define CSL_CPINTC_DBG_SELECT_REG42_DBG_ENABLE42_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG42_DBG_ENABLE42_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG42_DBG_ENABLE42_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG42_DBG_SELECT42_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG42_DBG_SELECT42_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG42_DBG_SELECT42_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG42_RESETVAL (0x00000000u)

/* dbg_select_reg43 */

#define CSL_CPINTC_DBG_SELECT_REG43_DBG_ENABLE43_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG43_DBG_ENABLE43_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG43_DBG_ENABLE43_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG43_DBG_SELECT43_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG43_DBG_SELECT43_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG43_DBG_SELECT43_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG43_RESETVAL (0x00000000u)

/* dbg_select_reg44 */

#define CSL_CPINTC_DBG_SELECT_REG44_DBG_ENABLE44_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG44_DBG_ENABLE44_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG44_DBG_ENABLE44_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG44_DBG_SELECT44_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG44_DBG_SELECT44_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG44_DBG_SELECT44_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG44_RESETVAL (0x00000000u)

/* dbg_select_reg45 */

#define CSL_CPINTC_DBG_SELECT_REG45_DBG_ENABLE45_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG45_DBG_ENABLE45_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG45_DBG_ENABLE45_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG45_DBG_SELECT45_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG45_DBG_SELECT45_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG45_DBG_SELECT45_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG45_RESETVAL (0x00000000u)

/* dbg_select_reg46 */

#define CSL_CPINTC_DBG_SELECT_REG46_DBG_ENABLE46_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG46_DBG_ENABLE46_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG46_DBG_ENABLE46_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG46_DBG_SELECT46_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG46_DBG_SELECT46_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG46_DBG_SELECT46_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG46_RESETVAL (0x00000000u)

/* dbg_select_reg47 */

#define CSL_CPINTC_DBG_SELECT_REG47_DBG_ENABLE47_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG47_DBG_ENABLE47_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG47_DBG_ENABLE47_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG47_DBG_SELECT47_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG47_DBG_SELECT47_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG47_DBG_SELECT47_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG47_RESETVAL (0x00000000u)

/* dbg_select_reg48 */

#define CSL_CPINTC_DBG_SELECT_REG48_DBG_ENABLE48_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG48_DBG_ENABLE48_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG48_DBG_ENABLE48_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG48_DBG_SELECT48_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG48_DBG_SELECT48_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG48_DBG_SELECT48_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG48_RESETVAL (0x00000000u)

/* dbg_select_reg49 */

#define CSL_CPINTC_DBG_SELECT_REG49_DBG_ENABLE49_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG49_DBG_ENABLE49_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG49_DBG_ENABLE49_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG49_DBG_SELECT49_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG49_DBG_SELECT49_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG49_DBG_SELECT49_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG49_RESETVAL (0x00000000u)

/* dbg_select_reg50 */

#define CSL_CPINTC_DBG_SELECT_REG50_DBG_ENABLE50_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG50_DBG_ENABLE50_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG50_DBG_ENABLE50_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG50_DBG_SELECT50_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG50_DBG_SELECT50_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG50_DBG_SELECT50_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG50_RESETVAL (0x00000000u)

/* dbg_select_reg51 */

#define CSL_CPINTC_DBG_SELECT_REG51_DBG_ENABLE51_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG51_DBG_ENABLE51_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG51_DBG_ENABLE51_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG51_DBG_SELECT51_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG51_DBG_SELECT51_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG51_DBG_SELECT51_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG51_RESETVAL (0x00000000u)

/* dbg_select_reg52 */

#define CSL_CPINTC_DBG_SELECT_REG52_DBG_ENABLE52_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG52_DBG_ENABLE52_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG52_DBG_ENABLE52_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG52_DBG_SELECT52_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG52_DBG_SELECT52_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG52_DBG_SELECT52_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG52_RESETVAL (0x00000000u)

/* dbg_select_reg53 */

#define CSL_CPINTC_DBG_SELECT_REG53_DBG_ENABLE53_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG53_DBG_ENABLE53_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG53_DBG_ENABLE53_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG53_DBG_SELECT53_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG53_DBG_SELECT53_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG53_DBG_SELECT53_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG53_RESETVAL (0x00000000u)

/* dbg_select_reg54 */

#define CSL_CPINTC_DBG_SELECT_REG54_DBG_ENABLE54_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG54_DBG_ENABLE54_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG54_DBG_ENABLE54_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG54_DBG_SELECT54_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG54_DBG_SELECT54_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG54_DBG_SELECT54_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG54_RESETVAL (0x00000000u)

/* dbg_select_reg55 */

#define CSL_CPINTC_DBG_SELECT_REG55_DBG_ENABLE55_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG55_DBG_ENABLE55_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG55_DBG_ENABLE55_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG55_DBG_SELECT55_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG55_DBG_SELECT55_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG55_DBG_SELECT55_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG55_RESETVAL (0x00000000u)

/* dbg_select_reg56 */

#define CSL_CPINTC_DBG_SELECT_REG56_DBG_ENABLE56_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG56_DBG_ENABLE56_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG56_DBG_ENABLE56_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG56_DBG_SELECT56_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG56_DBG_SELECT56_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG56_DBG_SELECT56_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG56_RESETVAL (0x00000000u)

/* dbg_select_reg57 */

#define CSL_CPINTC_DBG_SELECT_REG57_DBG_ENABLE57_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG57_DBG_ENABLE57_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG57_DBG_ENABLE57_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG57_DBG_SELECT57_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG57_DBG_SELECT57_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG57_DBG_SELECT57_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG57_RESETVAL (0x00000000u)

/* dbg_select_reg58 */

#define CSL_CPINTC_DBG_SELECT_REG58_DBG_ENABLE58_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG58_DBG_ENABLE58_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG58_DBG_ENABLE58_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG58_DBG_SELECT58_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG58_DBG_SELECT58_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG58_DBG_SELECT58_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG58_RESETVAL (0x00000000u)

/* dbg_select_reg59 */

#define CSL_CPINTC_DBG_SELECT_REG59_DBG_ENABLE59_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG59_DBG_ENABLE59_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG59_DBG_ENABLE59_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG59_DBG_SELECT59_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG59_DBG_SELECT59_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG59_DBG_SELECT59_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG59_RESETVAL (0x00000000u)

/* dbg_select_reg60 */

#define CSL_CPINTC_DBG_SELECT_REG60_DBG_ENABLE60_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG60_DBG_ENABLE60_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG60_DBG_ENABLE60_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG60_DBG_SELECT60_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG60_DBG_SELECT60_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG60_DBG_SELECT60_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG60_RESETVAL (0x00000000u)

/* dbg_select_reg61 */

#define CSL_CPINTC_DBG_SELECT_REG61_DBG_ENABLE61_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG61_DBG_ENABLE61_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG61_DBG_ENABLE61_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG61_DBG_SELECT61_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG61_DBG_SELECT61_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG61_DBG_SELECT61_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG61_RESETVAL (0x00000000u)

/* dbg_select_reg62 */

#define CSL_CPINTC_DBG_SELECT_REG62_DBG_ENABLE62_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG62_DBG_ENABLE62_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG62_DBG_ENABLE62_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG62_DBG_SELECT62_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG62_DBG_SELECT62_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG62_DBG_SELECT62_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG62_RESETVAL (0x00000000u)

/* dbg_select_reg63 */

#define CSL_CPINTC_DBG_SELECT_REG63_DBG_ENABLE63_MASK (0x80000000u)
#define CSL_CPINTC_DBG_SELECT_REG63_DBG_ENABLE63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_DBG_SELECT_REG63_DBG_ENABLE63_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG63_DBG_SELECT63_MASK (0x00003FFFu)
#define CSL_CPINTC_DBG_SELECT_REG63_DBG_SELECT63_SHIFT (0x00000000u)
#define CSL_CPINTC_DBG_SELECT_REG63_DBG_SELECT63_RESETVAL (0x00000000u)

#define CSL_CPINTC_DBG_SELECT_REG63_RESETVAL (0x00000000u)

/* secure_enable_reg0 */

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_0_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_0_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_1_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_1_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_2_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_2_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_3_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_3_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_4_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_4_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_5_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_5_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_6_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_6_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_7_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_7_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_8_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_8_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_9_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_9_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_10_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_10_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_11_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_11_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_12_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_12_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_13_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_13_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_14_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_14_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_15_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_15_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_16_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_16_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_17_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_17_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_18_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_18_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_19_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_19_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_20_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_20_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_21_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_21_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_22_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_22_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_23_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_23_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_24_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_24_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_25_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_25_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_26_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_26_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_27_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_27_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_28_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_28_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_29_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_29_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_30_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_30_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_31_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG0_SECURE_ENABLE_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG0_RESETVAL (0x00000000u)

/* secure_enable_reg1 */

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_32_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_32_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_33_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_33_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_34_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_34_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_35_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_35_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_36_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_36_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_37_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_37_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_38_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_38_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_39_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_39_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_40_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_40_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_41_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_41_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_42_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_42_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_43_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_43_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_44_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_44_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_45_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_45_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_46_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_46_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_47_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_47_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_48_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_48_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_49_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_49_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_50_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_50_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_51_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_51_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_52_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_52_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_53_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_53_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_54_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_54_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_55_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_55_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_56_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_56_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_57_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_57_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_58_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_58_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_59_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_59_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_60_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_60_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_61_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_61_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_62_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_62_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_63_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG1_SECURE_ENABLE_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG1_RESETVAL (0x00000000u)

/* secure_enable_reg2 */

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_64_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_64_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_65_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_65_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_66_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_66_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_67_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_67_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_68_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_68_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_69_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_69_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_70_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_70_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_71_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_71_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_72_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_72_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_73_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_73_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_74_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_74_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_75_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_75_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_76_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_76_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_77_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_77_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_78_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_78_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_79_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_79_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_80_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_80_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_81_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_81_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_82_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_82_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_83_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_83_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_84_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_84_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_85_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_85_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_86_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_86_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_87_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_87_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_88_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_88_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_89_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_89_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_90_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_90_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_91_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_91_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_92_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_92_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_93_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_93_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_94_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_94_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_95_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_95_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG2_SECURE_ENABLE_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG2_RESETVAL (0x00000000u)

/* secure_enable_reg3 */

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_96_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_96_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_97_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_97_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_98_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_98_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_99_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_99_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_100_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_100_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_101_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_101_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_102_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_102_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_103_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_103_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_104_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_104_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_105_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_105_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_106_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_106_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_107_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_107_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_108_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_108_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_109_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_109_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_110_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_110_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_111_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_111_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_112_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_112_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_113_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_113_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_114_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_114_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_115_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_115_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_116_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_116_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_117_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_117_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_118_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_118_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_119_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_119_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_120_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_120_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_121_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_121_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_122_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_122_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_123_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_123_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_124_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_124_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_125_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_125_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_126_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_126_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_127_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_127_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG3_SECURE_ENABLE_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG3_RESETVAL (0x00000000u)

/* secure_enable_reg4 */

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_128_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_128_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_129_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_129_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_130_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_130_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_131_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_131_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_132_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_132_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_133_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_133_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_134_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_134_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_135_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_135_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_136_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_136_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_137_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_137_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_138_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_138_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_139_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_139_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_140_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_140_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_141_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_141_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_142_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_142_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_143_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_143_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_144_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_144_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_145_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_145_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_146_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_146_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_147_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_147_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_148_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_148_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_149_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_149_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_150_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_150_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_151_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_151_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_152_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_152_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_153_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_153_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_154_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_154_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_155_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_155_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_156_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_156_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_157_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_157_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_158_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_158_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_159_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_159_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG4_SECURE_ENABLE_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG4_RESETVAL (0x00000000u)

/* secure_enable_reg5 */

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_160_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_160_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_161_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_161_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_162_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_162_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_163_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_163_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_164_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_164_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_165_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_165_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_166_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_166_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_167_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_167_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_168_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_168_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_169_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_169_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_170_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_170_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_171_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_171_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_172_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_172_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_173_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_173_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_174_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_174_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_175_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_175_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_176_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_176_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_177_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_177_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_178_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_178_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_179_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_179_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_180_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_180_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_181_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_181_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_182_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_182_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_183_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_183_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_184_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_184_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_185_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_185_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_186_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_186_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_187_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_187_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_188_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_188_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_189_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_189_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_190_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_190_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_191_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_191_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG5_SECURE_ENABLE_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG5_RESETVAL (0x00000000u)

/* secure_enable_reg6 */

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_192_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_192_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_193_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_193_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_194_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_194_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_195_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_195_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_196_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_196_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_197_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_197_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_198_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_198_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_199_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_199_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_200_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_200_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_201_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_201_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_202_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_202_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_203_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_203_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_204_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_204_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_205_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_205_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_206_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_206_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_207_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_207_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_208_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_208_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_209_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_209_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_210_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_210_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_211_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_211_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_212_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_212_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_213_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_213_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_214_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_214_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_215_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_215_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_216_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_216_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_217_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_217_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_218_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_218_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_219_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_219_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_220_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_220_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_221_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_221_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_222_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_222_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_223_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_223_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG6_SECURE_ENABLE_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG6_RESETVAL (0x00000000u)

/* secure_enable_reg7 */

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_224_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_224_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_225_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_225_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_226_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_226_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_227_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_227_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_228_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_228_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_229_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_229_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_230_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_230_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_231_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_231_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_232_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_232_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_233_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_233_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_234_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_234_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_235_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_235_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_236_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_236_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_237_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_237_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_238_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_238_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_239_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_239_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_240_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_240_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_241_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_241_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_242_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_242_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_243_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_243_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_244_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_244_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_245_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_245_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_246_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_246_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_247_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_247_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_248_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_248_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_249_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_249_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_250_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_250_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_251_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_251_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_252_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_252_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_253_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_253_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_254_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_254_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_255_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_255_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG7_SECURE_ENABLE_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG7_RESETVAL (0x00000000u)

/* secure_enable_reg8 */

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_256_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_256_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_256_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_257_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_257_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_257_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_258_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_258_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_258_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_259_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_259_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_259_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_260_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_260_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_260_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_261_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_261_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_261_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_262_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_262_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_262_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_263_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_263_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_263_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_264_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_264_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_264_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_265_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_265_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_265_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_266_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_266_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_266_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_267_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_267_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_267_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_268_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_268_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_268_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_269_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_269_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_269_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_270_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_270_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_270_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_271_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_271_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_271_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_272_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_272_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_272_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_273_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_273_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_273_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_274_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_274_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_274_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_275_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_275_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_275_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_276_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_276_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_276_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_277_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_277_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_277_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_278_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_278_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_278_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_279_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_279_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_279_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_280_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_280_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_280_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_281_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_281_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_281_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_282_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_282_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_282_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_283_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_283_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_283_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_284_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_284_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_284_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_285_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_285_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_285_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_286_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_286_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_286_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_287_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_287_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG8_SECURE_ENABLE_287_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG8_RESETVAL (0x00000000u)

/* secure_enable_reg9 */

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_288_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_288_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_288_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_289_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_289_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_289_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_290_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_290_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_290_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_291_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_291_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_291_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_292_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_292_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_292_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_293_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_293_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_293_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_294_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_294_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_294_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_295_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_295_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_295_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_296_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_296_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_296_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_297_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_297_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_297_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_298_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_298_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_298_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_299_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_299_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_299_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_300_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_300_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_300_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_301_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_301_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_301_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_302_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_302_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_302_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_303_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_303_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_303_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_304_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_304_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_304_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_305_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_305_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_305_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_306_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_306_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_306_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_307_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_307_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_307_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_308_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_308_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_308_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_309_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_309_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_309_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_310_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_310_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_310_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_311_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_311_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_311_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_312_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_312_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_312_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_313_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_313_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_313_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_314_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_314_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_314_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_315_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_315_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_315_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_316_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_316_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_316_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_317_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_317_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_317_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_318_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_318_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_318_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_319_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_319_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG9_SECURE_ENABLE_319_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG9_RESETVAL (0x00000000u)

/* secure_enable_reg10 */

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_320_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_320_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_320_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_321_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_321_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_321_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_322_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_322_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_322_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_323_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_323_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_323_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_324_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_324_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_324_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_325_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_325_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_325_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_326_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_326_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_326_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_327_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_327_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_327_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_328_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_328_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_328_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_329_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_329_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_329_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_330_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_330_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_330_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_331_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_331_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_331_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_332_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_332_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_332_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_333_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_333_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_333_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_334_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_334_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_334_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_335_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_335_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_335_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_336_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_336_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_336_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_337_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_337_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_337_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_338_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_338_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_338_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_339_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_339_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_339_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_340_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_340_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_340_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_341_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_341_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_341_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_342_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_342_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_342_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_343_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_343_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_343_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_344_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_344_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_344_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_345_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_345_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_345_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_346_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_346_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_346_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_347_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_347_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_347_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_348_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_348_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_348_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_349_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_349_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_349_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_350_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_350_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_350_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_351_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_351_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG10_SECURE_ENABLE_351_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG10_RESETVAL (0x00000000u)

/* secure_enable_reg11 */

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_352_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_352_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_352_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_353_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_353_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_353_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_354_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_354_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_354_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_355_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_355_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_355_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_356_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_356_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_356_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_357_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_357_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_357_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_358_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_358_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_358_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_359_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_359_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_359_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_360_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_360_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_360_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_361_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_361_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_361_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_362_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_362_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_362_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_363_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_363_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_363_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_364_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_364_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_364_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_365_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_365_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_365_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_366_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_366_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_366_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_367_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_367_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_367_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_368_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_368_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_368_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_369_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_369_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_369_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_370_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_370_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_370_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_371_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_371_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_371_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_372_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_372_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_372_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_373_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_373_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_373_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_374_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_374_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_374_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_375_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_375_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_375_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_376_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_376_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_376_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_377_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_377_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_377_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_378_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_378_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_378_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_379_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_379_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_379_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_380_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_380_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_380_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_381_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_381_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_381_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_382_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_382_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_382_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_383_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_383_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG11_SECURE_ENABLE_383_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG11_RESETVAL (0x00000000u)

/* secure_enable_reg12 */

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_384_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_384_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_384_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_385_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_385_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_385_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_386_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_386_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_386_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_387_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_387_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_387_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_388_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_388_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_388_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_389_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_389_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_389_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_390_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_390_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_390_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_391_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_391_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_391_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_392_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_392_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_392_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_393_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_393_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_393_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_394_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_394_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_394_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_395_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_395_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_395_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_396_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_396_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_396_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_397_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_397_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_397_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_398_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_398_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_398_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_399_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_399_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_399_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_400_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_400_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_400_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_401_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_401_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_401_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_402_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_402_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_402_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_403_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_403_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_403_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_404_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_404_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_404_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_405_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_405_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_405_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_406_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_406_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_406_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_407_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_407_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_407_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_408_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_408_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_408_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_409_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_409_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_409_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_410_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_410_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_410_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_411_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_411_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_411_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_412_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_412_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_412_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_413_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_413_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_413_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_414_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_414_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_414_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_415_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_415_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG12_SECURE_ENABLE_415_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG12_RESETVAL (0x00000000u)

/* secure_enable_reg13 */

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_416_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_416_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_416_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_417_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_417_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_417_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_418_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_418_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_418_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_419_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_419_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_419_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_420_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_420_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_420_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_421_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_421_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_421_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_422_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_422_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_422_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_423_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_423_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_423_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_424_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_424_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_424_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_425_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_425_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_425_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_426_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_426_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_426_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_427_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_427_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_427_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_428_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_428_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_428_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_429_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_429_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_429_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_430_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_430_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_430_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_431_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_431_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_431_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_432_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_432_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_432_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_433_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_433_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_433_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_434_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_434_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_434_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_435_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_435_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_435_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_436_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_436_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_436_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_437_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_437_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_437_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_438_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_438_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_438_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_439_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_439_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_439_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_440_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_440_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_440_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_441_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_441_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_441_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_442_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_442_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_442_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_443_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_443_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_443_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_444_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_444_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_444_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_445_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_445_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_445_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_446_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_446_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_446_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_447_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_447_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG13_SECURE_ENABLE_447_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG13_RESETVAL (0x00000000u)

/* secure_enable_reg14 */

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_448_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_448_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_448_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_449_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_449_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_449_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_450_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_450_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_450_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_451_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_451_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_451_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_452_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_452_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_452_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_453_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_453_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_453_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_454_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_454_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_454_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_455_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_455_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_455_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_456_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_456_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_456_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_457_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_457_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_457_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_458_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_458_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_458_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_459_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_459_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_459_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_460_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_460_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_460_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_461_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_461_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_461_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_462_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_462_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_462_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_463_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_463_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_463_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_464_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_464_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_464_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_465_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_465_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_465_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_466_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_466_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_466_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_467_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_467_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_467_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_468_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_468_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_468_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_469_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_469_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_469_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_470_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_470_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_470_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_471_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_471_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_471_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_472_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_472_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_472_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_473_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_473_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_473_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_474_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_474_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_474_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_475_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_475_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_475_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_476_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_476_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_476_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_477_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_477_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_477_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_478_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_478_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_478_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_479_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_479_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG14_SECURE_ENABLE_479_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG14_RESETVAL (0x00000000u)

/* secure_enable_reg15 */

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_480_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_480_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_480_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_481_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_481_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_481_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_482_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_482_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_482_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_483_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_483_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_483_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_484_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_484_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_484_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_485_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_485_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_485_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_486_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_486_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_486_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_487_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_487_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_487_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_488_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_488_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_488_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_489_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_489_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_489_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_490_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_490_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_490_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_491_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_491_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_491_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_492_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_492_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_492_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_493_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_493_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_493_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_494_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_494_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_494_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_495_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_495_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_495_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_496_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_496_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_496_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_497_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_497_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_497_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_498_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_498_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_498_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_499_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_499_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_499_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_500_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_500_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_500_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_501_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_501_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_501_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_502_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_502_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_502_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_503_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_503_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_503_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_504_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_504_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_504_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_505_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_505_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_505_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_506_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_506_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_506_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_507_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_507_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_507_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_508_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_508_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_508_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_509_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_509_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_509_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_510_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_510_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_510_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_511_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_511_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG15_SECURE_ENABLE_511_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG15_RESETVAL (0x00000000u)

/* secure_enable_reg16 */

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_512_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_512_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_512_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_513_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_513_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_513_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_514_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_514_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_514_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_515_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_515_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_515_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_516_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_516_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_516_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_517_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_517_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_517_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_518_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_518_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_518_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_519_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_519_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_519_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_520_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_520_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_520_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_521_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_521_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_521_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_522_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_522_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_522_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_523_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_523_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_523_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_524_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_524_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_524_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_525_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_525_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_525_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_526_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_526_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_526_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_527_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_527_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_527_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_528_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_528_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_528_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_529_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_529_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_529_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_530_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_530_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_530_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_531_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_531_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_531_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_532_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_532_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_532_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_533_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_533_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_533_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_534_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_534_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_534_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_535_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_535_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_535_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_536_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_536_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_536_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_537_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_537_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_537_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_538_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_538_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_538_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_539_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_539_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_539_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_540_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_540_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_540_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_541_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_541_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_541_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_542_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_542_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_542_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_543_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_543_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG16_SECURE_ENABLE_543_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG16_RESETVAL (0x00000000u)

/* secure_enable_reg17 */

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_544_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_544_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_544_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_545_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_545_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_545_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_546_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_546_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_546_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_547_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_547_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_547_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_548_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_548_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_548_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_549_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_549_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_549_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_550_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_550_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_550_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_551_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_551_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_551_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_552_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_552_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_552_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_553_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_553_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_553_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_554_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_554_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_554_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_555_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_555_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_555_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_556_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_556_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_556_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_557_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_557_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_557_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_558_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_558_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_558_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_559_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_559_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_559_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_560_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_560_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_560_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_561_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_561_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_561_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_562_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_562_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_562_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_563_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_563_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_563_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_564_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_564_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_564_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_565_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_565_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_565_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_566_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_566_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_566_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_567_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_567_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_567_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_568_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_568_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_568_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_569_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_569_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_569_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_570_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_570_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_570_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_571_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_571_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_571_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_572_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_572_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_572_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_573_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_573_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_573_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_574_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_574_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_574_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_575_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_575_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG17_SECURE_ENABLE_575_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG17_RESETVAL (0x00000000u)

/* secure_enable_reg18 */

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_576_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_576_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_576_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_577_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_577_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_577_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_578_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_578_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_578_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_579_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_579_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_579_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_580_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_580_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_580_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_581_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_581_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_581_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_582_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_582_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_582_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_583_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_583_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_583_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_584_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_584_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_584_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_585_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_585_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_585_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_586_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_586_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_586_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_587_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_587_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_587_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_588_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_588_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_588_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_589_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_589_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_589_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_590_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_590_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_590_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_591_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_591_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_591_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_592_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_592_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_592_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_593_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_593_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_593_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_594_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_594_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_594_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_595_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_595_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_595_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_596_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_596_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_596_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_597_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_597_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_597_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_598_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_598_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_598_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_599_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_599_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_599_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_600_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_600_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_600_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_601_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_601_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_601_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_602_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_602_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_602_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_603_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_603_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_603_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_604_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_604_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_604_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_605_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_605_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_605_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_606_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_606_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_606_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_607_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_607_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG18_SECURE_ENABLE_607_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG18_RESETVAL (0x00000000u)

/* secure_enable_reg19 */

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_608_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_608_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_608_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_609_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_609_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_609_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_610_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_610_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_610_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_611_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_611_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_611_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_612_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_612_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_612_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_613_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_613_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_613_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_614_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_614_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_614_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_615_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_615_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_615_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_616_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_616_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_616_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_617_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_617_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_617_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_618_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_618_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_618_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_619_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_619_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_619_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_620_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_620_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_620_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_621_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_621_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_621_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_622_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_622_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_622_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_623_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_623_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_623_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_624_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_624_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_624_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_625_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_625_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_625_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_626_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_626_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_626_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_627_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_627_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_627_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_628_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_628_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_628_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_629_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_629_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_629_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_630_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_630_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_630_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_631_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_631_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_631_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_632_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_632_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_632_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_633_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_633_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_633_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_634_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_634_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_634_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_635_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_635_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_635_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_636_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_636_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_636_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_637_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_637_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_637_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_638_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_638_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_638_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_639_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_639_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG19_SECURE_ENABLE_639_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG19_RESETVAL (0x00000000u)

/* secure_enable_reg20 */

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_640_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_640_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_640_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_641_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_641_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_641_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_642_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_642_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_642_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_643_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_643_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_643_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_644_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_644_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_644_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_645_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_645_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_645_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_646_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_646_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_646_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_647_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_647_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_647_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_648_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_648_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_648_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_649_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_649_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_649_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_650_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_650_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_650_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_651_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_651_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_651_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_652_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_652_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_652_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_653_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_653_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_653_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_654_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_654_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_654_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_655_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_655_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_655_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_656_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_656_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_656_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_657_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_657_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_657_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_658_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_658_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_658_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_659_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_659_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_659_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_660_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_660_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_660_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_661_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_661_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_661_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_662_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_662_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_662_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_663_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_663_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_663_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_664_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_664_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_664_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_665_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_665_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_665_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_666_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_666_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_666_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_667_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_667_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_667_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_668_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_668_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_668_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_669_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_669_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_669_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_670_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_670_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_670_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_671_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_671_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG20_SECURE_ENABLE_671_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG20_RESETVAL (0x00000000u)

/* secure_enable_reg21 */

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_672_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_672_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_672_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_673_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_673_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_673_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_674_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_674_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_674_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_675_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_675_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_675_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_676_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_676_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_676_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_677_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_677_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_677_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_678_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_678_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_678_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_679_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_679_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_679_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_680_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_680_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_680_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_681_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_681_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_681_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_682_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_682_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_682_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_683_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_683_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_683_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_684_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_684_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_684_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_685_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_685_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_685_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_686_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_686_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_686_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_687_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_687_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_687_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_688_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_688_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_688_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_689_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_689_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_689_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_690_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_690_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_690_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_691_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_691_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_691_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_692_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_692_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_692_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_693_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_693_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_693_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_694_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_694_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_694_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_695_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_695_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_695_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_696_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_696_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_696_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_697_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_697_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_697_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_698_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_698_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_698_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_699_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_699_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_699_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_700_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_700_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_700_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_701_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_701_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_701_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_702_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_702_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_702_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_703_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_703_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG21_SECURE_ENABLE_703_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG21_RESETVAL (0x00000000u)

/* secure_enable_reg22 */

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_704_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_704_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_704_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_705_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_705_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_705_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_706_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_706_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_706_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_707_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_707_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_707_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_708_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_708_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_708_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_709_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_709_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_709_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_710_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_710_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_710_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_711_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_711_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_711_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_712_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_712_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_712_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_713_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_713_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_713_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_714_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_714_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_714_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_715_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_715_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_715_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_716_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_716_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_716_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_717_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_717_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_717_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_718_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_718_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_718_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_719_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_719_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_719_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_720_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_720_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_720_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_721_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_721_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_721_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_722_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_722_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_722_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_723_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_723_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_723_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_724_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_724_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_724_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_725_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_725_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_725_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_726_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_726_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_726_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_727_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_727_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_727_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_728_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_728_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_728_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_729_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_729_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_729_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_730_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_730_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_730_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_731_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_731_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_731_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_732_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_732_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_732_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_733_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_733_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_733_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_734_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_734_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_734_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_735_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_735_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG22_SECURE_ENABLE_735_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG22_RESETVAL (0x00000000u)

/* secure_enable_reg23 */

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_736_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_736_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_736_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_737_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_737_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_737_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_738_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_738_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_738_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_739_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_739_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_739_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_740_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_740_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_740_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_741_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_741_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_741_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_742_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_742_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_742_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_743_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_743_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_743_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_744_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_744_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_744_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_745_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_745_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_745_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_746_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_746_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_746_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_747_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_747_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_747_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_748_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_748_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_748_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_749_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_749_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_749_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_750_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_750_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_750_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_751_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_751_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_751_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_752_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_752_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_752_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_753_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_753_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_753_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_754_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_754_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_754_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_755_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_755_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_755_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_756_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_756_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_756_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_757_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_757_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_757_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_758_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_758_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_758_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_759_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_759_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_759_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_760_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_760_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_760_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_761_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_761_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_761_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_762_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_762_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_762_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_763_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_763_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_763_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_764_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_764_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_764_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_765_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_765_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_765_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_766_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_766_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_766_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_767_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_767_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG23_SECURE_ENABLE_767_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG23_RESETVAL (0x00000000u)

/* secure_enable_reg24 */

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_768_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_768_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_768_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_769_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_769_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_769_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_770_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_770_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_770_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_771_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_771_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_771_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_772_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_772_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_772_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_773_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_773_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_773_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_774_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_774_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_774_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_775_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_775_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_775_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_776_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_776_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_776_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_777_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_777_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_777_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_778_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_778_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_778_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_779_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_779_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_779_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_780_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_780_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_780_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_781_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_781_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_781_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_782_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_782_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_782_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_783_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_783_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_783_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_784_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_784_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_784_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_785_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_785_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_785_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_786_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_786_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_786_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_787_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_787_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_787_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_788_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_788_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_788_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_789_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_789_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_789_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_790_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_790_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_790_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_791_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_791_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_791_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_792_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_792_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_792_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_793_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_793_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_793_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_794_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_794_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_794_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_795_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_795_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_795_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_796_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_796_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_796_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_797_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_797_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_797_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_798_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_798_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_798_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_799_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_799_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG24_SECURE_ENABLE_799_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG24_RESETVAL (0x00000000u)

/* secure_enable_reg25 */

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_800_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_800_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_800_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_801_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_801_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_801_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_802_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_802_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_802_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_803_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_803_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_803_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_804_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_804_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_804_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_805_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_805_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_805_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_806_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_806_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_806_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_807_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_807_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_807_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_808_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_808_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_808_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_809_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_809_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_809_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_810_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_810_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_810_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_811_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_811_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_811_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_812_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_812_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_812_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_813_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_813_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_813_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_814_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_814_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_814_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_815_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_815_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_815_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_816_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_816_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_816_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_817_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_817_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_817_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_818_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_818_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_818_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_819_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_819_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_819_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_820_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_820_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_820_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_821_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_821_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_821_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_822_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_822_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_822_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_823_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_823_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_823_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_824_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_824_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_824_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_825_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_825_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_825_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_826_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_826_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_826_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_827_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_827_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_827_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_828_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_828_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_828_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_829_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_829_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_829_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_830_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_830_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_830_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_831_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_831_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG25_SECURE_ENABLE_831_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG25_RESETVAL (0x00000000u)

/* secure_enable_reg26 */

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_832_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_832_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_832_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_833_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_833_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_833_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_834_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_834_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_834_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_835_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_835_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_835_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_836_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_836_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_836_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_837_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_837_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_837_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_838_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_838_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_838_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_839_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_839_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_839_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_840_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_840_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_840_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_841_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_841_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_841_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_842_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_842_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_842_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_843_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_843_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_843_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_844_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_844_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_844_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_845_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_845_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_845_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_846_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_846_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_846_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_847_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_847_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_847_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_848_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_848_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_848_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_849_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_849_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_849_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_850_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_850_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_850_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_851_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_851_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_851_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_852_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_852_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_852_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_853_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_853_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_853_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_854_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_854_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_854_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_855_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_855_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_855_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_856_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_856_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_856_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_857_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_857_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_857_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_858_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_858_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_858_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_859_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_859_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_859_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_860_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_860_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_860_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_861_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_861_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_861_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_862_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_862_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_862_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_863_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_863_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG26_SECURE_ENABLE_863_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG26_RESETVAL (0x00000000u)

/* secure_enable_reg27 */

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_864_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_864_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_864_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_865_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_865_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_865_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_866_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_866_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_866_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_867_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_867_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_867_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_868_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_868_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_868_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_869_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_869_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_869_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_870_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_870_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_870_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_871_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_871_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_871_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_872_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_872_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_872_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_873_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_873_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_873_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_874_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_874_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_874_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_875_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_875_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_875_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_876_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_876_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_876_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_877_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_877_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_877_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_878_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_878_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_878_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_879_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_879_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_879_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_880_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_880_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_880_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_881_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_881_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_881_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_882_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_882_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_882_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_883_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_883_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_883_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_884_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_884_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_884_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_885_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_885_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_885_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_886_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_886_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_886_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_887_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_887_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_887_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_888_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_888_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_888_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_889_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_889_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_889_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_890_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_890_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_890_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_891_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_891_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_891_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_892_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_892_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_892_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_893_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_893_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_893_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_894_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_894_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_894_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_895_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_895_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG27_SECURE_ENABLE_895_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG27_RESETVAL (0x00000000u)

/* secure_enable_reg28 */

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_896_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_896_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_896_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_897_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_897_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_897_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_898_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_898_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_898_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_899_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_899_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_899_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_900_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_900_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_900_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_901_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_901_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_901_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_902_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_902_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_902_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_903_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_903_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_903_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_904_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_904_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_904_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_905_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_905_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_905_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_906_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_906_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_906_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_907_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_907_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_907_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_908_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_908_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_908_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_909_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_909_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_909_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_910_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_910_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_910_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_911_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_911_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_911_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_912_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_912_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_912_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_913_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_913_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_913_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_914_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_914_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_914_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_915_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_915_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_915_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_916_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_916_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_916_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_917_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_917_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_917_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_918_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_918_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_918_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_919_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_919_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_919_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_920_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_920_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_920_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_921_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_921_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_921_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_922_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_922_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_922_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_923_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_923_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_923_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_924_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_924_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_924_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_925_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_925_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_925_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_926_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_926_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_926_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_927_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_927_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG28_SECURE_ENABLE_927_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG28_RESETVAL (0x00000000u)

/* secure_enable_reg29 */

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_928_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_928_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_928_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_929_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_929_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_929_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_930_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_930_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_930_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_931_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_931_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_931_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_932_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_932_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_932_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_933_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_933_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_933_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_934_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_934_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_934_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_935_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_935_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_935_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_936_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_936_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_936_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_937_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_937_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_937_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_938_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_938_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_938_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_939_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_939_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_939_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_940_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_940_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_940_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_941_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_941_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_941_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_942_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_942_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_942_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_943_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_943_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_943_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_944_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_944_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_944_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_945_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_945_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_945_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_946_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_946_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_946_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_947_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_947_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_947_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_948_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_948_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_948_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_949_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_949_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_949_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_950_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_950_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_950_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_951_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_951_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_951_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_952_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_952_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_952_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_953_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_953_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_953_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_954_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_954_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_954_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_955_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_955_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_955_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_956_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_956_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_956_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_957_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_957_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_957_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_958_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_958_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_958_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_959_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_959_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG29_SECURE_ENABLE_959_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG29_RESETVAL (0x00000000u)

/* secure_enable_reg30 */

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_960_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_960_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_960_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_961_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_961_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_961_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_962_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_962_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_962_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_963_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_963_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_963_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_964_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_964_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_964_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_965_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_965_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_965_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_966_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_966_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_966_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_967_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_967_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_967_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_968_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_968_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_968_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_969_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_969_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_969_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_970_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_970_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_970_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_971_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_971_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_971_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_972_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_972_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_972_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_973_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_973_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_973_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_974_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_974_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_974_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_975_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_975_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_975_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_976_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_976_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_976_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_977_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_977_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_977_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_978_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_978_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_978_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_979_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_979_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_979_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_980_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_980_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_980_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_981_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_981_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_981_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_982_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_982_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_982_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_983_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_983_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_983_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_984_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_984_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_984_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_985_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_985_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_985_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_986_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_986_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_986_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_987_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_987_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_987_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_988_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_988_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_988_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_989_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_989_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_989_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_990_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_990_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_990_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_991_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_991_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG30_SECURE_ENABLE_991_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG30_RESETVAL (0x00000000u)

/* secure_enable_reg31 */

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_992_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_992_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_992_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_993_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_993_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_993_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_994_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_994_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_994_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_995_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_995_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_995_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_996_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_996_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_996_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_997_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_997_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_997_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_998_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_998_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_998_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_999_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_999_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_999_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1000_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1000_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1000_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1001_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1001_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1001_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1002_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1002_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1002_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1003_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1003_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1003_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1004_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1004_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1004_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1005_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1005_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1005_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1006_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1006_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1006_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1007_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1007_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1007_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1008_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1008_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1008_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1009_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1009_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1009_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1010_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1010_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1010_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1011_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1011_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1011_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1012_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1012_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1012_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1013_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1013_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1013_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1014_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1014_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1014_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1015_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1015_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1015_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1016_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1016_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1016_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1017_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1017_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1017_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1018_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1018_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1018_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1019_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1019_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1019_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1020_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1020_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1020_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1021_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1021_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1021_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1022_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1022_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1022_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1023_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1023_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_REG31_SECURE_ENABLE_1023_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_REG31_RESETVAL (0x00000000u)

/* secure_enable_clr_reg0 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_0_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_0_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_0_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_1_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_1_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_1_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_2_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_2_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_2_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_3_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_3_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_3_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_4_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_4_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_4_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_5_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_5_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_5_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_6_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_6_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_6_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_7_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_7_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_7_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_8_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_8_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_8_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_9_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_9_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_9_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_10_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_10_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_10_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_11_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_11_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_11_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_12_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_12_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_12_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_13_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_13_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_13_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_14_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_14_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_14_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_15_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_15_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_15_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_16_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_16_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_16_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_17_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_17_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_17_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_18_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_18_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_18_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_19_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_19_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_19_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_20_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_20_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_20_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_21_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_21_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_21_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_22_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_22_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_22_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_23_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_23_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_23_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_24_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_24_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_24_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_25_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_25_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_25_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_26_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_26_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_26_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_27_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_27_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_27_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_28_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_28_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_28_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_29_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_29_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_29_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_30_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_30_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_30_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_31_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_31_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_SECURE_ENABLE_31_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG0_RESETVAL (0x00000000u)

/* secure_enable_clr_reg1 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_32_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_32_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_32_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_33_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_33_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_33_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_34_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_34_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_34_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_35_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_35_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_35_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_36_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_36_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_36_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_37_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_37_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_37_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_38_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_38_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_38_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_39_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_39_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_39_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_40_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_40_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_40_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_41_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_41_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_41_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_42_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_42_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_42_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_43_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_43_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_43_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_44_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_44_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_44_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_45_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_45_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_45_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_46_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_46_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_46_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_47_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_47_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_47_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_48_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_48_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_48_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_49_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_49_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_49_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_50_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_50_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_50_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_51_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_51_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_51_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_52_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_52_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_52_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_53_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_53_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_53_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_54_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_54_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_54_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_55_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_55_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_55_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_56_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_56_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_56_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_57_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_57_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_57_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_58_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_58_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_58_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_59_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_59_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_59_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_60_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_60_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_60_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_61_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_61_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_61_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_62_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_62_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_62_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_63_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_63_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_SECURE_ENABLE_63_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG1_RESETVAL (0x00000000u)

/* secure_enable_clr_reg2 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_64_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_64_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_64_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_65_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_65_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_65_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_66_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_66_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_66_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_67_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_67_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_67_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_68_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_68_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_68_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_69_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_69_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_69_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_70_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_70_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_70_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_71_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_71_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_71_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_72_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_72_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_72_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_73_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_73_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_73_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_74_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_74_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_74_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_75_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_75_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_75_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_76_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_76_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_76_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_77_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_77_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_77_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_78_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_78_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_78_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_79_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_79_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_79_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_80_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_80_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_80_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_81_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_81_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_81_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_82_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_82_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_82_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_83_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_83_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_83_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_84_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_84_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_84_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_85_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_85_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_85_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_86_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_86_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_86_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_87_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_87_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_87_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_88_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_88_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_88_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_89_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_89_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_89_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_90_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_90_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_90_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_91_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_91_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_91_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_92_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_92_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_92_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_93_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_93_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_93_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_94_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_94_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_94_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_95_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_95_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_SECURE_ENABLE_95_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG2_RESETVAL (0x00000000u)

/* secure_enable_clr_reg3 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_96_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_96_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_96_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_97_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_97_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_97_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_98_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_98_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_98_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_99_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_99_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_99_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_100_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_100_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_100_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_101_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_101_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_101_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_102_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_102_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_102_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_103_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_103_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_103_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_104_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_104_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_104_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_105_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_105_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_105_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_106_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_106_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_106_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_107_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_107_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_107_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_108_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_108_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_108_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_109_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_109_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_109_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_110_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_110_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_110_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_111_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_111_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_111_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_112_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_112_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_112_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_113_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_113_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_113_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_114_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_114_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_114_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_115_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_115_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_115_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_116_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_116_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_116_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_117_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_117_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_117_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_118_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_118_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_118_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_119_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_119_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_119_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_120_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_120_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_120_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_121_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_121_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_121_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_122_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_122_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_122_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_123_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_123_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_123_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_124_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_124_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_124_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_125_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_125_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_125_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_126_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_126_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_126_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_127_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_127_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_SECURE_ENABLE_127_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG3_RESETVAL (0x00000000u)

/* secure_enable_clr_reg4 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_128_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_128_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_128_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_129_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_129_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_129_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_130_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_130_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_130_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_131_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_131_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_131_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_132_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_132_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_132_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_133_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_133_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_133_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_134_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_134_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_134_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_135_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_135_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_135_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_136_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_136_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_136_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_137_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_137_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_137_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_138_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_138_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_138_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_139_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_139_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_139_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_140_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_140_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_140_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_141_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_141_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_141_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_142_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_142_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_142_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_143_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_143_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_143_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_144_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_144_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_144_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_145_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_145_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_145_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_146_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_146_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_146_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_147_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_147_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_147_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_148_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_148_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_148_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_149_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_149_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_149_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_150_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_150_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_150_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_151_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_151_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_151_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_152_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_152_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_152_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_153_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_153_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_153_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_154_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_154_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_154_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_155_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_155_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_155_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_156_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_156_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_156_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_157_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_157_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_157_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_158_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_158_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_158_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_159_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_159_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_SECURE_ENABLE_159_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG4_RESETVAL (0x00000000u)

/* secure_enable_clr_reg5 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_160_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_160_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_160_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_161_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_161_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_161_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_162_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_162_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_162_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_163_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_163_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_163_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_164_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_164_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_164_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_165_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_165_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_165_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_166_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_166_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_166_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_167_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_167_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_167_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_168_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_168_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_168_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_169_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_169_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_169_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_170_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_170_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_170_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_171_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_171_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_171_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_172_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_172_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_172_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_173_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_173_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_173_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_174_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_174_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_174_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_175_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_175_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_175_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_176_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_176_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_176_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_177_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_177_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_177_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_178_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_178_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_178_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_179_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_179_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_179_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_180_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_180_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_180_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_181_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_181_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_181_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_182_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_182_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_182_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_183_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_183_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_183_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_184_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_184_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_184_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_185_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_185_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_185_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_186_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_186_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_186_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_187_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_187_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_187_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_188_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_188_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_188_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_189_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_189_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_189_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_190_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_190_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_190_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_191_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_191_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_SECURE_ENABLE_191_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG5_RESETVAL (0x00000000u)

/* secure_enable_clr_reg6 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_192_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_192_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_192_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_193_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_193_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_193_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_194_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_194_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_194_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_195_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_195_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_195_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_196_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_196_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_196_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_197_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_197_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_197_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_198_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_198_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_198_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_199_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_199_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_199_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_200_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_200_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_200_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_201_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_201_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_201_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_202_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_202_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_202_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_203_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_203_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_203_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_204_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_204_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_204_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_205_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_205_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_205_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_206_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_206_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_206_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_207_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_207_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_207_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_208_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_208_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_208_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_209_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_209_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_209_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_210_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_210_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_210_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_211_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_211_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_211_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_212_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_212_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_212_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_213_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_213_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_213_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_214_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_214_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_214_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_215_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_215_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_215_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_216_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_216_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_216_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_217_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_217_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_217_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_218_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_218_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_218_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_219_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_219_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_219_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_220_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_220_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_220_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_221_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_221_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_221_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_222_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_222_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_222_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_223_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_223_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_SECURE_ENABLE_223_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG6_RESETVAL (0x00000000u)

/* secure_enable_clr_reg7 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_224_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_224_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_224_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_225_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_225_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_225_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_226_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_226_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_226_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_227_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_227_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_227_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_228_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_228_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_228_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_229_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_229_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_229_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_230_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_230_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_230_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_231_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_231_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_231_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_232_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_232_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_232_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_233_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_233_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_233_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_234_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_234_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_234_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_235_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_235_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_235_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_236_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_236_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_236_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_237_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_237_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_237_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_238_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_238_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_238_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_239_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_239_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_239_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_240_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_240_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_240_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_241_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_241_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_241_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_242_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_242_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_242_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_243_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_243_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_243_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_244_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_244_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_244_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_245_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_245_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_245_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_246_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_246_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_246_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_247_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_247_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_247_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_248_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_248_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_248_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_249_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_249_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_249_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_250_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_250_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_250_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_251_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_251_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_251_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_252_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_252_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_252_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_253_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_253_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_253_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_254_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_254_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_254_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_255_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_255_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_SECURE_ENABLE_255_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG7_RESETVAL (0x00000000u)

/* secure_enable_clr_reg8 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_256_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_256_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_256_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_257_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_257_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_257_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_258_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_258_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_258_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_259_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_259_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_259_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_260_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_260_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_260_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_261_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_261_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_261_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_262_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_262_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_262_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_263_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_263_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_263_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_264_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_264_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_264_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_265_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_265_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_265_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_266_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_266_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_266_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_267_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_267_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_267_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_268_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_268_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_268_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_269_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_269_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_269_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_270_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_270_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_270_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_271_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_271_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_271_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_272_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_272_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_272_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_273_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_273_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_273_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_274_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_274_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_274_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_275_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_275_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_275_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_276_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_276_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_276_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_277_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_277_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_277_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_278_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_278_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_278_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_279_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_279_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_279_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_280_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_280_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_280_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_281_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_281_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_281_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_282_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_282_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_282_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_283_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_283_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_283_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_284_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_284_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_284_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_285_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_285_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_285_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_286_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_286_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_286_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_287_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_287_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_SECURE_ENABLE_287_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG8_RESETVAL (0x00000000u)

/* secure_enable_clr_reg9 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_288_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_288_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_288_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_289_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_289_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_289_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_290_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_290_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_290_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_291_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_291_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_291_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_292_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_292_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_292_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_293_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_293_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_293_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_294_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_294_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_294_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_295_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_295_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_295_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_296_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_296_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_296_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_297_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_297_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_297_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_298_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_298_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_298_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_299_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_299_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_299_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_300_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_300_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_300_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_301_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_301_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_301_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_302_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_302_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_302_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_303_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_303_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_303_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_304_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_304_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_304_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_305_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_305_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_305_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_306_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_306_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_306_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_307_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_307_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_307_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_308_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_308_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_308_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_309_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_309_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_309_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_310_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_310_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_310_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_311_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_311_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_311_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_312_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_312_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_312_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_313_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_313_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_313_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_314_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_314_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_314_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_315_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_315_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_315_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_316_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_316_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_316_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_317_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_317_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_317_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_318_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_318_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_318_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_319_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_319_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_SECURE_ENABLE_319_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG9_RESETVAL (0x00000000u)

/* secure_enable_clr_reg10 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_320_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_320_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_320_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_321_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_321_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_321_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_322_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_322_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_322_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_323_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_323_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_323_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_324_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_324_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_324_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_325_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_325_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_325_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_326_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_326_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_326_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_327_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_327_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_327_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_328_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_328_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_328_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_329_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_329_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_329_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_330_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_330_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_330_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_331_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_331_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_331_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_332_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_332_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_332_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_333_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_333_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_333_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_334_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_334_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_334_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_335_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_335_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_335_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_336_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_336_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_336_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_337_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_337_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_337_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_338_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_338_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_338_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_339_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_339_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_339_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_340_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_340_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_340_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_341_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_341_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_341_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_342_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_342_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_342_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_343_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_343_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_343_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_344_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_344_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_344_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_345_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_345_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_345_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_346_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_346_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_346_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_347_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_347_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_347_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_348_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_348_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_348_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_349_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_349_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_349_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_350_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_350_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_350_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_351_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_351_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_SECURE_ENABLE_351_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG10_RESETVAL (0x00000000u)

/* secure_enable_clr_reg11 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_352_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_352_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_352_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_353_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_353_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_353_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_354_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_354_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_354_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_355_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_355_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_355_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_356_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_356_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_356_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_357_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_357_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_357_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_358_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_358_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_358_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_359_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_359_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_359_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_360_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_360_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_360_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_361_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_361_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_361_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_362_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_362_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_362_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_363_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_363_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_363_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_364_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_364_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_364_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_365_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_365_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_365_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_366_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_366_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_366_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_367_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_367_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_367_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_368_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_368_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_368_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_369_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_369_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_369_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_370_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_370_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_370_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_371_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_371_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_371_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_372_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_372_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_372_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_373_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_373_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_373_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_374_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_374_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_374_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_375_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_375_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_375_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_376_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_376_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_376_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_377_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_377_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_377_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_378_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_378_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_378_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_379_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_379_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_379_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_380_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_380_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_380_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_381_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_381_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_381_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_382_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_382_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_382_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_383_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_383_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_SECURE_ENABLE_383_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG11_RESETVAL (0x00000000u)

/* secure_enable_clr_reg12 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_384_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_384_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_384_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_385_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_385_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_385_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_386_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_386_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_386_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_387_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_387_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_387_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_388_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_388_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_388_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_389_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_389_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_389_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_390_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_390_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_390_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_391_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_391_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_391_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_392_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_392_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_392_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_393_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_393_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_393_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_394_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_394_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_394_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_395_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_395_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_395_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_396_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_396_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_396_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_397_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_397_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_397_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_398_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_398_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_398_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_399_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_399_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_399_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_400_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_400_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_400_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_401_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_401_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_401_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_402_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_402_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_402_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_403_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_403_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_403_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_404_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_404_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_404_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_405_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_405_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_405_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_406_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_406_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_406_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_407_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_407_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_407_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_408_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_408_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_408_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_409_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_409_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_409_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_410_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_410_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_410_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_411_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_411_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_411_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_412_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_412_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_412_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_413_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_413_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_413_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_414_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_414_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_414_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_415_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_415_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_SECURE_ENABLE_415_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG12_RESETVAL (0x00000000u)

/* secure_enable_clr_reg13 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_416_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_416_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_416_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_417_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_417_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_417_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_418_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_418_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_418_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_419_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_419_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_419_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_420_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_420_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_420_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_421_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_421_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_421_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_422_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_422_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_422_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_423_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_423_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_423_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_424_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_424_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_424_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_425_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_425_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_425_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_426_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_426_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_426_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_427_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_427_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_427_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_428_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_428_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_428_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_429_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_429_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_429_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_430_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_430_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_430_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_431_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_431_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_431_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_432_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_432_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_432_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_433_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_433_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_433_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_434_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_434_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_434_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_435_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_435_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_435_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_436_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_436_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_436_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_437_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_437_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_437_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_438_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_438_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_438_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_439_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_439_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_439_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_440_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_440_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_440_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_441_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_441_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_441_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_442_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_442_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_442_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_443_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_443_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_443_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_444_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_444_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_444_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_445_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_445_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_445_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_446_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_446_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_446_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_447_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_447_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_SECURE_ENABLE_447_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG13_RESETVAL (0x00000000u)

/* secure_enable_clr_reg14 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_448_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_448_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_448_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_449_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_449_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_449_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_450_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_450_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_450_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_451_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_451_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_451_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_452_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_452_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_452_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_453_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_453_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_453_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_454_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_454_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_454_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_455_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_455_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_455_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_456_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_456_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_456_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_457_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_457_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_457_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_458_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_458_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_458_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_459_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_459_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_459_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_460_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_460_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_460_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_461_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_461_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_461_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_462_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_462_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_462_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_463_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_463_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_463_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_464_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_464_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_464_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_465_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_465_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_465_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_466_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_466_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_466_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_467_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_467_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_467_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_468_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_468_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_468_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_469_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_469_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_469_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_470_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_470_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_470_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_471_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_471_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_471_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_472_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_472_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_472_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_473_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_473_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_473_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_474_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_474_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_474_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_475_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_475_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_475_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_476_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_476_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_476_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_477_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_477_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_477_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_478_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_478_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_478_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_479_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_479_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_SECURE_ENABLE_479_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG14_RESETVAL (0x00000000u)

/* secure_enable_clr_reg15 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_480_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_480_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_480_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_481_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_481_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_481_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_482_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_482_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_482_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_483_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_483_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_483_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_484_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_484_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_484_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_485_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_485_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_485_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_486_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_486_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_486_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_487_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_487_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_487_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_488_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_488_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_488_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_489_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_489_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_489_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_490_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_490_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_490_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_491_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_491_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_491_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_492_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_492_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_492_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_493_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_493_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_493_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_494_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_494_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_494_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_495_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_495_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_495_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_496_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_496_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_496_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_497_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_497_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_497_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_498_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_498_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_498_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_499_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_499_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_499_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_500_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_500_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_500_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_501_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_501_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_501_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_502_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_502_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_502_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_503_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_503_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_503_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_504_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_504_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_504_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_505_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_505_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_505_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_506_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_506_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_506_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_507_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_507_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_507_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_508_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_508_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_508_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_509_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_509_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_509_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_510_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_510_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_510_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_511_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_511_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_SECURE_ENABLE_511_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG15_RESETVAL (0x00000000u)

/* secure_enable_clr_reg16 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_512_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_512_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_512_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_513_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_513_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_513_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_514_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_514_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_514_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_515_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_515_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_515_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_516_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_516_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_516_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_517_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_517_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_517_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_518_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_518_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_518_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_519_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_519_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_519_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_520_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_520_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_520_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_521_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_521_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_521_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_522_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_522_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_522_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_523_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_523_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_523_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_524_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_524_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_524_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_525_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_525_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_525_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_526_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_526_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_526_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_527_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_527_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_527_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_528_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_528_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_528_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_529_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_529_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_529_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_530_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_530_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_530_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_531_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_531_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_531_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_532_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_532_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_532_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_533_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_533_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_533_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_534_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_534_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_534_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_535_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_535_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_535_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_536_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_536_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_536_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_537_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_537_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_537_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_538_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_538_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_538_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_539_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_539_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_539_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_540_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_540_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_540_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_541_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_541_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_541_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_542_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_542_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_542_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_543_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_543_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_SECURE_ENABLE_543_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG16_RESETVAL (0x00000000u)

/* secure_enable_clr_reg17 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_544_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_544_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_544_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_545_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_545_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_545_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_546_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_546_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_546_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_547_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_547_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_547_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_548_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_548_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_548_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_549_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_549_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_549_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_550_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_550_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_550_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_551_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_551_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_551_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_552_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_552_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_552_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_553_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_553_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_553_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_554_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_554_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_554_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_555_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_555_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_555_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_556_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_556_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_556_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_557_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_557_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_557_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_558_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_558_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_558_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_559_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_559_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_559_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_560_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_560_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_560_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_561_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_561_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_561_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_562_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_562_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_562_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_563_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_563_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_563_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_564_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_564_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_564_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_565_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_565_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_565_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_566_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_566_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_566_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_567_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_567_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_567_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_568_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_568_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_568_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_569_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_569_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_569_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_570_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_570_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_570_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_571_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_571_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_571_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_572_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_572_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_572_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_573_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_573_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_573_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_574_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_574_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_574_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_575_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_575_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_SECURE_ENABLE_575_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG17_RESETVAL (0x00000000u)

/* secure_enable_clr_reg18 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_576_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_576_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_576_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_577_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_577_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_577_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_578_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_578_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_578_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_579_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_579_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_579_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_580_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_580_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_580_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_581_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_581_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_581_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_582_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_582_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_582_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_583_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_583_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_583_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_584_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_584_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_584_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_585_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_585_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_585_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_586_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_586_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_586_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_587_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_587_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_587_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_588_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_588_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_588_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_589_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_589_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_589_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_590_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_590_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_590_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_591_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_591_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_591_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_592_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_592_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_592_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_593_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_593_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_593_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_594_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_594_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_594_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_595_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_595_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_595_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_596_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_596_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_596_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_597_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_597_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_597_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_598_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_598_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_598_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_599_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_599_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_599_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_600_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_600_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_600_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_601_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_601_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_601_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_602_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_602_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_602_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_603_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_603_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_603_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_604_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_604_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_604_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_605_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_605_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_605_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_606_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_606_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_606_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_607_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_607_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_SECURE_ENABLE_607_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG18_RESETVAL (0x00000000u)

/* secure_enable_clr_reg19 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_608_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_608_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_608_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_609_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_609_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_609_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_610_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_610_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_610_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_611_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_611_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_611_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_612_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_612_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_612_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_613_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_613_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_613_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_614_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_614_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_614_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_615_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_615_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_615_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_616_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_616_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_616_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_617_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_617_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_617_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_618_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_618_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_618_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_619_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_619_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_619_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_620_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_620_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_620_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_621_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_621_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_621_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_622_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_622_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_622_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_623_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_623_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_623_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_624_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_624_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_624_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_625_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_625_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_625_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_626_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_626_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_626_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_627_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_627_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_627_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_628_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_628_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_628_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_629_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_629_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_629_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_630_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_630_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_630_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_631_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_631_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_631_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_632_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_632_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_632_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_633_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_633_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_633_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_634_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_634_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_634_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_635_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_635_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_635_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_636_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_636_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_636_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_637_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_637_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_637_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_638_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_638_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_638_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_639_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_639_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_SECURE_ENABLE_639_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG19_RESETVAL (0x00000000u)

/* secure_enable_clr_reg20 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_640_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_640_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_640_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_641_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_641_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_641_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_642_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_642_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_642_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_643_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_643_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_643_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_644_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_644_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_644_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_645_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_645_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_645_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_646_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_646_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_646_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_647_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_647_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_647_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_648_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_648_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_648_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_649_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_649_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_649_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_650_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_650_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_650_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_651_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_651_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_651_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_652_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_652_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_652_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_653_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_653_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_653_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_654_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_654_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_654_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_655_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_655_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_655_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_656_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_656_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_656_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_657_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_657_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_657_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_658_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_658_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_658_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_659_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_659_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_659_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_660_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_660_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_660_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_661_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_661_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_661_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_662_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_662_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_662_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_663_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_663_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_663_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_664_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_664_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_664_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_665_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_665_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_665_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_666_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_666_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_666_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_667_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_667_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_667_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_668_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_668_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_668_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_669_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_669_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_669_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_670_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_670_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_670_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_671_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_671_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_SECURE_ENABLE_671_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG20_RESETVAL (0x00000000u)

/* secure_enable_clr_reg21 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_672_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_672_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_672_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_673_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_673_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_673_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_674_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_674_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_674_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_675_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_675_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_675_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_676_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_676_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_676_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_677_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_677_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_677_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_678_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_678_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_678_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_679_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_679_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_679_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_680_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_680_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_680_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_681_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_681_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_681_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_682_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_682_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_682_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_683_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_683_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_683_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_684_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_684_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_684_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_685_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_685_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_685_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_686_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_686_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_686_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_687_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_687_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_687_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_688_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_688_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_688_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_689_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_689_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_689_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_690_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_690_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_690_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_691_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_691_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_691_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_692_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_692_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_692_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_693_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_693_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_693_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_694_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_694_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_694_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_695_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_695_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_695_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_696_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_696_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_696_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_697_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_697_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_697_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_698_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_698_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_698_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_699_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_699_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_699_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_700_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_700_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_700_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_701_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_701_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_701_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_702_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_702_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_702_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_703_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_703_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_SECURE_ENABLE_703_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG21_RESETVAL (0x00000000u)

/* secure_enable_clr_reg22 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_704_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_704_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_704_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_705_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_705_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_705_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_706_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_706_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_706_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_707_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_707_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_707_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_708_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_708_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_708_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_709_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_709_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_709_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_710_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_710_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_710_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_711_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_711_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_711_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_712_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_712_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_712_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_713_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_713_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_713_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_714_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_714_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_714_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_715_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_715_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_715_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_716_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_716_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_716_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_717_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_717_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_717_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_718_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_718_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_718_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_719_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_719_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_719_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_720_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_720_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_720_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_721_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_721_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_721_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_722_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_722_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_722_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_723_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_723_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_723_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_724_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_724_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_724_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_725_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_725_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_725_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_726_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_726_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_726_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_727_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_727_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_727_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_728_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_728_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_728_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_729_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_729_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_729_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_730_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_730_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_730_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_731_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_731_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_731_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_732_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_732_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_732_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_733_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_733_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_733_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_734_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_734_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_734_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_735_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_735_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_SECURE_ENABLE_735_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG22_RESETVAL (0x00000000u)

/* secure_enable_clr_reg23 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_736_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_736_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_736_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_737_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_737_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_737_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_738_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_738_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_738_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_739_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_739_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_739_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_740_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_740_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_740_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_741_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_741_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_741_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_742_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_742_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_742_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_743_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_743_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_743_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_744_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_744_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_744_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_745_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_745_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_745_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_746_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_746_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_746_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_747_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_747_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_747_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_748_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_748_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_748_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_749_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_749_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_749_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_750_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_750_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_750_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_751_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_751_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_751_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_752_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_752_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_752_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_753_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_753_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_753_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_754_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_754_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_754_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_755_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_755_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_755_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_756_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_756_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_756_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_757_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_757_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_757_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_758_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_758_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_758_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_759_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_759_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_759_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_760_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_760_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_760_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_761_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_761_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_761_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_762_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_762_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_762_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_763_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_763_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_763_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_764_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_764_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_764_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_765_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_765_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_765_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_766_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_766_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_766_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_767_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_767_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_SECURE_ENABLE_767_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG23_RESETVAL (0x00000000u)

/* secure_enable_clr_reg24 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_768_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_768_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_768_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_769_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_769_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_769_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_770_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_770_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_770_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_771_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_771_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_771_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_772_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_772_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_772_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_773_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_773_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_773_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_774_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_774_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_774_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_775_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_775_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_775_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_776_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_776_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_776_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_777_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_777_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_777_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_778_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_778_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_778_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_779_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_779_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_779_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_780_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_780_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_780_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_781_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_781_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_781_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_782_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_782_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_782_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_783_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_783_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_783_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_784_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_784_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_784_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_785_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_785_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_785_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_786_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_786_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_786_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_787_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_787_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_787_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_788_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_788_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_788_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_789_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_789_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_789_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_790_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_790_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_790_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_791_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_791_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_791_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_792_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_792_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_792_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_793_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_793_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_793_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_794_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_794_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_794_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_795_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_795_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_795_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_796_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_796_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_796_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_797_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_797_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_797_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_798_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_798_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_798_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_799_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_799_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_SECURE_ENABLE_799_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG24_RESETVAL (0x00000000u)

/* secure_enable_clr_reg25 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_800_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_800_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_800_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_801_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_801_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_801_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_802_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_802_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_802_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_803_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_803_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_803_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_804_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_804_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_804_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_805_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_805_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_805_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_806_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_806_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_806_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_807_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_807_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_807_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_808_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_808_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_808_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_809_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_809_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_809_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_810_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_810_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_810_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_811_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_811_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_811_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_812_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_812_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_812_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_813_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_813_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_813_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_814_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_814_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_814_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_815_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_815_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_815_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_816_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_816_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_816_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_817_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_817_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_817_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_818_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_818_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_818_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_819_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_819_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_819_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_820_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_820_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_820_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_821_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_821_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_821_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_822_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_822_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_822_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_823_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_823_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_823_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_824_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_824_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_824_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_825_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_825_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_825_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_826_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_826_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_826_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_827_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_827_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_827_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_828_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_828_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_828_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_829_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_829_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_829_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_830_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_830_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_830_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_831_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_831_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_SECURE_ENABLE_831_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG25_RESETVAL (0x00000000u)

/* secure_enable_clr_reg26 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_832_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_832_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_832_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_833_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_833_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_833_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_834_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_834_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_834_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_835_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_835_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_835_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_836_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_836_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_836_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_837_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_837_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_837_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_838_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_838_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_838_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_839_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_839_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_839_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_840_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_840_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_840_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_841_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_841_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_841_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_842_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_842_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_842_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_843_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_843_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_843_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_844_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_844_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_844_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_845_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_845_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_845_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_846_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_846_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_846_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_847_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_847_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_847_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_848_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_848_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_848_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_849_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_849_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_849_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_850_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_850_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_850_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_851_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_851_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_851_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_852_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_852_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_852_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_853_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_853_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_853_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_854_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_854_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_854_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_855_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_855_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_855_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_856_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_856_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_856_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_857_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_857_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_857_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_858_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_858_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_858_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_859_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_859_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_859_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_860_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_860_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_860_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_861_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_861_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_861_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_862_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_862_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_862_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_863_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_863_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_SECURE_ENABLE_863_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG26_RESETVAL (0x00000000u)

/* secure_enable_clr_reg27 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_864_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_864_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_864_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_865_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_865_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_865_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_866_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_866_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_866_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_867_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_867_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_867_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_868_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_868_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_868_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_869_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_869_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_869_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_870_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_870_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_870_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_871_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_871_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_871_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_872_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_872_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_872_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_873_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_873_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_873_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_874_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_874_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_874_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_875_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_875_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_875_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_876_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_876_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_876_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_877_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_877_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_877_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_878_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_878_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_878_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_879_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_879_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_879_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_880_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_880_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_880_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_881_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_881_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_881_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_882_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_882_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_882_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_883_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_883_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_883_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_884_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_884_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_884_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_885_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_885_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_885_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_886_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_886_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_886_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_887_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_887_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_887_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_888_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_888_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_888_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_889_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_889_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_889_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_890_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_890_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_890_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_891_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_891_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_891_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_892_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_892_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_892_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_893_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_893_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_893_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_894_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_894_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_894_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_895_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_895_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_SECURE_ENABLE_895_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG27_RESETVAL (0x00000000u)

/* secure_enable_clr_reg28 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_896_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_896_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_896_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_897_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_897_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_897_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_898_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_898_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_898_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_899_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_899_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_899_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_900_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_900_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_900_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_901_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_901_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_901_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_902_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_902_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_902_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_903_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_903_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_903_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_904_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_904_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_904_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_905_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_905_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_905_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_906_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_906_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_906_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_907_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_907_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_907_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_908_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_908_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_908_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_909_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_909_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_909_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_910_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_910_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_910_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_911_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_911_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_911_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_912_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_912_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_912_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_913_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_913_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_913_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_914_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_914_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_914_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_915_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_915_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_915_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_916_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_916_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_916_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_917_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_917_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_917_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_918_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_918_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_918_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_919_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_919_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_919_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_920_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_920_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_920_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_921_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_921_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_921_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_922_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_922_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_922_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_923_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_923_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_923_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_924_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_924_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_924_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_925_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_925_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_925_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_926_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_926_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_926_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_927_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_927_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_SECURE_ENABLE_927_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG28_RESETVAL (0x00000000u)

/* secure_enable_clr_reg29 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_928_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_928_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_928_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_929_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_929_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_929_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_930_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_930_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_930_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_931_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_931_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_931_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_932_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_932_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_932_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_933_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_933_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_933_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_934_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_934_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_934_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_935_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_935_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_935_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_936_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_936_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_936_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_937_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_937_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_937_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_938_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_938_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_938_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_939_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_939_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_939_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_940_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_940_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_940_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_941_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_941_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_941_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_942_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_942_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_942_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_943_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_943_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_943_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_944_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_944_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_944_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_945_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_945_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_945_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_946_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_946_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_946_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_947_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_947_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_947_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_948_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_948_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_948_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_949_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_949_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_949_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_950_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_950_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_950_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_951_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_951_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_951_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_952_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_952_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_952_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_953_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_953_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_953_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_954_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_954_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_954_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_955_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_955_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_955_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_956_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_956_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_956_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_957_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_957_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_957_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_958_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_958_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_958_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_959_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_959_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_SECURE_ENABLE_959_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG29_RESETVAL (0x00000000u)

/* secure_enable_clr_reg30 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_960_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_960_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_960_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_961_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_961_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_961_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_962_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_962_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_962_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_963_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_963_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_963_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_964_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_964_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_964_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_965_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_965_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_965_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_966_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_966_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_966_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_967_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_967_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_967_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_968_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_968_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_968_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_969_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_969_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_969_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_970_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_970_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_970_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_971_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_971_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_971_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_972_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_972_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_972_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_973_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_973_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_973_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_974_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_974_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_974_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_975_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_975_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_975_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_976_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_976_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_976_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_977_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_977_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_977_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_978_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_978_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_978_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_979_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_979_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_979_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_980_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_980_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_980_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_981_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_981_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_981_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_982_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_982_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_982_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_983_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_983_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_983_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_984_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_984_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_984_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_985_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_985_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_985_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_986_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_986_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_986_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_987_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_987_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_987_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_988_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_988_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_988_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_989_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_989_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_989_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_990_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_990_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_990_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_991_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_991_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_SECURE_ENABLE_991_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG30_RESETVAL (0x00000000u)

/* secure_enable_clr_reg31 */

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_992_CLR_MASK (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_992_CLR_SHIFT (0x00000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_992_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_993_CLR_MASK (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_993_CLR_SHIFT (0x00000001u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_993_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_994_CLR_MASK (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_994_CLR_SHIFT (0x00000002u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_994_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_995_CLR_MASK (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_995_CLR_SHIFT (0x00000003u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_995_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_996_CLR_MASK (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_996_CLR_SHIFT (0x00000004u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_996_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_997_CLR_MASK (0x00000020u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_997_CLR_SHIFT (0x00000005u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_997_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_998_CLR_MASK (0x00000040u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_998_CLR_SHIFT (0x00000006u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_998_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_999_CLR_MASK (0x00000080u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_999_CLR_SHIFT (0x00000007u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_999_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1000_CLR_MASK (0x00000100u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1000_CLR_SHIFT (0x00000008u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1000_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1001_CLR_MASK (0x00000200u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1001_CLR_SHIFT (0x00000009u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1001_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1002_CLR_MASK (0x00000400u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1002_CLR_SHIFT (0x0000000Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1002_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1003_CLR_MASK (0x00000800u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1003_CLR_SHIFT (0x0000000Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1003_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1004_CLR_MASK (0x00001000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1004_CLR_SHIFT (0x0000000Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1004_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1005_CLR_MASK (0x00002000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1005_CLR_SHIFT (0x0000000Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1005_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1006_CLR_MASK (0x00004000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1006_CLR_SHIFT (0x0000000Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1006_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1007_CLR_MASK (0x00008000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1007_CLR_SHIFT (0x0000000Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1007_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1008_CLR_MASK (0x00010000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1008_CLR_SHIFT (0x00000010u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1008_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1009_CLR_MASK (0x00020000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1009_CLR_SHIFT (0x00000011u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1009_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1010_CLR_MASK (0x00040000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1010_CLR_SHIFT (0x00000012u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1010_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1011_CLR_MASK (0x00080000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1011_CLR_SHIFT (0x00000013u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1011_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1012_CLR_MASK (0x00100000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1012_CLR_SHIFT (0x00000014u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1012_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1013_CLR_MASK (0x00200000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1013_CLR_SHIFT (0x00000015u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1013_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1014_CLR_MASK (0x00400000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1014_CLR_SHIFT (0x00000016u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1014_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1015_CLR_MASK (0x00800000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1015_CLR_SHIFT (0x00000017u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1015_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1016_CLR_MASK (0x01000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1016_CLR_SHIFT (0x00000018u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1016_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1017_CLR_MASK (0x02000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1017_CLR_SHIFT (0x00000019u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1017_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1018_CLR_MASK (0x04000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1018_CLR_SHIFT (0x0000001Au)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1018_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1019_CLR_MASK (0x08000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1019_CLR_SHIFT (0x0000001Bu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1019_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1020_CLR_MASK (0x10000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1020_CLR_SHIFT (0x0000001Cu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1020_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1021_CLR_MASK (0x20000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1021_CLR_SHIFT (0x0000001Du)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1021_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1022_CLR_MASK (0x40000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1022_CLR_SHIFT (0x0000001Eu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1022_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1023_CLR_MASK (0x80000000u)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1023_CLR_SHIFT (0x0000001Fu)
#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_SECURE_ENABLE_1023_CLR_RESETVAL (0x00000000u)

#define CSL_CPINTC_SECURE_ENABLE_CLR_REG31_RESETVAL (0x00000000u)

/* nest_level_reg0 */

#define CSL_CPINTC_NEST_LEVEL_REG0_NEST_HINT_0_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG0_NEST_HINT_0_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG0_NEST_HINT_0_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG0_RESETVAL (0x00000100u)

/* nest_level_reg1 */

#define CSL_CPINTC_NEST_LEVEL_REG1_NEST_HINT_1_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG1_NEST_HINT_1_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG1_NEST_HINT_1_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG1_RESETVAL (0x00000100u)

/* nest_level_reg2 */

#define CSL_CPINTC_NEST_LEVEL_REG2_NEST_HINT_2_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG2_NEST_HINT_2_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG2_NEST_HINT_2_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG2_RESETVAL (0x00000100u)

/* nest_level_reg3 */

#define CSL_CPINTC_NEST_LEVEL_REG3_NEST_HINT_3_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG3_NEST_HINT_3_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG3_NEST_HINT_3_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG3_RESETVAL (0x00000100u)

/* nest_level_reg4 */

#define CSL_CPINTC_NEST_LEVEL_REG4_NEST_HINT_4_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG4_NEST_HINT_4_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG4_NEST_HINT_4_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG4_RESETVAL (0x00000100u)

/* nest_level_reg5 */

#define CSL_CPINTC_NEST_LEVEL_REG5_NEST_HINT_5_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG5_NEST_HINT_5_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG5_NEST_HINT_5_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG5_RESETVAL (0x00000100u)

/* nest_level_reg6 */

#define CSL_CPINTC_NEST_LEVEL_REG6_NEST_HINT_6_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG6_NEST_HINT_6_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG6_NEST_HINT_6_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG6_RESETVAL (0x00000100u)

/* nest_level_reg7 */

#define CSL_CPINTC_NEST_LEVEL_REG7_NEST_HINT_7_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG7_NEST_HINT_7_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG7_NEST_HINT_7_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG7_RESETVAL (0x00000100u)

/* nest_level_reg8 */

#define CSL_CPINTC_NEST_LEVEL_REG8_NEST_HINT_8_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG8_NEST_HINT_8_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG8_NEST_HINT_8_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG8_RESETVAL (0x00000100u)

/* nest_level_reg9 */

#define CSL_CPINTC_NEST_LEVEL_REG9_NEST_HINT_9_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG9_NEST_HINT_9_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG9_NEST_HINT_9_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG9_RESETVAL (0x00000100u)

/* nest_level_reg10 */

#define CSL_CPINTC_NEST_LEVEL_REG10_NEST_HINT_10_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG10_NEST_HINT_10_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG10_NEST_HINT_10_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG10_RESETVAL (0x00000100u)

/* nest_level_reg11 */

#define CSL_CPINTC_NEST_LEVEL_REG11_NEST_HINT_11_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG11_NEST_HINT_11_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG11_NEST_HINT_11_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG11_RESETVAL (0x00000100u)

/* nest_level_reg12 */

#define CSL_CPINTC_NEST_LEVEL_REG12_NEST_HINT_12_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG12_NEST_HINT_12_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG12_NEST_HINT_12_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG12_RESETVAL (0x00000100u)

/* nest_level_reg13 */

#define CSL_CPINTC_NEST_LEVEL_REG13_NEST_HINT_13_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG13_NEST_HINT_13_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG13_NEST_HINT_13_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG13_RESETVAL (0x00000100u)

/* nest_level_reg14 */

#define CSL_CPINTC_NEST_LEVEL_REG14_NEST_HINT_14_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG14_NEST_HINT_14_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG14_NEST_HINT_14_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG14_RESETVAL (0x00000100u)

/* nest_level_reg15 */

#define CSL_CPINTC_NEST_LEVEL_REG15_NEST_HINT_15_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG15_NEST_HINT_15_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG15_NEST_HINT_15_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG15_RESETVAL (0x00000100u)

/* nest_level_reg16 */

#define CSL_CPINTC_NEST_LEVEL_REG16_NEST_HINT_16_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG16_NEST_HINT_16_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG16_NEST_HINT_16_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG16_RESETVAL (0x00000100u)

/* nest_level_reg17 */

#define CSL_CPINTC_NEST_LEVEL_REG17_NEST_HINT_17_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG17_NEST_HINT_17_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG17_NEST_HINT_17_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG17_RESETVAL (0x00000100u)

/* nest_level_reg18 */

#define CSL_CPINTC_NEST_LEVEL_REG18_NEST_HINT_18_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG18_NEST_HINT_18_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG18_NEST_HINT_18_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG18_RESETVAL (0x00000100u)

/* nest_level_reg19 */

#define CSL_CPINTC_NEST_LEVEL_REG19_NEST_HINT_19_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG19_NEST_HINT_19_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG19_NEST_HINT_19_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG19_RESETVAL (0x00000100u)

/* nest_level_reg20 */

#define CSL_CPINTC_NEST_LEVEL_REG20_NEST_HINT_20_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG20_NEST_HINT_20_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG20_NEST_HINT_20_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG20_RESETVAL (0x00000100u)

/* nest_level_reg21 */

#define CSL_CPINTC_NEST_LEVEL_REG21_NEST_HINT_21_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG21_NEST_HINT_21_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG21_NEST_HINT_21_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG21_RESETVAL (0x00000100u)

/* nest_level_reg22 */

#define CSL_CPINTC_NEST_LEVEL_REG22_NEST_HINT_22_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG22_NEST_HINT_22_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG22_NEST_HINT_22_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG22_RESETVAL (0x00000100u)

/* nest_level_reg23 */

#define CSL_CPINTC_NEST_LEVEL_REG23_NEST_HINT_23_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG23_NEST_HINT_23_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG23_NEST_HINT_23_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG23_RESETVAL (0x00000100u)

/* nest_level_reg24 */

#define CSL_CPINTC_NEST_LEVEL_REG24_NEST_HINT_24_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG24_NEST_HINT_24_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG24_NEST_HINT_24_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG24_RESETVAL (0x00000100u)

/* nest_level_reg25 */

#define CSL_CPINTC_NEST_LEVEL_REG25_NEST_HINT_25_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG25_NEST_HINT_25_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG25_NEST_HINT_25_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG25_RESETVAL (0x00000100u)

/* nest_level_reg26 */

#define CSL_CPINTC_NEST_LEVEL_REG26_NEST_HINT_26_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG26_NEST_HINT_26_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG26_NEST_HINT_26_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG26_RESETVAL (0x00000100u)

/* nest_level_reg27 */

#define CSL_CPINTC_NEST_LEVEL_REG27_NEST_HINT_27_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG27_NEST_HINT_27_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG27_NEST_HINT_27_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG27_RESETVAL (0x00000100u)

/* nest_level_reg28 */

#define CSL_CPINTC_NEST_LEVEL_REG28_NEST_HINT_28_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG28_NEST_HINT_28_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG28_NEST_HINT_28_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG28_RESETVAL (0x00000100u)

/* nest_level_reg29 */

#define CSL_CPINTC_NEST_LEVEL_REG29_NEST_HINT_29_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG29_NEST_HINT_29_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG29_NEST_HINT_29_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG29_RESETVAL (0x00000100u)

/* nest_level_reg30 */

#define CSL_CPINTC_NEST_LEVEL_REG30_NEST_HINT_30_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG30_NEST_HINT_30_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG30_NEST_HINT_30_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG30_RESETVAL (0x00000100u)

/* nest_level_reg31 */

#define CSL_CPINTC_NEST_LEVEL_REG31_NEST_HINT_31_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG31_NEST_HINT_31_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG31_NEST_HINT_31_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG31_RESETVAL (0x00000100u)

/* nest_level_reg32 */

#define CSL_CPINTC_NEST_LEVEL_REG32_NEST_HINT_32_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG32_NEST_HINT_32_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG32_NEST_HINT_32_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG32_RESETVAL (0x00000100u)

/* nest_level_reg33 */

#define CSL_CPINTC_NEST_LEVEL_REG33_NEST_HINT_33_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG33_NEST_HINT_33_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG33_NEST_HINT_33_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG33_RESETVAL (0x00000100u)

/* nest_level_reg34 */

#define CSL_CPINTC_NEST_LEVEL_REG34_NEST_HINT_34_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG34_NEST_HINT_34_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG34_NEST_HINT_34_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG34_RESETVAL (0x00000100u)

/* nest_level_reg35 */

#define CSL_CPINTC_NEST_LEVEL_REG35_NEST_HINT_35_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG35_NEST_HINT_35_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG35_NEST_HINT_35_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG35_RESETVAL (0x00000100u)

/* nest_level_reg36 */

#define CSL_CPINTC_NEST_LEVEL_REG36_NEST_HINT_36_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG36_NEST_HINT_36_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG36_NEST_HINT_36_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG36_RESETVAL (0x00000100u)

/* nest_level_reg37 */

#define CSL_CPINTC_NEST_LEVEL_REG37_NEST_HINT_37_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG37_NEST_HINT_37_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG37_NEST_HINT_37_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG37_RESETVAL (0x00000100u)

/* nest_level_reg38 */

#define CSL_CPINTC_NEST_LEVEL_REG38_NEST_HINT_38_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG38_NEST_HINT_38_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG38_NEST_HINT_38_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG38_RESETVAL (0x00000100u)

/* nest_level_reg39 */

#define CSL_CPINTC_NEST_LEVEL_REG39_NEST_HINT_39_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG39_NEST_HINT_39_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG39_NEST_HINT_39_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG39_RESETVAL (0x00000100u)

/* nest_level_reg40 */

#define CSL_CPINTC_NEST_LEVEL_REG40_NEST_HINT_40_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG40_NEST_HINT_40_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG40_NEST_HINT_40_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG40_RESETVAL (0x00000100u)

/* nest_level_reg41 */

#define CSL_CPINTC_NEST_LEVEL_REG41_NEST_HINT_41_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG41_NEST_HINT_41_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG41_NEST_HINT_41_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG41_RESETVAL (0x00000100u)

/* nest_level_reg42 */

#define CSL_CPINTC_NEST_LEVEL_REG42_NEST_HINT_42_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG42_NEST_HINT_42_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG42_NEST_HINT_42_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG42_RESETVAL (0x00000100u)

/* nest_level_reg43 */

#define CSL_CPINTC_NEST_LEVEL_REG43_NEST_HINT_43_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG43_NEST_HINT_43_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG43_NEST_HINT_43_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG43_RESETVAL (0x00000100u)

/* nest_level_reg44 */

#define CSL_CPINTC_NEST_LEVEL_REG44_NEST_HINT_44_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG44_NEST_HINT_44_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG44_NEST_HINT_44_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG44_RESETVAL (0x00000100u)

/* nest_level_reg45 */

#define CSL_CPINTC_NEST_LEVEL_REG45_NEST_HINT_45_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG45_NEST_HINT_45_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG45_NEST_HINT_45_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG45_RESETVAL (0x00000100u)

/* nest_level_reg46 */

#define CSL_CPINTC_NEST_LEVEL_REG46_NEST_HINT_46_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG46_NEST_HINT_46_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG46_NEST_HINT_46_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG46_RESETVAL (0x00000100u)

/* nest_level_reg47 */

#define CSL_CPINTC_NEST_LEVEL_REG47_NEST_HINT_47_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG47_NEST_HINT_47_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG47_NEST_HINT_47_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG47_RESETVAL (0x00000100u)

/* nest_level_reg48 */

#define CSL_CPINTC_NEST_LEVEL_REG48_NEST_HINT_48_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG48_NEST_HINT_48_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG48_NEST_HINT_48_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG48_RESETVAL (0x00000100u)

/* nest_level_reg49 */

#define CSL_CPINTC_NEST_LEVEL_REG49_NEST_HINT_49_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG49_NEST_HINT_49_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG49_NEST_HINT_49_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG49_RESETVAL (0x00000100u)

/* nest_level_reg50 */

#define CSL_CPINTC_NEST_LEVEL_REG50_NEST_HINT_50_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG50_NEST_HINT_50_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG50_NEST_HINT_50_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG50_RESETVAL (0x00000100u)

/* nest_level_reg51 */

#define CSL_CPINTC_NEST_LEVEL_REG51_NEST_HINT_51_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG51_NEST_HINT_51_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG51_NEST_HINT_51_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG51_RESETVAL (0x00000100u)

/* nest_level_reg52 */

#define CSL_CPINTC_NEST_LEVEL_REG52_NEST_HINT_52_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG52_NEST_HINT_52_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG52_NEST_HINT_52_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG52_RESETVAL (0x00000100u)

/* nest_level_reg53 */

#define CSL_CPINTC_NEST_LEVEL_REG53_NEST_HINT_53_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG53_NEST_HINT_53_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG53_NEST_HINT_53_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG53_RESETVAL (0x00000100u)

/* nest_level_reg54 */

#define CSL_CPINTC_NEST_LEVEL_REG54_NEST_HINT_54_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG54_NEST_HINT_54_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG54_NEST_HINT_54_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG54_RESETVAL (0x00000100u)

/* nest_level_reg55 */

#define CSL_CPINTC_NEST_LEVEL_REG55_NEST_HINT_55_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG55_NEST_HINT_55_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG55_NEST_HINT_55_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG55_RESETVAL (0x00000100u)

/* nest_level_reg56 */

#define CSL_CPINTC_NEST_LEVEL_REG56_NEST_HINT_56_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG56_NEST_HINT_56_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG56_NEST_HINT_56_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG56_RESETVAL (0x00000100u)

/* nest_level_reg57 */

#define CSL_CPINTC_NEST_LEVEL_REG57_NEST_HINT_57_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG57_NEST_HINT_57_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG57_NEST_HINT_57_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG57_RESETVAL (0x00000100u)

/* nest_level_reg58 */

#define CSL_CPINTC_NEST_LEVEL_REG58_NEST_HINT_58_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG58_NEST_HINT_58_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG58_NEST_HINT_58_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG58_RESETVAL (0x00000100u)

/* nest_level_reg59 */

#define CSL_CPINTC_NEST_LEVEL_REG59_NEST_HINT_59_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG59_NEST_HINT_59_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG59_NEST_HINT_59_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG59_RESETVAL (0x00000100u)

/* nest_level_reg60 */

#define CSL_CPINTC_NEST_LEVEL_REG60_NEST_HINT_60_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG60_NEST_HINT_60_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG60_NEST_HINT_60_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG60_RESETVAL (0x00000100u)

/* nest_level_reg61 */

#define CSL_CPINTC_NEST_LEVEL_REG61_NEST_HINT_61_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG61_NEST_HINT_61_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG61_NEST_HINT_61_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG61_RESETVAL (0x00000100u)

/* nest_level_reg62 */

#define CSL_CPINTC_NEST_LEVEL_REG62_NEST_HINT_62_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG62_NEST_HINT_62_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG62_NEST_HINT_62_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG62_RESETVAL (0x00000100u)

/* nest_level_reg63 */

#define CSL_CPINTC_NEST_LEVEL_REG63_NEST_HINT_63_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG63_NEST_HINT_63_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG63_NEST_HINT_63_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG63_RESETVAL (0x00000100u)

/* nest_level_reg64 */

#define CSL_CPINTC_NEST_LEVEL_REG64_NEST_HINT_64_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG64_NEST_HINT_64_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG64_NEST_HINT_64_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG64_RESETVAL (0x00000100u)

/* nest_level_reg65 */

#define CSL_CPINTC_NEST_LEVEL_REG65_NEST_HINT_65_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG65_NEST_HINT_65_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG65_NEST_HINT_65_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG65_RESETVAL (0x00000100u)

/* nest_level_reg66 */

#define CSL_CPINTC_NEST_LEVEL_REG66_NEST_HINT_66_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG66_NEST_HINT_66_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG66_NEST_HINT_66_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG66_RESETVAL (0x00000100u)

/* nest_level_reg67 */

#define CSL_CPINTC_NEST_LEVEL_REG67_NEST_HINT_67_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG67_NEST_HINT_67_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG67_NEST_HINT_67_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG67_RESETVAL (0x00000100u)

/* nest_level_reg68 */

#define CSL_CPINTC_NEST_LEVEL_REG68_NEST_HINT_68_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG68_NEST_HINT_68_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG68_NEST_HINT_68_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG68_RESETVAL (0x00000100u)

/* nest_level_reg69 */

#define CSL_CPINTC_NEST_LEVEL_REG69_NEST_HINT_69_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG69_NEST_HINT_69_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG69_NEST_HINT_69_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG69_RESETVAL (0x00000100u)

/* nest_level_reg70 */

#define CSL_CPINTC_NEST_LEVEL_REG70_NEST_HINT_70_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG70_NEST_HINT_70_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG70_NEST_HINT_70_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG70_RESETVAL (0x00000100u)

/* nest_level_reg71 */

#define CSL_CPINTC_NEST_LEVEL_REG71_NEST_HINT_71_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG71_NEST_HINT_71_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG71_NEST_HINT_71_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG71_RESETVAL (0x00000100u)

/* nest_level_reg72 */

#define CSL_CPINTC_NEST_LEVEL_REG72_NEST_HINT_72_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG72_NEST_HINT_72_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG72_NEST_HINT_72_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG72_RESETVAL (0x00000100u)

/* nest_level_reg73 */

#define CSL_CPINTC_NEST_LEVEL_REG73_NEST_HINT_73_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG73_NEST_HINT_73_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG73_NEST_HINT_73_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG73_RESETVAL (0x00000100u)

/* nest_level_reg74 */

#define CSL_CPINTC_NEST_LEVEL_REG74_NEST_HINT_74_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG74_NEST_HINT_74_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG74_NEST_HINT_74_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG74_RESETVAL (0x00000100u)

/* nest_level_reg75 */

#define CSL_CPINTC_NEST_LEVEL_REG75_NEST_HINT_75_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG75_NEST_HINT_75_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG75_NEST_HINT_75_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG75_RESETVAL (0x00000100u)

/* nest_level_reg76 */

#define CSL_CPINTC_NEST_LEVEL_REG76_NEST_HINT_76_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG76_NEST_HINT_76_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG76_NEST_HINT_76_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG76_RESETVAL (0x00000100u)

/* nest_level_reg77 */

#define CSL_CPINTC_NEST_LEVEL_REG77_NEST_HINT_77_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG77_NEST_HINT_77_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG77_NEST_HINT_77_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG77_RESETVAL (0x00000100u)

/* nest_level_reg78 */

#define CSL_CPINTC_NEST_LEVEL_REG78_NEST_HINT_78_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG78_NEST_HINT_78_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG78_NEST_HINT_78_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG78_RESETVAL (0x00000100u)

/* nest_level_reg79 */

#define CSL_CPINTC_NEST_LEVEL_REG79_NEST_HINT_79_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG79_NEST_HINT_79_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG79_NEST_HINT_79_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG79_RESETVAL (0x00000100u)

/* nest_level_reg80 */

#define CSL_CPINTC_NEST_LEVEL_REG80_NEST_HINT_80_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG80_NEST_HINT_80_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG80_NEST_HINT_80_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG80_RESETVAL (0x00000100u)

/* nest_level_reg81 */

#define CSL_CPINTC_NEST_LEVEL_REG81_NEST_HINT_81_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG81_NEST_HINT_81_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG81_NEST_HINT_81_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG81_RESETVAL (0x00000100u)

/* nest_level_reg82 */

#define CSL_CPINTC_NEST_LEVEL_REG82_NEST_HINT_82_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG82_NEST_HINT_82_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG82_NEST_HINT_82_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG82_RESETVAL (0x00000100u)

/* nest_level_reg83 */

#define CSL_CPINTC_NEST_LEVEL_REG83_NEST_HINT_83_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG83_NEST_HINT_83_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG83_NEST_HINT_83_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG83_RESETVAL (0x00000100u)

/* nest_level_reg84 */

#define CSL_CPINTC_NEST_LEVEL_REG84_NEST_HINT_84_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG84_NEST_HINT_84_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG84_NEST_HINT_84_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG84_RESETVAL (0x00000100u)

/* nest_level_reg85 */

#define CSL_CPINTC_NEST_LEVEL_REG85_NEST_HINT_85_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG85_NEST_HINT_85_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG85_NEST_HINT_85_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG85_RESETVAL (0x00000100u)

/* nest_level_reg86 */

#define CSL_CPINTC_NEST_LEVEL_REG86_NEST_HINT_86_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG86_NEST_HINT_86_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG86_NEST_HINT_86_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG86_RESETVAL (0x00000100u)

/* nest_level_reg87 */

#define CSL_CPINTC_NEST_LEVEL_REG87_NEST_HINT_87_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG87_NEST_HINT_87_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG87_NEST_HINT_87_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG87_RESETVAL (0x00000100u)

/* nest_level_reg88 */

#define CSL_CPINTC_NEST_LEVEL_REG88_NEST_HINT_88_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG88_NEST_HINT_88_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG88_NEST_HINT_88_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG88_RESETVAL (0x00000100u)

/* nest_level_reg89 */

#define CSL_CPINTC_NEST_LEVEL_REG89_NEST_HINT_89_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG89_NEST_HINT_89_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG89_NEST_HINT_89_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG89_RESETVAL (0x00000100u)

/* nest_level_reg90 */

#define CSL_CPINTC_NEST_LEVEL_REG90_NEST_HINT_90_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG90_NEST_HINT_90_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG90_NEST_HINT_90_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG90_RESETVAL (0x00000100u)

/* nest_level_reg91 */

#define CSL_CPINTC_NEST_LEVEL_REG91_NEST_HINT_91_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG91_NEST_HINT_91_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG91_NEST_HINT_91_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG91_RESETVAL (0x00000100u)

/* nest_level_reg92 */

#define CSL_CPINTC_NEST_LEVEL_REG92_NEST_HINT_92_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG92_NEST_HINT_92_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG92_NEST_HINT_92_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG92_RESETVAL (0x00000100u)

/* nest_level_reg93 */

#define CSL_CPINTC_NEST_LEVEL_REG93_NEST_HINT_93_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG93_NEST_HINT_93_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG93_NEST_HINT_93_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG93_RESETVAL (0x00000100u)

/* nest_level_reg94 */

#define CSL_CPINTC_NEST_LEVEL_REG94_NEST_HINT_94_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG94_NEST_HINT_94_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG94_NEST_HINT_94_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG94_RESETVAL (0x00000100u)

/* nest_level_reg95 */

#define CSL_CPINTC_NEST_LEVEL_REG95_NEST_HINT_95_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG95_NEST_HINT_95_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG95_NEST_HINT_95_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG95_RESETVAL (0x00000100u)

/* nest_level_reg96 */

#define CSL_CPINTC_NEST_LEVEL_REG96_NEST_HINT_96_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG96_NEST_HINT_96_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG96_NEST_HINT_96_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG96_RESETVAL (0x00000100u)

/* nest_level_reg97 */

#define CSL_CPINTC_NEST_LEVEL_REG97_NEST_HINT_97_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG97_NEST_HINT_97_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG97_NEST_HINT_97_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG97_RESETVAL (0x00000100u)

/* nest_level_reg98 */

#define CSL_CPINTC_NEST_LEVEL_REG98_NEST_HINT_98_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG98_NEST_HINT_98_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG98_NEST_HINT_98_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG98_RESETVAL (0x00000100u)

/* nest_level_reg99 */

#define CSL_CPINTC_NEST_LEVEL_REG99_NEST_HINT_99_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG99_NEST_HINT_99_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG99_NEST_HINT_99_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG99_RESETVAL (0x00000100u)

/* nest_level_reg100 */

#define CSL_CPINTC_NEST_LEVEL_REG100_NEST_HINT_100_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG100_NEST_HINT_100_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG100_NEST_HINT_100_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG100_RESETVAL (0x00000100u)

/* nest_level_reg101 */

#define CSL_CPINTC_NEST_LEVEL_REG101_NEST_HINT_101_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG101_NEST_HINT_101_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG101_NEST_HINT_101_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG101_RESETVAL (0x00000100u)

/* nest_level_reg102 */

#define CSL_CPINTC_NEST_LEVEL_REG102_NEST_HINT_102_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG102_NEST_HINT_102_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG102_NEST_HINT_102_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG102_RESETVAL (0x00000100u)

/* nest_level_reg103 */

#define CSL_CPINTC_NEST_LEVEL_REG103_NEST_HINT_103_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG103_NEST_HINT_103_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG103_NEST_HINT_103_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG103_RESETVAL (0x00000100u)

/* nest_level_reg104 */

#define CSL_CPINTC_NEST_LEVEL_REG104_NEST_HINT_104_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG104_NEST_HINT_104_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG104_NEST_HINT_104_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG104_RESETVAL (0x00000100u)

/* nest_level_reg105 */

#define CSL_CPINTC_NEST_LEVEL_REG105_NEST_HINT_105_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG105_NEST_HINT_105_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG105_NEST_HINT_105_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG105_RESETVAL (0x00000100u)

/* nest_level_reg106 */

#define CSL_CPINTC_NEST_LEVEL_REG106_NEST_HINT_106_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG106_NEST_HINT_106_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG106_NEST_HINT_106_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG106_RESETVAL (0x00000100u)

/* nest_level_reg107 */

#define CSL_CPINTC_NEST_LEVEL_REG107_NEST_HINT_107_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG107_NEST_HINT_107_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG107_NEST_HINT_107_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG107_RESETVAL (0x00000100u)

/* nest_level_reg108 */

#define CSL_CPINTC_NEST_LEVEL_REG108_NEST_HINT_108_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG108_NEST_HINT_108_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG108_NEST_HINT_108_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG108_RESETVAL (0x00000100u)

/* nest_level_reg109 */

#define CSL_CPINTC_NEST_LEVEL_REG109_NEST_HINT_109_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG109_NEST_HINT_109_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG109_NEST_HINT_109_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG109_RESETVAL (0x00000100u)

/* nest_level_reg110 */

#define CSL_CPINTC_NEST_LEVEL_REG110_NEST_HINT_110_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG110_NEST_HINT_110_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG110_NEST_HINT_110_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG110_RESETVAL (0x00000100u)

/* nest_level_reg111 */

#define CSL_CPINTC_NEST_LEVEL_REG111_NEST_HINT_111_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG111_NEST_HINT_111_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG111_NEST_HINT_111_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG111_RESETVAL (0x00000100u)

/* nest_level_reg112 */

#define CSL_CPINTC_NEST_LEVEL_REG112_NEST_HINT_112_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG112_NEST_HINT_112_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG112_NEST_HINT_112_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG112_RESETVAL (0x00000100u)

/* nest_level_reg113 */

#define CSL_CPINTC_NEST_LEVEL_REG113_NEST_HINT_113_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG113_NEST_HINT_113_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG113_NEST_HINT_113_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG113_RESETVAL (0x00000100u)

/* nest_level_reg114 */

#define CSL_CPINTC_NEST_LEVEL_REG114_NEST_HINT_114_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG114_NEST_HINT_114_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG114_NEST_HINT_114_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG114_RESETVAL (0x00000100u)

/* nest_level_reg115 */

#define CSL_CPINTC_NEST_LEVEL_REG115_NEST_HINT_115_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG115_NEST_HINT_115_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG115_NEST_HINT_115_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG115_RESETVAL (0x00000100u)

/* nest_level_reg116 */

#define CSL_CPINTC_NEST_LEVEL_REG116_NEST_HINT_116_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG116_NEST_HINT_116_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG116_NEST_HINT_116_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG116_RESETVAL (0x00000100u)

/* nest_level_reg117 */

#define CSL_CPINTC_NEST_LEVEL_REG117_NEST_HINT_117_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG117_NEST_HINT_117_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG117_NEST_HINT_117_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG117_RESETVAL (0x00000100u)

/* nest_level_reg118 */

#define CSL_CPINTC_NEST_LEVEL_REG118_NEST_HINT_118_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG118_NEST_HINT_118_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG118_NEST_HINT_118_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG118_RESETVAL (0x00000100u)

/* nest_level_reg119 */

#define CSL_CPINTC_NEST_LEVEL_REG119_NEST_HINT_119_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG119_NEST_HINT_119_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG119_NEST_HINT_119_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG119_RESETVAL (0x00000100u)

/* nest_level_reg120 */

#define CSL_CPINTC_NEST_LEVEL_REG120_NEST_HINT_120_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG120_NEST_HINT_120_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG120_NEST_HINT_120_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG120_RESETVAL (0x00000100u)

/* nest_level_reg121 */

#define CSL_CPINTC_NEST_LEVEL_REG121_NEST_HINT_121_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG121_NEST_HINT_121_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG121_NEST_HINT_121_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG121_RESETVAL (0x00000100u)

/* nest_level_reg122 */

#define CSL_CPINTC_NEST_LEVEL_REG122_NEST_HINT_122_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG122_NEST_HINT_122_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG122_NEST_HINT_122_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG122_RESETVAL (0x00000100u)

/* nest_level_reg123 */

#define CSL_CPINTC_NEST_LEVEL_REG123_NEST_HINT_123_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG123_NEST_HINT_123_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG123_NEST_HINT_123_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG123_RESETVAL (0x00000100u)

/* nest_level_reg124 */

#define CSL_CPINTC_NEST_LEVEL_REG124_NEST_HINT_124_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG124_NEST_HINT_124_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG124_NEST_HINT_124_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG124_RESETVAL (0x00000100u)

/* nest_level_reg125 */

#define CSL_CPINTC_NEST_LEVEL_REG125_NEST_HINT_125_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG125_NEST_HINT_125_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG125_NEST_HINT_125_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG125_RESETVAL (0x00000100u)

/* nest_level_reg126 */

#define CSL_CPINTC_NEST_LEVEL_REG126_NEST_HINT_126_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG126_NEST_HINT_126_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG126_NEST_HINT_126_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG126_RESETVAL (0x00000100u)

/* nest_level_reg127 */

#define CSL_CPINTC_NEST_LEVEL_REG127_NEST_HINT_127_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG127_NEST_HINT_127_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG127_NEST_HINT_127_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG127_RESETVAL (0x00000100u)

/* nest_level_reg128 */

#define CSL_CPINTC_NEST_LEVEL_REG128_NEST_HINT_128_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG128_NEST_HINT_128_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG128_NEST_HINT_128_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG128_RESETVAL (0x00000100u)

/* nest_level_reg129 */

#define CSL_CPINTC_NEST_LEVEL_REG129_NEST_HINT_129_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG129_NEST_HINT_129_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG129_NEST_HINT_129_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG129_RESETVAL (0x00000100u)

/* nest_level_reg130 */

#define CSL_CPINTC_NEST_LEVEL_REG130_NEST_HINT_130_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG130_NEST_HINT_130_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG130_NEST_HINT_130_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG130_RESETVAL (0x00000100u)

/* nest_level_reg131 */

#define CSL_CPINTC_NEST_LEVEL_REG131_NEST_HINT_131_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG131_NEST_HINT_131_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG131_NEST_HINT_131_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG131_RESETVAL (0x00000100u)

/* nest_level_reg132 */

#define CSL_CPINTC_NEST_LEVEL_REG132_NEST_HINT_132_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG132_NEST_HINT_132_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG132_NEST_HINT_132_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG132_RESETVAL (0x00000100u)

/* nest_level_reg133 */

#define CSL_CPINTC_NEST_LEVEL_REG133_NEST_HINT_133_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG133_NEST_HINT_133_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG133_NEST_HINT_133_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG133_RESETVAL (0x00000100u)

/* nest_level_reg134 */

#define CSL_CPINTC_NEST_LEVEL_REG134_NEST_HINT_134_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG134_NEST_HINT_134_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG134_NEST_HINT_134_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG134_RESETVAL (0x00000100u)

/* nest_level_reg135 */

#define CSL_CPINTC_NEST_LEVEL_REG135_NEST_HINT_135_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG135_NEST_HINT_135_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG135_NEST_HINT_135_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG135_RESETVAL (0x00000100u)

/* nest_level_reg136 */

#define CSL_CPINTC_NEST_LEVEL_REG136_NEST_HINT_136_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG136_NEST_HINT_136_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG136_NEST_HINT_136_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG136_RESETVAL (0x00000100u)

/* nest_level_reg137 */

#define CSL_CPINTC_NEST_LEVEL_REG137_NEST_HINT_137_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG137_NEST_HINT_137_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG137_NEST_HINT_137_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG137_RESETVAL (0x00000100u)

/* nest_level_reg138 */

#define CSL_CPINTC_NEST_LEVEL_REG138_NEST_HINT_138_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG138_NEST_HINT_138_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG138_NEST_HINT_138_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG138_RESETVAL (0x00000100u)

/* nest_level_reg139 */

#define CSL_CPINTC_NEST_LEVEL_REG139_NEST_HINT_139_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG139_NEST_HINT_139_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG139_NEST_HINT_139_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG139_RESETVAL (0x00000100u)

/* nest_level_reg140 */

#define CSL_CPINTC_NEST_LEVEL_REG140_NEST_HINT_140_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG140_NEST_HINT_140_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG140_NEST_HINT_140_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG140_RESETVAL (0x00000100u)

/* nest_level_reg141 */

#define CSL_CPINTC_NEST_LEVEL_REG141_NEST_HINT_141_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG141_NEST_HINT_141_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG141_NEST_HINT_141_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG141_RESETVAL (0x00000100u)

/* nest_level_reg142 */

#define CSL_CPINTC_NEST_LEVEL_REG142_NEST_HINT_142_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG142_NEST_HINT_142_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG142_NEST_HINT_142_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG142_RESETVAL (0x00000100u)

/* nest_level_reg143 */

#define CSL_CPINTC_NEST_LEVEL_REG143_NEST_HINT_143_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG143_NEST_HINT_143_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG143_NEST_HINT_143_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG143_RESETVAL (0x00000100u)

/* nest_level_reg144 */

#define CSL_CPINTC_NEST_LEVEL_REG144_NEST_HINT_144_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG144_NEST_HINT_144_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG144_NEST_HINT_144_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG144_RESETVAL (0x00000100u)

/* nest_level_reg145 */

#define CSL_CPINTC_NEST_LEVEL_REG145_NEST_HINT_145_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG145_NEST_HINT_145_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG145_NEST_HINT_145_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG145_RESETVAL (0x00000100u)

/* nest_level_reg146 */

#define CSL_CPINTC_NEST_LEVEL_REG146_NEST_HINT_146_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG146_NEST_HINT_146_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG146_NEST_HINT_146_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG146_RESETVAL (0x00000100u)

/* nest_level_reg147 */

#define CSL_CPINTC_NEST_LEVEL_REG147_NEST_HINT_147_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG147_NEST_HINT_147_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG147_NEST_HINT_147_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG147_RESETVAL (0x00000100u)

/* nest_level_reg148 */

#define CSL_CPINTC_NEST_LEVEL_REG148_NEST_HINT_148_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG148_NEST_HINT_148_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG148_NEST_HINT_148_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG148_RESETVAL (0x00000100u)

/* nest_level_reg149 */

#define CSL_CPINTC_NEST_LEVEL_REG149_NEST_HINT_149_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG149_NEST_HINT_149_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG149_NEST_HINT_149_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG149_RESETVAL (0x00000100u)

/* nest_level_reg150 */

#define CSL_CPINTC_NEST_LEVEL_REG150_NEST_HINT_150_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG150_NEST_HINT_150_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG150_NEST_HINT_150_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG150_RESETVAL (0x00000100u)

/* nest_level_reg151 */

#define CSL_CPINTC_NEST_LEVEL_REG151_NEST_HINT_151_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG151_NEST_HINT_151_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG151_NEST_HINT_151_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG151_RESETVAL (0x00000100u)

/* nest_level_reg152 */

#define CSL_CPINTC_NEST_LEVEL_REG152_NEST_HINT_152_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG152_NEST_HINT_152_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG152_NEST_HINT_152_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG152_RESETVAL (0x00000100u)

/* nest_level_reg153 */

#define CSL_CPINTC_NEST_LEVEL_REG153_NEST_HINT_153_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG153_NEST_HINT_153_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG153_NEST_HINT_153_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG153_RESETVAL (0x00000100u)

/* nest_level_reg154 */

#define CSL_CPINTC_NEST_LEVEL_REG154_NEST_HINT_154_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG154_NEST_HINT_154_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG154_NEST_HINT_154_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG154_RESETVAL (0x00000100u)

/* nest_level_reg155 */

#define CSL_CPINTC_NEST_LEVEL_REG155_NEST_HINT_155_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG155_NEST_HINT_155_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG155_NEST_HINT_155_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG155_RESETVAL (0x00000100u)

/* nest_level_reg156 */

#define CSL_CPINTC_NEST_LEVEL_REG156_NEST_HINT_156_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG156_NEST_HINT_156_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG156_NEST_HINT_156_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG156_RESETVAL (0x00000100u)

/* nest_level_reg157 */

#define CSL_CPINTC_NEST_LEVEL_REG157_NEST_HINT_157_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG157_NEST_HINT_157_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG157_NEST_HINT_157_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG157_RESETVAL (0x00000100u)

/* nest_level_reg158 */

#define CSL_CPINTC_NEST_LEVEL_REG158_NEST_HINT_158_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG158_NEST_HINT_158_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG158_NEST_HINT_158_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG158_RESETVAL (0x00000100u)

/* nest_level_reg159 */

#define CSL_CPINTC_NEST_LEVEL_REG159_NEST_HINT_159_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG159_NEST_HINT_159_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG159_NEST_HINT_159_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG159_RESETVAL (0x00000100u)

/* nest_level_reg160 */

#define CSL_CPINTC_NEST_LEVEL_REG160_NEST_HINT_160_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG160_NEST_HINT_160_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG160_NEST_HINT_160_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG160_RESETVAL (0x00000100u)

/* nest_level_reg161 */

#define CSL_CPINTC_NEST_LEVEL_REG161_NEST_HINT_161_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG161_NEST_HINT_161_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG161_NEST_HINT_161_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG161_RESETVAL (0x00000100u)

/* nest_level_reg162 */

#define CSL_CPINTC_NEST_LEVEL_REG162_NEST_HINT_162_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG162_NEST_HINT_162_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG162_NEST_HINT_162_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG162_RESETVAL (0x00000100u)

/* nest_level_reg163 */

#define CSL_CPINTC_NEST_LEVEL_REG163_NEST_HINT_163_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG163_NEST_HINT_163_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG163_NEST_HINT_163_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG163_RESETVAL (0x00000100u)

/* nest_level_reg164 */

#define CSL_CPINTC_NEST_LEVEL_REG164_NEST_HINT_164_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG164_NEST_HINT_164_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG164_NEST_HINT_164_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG164_RESETVAL (0x00000100u)

/* nest_level_reg165 */

#define CSL_CPINTC_NEST_LEVEL_REG165_NEST_HINT_165_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG165_NEST_HINT_165_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG165_NEST_HINT_165_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG165_RESETVAL (0x00000100u)

/* nest_level_reg166 */

#define CSL_CPINTC_NEST_LEVEL_REG166_NEST_HINT_166_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG166_NEST_HINT_166_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG166_NEST_HINT_166_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG166_RESETVAL (0x00000100u)

/* nest_level_reg167 */

#define CSL_CPINTC_NEST_LEVEL_REG167_NEST_HINT_167_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG167_NEST_HINT_167_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG167_NEST_HINT_167_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG167_RESETVAL (0x00000100u)

/* nest_level_reg168 */

#define CSL_CPINTC_NEST_LEVEL_REG168_NEST_HINT_168_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG168_NEST_HINT_168_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG168_NEST_HINT_168_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG168_RESETVAL (0x00000100u)

/* nest_level_reg169 */

#define CSL_CPINTC_NEST_LEVEL_REG169_NEST_HINT_169_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG169_NEST_HINT_169_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG169_NEST_HINT_169_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG169_RESETVAL (0x00000100u)

/* nest_level_reg170 */

#define CSL_CPINTC_NEST_LEVEL_REG170_NEST_HINT_170_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG170_NEST_HINT_170_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG170_NEST_HINT_170_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG170_RESETVAL (0x00000100u)

/* nest_level_reg171 */

#define CSL_CPINTC_NEST_LEVEL_REG171_NEST_HINT_171_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG171_NEST_HINT_171_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG171_NEST_HINT_171_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG171_RESETVAL (0x00000100u)

/* nest_level_reg172 */

#define CSL_CPINTC_NEST_LEVEL_REG172_NEST_HINT_172_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG172_NEST_HINT_172_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG172_NEST_HINT_172_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG172_RESETVAL (0x00000100u)

/* nest_level_reg173 */

#define CSL_CPINTC_NEST_LEVEL_REG173_NEST_HINT_173_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG173_NEST_HINT_173_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG173_NEST_HINT_173_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG173_RESETVAL (0x00000100u)

/* nest_level_reg174 */

#define CSL_CPINTC_NEST_LEVEL_REG174_NEST_HINT_174_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG174_NEST_HINT_174_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG174_NEST_HINT_174_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG174_RESETVAL (0x00000100u)

/* nest_level_reg175 */

#define CSL_CPINTC_NEST_LEVEL_REG175_NEST_HINT_175_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG175_NEST_HINT_175_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG175_NEST_HINT_175_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG175_RESETVAL (0x00000100u)

/* nest_level_reg176 */

#define CSL_CPINTC_NEST_LEVEL_REG176_NEST_HINT_176_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG176_NEST_HINT_176_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG176_NEST_HINT_176_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG176_RESETVAL (0x00000100u)

/* nest_level_reg177 */

#define CSL_CPINTC_NEST_LEVEL_REG177_NEST_HINT_177_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG177_NEST_HINT_177_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG177_NEST_HINT_177_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG177_RESETVAL (0x00000100u)

/* nest_level_reg178 */

#define CSL_CPINTC_NEST_LEVEL_REG178_NEST_HINT_178_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG178_NEST_HINT_178_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG178_NEST_HINT_178_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG178_RESETVAL (0x00000100u)

/* nest_level_reg179 */

#define CSL_CPINTC_NEST_LEVEL_REG179_NEST_HINT_179_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG179_NEST_HINT_179_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG179_NEST_HINT_179_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG179_RESETVAL (0x00000100u)

/* nest_level_reg180 */

#define CSL_CPINTC_NEST_LEVEL_REG180_NEST_HINT_180_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG180_NEST_HINT_180_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG180_NEST_HINT_180_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG180_RESETVAL (0x00000100u)

/* nest_level_reg181 */

#define CSL_CPINTC_NEST_LEVEL_REG181_NEST_HINT_181_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG181_NEST_HINT_181_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG181_NEST_HINT_181_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG181_RESETVAL (0x00000100u)

/* nest_level_reg182 */

#define CSL_CPINTC_NEST_LEVEL_REG182_NEST_HINT_182_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG182_NEST_HINT_182_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG182_NEST_HINT_182_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG182_RESETVAL (0x00000100u)

/* nest_level_reg183 */

#define CSL_CPINTC_NEST_LEVEL_REG183_NEST_HINT_183_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG183_NEST_HINT_183_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG183_NEST_HINT_183_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG183_RESETVAL (0x00000100u)

/* nest_level_reg184 */

#define CSL_CPINTC_NEST_LEVEL_REG184_NEST_HINT_184_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG184_NEST_HINT_184_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG184_NEST_HINT_184_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG184_RESETVAL (0x00000100u)

/* nest_level_reg185 */

#define CSL_CPINTC_NEST_LEVEL_REG185_NEST_HINT_185_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG185_NEST_HINT_185_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG185_NEST_HINT_185_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG185_RESETVAL (0x00000100u)

/* nest_level_reg186 */

#define CSL_CPINTC_NEST_LEVEL_REG186_NEST_HINT_186_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG186_NEST_HINT_186_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG186_NEST_HINT_186_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG186_RESETVAL (0x00000100u)

/* nest_level_reg187 */

#define CSL_CPINTC_NEST_LEVEL_REG187_NEST_HINT_187_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG187_NEST_HINT_187_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG187_NEST_HINT_187_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG187_RESETVAL (0x00000100u)

/* nest_level_reg188 */

#define CSL_CPINTC_NEST_LEVEL_REG188_NEST_HINT_188_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG188_NEST_HINT_188_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG188_NEST_HINT_188_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG188_RESETVAL (0x00000100u)

/* nest_level_reg189 */

#define CSL_CPINTC_NEST_LEVEL_REG189_NEST_HINT_189_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG189_NEST_HINT_189_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG189_NEST_HINT_189_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG189_RESETVAL (0x00000100u)

/* nest_level_reg190 */

#define CSL_CPINTC_NEST_LEVEL_REG190_NEST_HINT_190_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG190_NEST_HINT_190_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG190_NEST_HINT_190_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG190_RESETVAL (0x00000100u)

/* nest_level_reg191 */

#define CSL_CPINTC_NEST_LEVEL_REG191_NEST_HINT_191_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG191_NEST_HINT_191_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG191_NEST_HINT_191_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG191_RESETVAL (0x00000100u)

/* nest_level_reg192 */

#define CSL_CPINTC_NEST_LEVEL_REG192_NEST_HINT_192_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG192_NEST_HINT_192_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG192_NEST_HINT_192_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG192_RESETVAL (0x00000100u)

/* nest_level_reg193 */

#define CSL_CPINTC_NEST_LEVEL_REG193_NEST_HINT_193_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG193_NEST_HINT_193_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG193_NEST_HINT_193_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG193_RESETVAL (0x00000100u)

/* nest_level_reg194 */

#define CSL_CPINTC_NEST_LEVEL_REG194_NEST_HINT_194_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG194_NEST_HINT_194_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG194_NEST_HINT_194_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG194_RESETVAL (0x00000100u)

/* nest_level_reg195 */

#define CSL_CPINTC_NEST_LEVEL_REG195_NEST_HINT_195_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG195_NEST_HINT_195_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG195_NEST_HINT_195_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG195_RESETVAL (0x00000100u)

/* nest_level_reg196 */

#define CSL_CPINTC_NEST_LEVEL_REG196_NEST_HINT_196_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG196_NEST_HINT_196_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG196_NEST_HINT_196_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG196_RESETVAL (0x00000100u)

/* nest_level_reg197 */

#define CSL_CPINTC_NEST_LEVEL_REG197_NEST_HINT_197_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG197_NEST_HINT_197_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG197_NEST_HINT_197_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG197_RESETVAL (0x00000100u)

/* nest_level_reg198 */

#define CSL_CPINTC_NEST_LEVEL_REG198_NEST_HINT_198_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG198_NEST_HINT_198_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG198_NEST_HINT_198_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG198_RESETVAL (0x00000100u)

/* nest_level_reg199 */

#define CSL_CPINTC_NEST_LEVEL_REG199_NEST_HINT_199_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG199_NEST_HINT_199_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG199_NEST_HINT_199_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG199_RESETVAL (0x00000100u)

/* nest_level_reg200 */

#define CSL_CPINTC_NEST_LEVEL_REG200_NEST_HINT_200_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG200_NEST_HINT_200_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG200_NEST_HINT_200_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG200_RESETVAL (0x00000100u)

/* nest_level_reg201 */

#define CSL_CPINTC_NEST_LEVEL_REG201_NEST_HINT_201_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG201_NEST_HINT_201_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG201_NEST_HINT_201_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG201_RESETVAL (0x00000100u)

/* nest_level_reg202 */

#define CSL_CPINTC_NEST_LEVEL_REG202_NEST_HINT_202_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG202_NEST_HINT_202_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG202_NEST_HINT_202_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG202_RESETVAL (0x00000100u)

/* nest_level_reg203 */

#define CSL_CPINTC_NEST_LEVEL_REG203_NEST_HINT_203_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG203_NEST_HINT_203_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG203_NEST_HINT_203_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG203_RESETVAL (0x00000100u)

/* nest_level_reg204 */

#define CSL_CPINTC_NEST_LEVEL_REG204_NEST_HINT_204_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG204_NEST_HINT_204_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG204_NEST_HINT_204_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG204_RESETVAL (0x00000100u)

/* nest_level_reg205 */

#define CSL_CPINTC_NEST_LEVEL_REG205_NEST_HINT_205_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG205_NEST_HINT_205_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG205_NEST_HINT_205_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG205_RESETVAL (0x00000100u)

/* nest_level_reg206 */

#define CSL_CPINTC_NEST_LEVEL_REG206_NEST_HINT_206_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG206_NEST_HINT_206_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG206_NEST_HINT_206_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG206_RESETVAL (0x00000100u)

/* nest_level_reg207 */

#define CSL_CPINTC_NEST_LEVEL_REG207_NEST_HINT_207_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG207_NEST_HINT_207_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG207_NEST_HINT_207_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG207_RESETVAL (0x00000100u)

/* nest_level_reg208 */

#define CSL_CPINTC_NEST_LEVEL_REG208_NEST_HINT_208_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG208_NEST_HINT_208_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG208_NEST_HINT_208_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG208_RESETVAL (0x00000100u)

/* nest_level_reg209 */

#define CSL_CPINTC_NEST_LEVEL_REG209_NEST_HINT_209_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG209_NEST_HINT_209_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG209_NEST_HINT_209_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG209_RESETVAL (0x00000100u)

/* nest_level_reg210 */

#define CSL_CPINTC_NEST_LEVEL_REG210_NEST_HINT_210_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG210_NEST_HINT_210_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG210_NEST_HINT_210_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG210_RESETVAL (0x00000100u)

/* nest_level_reg211 */

#define CSL_CPINTC_NEST_LEVEL_REG211_NEST_HINT_211_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG211_NEST_HINT_211_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG211_NEST_HINT_211_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG211_RESETVAL (0x00000100u)

/* nest_level_reg212 */

#define CSL_CPINTC_NEST_LEVEL_REG212_NEST_HINT_212_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG212_NEST_HINT_212_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG212_NEST_HINT_212_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG212_RESETVAL (0x00000100u)

/* nest_level_reg213 */

#define CSL_CPINTC_NEST_LEVEL_REG213_NEST_HINT_213_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG213_NEST_HINT_213_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG213_NEST_HINT_213_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG213_RESETVAL (0x00000100u)

/* nest_level_reg214 */

#define CSL_CPINTC_NEST_LEVEL_REG214_NEST_HINT_214_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG214_NEST_HINT_214_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG214_NEST_HINT_214_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG214_RESETVAL (0x00000100u)

/* nest_level_reg215 */

#define CSL_CPINTC_NEST_LEVEL_REG215_NEST_HINT_215_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG215_NEST_HINT_215_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG215_NEST_HINT_215_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG215_RESETVAL (0x00000100u)

/* nest_level_reg216 */

#define CSL_CPINTC_NEST_LEVEL_REG216_NEST_HINT_216_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG216_NEST_HINT_216_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG216_NEST_HINT_216_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG216_RESETVAL (0x00000100u)

/* nest_level_reg217 */

#define CSL_CPINTC_NEST_LEVEL_REG217_NEST_HINT_217_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG217_NEST_HINT_217_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG217_NEST_HINT_217_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG217_RESETVAL (0x00000100u)

/* nest_level_reg218 */

#define CSL_CPINTC_NEST_LEVEL_REG218_NEST_HINT_218_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG218_NEST_HINT_218_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG218_NEST_HINT_218_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG218_RESETVAL (0x00000100u)

/* nest_level_reg219 */

#define CSL_CPINTC_NEST_LEVEL_REG219_NEST_HINT_219_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG219_NEST_HINT_219_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG219_NEST_HINT_219_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG219_RESETVAL (0x00000100u)

/* nest_level_reg220 */

#define CSL_CPINTC_NEST_LEVEL_REG220_NEST_HINT_220_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG220_NEST_HINT_220_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG220_NEST_HINT_220_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG220_RESETVAL (0x00000100u)

/* nest_level_reg221 */

#define CSL_CPINTC_NEST_LEVEL_REG221_NEST_HINT_221_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG221_NEST_HINT_221_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG221_NEST_HINT_221_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG221_RESETVAL (0x00000100u)

/* nest_level_reg222 */

#define CSL_CPINTC_NEST_LEVEL_REG222_NEST_HINT_222_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG222_NEST_HINT_222_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG222_NEST_HINT_222_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG222_RESETVAL (0x00000100u)

/* nest_level_reg223 */

#define CSL_CPINTC_NEST_LEVEL_REG223_NEST_HINT_223_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG223_NEST_HINT_223_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG223_NEST_HINT_223_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG223_RESETVAL (0x00000100u)

/* nest_level_reg224 */

#define CSL_CPINTC_NEST_LEVEL_REG224_NEST_HINT_224_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG224_NEST_HINT_224_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG224_NEST_HINT_224_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG224_RESETVAL (0x00000100u)

/* nest_level_reg225 */

#define CSL_CPINTC_NEST_LEVEL_REG225_NEST_HINT_225_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG225_NEST_HINT_225_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG225_NEST_HINT_225_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG225_RESETVAL (0x00000100u)

/* nest_level_reg226 */

#define CSL_CPINTC_NEST_LEVEL_REG226_NEST_HINT_226_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG226_NEST_HINT_226_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG226_NEST_HINT_226_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG226_RESETVAL (0x00000100u)

/* nest_level_reg227 */

#define CSL_CPINTC_NEST_LEVEL_REG227_NEST_HINT_227_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG227_NEST_HINT_227_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG227_NEST_HINT_227_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG227_RESETVAL (0x00000100u)

/* nest_level_reg228 */

#define CSL_CPINTC_NEST_LEVEL_REG228_NEST_HINT_228_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG228_NEST_HINT_228_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG228_NEST_HINT_228_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG228_RESETVAL (0x00000100u)

/* nest_level_reg229 */

#define CSL_CPINTC_NEST_LEVEL_REG229_NEST_HINT_229_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG229_NEST_HINT_229_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG229_NEST_HINT_229_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG229_RESETVAL (0x00000100u)

/* nest_level_reg230 */

#define CSL_CPINTC_NEST_LEVEL_REG230_NEST_HINT_230_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG230_NEST_HINT_230_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG230_NEST_HINT_230_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG230_RESETVAL (0x00000100u)

/* nest_level_reg231 */

#define CSL_CPINTC_NEST_LEVEL_REG231_NEST_HINT_231_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG231_NEST_HINT_231_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG231_NEST_HINT_231_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG231_RESETVAL (0x00000100u)

/* nest_level_reg232 */

#define CSL_CPINTC_NEST_LEVEL_REG232_NEST_HINT_232_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG232_NEST_HINT_232_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG232_NEST_HINT_232_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG232_RESETVAL (0x00000100u)

/* nest_level_reg233 */

#define CSL_CPINTC_NEST_LEVEL_REG233_NEST_HINT_233_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG233_NEST_HINT_233_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG233_NEST_HINT_233_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG233_RESETVAL (0x00000100u)

/* nest_level_reg234 */

#define CSL_CPINTC_NEST_LEVEL_REG234_NEST_HINT_234_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG234_NEST_HINT_234_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG234_NEST_HINT_234_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG234_RESETVAL (0x00000100u)

/* nest_level_reg235 */

#define CSL_CPINTC_NEST_LEVEL_REG235_NEST_HINT_235_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG235_NEST_HINT_235_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG235_NEST_HINT_235_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG235_RESETVAL (0x00000100u)

/* nest_level_reg236 */

#define CSL_CPINTC_NEST_LEVEL_REG236_NEST_HINT_236_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG236_NEST_HINT_236_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG236_NEST_HINT_236_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG236_RESETVAL (0x00000100u)

/* nest_level_reg237 */

#define CSL_CPINTC_NEST_LEVEL_REG237_NEST_HINT_237_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG237_NEST_HINT_237_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG237_NEST_HINT_237_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG237_RESETVAL (0x00000100u)

/* nest_level_reg238 */

#define CSL_CPINTC_NEST_LEVEL_REG238_NEST_HINT_238_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG238_NEST_HINT_238_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG238_NEST_HINT_238_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG238_RESETVAL (0x00000100u)

/* nest_level_reg239 */

#define CSL_CPINTC_NEST_LEVEL_REG239_NEST_HINT_239_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG239_NEST_HINT_239_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG239_NEST_HINT_239_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG239_RESETVAL (0x00000100u)

/* nest_level_reg240 */

#define CSL_CPINTC_NEST_LEVEL_REG240_NEST_HINT_240_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG240_NEST_HINT_240_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG240_NEST_HINT_240_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG240_RESETVAL (0x00000100u)

/* nest_level_reg241 */

#define CSL_CPINTC_NEST_LEVEL_REG241_NEST_HINT_241_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG241_NEST_HINT_241_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG241_NEST_HINT_241_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG241_RESETVAL (0x00000100u)

/* nest_level_reg242 */

#define CSL_CPINTC_NEST_LEVEL_REG242_NEST_HINT_242_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG242_NEST_HINT_242_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG242_NEST_HINT_242_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG242_RESETVAL (0x00000100u)

/* nest_level_reg243 */

#define CSL_CPINTC_NEST_LEVEL_REG243_NEST_HINT_243_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG243_NEST_HINT_243_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG243_NEST_HINT_243_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG243_RESETVAL (0x00000100u)

/* nest_level_reg244 */

#define CSL_CPINTC_NEST_LEVEL_REG244_NEST_HINT_244_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG244_NEST_HINT_244_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG244_NEST_HINT_244_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG244_RESETVAL (0x00000100u)

/* nest_level_reg245 */

#define CSL_CPINTC_NEST_LEVEL_REG245_NEST_HINT_245_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG245_NEST_HINT_245_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG245_NEST_HINT_245_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG245_RESETVAL (0x00000100u)

/* nest_level_reg246 */

#define CSL_CPINTC_NEST_LEVEL_REG246_NEST_HINT_246_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG246_NEST_HINT_246_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG246_NEST_HINT_246_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG246_RESETVAL (0x00000100u)

/* nest_level_reg247 */

#define CSL_CPINTC_NEST_LEVEL_REG247_NEST_HINT_247_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG247_NEST_HINT_247_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG247_NEST_HINT_247_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG247_RESETVAL (0x00000100u)

/* nest_level_reg248 */

#define CSL_CPINTC_NEST_LEVEL_REG248_NEST_HINT_248_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG248_NEST_HINT_248_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG248_NEST_HINT_248_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG248_RESETVAL (0x00000100u)

/* nest_level_reg249 */

#define CSL_CPINTC_NEST_LEVEL_REG249_NEST_HINT_249_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG249_NEST_HINT_249_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG249_NEST_HINT_249_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG249_RESETVAL (0x00000100u)

/* nest_level_reg250 */

#define CSL_CPINTC_NEST_LEVEL_REG250_NEST_HINT_250_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG250_NEST_HINT_250_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG250_NEST_HINT_250_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG250_RESETVAL (0x00000100u)

/* nest_level_reg251 */

#define CSL_CPINTC_NEST_LEVEL_REG251_NEST_HINT_251_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG251_NEST_HINT_251_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG251_NEST_HINT_251_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG251_RESETVAL (0x00000100u)

/* nest_level_reg252 */

#define CSL_CPINTC_NEST_LEVEL_REG252_NEST_HINT_252_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG252_NEST_HINT_252_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG252_NEST_HINT_252_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG252_RESETVAL (0x00000100u)

/* nest_level_reg253 */

#define CSL_CPINTC_NEST_LEVEL_REG253_NEST_HINT_253_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG253_NEST_HINT_253_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG253_NEST_HINT_253_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG253_RESETVAL (0x00000100u)

/* nest_level_reg254 */

#define CSL_CPINTC_NEST_LEVEL_REG254_NEST_HINT_254_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG254_NEST_HINT_254_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG254_NEST_HINT_254_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG254_RESETVAL (0x00000100u)

/* nest_level_reg255 */

#define CSL_CPINTC_NEST_LEVEL_REG255_NEST_HINT_255_MASK (0x000001FFu)
#define CSL_CPINTC_NEST_LEVEL_REG255_NEST_HINT_255_SHIFT (0x00000000u)
#define CSL_CPINTC_NEST_LEVEL_REG255_NEST_HINT_255_RESETVAL (0x00000100u)

#define CSL_CPINTC_NEST_LEVEL_REG255_RESETVAL (0x00000100u)

/* enable_hint_reg0 */

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_0_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_0_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_1_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_1_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_2_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_2_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_3_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_3_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_4_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_4_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_5_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_5_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_6_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_6_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_7_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_7_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_8_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_8_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_9_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_9_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_10_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_10_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_11_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_11_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_12_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_12_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_13_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_13_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_14_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_14_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_15_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_15_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_16_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_16_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_17_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_17_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_18_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_18_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_19_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_19_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_20_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_20_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_21_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_21_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_22_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_22_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_23_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_23_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_24_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_24_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_25_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_25_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_26_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_26_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_27_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_27_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_28_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_28_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_29_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_29_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_30_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_30_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_31_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_31_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_HINT_REG0_ENABLE_HINT_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG0_RESETVAL (0x00000000u)

/* enable_hint_reg1 */

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_32_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_32_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_33_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_33_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_34_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_34_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_35_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_35_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_36_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_36_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_37_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_37_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_38_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_38_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_39_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_39_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_40_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_40_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_41_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_41_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_42_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_42_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_43_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_43_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_44_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_44_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_45_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_45_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_46_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_46_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_47_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_47_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_48_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_48_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_49_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_49_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_50_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_50_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_51_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_51_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_52_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_52_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_53_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_53_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_54_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_54_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_55_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_55_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_56_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_56_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_57_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_57_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_58_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_58_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_59_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_59_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_60_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_60_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_61_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_61_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_62_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_62_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_63_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_63_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_HINT_REG1_ENABLE_HINT_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG1_RESETVAL (0x00000000u)

/* enable_hint_reg2 */

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_64_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_64_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_65_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_65_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_66_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_66_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_67_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_67_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_68_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_68_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_69_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_69_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_70_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_70_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_71_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_71_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_72_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_72_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_73_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_73_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_74_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_74_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_75_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_75_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_76_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_76_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_77_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_77_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_78_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_78_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_79_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_79_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_80_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_80_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_81_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_81_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_82_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_82_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_83_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_83_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_84_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_84_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_85_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_85_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_86_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_86_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_87_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_87_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_88_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_88_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_89_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_89_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_90_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_90_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_91_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_91_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_92_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_92_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_93_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_93_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_94_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_94_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_95_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_95_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_HINT_REG2_ENABLE_HINT_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG2_RESETVAL (0x00000000u)

/* enable_hint_reg3 */

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_96_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_96_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_97_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_97_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_98_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_98_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_99_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_99_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_100_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_100_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_101_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_101_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_102_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_102_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_103_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_103_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_104_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_104_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_105_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_105_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_106_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_106_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_107_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_107_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_108_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_108_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_109_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_109_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_110_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_110_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_111_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_111_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_112_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_112_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_113_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_113_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_114_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_114_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_115_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_115_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_116_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_116_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_117_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_117_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_118_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_118_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_119_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_119_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_120_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_120_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_121_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_121_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_122_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_122_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_123_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_123_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_124_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_124_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_125_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_125_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_126_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_126_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_127_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_127_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_HINT_REG3_ENABLE_HINT_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG3_RESETVAL (0x00000000u)

/* enable_hint_reg4 */

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_128_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_128_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_129_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_129_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_130_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_130_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_131_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_131_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_132_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_132_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_133_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_133_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_134_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_134_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_135_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_135_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_136_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_136_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_137_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_137_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_138_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_138_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_139_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_139_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_140_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_140_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_141_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_141_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_142_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_142_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_143_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_143_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_144_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_144_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_145_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_145_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_146_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_146_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_147_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_147_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_148_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_148_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_149_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_149_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_150_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_150_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_151_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_151_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_152_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_152_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_153_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_153_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_154_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_154_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_155_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_155_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_156_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_156_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_157_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_157_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_158_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_158_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_159_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_159_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_HINT_REG4_ENABLE_HINT_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG4_RESETVAL (0x00000000u)

/* enable_hint_reg5 */

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_160_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_160_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_161_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_161_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_162_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_162_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_163_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_163_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_164_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_164_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_165_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_165_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_166_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_166_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_167_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_167_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_168_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_168_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_169_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_169_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_170_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_170_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_171_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_171_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_172_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_172_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_173_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_173_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_174_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_174_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_175_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_175_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_176_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_176_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_177_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_177_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_178_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_178_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_179_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_179_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_180_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_180_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_181_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_181_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_182_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_182_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_183_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_183_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_184_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_184_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_185_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_185_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_186_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_186_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_187_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_187_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_188_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_188_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_189_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_189_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_190_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_190_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_191_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_191_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_HINT_REG5_ENABLE_HINT_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG5_RESETVAL (0x00000000u)

/* enable_hint_reg6 */

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_192_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_192_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_193_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_193_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_194_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_194_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_195_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_195_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_196_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_196_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_197_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_197_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_198_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_198_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_199_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_199_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_200_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_200_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_201_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_201_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_202_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_202_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_203_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_203_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_204_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_204_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_205_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_205_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_206_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_206_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_207_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_207_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_208_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_208_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_209_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_209_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_210_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_210_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_211_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_211_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_212_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_212_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_213_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_213_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_214_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_214_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_215_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_215_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_216_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_216_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_217_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_217_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_218_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_218_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_219_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_219_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_220_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_220_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_221_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_221_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_222_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_222_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_223_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_223_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_HINT_REG6_ENABLE_HINT_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG6_RESETVAL (0x00000000u)

/* enable_hint_reg7 */

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_224_MASK (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_224_SHIFT (0x00000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_225_MASK (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_225_SHIFT (0x00000001u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_226_MASK (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_226_SHIFT (0x00000002u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_227_MASK (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_227_SHIFT (0x00000003u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_228_MASK (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_228_SHIFT (0x00000004u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_229_MASK (0x00000020u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_229_SHIFT (0x00000005u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_230_MASK (0x00000040u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_230_SHIFT (0x00000006u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_231_MASK (0x00000080u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_231_SHIFT (0x00000007u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_232_MASK (0x00000100u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_232_SHIFT (0x00000008u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_233_MASK (0x00000200u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_233_SHIFT (0x00000009u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_234_MASK (0x00000400u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_234_SHIFT (0x0000000Au)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_235_MASK (0x00000800u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_235_SHIFT (0x0000000Bu)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_236_MASK (0x00001000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_236_SHIFT (0x0000000Cu)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_237_MASK (0x00002000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_237_SHIFT (0x0000000Du)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_238_MASK (0x00004000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_238_SHIFT (0x0000000Eu)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_239_MASK (0x00008000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_239_SHIFT (0x0000000Fu)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_240_MASK (0x00010000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_240_SHIFT (0x00000010u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_241_MASK (0x00020000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_241_SHIFT (0x00000011u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_242_MASK (0x00040000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_242_SHIFT (0x00000012u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_243_MASK (0x00080000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_243_SHIFT (0x00000013u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_244_MASK (0x00100000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_244_SHIFT (0x00000014u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_245_MASK (0x00200000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_245_SHIFT (0x00000015u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_246_MASK (0x00400000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_246_SHIFT (0x00000016u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_247_MASK (0x00800000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_247_SHIFT (0x00000017u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_248_MASK (0x01000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_248_SHIFT (0x00000018u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_249_MASK (0x02000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_249_SHIFT (0x00000019u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_250_MASK (0x04000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_250_SHIFT (0x0000001Au)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_251_MASK (0x08000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_251_SHIFT (0x0000001Bu)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_252_MASK (0x10000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_252_SHIFT (0x0000001Cu)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_253_MASK (0x20000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_253_SHIFT (0x0000001Du)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_254_MASK (0x40000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_254_SHIFT (0x0000001Eu)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_255_MASK (0x80000000u)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_255_SHIFT (0x0000001Fu)
#define CSL_CPINTC_ENABLE_HINT_REG7_ENABLE_HINT_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_ENABLE_HINT_REG7_RESETVAL (0x00000000u)

/* vector_address_reg_0 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_0_VECTOR_ADDRESS_0_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_0_VECTOR_ADDRESS_0_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_0_VECTOR_ADDRESS_0_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_0_RESETVAL (0x00000000u)

/* vector_address_reg_1 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1_VECTOR_ADDRESS_1_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1_VECTOR_ADDRESS_1_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1_VECTOR_ADDRESS_1_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1_RESETVAL (0x00000000u)

/* vector_address_reg_2 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_2_VECTOR_ADDRESS_2_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_2_VECTOR_ADDRESS_2_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_2_VECTOR_ADDRESS_2_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_2_RESETVAL (0x00000000u)

/* vector_address_reg_3 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_3_VECTOR_ADDRESS_3_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_3_VECTOR_ADDRESS_3_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_3_VECTOR_ADDRESS_3_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_3_RESETVAL (0x00000000u)

/* vector_address_reg_4 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_4_VECTOR_ADDRESS_4_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_4_VECTOR_ADDRESS_4_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_4_VECTOR_ADDRESS_4_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_4_RESETVAL (0x00000000u)

/* vector_address_reg_5 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_5_VECTOR_ADDRESS_5_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_5_VECTOR_ADDRESS_5_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_5_VECTOR_ADDRESS_5_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_5_RESETVAL (0x00000000u)

/* vector_address_reg_6 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_6_VECTOR_ADDRESS_6_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_6_VECTOR_ADDRESS_6_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_6_VECTOR_ADDRESS_6_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_6_RESETVAL (0x00000000u)

/* vector_address_reg_7 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_7_VECTOR_ADDRESS_7_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_7_VECTOR_ADDRESS_7_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_7_VECTOR_ADDRESS_7_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_7_RESETVAL (0x00000000u)

/* vector_address_reg_8 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_8_VECTOR_ADDRESS_8_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_8_VECTOR_ADDRESS_8_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_8_VECTOR_ADDRESS_8_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_8_RESETVAL (0x00000000u)

/* vector_address_reg_9 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_9_VECTOR_ADDRESS_9_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_9_VECTOR_ADDRESS_9_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_9_VECTOR_ADDRESS_9_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_9_RESETVAL (0x00000000u)

/* vector_address_reg_10 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_10_VECTOR_ADDRESS_10_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_10_VECTOR_ADDRESS_10_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_10_VECTOR_ADDRESS_10_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_10_RESETVAL (0x00000000u)

/* vector_address_reg_11 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_11_VECTOR_ADDRESS_11_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_11_VECTOR_ADDRESS_11_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_11_VECTOR_ADDRESS_11_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_11_RESETVAL (0x00000000u)

/* vector_address_reg_12 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_12_VECTOR_ADDRESS_12_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_12_VECTOR_ADDRESS_12_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_12_VECTOR_ADDRESS_12_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_12_RESETVAL (0x00000000u)

/* vector_address_reg_13 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_13_VECTOR_ADDRESS_13_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_13_VECTOR_ADDRESS_13_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_13_VECTOR_ADDRESS_13_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_13_RESETVAL (0x00000000u)

/* vector_address_reg_14 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_14_VECTOR_ADDRESS_14_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_14_VECTOR_ADDRESS_14_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_14_VECTOR_ADDRESS_14_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_14_RESETVAL (0x00000000u)

/* vector_address_reg_15 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_15_VECTOR_ADDRESS_15_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_15_VECTOR_ADDRESS_15_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_15_VECTOR_ADDRESS_15_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_15_RESETVAL (0x00000000u)

/* vector_address_reg_16 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_16_VECTOR_ADDRESS_16_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_16_VECTOR_ADDRESS_16_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_16_VECTOR_ADDRESS_16_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_16_RESETVAL (0x00000000u)

/* vector_address_reg_17 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_17_VECTOR_ADDRESS_17_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_17_VECTOR_ADDRESS_17_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_17_VECTOR_ADDRESS_17_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_17_RESETVAL (0x00000000u)

/* vector_address_reg_18 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_18_VECTOR_ADDRESS_18_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_18_VECTOR_ADDRESS_18_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_18_VECTOR_ADDRESS_18_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_18_RESETVAL (0x00000000u)

/* vector_address_reg_19 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_19_VECTOR_ADDRESS_19_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_19_VECTOR_ADDRESS_19_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_19_VECTOR_ADDRESS_19_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_19_RESETVAL (0x00000000u)

/* vector_address_reg_20 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_20_VECTOR_ADDRESS_20_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_20_VECTOR_ADDRESS_20_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_20_VECTOR_ADDRESS_20_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_20_RESETVAL (0x00000000u)

/* vector_address_reg_21 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_21_VECTOR_ADDRESS_21_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_21_VECTOR_ADDRESS_21_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_21_VECTOR_ADDRESS_21_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_21_RESETVAL (0x00000000u)

/* vector_address_reg_22 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_22_VECTOR_ADDRESS_22_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_22_VECTOR_ADDRESS_22_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_22_VECTOR_ADDRESS_22_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_22_RESETVAL (0x00000000u)

/* vector_address_reg_23 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_23_VECTOR_ADDRESS_23_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_23_VECTOR_ADDRESS_23_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_23_VECTOR_ADDRESS_23_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_23_RESETVAL (0x00000000u)

/* vector_address_reg_24 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_24_VECTOR_ADDRESS_24_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_24_VECTOR_ADDRESS_24_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_24_VECTOR_ADDRESS_24_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_24_RESETVAL (0x00000000u)

/* vector_address_reg_25 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_25_VECTOR_ADDRESS_25_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_25_VECTOR_ADDRESS_25_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_25_VECTOR_ADDRESS_25_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_25_RESETVAL (0x00000000u)

/* vector_address_reg_26 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_26_VECTOR_ADDRESS_26_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_26_VECTOR_ADDRESS_26_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_26_VECTOR_ADDRESS_26_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_26_RESETVAL (0x00000000u)

/* vector_address_reg_27 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_27_VECTOR_ADDRESS_27_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_27_VECTOR_ADDRESS_27_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_27_VECTOR_ADDRESS_27_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_27_RESETVAL (0x00000000u)

/* vector_address_reg_28 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_28_VECTOR_ADDRESS_28_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_28_VECTOR_ADDRESS_28_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_28_VECTOR_ADDRESS_28_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_28_RESETVAL (0x00000000u)

/* vector_address_reg_29 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_29_VECTOR_ADDRESS_29_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_29_VECTOR_ADDRESS_29_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_29_VECTOR_ADDRESS_29_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_29_RESETVAL (0x00000000u)

/* vector_address_reg_30 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_30_VECTOR_ADDRESS_30_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_30_VECTOR_ADDRESS_30_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_30_VECTOR_ADDRESS_30_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_30_RESETVAL (0x00000000u)

/* vector_address_reg_31 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_31_VECTOR_ADDRESS_31_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_31_VECTOR_ADDRESS_31_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_31_VECTOR_ADDRESS_31_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_31_RESETVAL (0x00000000u)

/* vector_address_reg_32 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_32_VECTOR_ADDRESS_32_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_32_VECTOR_ADDRESS_32_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_32_VECTOR_ADDRESS_32_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_32_RESETVAL (0x00000000u)

/* vector_address_reg_33 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_33_VECTOR_ADDRESS_33_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_33_VECTOR_ADDRESS_33_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_33_VECTOR_ADDRESS_33_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_33_RESETVAL (0x00000000u)

/* vector_address_reg_34 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_34_VECTOR_ADDRESS_34_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_34_VECTOR_ADDRESS_34_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_34_VECTOR_ADDRESS_34_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_34_RESETVAL (0x00000000u)

/* vector_address_reg_35 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_35_VECTOR_ADDRESS_35_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_35_VECTOR_ADDRESS_35_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_35_VECTOR_ADDRESS_35_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_35_RESETVAL (0x00000000u)

/* vector_address_reg_36 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_36_VECTOR_ADDRESS_36_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_36_VECTOR_ADDRESS_36_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_36_VECTOR_ADDRESS_36_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_36_RESETVAL (0x00000000u)

/* vector_address_reg_37 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_37_VECTOR_ADDRESS_37_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_37_VECTOR_ADDRESS_37_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_37_VECTOR_ADDRESS_37_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_37_RESETVAL (0x00000000u)

/* vector_address_reg_38 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_38_VECTOR_ADDRESS_38_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_38_VECTOR_ADDRESS_38_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_38_VECTOR_ADDRESS_38_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_38_RESETVAL (0x00000000u)

/* vector_address_reg_39 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_39_VECTOR_ADDRESS_39_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_39_VECTOR_ADDRESS_39_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_39_VECTOR_ADDRESS_39_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_39_RESETVAL (0x00000000u)

/* vector_address_reg_40 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_40_VECTOR_ADDRESS_40_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_40_VECTOR_ADDRESS_40_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_40_VECTOR_ADDRESS_40_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_40_RESETVAL (0x00000000u)

/* vector_address_reg_41 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_41_VECTOR_ADDRESS_41_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_41_VECTOR_ADDRESS_41_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_41_VECTOR_ADDRESS_41_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_41_RESETVAL (0x00000000u)

/* vector_address_reg_42 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_42_VECTOR_ADDRESS_42_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_42_VECTOR_ADDRESS_42_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_42_VECTOR_ADDRESS_42_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_42_RESETVAL (0x00000000u)

/* vector_address_reg_43 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_43_VECTOR_ADDRESS_43_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_43_VECTOR_ADDRESS_43_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_43_VECTOR_ADDRESS_43_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_43_RESETVAL (0x00000000u)

/* vector_address_reg_44 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_44_VECTOR_ADDRESS_44_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_44_VECTOR_ADDRESS_44_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_44_VECTOR_ADDRESS_44_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_44_RESETVAL (0x00000000u)

/* vector_address_reg_45 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_45_VECTOR_ADDRESS_45_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_45_VECTOR_ADDRESS_45_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_45_VECTOR_ADDRESS_45_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_45_RESETVAL (0x00000000u)

/* vector_address_reg_46 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_46_VECTOR_ADDRESS_46_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_46_VECTOR_ADDRESS_46_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_46_VECTOR_ADDRESS_46_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_46_RESETVAL (0x00000000u)

/* vector_address_reg_47 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_47_VECTOR_ADDRESS_47_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_47_VECTOR_ADDRESS_47_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_47_VECTOR_ADDRESS_47_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_47_RESETVAL (0x00000000u)

/* vector_address_reg_48 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_48_VECTOR_ADDRESS_48_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_48_VECTOR_ADDRESS_48_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_48_VECTOR_ADDRESS_48_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_48_RESETVAL (0x00000000u)

/* vector_address_reg_49 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_49_VECTOR_ADDRESS_49_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_49_VECTOR_ADDRESS_49_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_49_VECTOR_ADDRESS_49_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_49_RESETVAL (0x00000000u)

/* vector_address_reg_50 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_50_VECTOR_ADDRESS_50_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_50_VECTOR_ADDRESS_50_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_50_VECTOR_ADDRESS_50_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_50_RESETVAL (0x00000000u)

/* vector_address_reg_51 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_51_VECTOR_ADDRESS_51_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_51_VECTOR_ADDRESS_51_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_51_VECTOR_ADDRESS_51_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_51_RESETVAL (0x00000000u)

/* vector_address_reg_52 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_52_VECTOR_ADDRESS_52_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_52_VECTOR_ADDRESS_52_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_52_VECTOR_ADDRESS_52_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_52_RESETVAL (0x00000000u)

/* vector_address_reg_53 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_53_VECTOR_ADDRESS_53_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_53_VECTOR_ADDRESS_53_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_53_VECTOR_ADDRESS_53_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_53_RESETVAL (0x00000000u)

/* vector_address_reg_54 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_54_VECTOR_ADDRESS_54_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_54_VECTOR_ADDRESS_54_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_54_VECTOR_ADDRESS_54_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_54_RESETVAL (0x00000000u)

/* vector_address_reg_55 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_55_VECTOR_ADDRESS_55_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_55_VECTOR_ADDRESS_55_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_55_VECTOR_ADDRESS_55_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_55_RESETVAL (0x00000000u)

/* vector_address_reg_56 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_56_VECTOR_ADDRESS_56_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_56_VECTOR_ADDRESS_56_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_56_VECTOR_ADDRESS_56_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_56_RESETVAL (0x00000000u)

/* vector_address_reg_57 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_57_VECTOR_ADDRESS_57_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_57_VECTOR_ADDRESS_57_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_57_VECTOR_ADDRESS_57_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_57_RESETVAL (0x00000000u)

/* vector_address_reg_58 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_58_VECTOR_ADDRESS_58_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_58_VECTOR_ADDRESS_58_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_58_VECTOR_ADDRESS_58_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_58_RESETVAL (0x00000000u)

/* vector_address_reg_59 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_59_VECTOR_ADDRESS_59_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_59_VECTOR_ADDRESS_59_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_59_VECTOR_ADDRESS_59_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_59_RESETVAL (0x00000000u)

/* vector_address_reg_60 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_60_VECTOR_ADDRESS_60_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_60_VECTOR_ADDRESS_60_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_60_VECTOR_ADDRESS_60_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_60_RESETVAL (0x00000000u)

/* vector_address_reg_61 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_61_VECTOR_ADDRESS_61_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_61_VECTOR_ADDRESS_61_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_61_VECTOR_ADDRESS_61_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_61_RESETVAL (0x00000000u)

/* vector_address_reg_62 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_62_VECTOR_ADDRESS_62_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_62_VECTOR_ADDRESS_62_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_62_VECTOR_ADDRESS_62_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_62_RESETVAL (0x00000000u)

/* vector_address_reg_63 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_63_VECTOR_ADDRESS_63_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_63_VECTOR_ADDRESS_63_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_63_VECTOR_ADDRESS_63_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_63_RESETVAL (0x00000000u)

/* vector_address_reg_64 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_64_VECTOR_ADDRESS_64_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_64_VECTOR_ADDRESS_64_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_64_VECTOR_ADDRESS_64_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_64_RESETVAL (0x00000000u)

/* vector_address_reg_65 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_65_VECTOR_ADDRESS_65_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_65_VECTOR_ADDRESS_65_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_65_VECTOR_ADDRESS_65_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_65_RESETVAL (0x00000000u)

/* vector_address_reg_66 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_66_VECTOR_ADDRESS_66_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_66_VECTOR_ADDRESS_66_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_66_VECTOR_ADDRESS_66_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_66_RESETVAL (0x00000000u)

/* vector_address_reg_67 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_67_VECTOR_ADDRESS_67_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_67_VECTOR_ADDRESS_67_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_67_VECTOR_ADDRESS_67_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_67_RESETVAL (0x00000000u)

/* vector_address_reg_68 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_68_VECTOR_ADDRESS_68_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_68_VECTOR_ADDRESS_68_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_68_VECTOR_ADDRESS_68_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_68_RESETVAL (0x00000000u)

/* vector_address_reg_69 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_69_VECTOR_ADDRESS_69_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_69_VECTOR_ADDRESS_69_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_69_VECTOR_ADDRESS_69_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_69_RESETVAL (0x00000000u)

/* vector_address_reg_70 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_70_VECTOR_ADDRESS_70_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_70_VECTOR_ADDRESS_70_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_70_VECTOR_ADDRESS_70_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_70_RESETVAL (0x00000000u)

/* vector_address_reg_71 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_71_VECTOR_ADDRESS_71_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_71_VECTOR_ADDRESS_71_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_71_VECTOR_ADDRESS_71_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_71_RESETVAL (0x00000000u)

/* vector_address_reg_72 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_72_VECTOR_ADDRESS_72_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_72_VECTOR_ADDRESS_72_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_72_VECTOR_ADDRESS_72_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_72_RESETVAL (0x00000000u)

/* vector_address_reg_73 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_73_VECTOR_ADDRESS_73_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_73_VECTOR_ADDRESS_73_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_73_VECTOR_ADDRESS_73_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_73_RESETVAL (0x00000000u)

/* vector_address_reg_74 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_74_VECTOR_ADDRESS_74_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_74_VECTOR_ADDRESS_74_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_74_VECTOR_ADDRESS_74_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_74_RESETVAL (0x00000000u)

/* vector_address_reg_75 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_75_VECTOR_ADDRESS_75_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_75_VECTOR_ADDRESS_75_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_75_VECTOR_ADDRESS_75_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_75_RESETVAL (0x00000000u)

/* vector_address_reg_76 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_76_VECTOR_ADDRESS_76_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_76_VECTOR_ADDRESS_76_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_76_VECTOR_ADDRESS_76_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_76_RESETVAL (0x00000000u)

/* vector_address_reg_77 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_77_VECTOR_ADDRESS_77_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_77_VECTOR_ADDRESS_77_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_77_VECTOR_ADDRESS_77_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_77_RESETVAL (0x00000000u)

/* vector_address_reg_78 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_78_VECTOR_ADDRESS_78_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_78_VECTOR_ADDRESS_78_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_78_VECTOR_ADDRESS_78_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_78_RESETVAL (0x00000000u)

/* vector_address_reg_79 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_79_VECTOR_ADDRESS_79_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_79_VECTOR_ADDRESS_79_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_79_VECTOR_ADDRESS_79_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_79_RESETVAL (0x00000000u)

/* vector_address_reg_80 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_80_VECTOR_ADDRESS_80_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_80_VECTOR_ADDRESS_80_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_80_VECTOR_ADDRESS_80_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_80_RESETVAL (0x00000000u)

/* vector_address_reg_81 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_81_VECTOR_ADDRESS_81_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_81_VECTOR_ADDRESS_81_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_81_VECTOR_ADDRESS_81_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_81_RESETVAL (0x00000000u)

/* vector_address_reg_82 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_82_VECTOR_ADDRESS_82_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_82_VECTOR_ADDRESS_82_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_82_VECTOR_ADDRESS_82_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_82_RESETVAL (0x00000000u)

/* vector_address_reg_83 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_83_VECTOR_ADDRESS_83_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_83_VECTOR_ADDRESS_83_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_83_VECTOR_ADDRESS_83_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_83_RESETVAL (0x00000000u)

/* vector_address_reg_84 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_84_VECTOR_ADDRESS_84_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_84_VECTOR_ADDRESS_84_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_84_VECTOR_ADDRESS_84_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_84_RESETVAL (0x00000000u)

/* vector_address_reg_85 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_85_VECTOR_ADDRESS_85_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_85_VECTOR_ADDRESS_85_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_85_VECTOR_ADDRESS_85_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_85_RESETVAL (0x00000000u)

/* vector_address_reg_86 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_86_VECTOR_ADDRESS_86_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_86_VECTOR_ADDRESS_86_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_86_VECTOR_ADDRESS_86_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_86_RESETVAL (0x00000000u)

/* vector_address_reg_87 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_87_VECTOR_ADDRESS_87_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_87_VECTOR_ADDRESS_87_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_87_VECTOR_ADDRESS_87_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_87_RESETVAL (0x00000000u)

/* vector_address_reg_88 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_88_VECTOR_ADDRESS_88_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_88_VECTOR_ADDRESS_88_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_88_VECTOR_ADDRESS_88_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_88_RESETVAL (0x00000000u)

/* vector_address_reg_89 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_89_VECTOR_ADDRESS_89_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_89_VECTOR_ADDRESS_89_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_89_VECTOR_ADDRESS_89_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_89_RESETVAL (0x00000000u)

/* vector_address_reg_90 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_90_VECTOR_ADDRESS_90_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_90_VECTOR_ADDRESS_90_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_90_VECTOR_ADDRESS_90_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_90_RESETVAL (0x00000000u)

/* vector_address_reg_91 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_91_VECTOR_ADDRESS_91_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_91_VECTOR_ADDRESS_91_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_91_VECTOR_ADDRESS_91_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_91_RESETVAL (0x00000000u)

/* vector_address_reg_92 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_92_VECTOR_ADDRESS_92_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_92_VECTOR_ADDRESS_92_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_92_VECTOR_ADDRESS_92_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_92_RESETVAL (0x00000000u)

/* vector_address_reg_93 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_93_VECTOR_ADDRESS_93_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_93_VECTOR_ADDRESS_93_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_93_VECTOR_ADDRESS_93_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_93_RESETVAL (0x00000000u)

/* vector_address_reg_94 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_94_VECTOR_ADDRESS_94_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_94_VECTOR_ADDRESS_94_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_94_VECTOR_ADDRESS_94_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_94_RESETVAL (0x00000000u)

/* vector_address_reg_95 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_95_VECTOR_ADDRESS_95_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_95_VECTOR_ADDRESS_95_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_95_VECTOR_ADDRESS_95_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_95_RESETVAL (0x00000000u)

/* vector_address_reg_96 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_96_VECTOR_ADDRESS_96_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_96_VECTOR_ADDRESS_96_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_96_VECTOR_ADDRESS_96_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_96_RESETVAL (0x00000000u)

/* vector_address_reg_97 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_97_VECTOR_ADDRESS_97_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_97_VECTOR_ADDRESS_97_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_97_VECTOR_ADDRESS_97_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_97_RESETVAL (0x00000000u)

/* vector_address_reg_98 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_98_VECTOR_ADDRESS_98_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_98_VECTOR_ADDRESS_98_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_98_VECTOR_ADDRESS_98_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_98_RESETVAL (0x00000000u)

/* vector_address_reg_99 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_99_VECTOR_ADDRESS_99_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_99_VECTOR_ADDRESS_99_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_99_VECTOR_ADDRESS_99_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_99_RESETVAL (0x00000000u)

/* vector_address_reg_100 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_100_VECTOR_ADDRESS_100_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_100_VECTOR_ADDRESS_100_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_100_VECTOR_ADDRESS_100_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_100_RESETVAL (0x00000000u)

/* vector_address_reg_101 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_101_VECTOR_ADDRESS_101_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_101_VECTOR_ADDRESS_101_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_101_VECTOR_ADDRESS_101_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_101_RESETVAL (0x00000000u)

/* vector_address_reg_102 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_102_VECTOR_ADDRESS_102_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_102_VECTOR_ADDRESS_102_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_102_VECTOR_ADDRESS_102_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_102_RESETVAL (0x00000000u)

/* vector_address_reg_103 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_103_VECTOR_ADDRESS_103_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_103_VECTOR_ADDRESS_103_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_103_VECTOR_ADDRESS_103_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_103_RESETVAL (0x00000000u)

/* vector_address_reg_104 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_104_VECTOR_ADDRESS_104_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_104_VECTOR_ADDRESS_104_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_104_VECTOR_ADDRESS_104_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_104_RESETVAL (0x00000000u)

/* vector_address_reg_105 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_105_VECTOR_ADDRESS_105_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_105_VECTOR_ADDRESS_105_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_105_VECTOR_ADDRESS_105_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_105_RESETVAL (0x00000000u)

/* vector_address_reg_106 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_106_VECTOR_ADDRESS_106_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_106_VECTOR_ADDRESS_106_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_106_VECTOR_ADDRESS_106_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_106_RESETVAL (0x00000000u)

/* vector_address_reg_107 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_107_VECTOR_ADDRESS_107_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_107_VECTOR_ADDRESS_107_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_107_VECTOR_ADDRESS_107_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_107_RESETVAL (0x00000000u)

/* vector_address_reg_108 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_108_VECTOR_ADDRESS_108_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_108_VECTOR_ADDRESS_108_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_108_VECTOR_ADDRESS_108_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_108_RESETVAL (0x00000000u)

/* vector_address_reg_109 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_109_VECTOR_ADDRESS_109_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_109_VECTOR_ADDRESS_109_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_109_VECTOR_ADDRESS_109_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_109_RESETVAL (0x00000000u)

/* vector_address_reg_110 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_110_VECTOR_ADDRESS_110_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_110_VECTOR_ADDRESS_110_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_110_VECTOR_ADDRESS_110_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_110_RESETVAL (0x00000000u)

/* vector_address_reg_111 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_111_VECTOR_ADDRESS_111_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_111_VECTOR_ADDRESS_111_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_111_VECTOR_ADDRESS_111_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_111_RESETVAL (0x00000000u)

/* vector_address_reg_112 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_112_VECTOR_ADDRESS_112_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_112_VECTOR_ADDRESS_112_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_112_VECTOR_ADDRESS_112_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_112_RESETVAL (0x00000000u)

/* vector_address_reg_113 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_113_VECTOR_ADDRESS_113_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_113_VECTOR_ADDRESS_113_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_113_VECTOR_ADDRESS_113_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_113_RESETVAL (0x00000000u)

/* vector_address_reg_114 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_114_VECTOR_ADDRESS_114_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_114_VECTOR_ADDRESS_114_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_114_VECTOR_ADDRESS_114_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_114_RESETVAL (0x00000000u)

/* vector_address_reg_115 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_115_VECTOR_ADDRESS_115_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_115_VECTOR_ADDRESS_115_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_115_VECTOR_ADDRESS_115_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_115_RESETVAL (0x00000000u)

/* vector_address_reg_116 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_116_VECTOR_ADDRESS_116_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_116_VECTOR_ADDRESS_116_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_116_VECTOR_ADDRESS_116_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_116_RESETVAL (0x00000000u)

/* vector_address_reg_117 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_117_VECTOR_ADDRESS_117_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_117_VECTOR_ADDRESS_117_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_117_VECTOR_ADDRESS_117_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_117_RESETVAL (0x00000000u)

/* vector_address_reg_118 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_118_VECTOR_ADDRESS_118_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_118_VECTOR_ADDRESS_118_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_118_VECTOR_ADDRESS_118_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_118_RESETVAL (0x00000000u)

/* vector_address_reg_119 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_119_VECTOR_ADDRESS_119_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_119_VECTOR_ADDRESS_119_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_119_VECTOR_ADDRESS_119_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_119_RESETVAL (0x00000000u)

/* vector_address_reg_120 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_120_VECTOR_ADDRESS_120_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_120_VECTOR_ADDRESS_120_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_120_VECTOR_ADDRESS_120_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_120_RESETVAL (0x00000000u)

/* vector_address_reg_121 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_121_VECTOR_ADDRESS_121_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_121_VECTOR_ADDRESS_121_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_121_VECTOR_ADDRESS_121_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_121_RESETVAL (0x00000000u)

/* vector_address_reg_122 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_122_VECTOR_ADDRESS_122_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_122_VECTOR_ADDRESS_122_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_122_VECTOR_ADDRESS_122_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_122_RESETVAL (0x00000000u)

/* vector_address_reg_123 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_123_VECTOR_ADDRESS_123_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_123_VECTOR_ADDRESS_123_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_123_VECTOR_ADDRESS_123_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_123_RESETVAL (0x00000000u)

/* vector_address_reg_124 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_124_VECTOR_ADDRESS_124_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_124_VECTOR_ADDRESS_124_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_124_VECTOR_ADDRESS_124_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_124_RESETVAL (0x00000000u)

/* vector_address_reg_125 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_125_VECTOR_ADDRESS_125_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_125_VECTOR_ADDRESS_125_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_125_VECTOR_ADDRESS_125_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_125_RESETVAL (0x00000000u)

/* vector_address_reg_126 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_126_VECTOR_ADDRESS_126_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_126_VECTOR_ADDRESS_126_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_126_VECTOR_ADDRESS_126_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_126_RESETVAL (0x00000000u)

/* vector_address_reg_127 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_127_VECTOR_ADDRESS_127_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_127_VECTOR_ADDRESS_127_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_127_VECTOR_ADDRESS_127_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_127_RESETVAL (0x00000000u)

/* vector_address_reg_128 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_128_VECTOR_ADDRESS_128_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_128_VECTOR_ADDRESS_128_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_128_VECTOR_ADDRESS_128_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_128_RESETVAL (0x00000000u)

/* vector_address_reg_129 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_129_VECTOR_ADDRESS_129_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_129_VECTOR_ADDRESS_129_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_129_VECTOR_ADDRESS_129_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_129_RESETVAL (0x00000000u)

/* vector_address_reg_130 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_130_VECTOR_ADDRESS_130_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_130_VECTOR_ADDRESS_130_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_130_VECTOR_ADDRESS_130_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_130_RESETVAL (0x00000000u)

/* vector_address_reg_131 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_131_VECTOR_ADDRESS_131_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_131_VECTOR_ADDRESS_131_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_131_VECTOR_ADDRESS_131_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_131_RESETVAL (0x00000000u)

/* vector_address_reg_132 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_132_VECTOR_ADDRESS_132_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_132_VECTOR_ADDRESS_132_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_132_VECTOR_ADDRESS_132_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_132_RESETVAL (0x00000000u)

/* vector_address_reg_133 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_133_VECTOR_ADDRESS_133_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_133_VECTOR_ADDRESS_133_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_133_VECTOR_ADDRESS_133_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_133_RESETVAL (0x00000000u)

/* vector_address_reg_134 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_134_VECTOR_ADDRESS_134_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_134_VECTOR_ADDRESS_134_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_134_VECTOR_ADDRESS_134_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_134_RESETVAL (0x00000000u)

/* vector_address_reg_135 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_135_VECTOR_ADDRESS_135_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_135_VECTOR_ADDRESS_135_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_135_VECTOR_ADDRESS_135_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_135_RESETVAL (0x00000000u)

/* vector_address_reg_136 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_136_VECTOR_ADDRESS_136_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_136_VECTOR_ADDRESS_136_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_136_VECTOR_ADDRESS_136_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_136_RESETVAL (0x00000000u)

/* vector_address_reg_137 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_137_VECTOR_ADDRESS_137_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_137_VECTOR_ADDRESS_137_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_137_VECTOR_ADDRESS_137_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_137_RESETVAL (0x00000000u)

/* vector_address_reg_138 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_138_VECTOR_ADDRESS_138_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_138_VECTOR_ADDRESS_138_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_138_VECTOR_ADDRESS_138_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_138_RESETVAL (0x00000000u)

/* vector_address_reg_139 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_139_VECTOR_ADDRESS_139_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_139_VECTOR_ADDRESS_139_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_139_VECTOR_ADDRESS_139_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_139_RESETVAL (0x00000000u)

/* vector_address_reg_140 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_140_VECTOR_ADDRESS_140_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_140_VECTOR_ADDRESS_140_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_140_VECTOR_ADDRESS_140_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_140_RESETVAL (0x00000000u)

/* vector_address_reg_141 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_141_VECTOR_ADDRESS_141_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_141_VECTOR_ADDRESS_141_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_141_VECTOR_ADDRESS_141_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_141_RESETVAL (0x00000000u)

/* vector_address_reg_142 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_142_VECTOR_ADDRESS_142_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_142_VECTOR_ADDRESS_142_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_142_VECTOR_ADDRESS_142_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_142_RESETVAL (0x00000000u)

/* vector_address_reg_143 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_143_VECTOR_ADDRESS_143_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_143_VECTOR_ADDRESS_143_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_143_VECTOR_ADDRESS_143_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_143_RESETVAL (0x00000000u)

/* vector_address_reg_144 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_144_VECTOR_ADDRESS_144_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_144_VECTOR_ADDRESS_144_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_144_VECTOR_ADDRESS_144_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_144_RESETVAL (0x00000000u)

/* vector_address_reg_145 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_145_VECTOR_ADDRESS_145_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_145_VECTOR_ADDRESS_145_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_145_VECTOR_ADDRESS_145_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_145_RESETVAL (0x00000000u)

/* vector_address_reg_146 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_146_VECTOR_ADDRESS_146_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_146_VECTOR_ADDRESS_146_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_146_VECTOR_ADDRESS_146_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_146_RESETVAL (0x00000000u)

/* vector_address_reg_147 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_147_VECTOR_ADDRESS_147_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_147_VECTOR_ADDRESS_147_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_147_VECTOR_ADDRESS_147_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_147_RESETVAL (0x00000000u)

/* vector_address_reg_148 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_148_VECTOR_ADDRESS_148_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_148_VECTOR_ADDRESS_148_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_148_VECTOR_ADDRESS_148_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_148_RESETVAL (0x00000000u)

/* vector_address_reg_149 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_149_VECTOR_ADDRESS_149_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_149_VECTOR_ADDRESS_149_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_149_VECTOR_ADDRESS_149_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_149_RESETVAL (0x00000000u)

/* vector_address_reg_150 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_150_VECTOR_ADDRESS_150_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_150_VECTOR_ADDRESS_150_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_150_VECTOR_ADDRESS_150_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_150_RESETVAL (0x00000000u)

/* vector_address_reg_151 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_151_VECTOR_ADDRESS_151_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_151_VECTOR_ADDRESS_151_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_151_VECTOR_ADDRESS_151_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_151_RESETVAL (0x00000000u)

/* vector_address_reg_152 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_152_VECTOR_ADDRESS_152_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_152_VECTOR_ADDRESS_152_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_152_VECTOR_ADDRESS_152_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_152_RESETVAL (0x00000000u)

/* vector_address_reg_153 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_153_VECTOR_ADDRESS_153_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_153_VECTOR_ADDRESS_153_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_153_VECTOR_ADDRESS_153_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_153_RESETVAL (0x00000000u)

/* vector_address_reg_154 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_154_VECTOR_ADDRESS_154_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_154_VECTOR_ADDRESS_154_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_154_VECTOR_ADDRESS_154_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_154_RESETVAL (0x00000000u)

/* vector_address_reg_155 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_155_VECTOR_ADDRESS_155_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_155_VECTOR_ADDRESS_155_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_155_VECTOR_ADDRESS_155_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_155_RESETVAL (0x00000000u)

/* vector_address_reg_156 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_156_VECTOR_ADDRESS_156_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_156_VECTOR_ADDRESS_156_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_156_VECTOR_ADDRESS_156_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_156_RESETVAL (0x00000000u)

/* vector_address_reg_157 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_157_VECTOR_ADDRESS_157_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_157_VECTOR_ADDRESS_157_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_157_VECTOR_ADDRESS_157_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_157_RESETVAL (0x00000000u)

/* vector_address_reg_158 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_158_VECTOR_ADDRESS_158_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_158_VECTOR_ADDRESS_158_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_158_VECTOR_ADDRESS_158_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_158_RESETVAL (0x00000000u)

/* vector_address_reg_159 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_159_VECTOR_ADDRESS_159_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_159_VECTOR_ADDRESS_159_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_159_VECTOR_ADDRESS_159_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_159_RESETVAL (0x00000000u)

/* vector_address_reg_160 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_160_VECTOR_ADDRESS_160_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_160_VECTOR_ADDRESS_160_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_160_VECTOR_ADDRESS_160_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_160_RESETVAL (0x00000000u)

/* vector_address_reg_161 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_161_VECTOR_ADDRESS_161_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_161_VECTOR_ADDRESS_161_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_161_VECTOR_ADDRESS_161_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_161_RESETVAL (0x00000000u)

/* vector_address_reg_162 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_162_VECTOR_ADDRESS_162_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_162_VECTOR_ADDRESS_162_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_162_VECTOR_ADDRESS_162_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_162_RESETVAL (0x00000000u)

/* vector_address_reg_163 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_163_VECTOR_ADDRESS_163_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_163_VECTOR_ADDRESS_163_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_163_VECTOR_ADDRESS_163_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_163_RESETVAL (0x00000000u)

/* vector_address_reg_164 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_164_VECTOR_ADDRESS_164_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_164_VECTOR_ADDRESS_164_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_164_VECTOR_ADDRESS_164_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_164_RESETVAL (0x00000000u)

/* vector_address_reg_165 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_165_VECTOR_ADDRESS_165_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_165_VECTOR_ADDRESS_165_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_165_VECTOR_ADDRESS_165_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_165_RESETVAL (0x00000000u)

/* vector_address_reg_166 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_166_VECTOR_ADDRESS_166_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_166_VECTOR_ADDRESS_166_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_166_VECTOR_ADDRESS_166_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_166_RESETVAL (0x00000000u)

/* vector_address_reg_167 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_167_VECTOR_ADDRESS_167_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_167_VECTOR_ADDRESS_167_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_167_VECTOR_ADDRESS_167_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_167_RESETVAL (0x00000000u)

/* vector_address_reg_168 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_168_VECTOR_ADDRESS_168_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_168_VECTOR_ADDRESS_168_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_168_VECTOR_ADDRESS_168_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_168_RESETVAL (0x00000000u)

/* vector_address_reg_169 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_169_VECTOR_ADDRESS_169_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_169_VECTOR_ADDRESS_169_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_169_VECTOR_ADDRESS_169_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_169_RESETVAL (0x00000000u)

/* vector_address_reg_170 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_170_VECTOR_ADDRESS_170_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_170_VECTOR_ADDRESS_170_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_170_VECTOR_ADDRESS_170_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_170_RESETVAL (0x00000000u)

/* vector_address_reg_171 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_171_VECTOR_ADDRESS_171_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_171_VECTOR_ADDRESS_171_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_171_VECTOR_ADDRESS_171_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_171_RESETVAL (0x00000000u)

/* vector_address_reg_172 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_172_VECTOR_ADDRESS_172_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_172_VECTOR_ADDRESS_172_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_172_VECTOR_ADDRESS_172_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_172_RESETVAL (0x00000000u)

/* vector_address_reg_173 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_173_VECTOR_ADDRESS_173_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_173_VECTOR_ADDRESS_173_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_173_VECTOR_ADDRESS_173_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_173_RESETVAL (0x00000000u)

/* vector_address_reg_174 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_174_VECTOR_ADDRESS_174_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_174_VECTOR_ADDRESS_174_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_174_VECTOR_ADDRESS_174_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_174_RESETVAL (0x00000000u)

/* vector_address_reg_175 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_175_VECTOR_ADDRESS_175_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_175_VECTOR_ADDRESS_175_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_175_VECTOR_ADDRESS_175_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_175_RESETVAL (0x00000000u)

/* vector_address_reg_176 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_176_VECTOR_ADDRESS_176_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_176_VECTOR_ADDRESS_176_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_176_VECTOR_ADDRESS_176_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_176_RESETVAL (0x00000000u)

/* vector_address_reg_177 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_177_VECTOR_ADDRESS_177_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_177_VECTOR_ADDRESS_177_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_177_VECTOR_ADDRESS_177_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_177_RESETVAL (0x00000000u)

/* vector_address_reg_178 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_178_VECTOR_ADDRESS_178_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_178_VECTOR_ADDRESS_178_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_178_VECTOR_ADDRESS_178_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_178_RESETVAL (0x00000000u)

/* vector_address_reg_179 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_179_VECTOR_ADDRESS_179_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_179_VECTOR_ADDRESS_179_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_179_VECTOR_ADDRESS_179_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_179_RESETVAL (0x00000000u)

/* vector_address_reg_180 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_180_VECTOR_ADDRESS_180_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_180_VECTOR_ADDRESS_180_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_180_VECTOR_ADDRESS_180_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_180_RESETVAL (0x00000000u)

/* vector_address_reg_181 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_181_VECTOR_ADDRESS_181_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_181_VECTOR_ADDRESS_181_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_181_VECTOR_ADDRESS_181_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_181_RESETVAL (0x00000000u)

/* vector_address_reg_182 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_182_VECTOR_ADDRESS_182_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_182_VECTOR_ADDRESS_182_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_182_VECTOR_ADDRESS_182_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_182_RESETVAL (0x00000000u)

/* vector_address_reg_183 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_183_VECTOR_ADDRESS_183_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_183_VECTOR_ADDRESS_183_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_183_VECTOR_ADDRESS_183_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_183_RESETVAL (0x00000000u)

/* vector_address_reg_184 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_184_VECTOR_ADDRESS_184_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_184_VECTOR_ADDRESS_184_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_184_VECTOR_ADDRESS_184_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_184_RESETVAL (0x00000000u)

/* vector_address_reg_185 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_185_VECTOR_ADDRESS_185_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_185_VECTOR_ADDRESS_185_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_185_VECTOR_ADDRESS_185_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_185_RESETVAL (0x00000000u)

/* vector_address_reg_186 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_186_VECTOR_ADDRESS_186_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_186_VECTOR_ADDRESS_186_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_186_VECTOR_ADDRESS_186_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_186_RESETVAL (0x00000000u)

/* vector_address_reg_187 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_187_VECTOR_ADDRESS_187_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_187_VECTOR_ADDRESS_187_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_187_VECTOR_ADDRESS_187_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_187_RESETVAL (0x00000000u)

/* vector_address_reg_188 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_188_VECTOR_ADDRESS_188_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_188_VECTOR_ADDRESS_188_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_188_VECTOR_ADDRESS_188_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_188_RESETVAL (0x00000000u)

/* vector_address_reg_189 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_189_VECTOR_ADDRESS_189_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_189_VECTOR_ADDRESS_189_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_189_VECTOR_ADDRESS_189_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_189_RESETVAL (0x00000000u)

/* vector_address_reg_190 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_190_VECTOR_ADDRESS_190_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_190_VECTOR_ADDRESS_190_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_190_VECTOR_ADDRESS_190_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_190_RESETVAL (0x00000000u)

/* vector_address_reg_191 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_191_VECTOR_ADDRESS_191_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_191_VECTOR_ADDRESS_191_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_191_VECTOR_ADDRESS_191_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_191_RESETVAL (0x00000000u)

/* vector_address_reg_192 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_192_VECTOR_ADDRESS_192_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_192_VECTOR_ADDRESS_192_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_192_VECTOR_ADDRESS_192_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_192_RESETVAL (0x00000000u)

/* vector_address_reg_193 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_193_VECTOR_ADDRESS_193_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_193_VECTOR_ADDRESS_193_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_193_VECTOR_ADDRESS_193_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_193_RESETVAL (0x00000000u)

/* vector_address_reg_194 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_194_VECTOR_ADDRESS_194_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_194_VECTOR_ADDRESS_194_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_194_VECTOR_ADDRESS_194_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_194_RESETVAL (0x00000000u)

/* vector_address_reg_195 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_195_VECTOR_ADDRESS_195_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_195_VECTOR_ADDRESS_195_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_195_VECTOR_ADDRESS_195_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_195_RESETVAL (0x00000000u)

/* vector_address_reg_196 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_196_VECTOR_ADDRESS_196_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_196_VECTOR_ADDRESS_196_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_196_VECTOR_ADDRESS_196_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_196_RESETVAL (0x00000000u)

/* vector_address_reg_197 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_197_VECTOR_ADDRESS_197_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_197_VECTOR_ADDRESS_197_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_197_VECTOR_ADDRESS_197_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_197_RESETVAL (0x00000000u)

/* vector_address_reg_198 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_198_VECTOR_ADDRESS_198_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_198_VECTOR_ADDRESS_198_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_198_VECTOR_ADDRESS_198_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_198_RESETVAL (0x00000000u)

/* vector_address_reg_199 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_199_VECTOR_ADDRESS_199_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_199_VECTOR_ADDRESS_199_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_199_VECTOR_ADDRESS_199_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_199_RESETVAL (0x00000000u)

/* vector_address_reg_200 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_200_VECTOR_ADDRESS_200_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_200_VECTOR_ADDRESS_200_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_200_VECTOR_ADDRESS_200_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_200_RESETVAL (0x00000000u)

/* vector_address_reg_201 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_201_VECTOR_ADDRESS_201_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_201_VECTOR_ADDRESS_201_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_201_VECTOR_ADDRESS_201_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_201_RESETVAL (0x00000000u)

/* vector_address_reg_202 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_202_VECTOR_ADDRESS_202_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_202_VECTOR_ADDRESS_202_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_202_VECTOR_ADDRESS_202_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_202_RESETVAL (0x00000000u)

/* vector_address_reg_203 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_203_VECTOR_ADDRESS_203_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_203_VECTOR_ADDRESS_203_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_203_VECTOR_ADDRESS_203_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_203_RESETVAL (0x00000000u)

/* vector_address_reg_204 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_204_VECTOR_ADDRESS_204_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_204_VECTOR_ADDRESS_204_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_204_VECTOR_ADDRESS_204_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_204_RESETVAL (0x00000000u)

/* vector_address_reg_205 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_205_VECTOR_ADDRESS_205_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_205_VECTOR_ADDRESS_205_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_205_VECTOR_ADDRESS_205_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_205_RESETVAL (0x00000000u)

/* vector_address_reg_206 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_206_VECTOR_ADDRESS_206_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_206_VECTOR_ADDRESS_206_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_206_VECTOR_ADDRESS_206_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_206_RESETVAL (0x00000000u)

/* vector_address_reg_207 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_207_VECTOR_ADDRESS_207_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_207_VECTOR_ADDRESS_207_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_207_VECTOR_ADDRESS_207_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_207_RESETVAL (0x00000000u)

/* vector_address_reg_208 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_208_VECTOR_ADDRESS_208_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_208_VECTOR_ADDRESS_208_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_208_VECTOR_ADDRESS_208_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_208_RESETVAL (0x00000000u)

/* vector_address_reg_209 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_209_VECTOR_ADDRESS_209_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_209_VECTOR_ADDRESS_209_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_209_VECTOR_ADDRESS_209_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_209_RESETVAL (0x00000000u)

/* vector_address_reg_210 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_210_VECTOR_ADDRESS_210_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_210_VECTOR_ADDRESS_210_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_210_VECTOR_ADDRESS_210_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_210_RESETVAL (0x00000000u)

/* vector_address_reg_211 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_211_VECTOR_ADDRESS_211_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_211_VECTOR_ADDRESS_211_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_211_VECTOR_ADDRESS_211_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_211_RESETVAL (0x00000000u)

/* vector_address_reg_212 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_212_VECTOR_ADDRESS_212_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_212_VECTOR_ADDRESS_212_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_212_VECTOR_ADDRESS_212_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_212_RESETVAL (0x00000000u)

/* vector_address_reg_213 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_213_VECTOR_ADDRESS_213_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_213_VECTOR_ADDRESS_213_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_213_VECTOR_ADDRESS_213_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_213_RESETVAL (0x00000000u)

/* vector_address_reg_214 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_214_VECTOR_ADDRESS_214_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_214_VECTOR_ADDRESS_214_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_214_VECTOR_ADDRESS_214_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_214_RESETVAL (0x00000000u)

/* vector_address_reg_215 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_215_VECTOR_ADDRESS_215_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_215_VECTOR_ADDRESS_215_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_215_VECTOR_ADDRESS_215_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_215_RESETVAL (0x00000000u)

/* vector_address_reg_216 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_216_VECTOR_ADDRESS_216_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_216_VECTOR_ADDRESS_216_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_216_VECTOR_ADDRESS_216_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_216_RESETVAL (0x00000000u)

/* vector_address_reg_217 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_217_VECTOR_ADDRESS_217_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_217_VECTOR_ADDRESS_217_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_217_VECTOR_ADDRESS_217_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_217_RESETVAL (0x00000000u)

/* vector_address_reg_218 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_218_VECTOR_ADDRESS_218_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_218_VECTOR_ADDRESS_218_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_218_VECTOR_ADDRESS_218_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_218_RESETVAL (0x00000000u)

/* vector_address_reg_219 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_219_VECTOR_ADDRESS_219_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_219_VECTOR_ADDRESS_219_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_219_VECTOR_ADDRESS_219_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_219_RESETVAL (0x00000000u)

/* vector_address_reg_220 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_220_VECTOR_ADDRESS_220_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_220_VECTOR_ADDRESS_220_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_220_VECTOR_ADDRESS_220_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_220_RESETVAL (0x00000000u)

/* vector_address_reg_221 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_221_VECTOR_ADDRESS_221_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_221_VECTOR_ADDRESS_221_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_221_VECTOR_ADDRESS_221_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_221_RESETVAL (0x00000000u)

/* vector_address_reg_222 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_222_VECTOR_ADDRESS_222_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_222_VECTOR_ADDRESS_222_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_222_VECTOR_ADDRESS_222_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_222_RESETVAL (0x00000000u)

/* vector_address_reg_223 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_223_VECTOR_ADDRESS_223_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_223_VECTOR_ADDRESS_223_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_223_VECTOR_ADDRESS_223_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_223_RESETVAL (0x00000000u)

/* vector_address_reg_224 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_224_VECTOR_ADDRESS_224_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_224_VECTOR_ADDRESS_224_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_224_VECTOR_ADDRESS_224_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_224_RESETVAL (0x00000000u)

/* vector_address_reg_225 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_225_VECTOR_ADDRESS_225_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_225_VECTOR_ADDRESS_225_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_225_VECTOR_ADDRESS_225_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_225_RESETVAL (0x00000000u)

/* vector_address_reg_226 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_226_VECTOR_ADDRESS_226_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_226_VECTOR_ADDRESS_226_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_226_VECTOR_ADDRESS_226_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_226_RESETVAL (0x00000000u)

/* vector_address_reg_227 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_227_VECTOR_ADDRESS_227_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_227_VECTOR_ADDRESS_227_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_227_VECTOR_ADDRESS_227_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_227_RESETVAL (0x00000000u)

/* vector_address_reg_228 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_228_VECTOR_ADDRESS_228_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_228_VECTOR_ADDRESS_228_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_228_VECTOR_ADDRESS_228_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_228_RESETVAL (0x00000000u)

/* vector_address_reg_229 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_229_VECTOR_ADDRESS_229_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_229_VECTOR_ADDRESS_229_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_229_VECTOR_ADDRESS_229_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_229_RESETVAL (0x00000000u)

/* vector_address_reg_230 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_230_VECTOR_ADDRESS_230_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_230_VECTOR_ADDRESS_230_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_230_VECTOR_ADDRESS_230_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_230_RESETVAL (0x00000000u)

/* vector_address_reg_231 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_231_VECTOR_ADDRESS_231_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_231_VECTOR_ADDRESS_231_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_231_VECTOR_ADDRESS_231_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_231_RESETVAL (0x00000000u)

/* vector_address_reg_232 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_232_VECTOR_ADDRESS_232_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_232_VECTOR_ADDRESS_232_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_232_VECTOR_ADDRESS_232_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_232_RESETVAL (0x00000000u)

/* vector_address_reg_233 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_233_VECTOR_ADDRESS_233_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_233_VECTOR_ADDRESS_233_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_233_VECTOR_ADDRESS_233_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_233_RESETVAL (0x00000000u)

/* vector_address_reg_234 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_234_VECTOR_ADDRESS_234_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_234_VECTOR_ADDRESS_234_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_234_VECTOR_ADDRESS_234_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_234_RESETVAL (0x00000000u)

/* vector_address_reg_235 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_235_VECTOR_ADDRESS_235_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_235_VECTOR_ADDRESS_235_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_235_VECTOR_ADDRESS_235_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_235_RESETVAL (0x00000000u)

/* vector_address_reg_236 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_236_VECTOR_ADDRESS_236_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_236_VECTOR_ADDRESS_236_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_236_VECTOR_ADDRESS_236_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_236_RESETVAL (0x00000000u)

/* vector_address_reg_237 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_237_VECTOR_ADDRESS_237_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_237_VECTOR_ADDRESS_237_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_237_VECTOR_ADDRESS_237_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_237_RESETVAL (0x00000000u)

/* vector_address_reg_238 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_238_VECTOR_ADDRESS_238_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_238_VECTOR_ADDRESS_238_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_238_VECTOR_ADDRESS_238_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_238_RESETVAL (0x00000000u)

/* vector_address_reg_239 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_239_VECTOR_ADDRESS_239_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_239_VECTOR_ADDRESS_239_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_239_VECTOR_ADDRESS_239_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_239_RESETVAL (0x00000000u)

/* vector_address_reg_240 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_240_VECTOR_ADDRESS_240_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_240_VECTOR_ADDRESS_240_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_240_VECTOR_ADDRESS_240_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_240_RESETVAL (0x00000000u)

/* vector_address_reg_241 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_241_VECTOR_ADDRESS_241_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_241_VECTOR_ADDRESS_241_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_241_VECTOR_ADDRESS_241_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_241_RESETVAL (0x00000000u)

/* vector_address_reg_242 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_242_VECTOR_ADDRESS_242_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_242_VECTOR_ADDRESS_242_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_242_VECTOR_ADDRESS_242_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_242_RESETVAL (0x00000000u)

/* vector_address_reg_243 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_243_VECTOR_ADDRESS_243_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_243_VECTOR_ADDRESS_243_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_243_VECTOR_ADDRESS_243_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_243_RESETVAL (0x00000000u)

/* vector_address_reg_244 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_244_VECTOR_ADDRESS_244_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_244_VECTOR_ADDRESS_244_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_244_VECTOR_ADDRESS_244_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_244_RESETVAL (0x00000000u)

/* vector_address_reg_245 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_245_VECTOR_ADDRESS_245_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_245_VECTOR_ADDRESS_245_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_245_VECTOR_ADDRESS_245_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_245_RESETVAL (0x00000000u)

/* vector_address_reg_246 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_246_VECTOR_ADDRESS_246_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_246_VECTOR_ADDRESS_246_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_246_VECTOR_ADDRESS_246_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_246_RESETVAL (0x00000000u)

/* vector_address_reg_247 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_247_VECTOR_ADDRESS_247_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_247_VECTOR_ADDRESS_247_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_247_VECTOR_ADDRESS_247_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_247_RESETVAL (0x00000000u)

/* vector_address_reg_248 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_248_VECTOR_ADDRESS_248_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_248_VECTOR_ADDRESS_248_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_248_VECTOR_ADDRESS_248_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_248_RESETVAL (0x00000000u)

/* vector_address_reg_249 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_249_VECTOR_ADDRESS_249_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_249_VECTOR_ADDRESS_249_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_249_VECTOR_ADDRESS_249_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_249_RESETVAL (0x00000000u)

/* vector_address_reg_250 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_250_VECTOR_ADDRESS_250_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_250_VECTOR_ADDRESS_250_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_250_VECTOR_ADDRESS_250_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_250_RESETVAL (0x00000000u)

/* vector_address_reg_251 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_251_VECTOR_ADDRESS_251_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_251_VECTOR_ADDRESS_251_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_251_VECTOR_ADDRESS_251_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_251_RESETVAL (0x00000000u)

/* vector_address_reg_252 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_252_VECTOR_ADDRESS_252_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_252_VECTOR_ADDRESS_252_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_252_VECTOR_ADDRESS_252_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_252_RESETVAL (0x00000000u)

/* vector_address_reg_253 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_253_VECTOR_ADDRESS_253_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_253_VECTOR_ADDRESS_253_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_253_VECTOR_ADDRESS_253_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_253_RESETVAL (0x00000000u)

/* vector_address_reg_254 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_254_VECTOR_ADDRESS_254_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_254_VECTOR_ADDRESS_254_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_254_VECTOR_ADDRESS_254_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_254_RESETVAL (0x00000000u)

/* vector_address_reg_255 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_255_VECTOR_ADDRESS_255_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_255_VECTOR_ADDRESS_255_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_255_VECTOR_ADDRESS_255_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_255_RESETVAL (0x00000000u)

/* vector_address_reg_256 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_256_VECTOR_ADDRESS_256_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_256_VECTOR_ADDRESS_256_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_256_VECTOR_ADDRESS_256_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_256_RESETVAL (0x00000000u)

/* vector_address_reg_257 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_257_VECTOR_ADDRESS_257_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_257_VECTOR_ADDRESS_257_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_257_VECTOR_ADDRESS_257_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_257_RESETVAL (0x00000000u)

/* vector_address_reg_258 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_258_VECTOR_ADDRESS_258_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_258_VECTOR_ADDRESS_258_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_258_VECTOR_ADDRESS_258_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_258_RESETVAL (0x00000000u)

/* vector_address_reg_259 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_259_VECTOR_ADDRESS_259_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_259_VECTOR_ADDRESS_259_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_259_VECTOR_ADDRESS_259_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_259_RESETVAL (0x00000000u)

/* vector_address_reg_260 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_260_VECTOR_ADDRESS_260_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_260_VECTOR_ADDRESS_260_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_260_VECTOR_ADDRESS_260_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_260_RESETVAL (0x00000000u)

/* vector_address_reg_261 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_261_VECTOR_ADDRESS_261_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_261_VECTOR_ADDRESS_261_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_261_VECTOR_ADDRESS_261_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_261_RESETVAL (0x00000000u)

/* vector_address_reg_262 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_262_VECTOR_ADDRESS_262_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_262_VECTOR_ADDRESS_262_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_262_VECTOR_ADDRESS_262_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_262_RESETVAL (0x00000000u)

/* vector_address_reg_263 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_263_VECTOR_ADDRESS_263_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_263_VECTOR_ADDRESS_263_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_263_VECTOR_ADDRESS_263_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_263_RESETVAL (0x00000000u)

/* vector_address_reg_264 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_264_VECTOR_ADDRESS_264_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_264_VECTOR_ADDRESS_264_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_264_VECTOR_ADDRESS_264_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_264_RESETVAL (0x00000000u)

/* vector_address_reg_265 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_265_VECTOR_ADDRESS_265_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_265_VECTOR_ADDRESS_265_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_265_VECTOR_ADDRESS_265_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_265_RESETVAL (0x00000000u)

/* vector_address_reg_266 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_266_VECTOR_ADDRESS_266_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_266_VECTOR_ADDRESS_266_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_266_VECTOR_ADDRESS_266_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_266_RESETVAL (0x00000000u)

/* vector_address_reg_267 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_267_VECTOR_ADDRESS_267_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_267_VECTOR_ADDRESS_267_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_267_VECTOR_ADDRESS_267_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_267_RESETVAL (0x00000000u)

/* vector_address_reg_268 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_268_VECTOR_ADDRESS_268_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_268_VECTOR_ADDRESS_268_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_268_VECTOR_ADDRESS_268_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_268_RESETVAL (0x00000000u)

/* vector_address_reg_269 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_269_VECTOR_ADDRESS_269_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_269_VECTOR_ADDRESS_269_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_269_VECTOR_ADDRESS_269_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_269_RESETVAL (0x00000000u)

/* vector_address_reg_270 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_270_VECTOR_ADDRESS_270_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_270_VECTOR_ADDRESS_270_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_270_VECTOR_ADDRESS_270_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_270_RESETVAL (0x00000000u)

/* vector_address_reg_271 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_271_VECTOR_ADDRESS_271_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_271_VECTOR_ADDRESS_271_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_271_VECTOR_ADDRESS_271_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_271_RESETVAL (0x00000000u)

/* vector_address_reg_272 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_272_VECTOR_ADDRESS_272_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_272_VECTOR_ADDRESS_272_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_272_VECTOR_ADDRESS_272_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_272_RESETVAL (0x00000000u)

/* vector_address_reg_273 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_273_VECTOR_ADDRESS_273_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_273_VECTOR_ADDRESS_273_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_273_VECTOR_ADDRESS_273_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_273_RESETVAL (0x00000000u)

/* vector_address_reg_274 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_274_VECTOR_ADDRESS_274_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_274_VECTOR_ADDRESS_274_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_274_VECTOR_ADDRESS_274_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_274_RESETVAL (0x00000000u)

/* vector_address_reg_275 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_275_VECTOR_ADDRESS_275_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_275_VECTOR_ADDRESS_275_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_275_VECTOR_ADDRESS_275_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_275_RESETVAL (0x00000000u)

/* vector_address_reg_276 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_276_VECTOR_ADDRESS_276_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_276_VECTOR_ADDRESS_276_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_276_VECTOR_ADDRESS_276_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_276_RESETVAL (0x00000000u)

/* vector_address_reg_277 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_277_VECTOR_ADDRESS_277_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_277_VECTOR_ADDRESS_277_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_277_VECTOR_ADDRESS_277_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_277_RESETVAL (0x00000000u)

/* vector_address_reg_278 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_278_VECTOR_ADDRESS_278_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_278_VECTOR_ADDRESS_278_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_278_VECTOR_ADDRESS_278_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_278_RESETVAL (0x00000000u)

/* vector_address_reg_279 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_279_VECTOR_ADDRESS_279_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_279_VECTOR_ADDRESS_279_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_279_VECTOR_ADDRESS_279_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_279_RESETVAL (0x00000000u)

/* vector_address_reg_280 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_280_VECTOR_ADDRESS_280_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_280_VECTOR_ADDRESS_280_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_280_VECTOR_ADDRESS_280_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_280_RESETVAL (0x00000000u)

/* vector_address_reg_281 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_281_VECTOR_ADDRESS_281_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_281_VECTOR_ADDRESS_281_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_281_VECTOR_ADDRESS_281_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_281_RESETVAL (0x00000000u)

/* vector_address_reg_282 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_282_VECTOR_ADDRESS_282_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_282_VECTOR_ADDRESS_282_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_282_VECTOR_ADDRESS_282_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_282_RESETVAL (0x00000000u)

/* vector_address_reg_283 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_283_VECTOR_ADDRESS_283_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_283_VECTOR_ADDRESS_283_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_283_VECTOR_ADDRESS_283_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_283_RESETVAL (0x00000000u)

/* vector_address_reg_284 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_284_VECTOR_ADDRESS_284_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_284_VECTOR_ADDRESS_284_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_284_VECTOR_ADDRESS_284_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_284_RESETVAL (0x00000000u)

/* vector_address_reg_285 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_285_VECTOR_ADDRESS_285_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_285_VECTOR_ADDRESS_285_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_285_VECTOR_ADDRESS_285_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_285_RESETVAL (0x00000000u)

/* vector_address_reg_286 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_286_VECTOR_ADDRESS_286_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_286_VECTOR_ADDRESS_286_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_286_VECTOR_ADDRESS_286_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_286_RESETVAL (0x00000000u)

/* vector_address_reg_287 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_287_VECTOR_ADDRESS_287_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_287_VECTOR_ADDRESS_287_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_287_VECTOR_ADDRESS_287_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_287_RESETVAL (0x00000000u)

/* vector_address_reg_288 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_288_VECTOR_ADDRESS_288_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_288_VECTOR_ADDRESS_288_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_288_VECTOR_ADDRESS_288_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_288_RESETVAL (0x00000000u)

/* vector_address_reg_289 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_289_VECTOR_ADDRESS_289_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_289_VECTOR_ADDRESS_289_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_289_VECTOR_ADDRESS_289_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_289_RESETVAL (0x00000000u)

/* vector_address_reg_290 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_290_VECTOR_ADDRESS_290_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_290_VECTOR_ADDRESS_290_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_290_VECTOR_ADDRESS_290_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_290_RESETVAL (0x00000000u)

/* vector_address_reg_291 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_291_VECTOR_ADDRESS_291_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_291_VECTOR_ADDRESS_291_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_291_VECTOR_ADDRESS_291_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_291_RESETVAL (0x00000000u)

/* vector_address_reg_292 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_292_VECTOR_ADDRESS_292_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_292_VECTOR_ADDRESS_292_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_292_VECTOR_ADDRESS_292_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_292_RESETVAL (0x00000000u)

/* vector_address_reg_293 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_293_VECTOR_ADDRESS_293_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_293_VECTOR_ADDRESS_293_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_293_VECTOR_ADDRESS_293_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_293_RESETVAL (0x00000000u)

/* vector_address_reg_294 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_294_VECTOR_ADDRESS_294_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_294_VECTOR_ADDRESS_294_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_294_VECTOR_ADDRESS_294_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_294_RESETVAL (0x00000000u)

/* vector_address_reg_295 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_295_VECTOR_ADDRESS_295_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_295_VECTOR_ADDRESS_295_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_295_VECTOR_ADDRESS_295_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_295_RESETVAL (0x00000000u)

/* vector_address_reg_296 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_296_VECTOR_ADDRESS_296_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_296_VECTOR_ADDRESS_296_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_296_VECTOR_ADDRESS_296_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_296_RESETVAL (0x00000000u)

/* vector_address_reg_297 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_297_VECTOR_ADDRESS_297_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_297_VECTOR_ADDRESS_297_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_297_VECTOR_ADDRESS_297_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_297_RESETVAL (0x00000000u)

/* vector_address_reg_298 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_298_VECTOR_ADDRESS_298_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_298_VECTOR_ADDRESS_298_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_298_VECTOR_ADDRESS_298_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_298_RESETVAL (0x00000000u)

/* vector_address_reg_299 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_299_VECTOR_ADDRESS_299_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_299_VECTOR_ADDRESS_299_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_299_VECTOR_ADDRESS_299_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_299_RESETVAL (0x00000000u)

/* vector_address_reg_300 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_300_VECTOR_ADDRESS_300_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_300_VECTOR_ADDRESS_300_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_300_VECTOR_ADDRESS_300_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_300_RESETVAL (0x00000000u)

/* vector_address_reg_301 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_301_VECTOR_ADDRESS_301_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_301_VECTOR_ADDRESS_301_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_301_VECTOR_ADDRESS_301_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_301_RESETVAL (0x00000000u)

/* vector_address_reg_302 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_302_VECTOR_ADDRESS_302_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_302_VECTOR_ADDRESS_302_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_302_VECTOR_ADDRESS_302_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_302_RESETVAL (0x00000000u)

/* vector_address_reg_303 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_303_VECTOR_ADDRESS_303_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_303_VECTOR_ADDRESS_303_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_303_VECTOR_ADDRESS_303_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_303_RESETVAL (0x00000000u)

/* vector_address_reg_304 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_304_VECTOR_ADDRESS_304_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_304_VECTOR_ADDRESS_304_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_304_VECTOR_ADDRESS_304_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_304_RESETVAL (0x00000000u)

/* vector_address_reg_305 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_305_VECTOR_ADDRESS_305_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_305_VECTOR_ADDRESS_305_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_305_VECTOR_ADDRESS_305_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_305_RESETVAL (0x00000000u)

/* vector_address_reg_306 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_306_VECTOR_ADDRESS_306_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_306_VECTOR_ADDRESS_306_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_306_VECTOR_ADDRESS_306_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_306_RESETVAL (0x00000000u)

/* vector_address_reg_307 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_307_VECTOR_ADDRESS_307_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_307_VECTOR_ADDRESS_307_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_307_VECTOR_ADDRESS_307_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_307_RESETVAL (0x00000000u)

/* vector_address_reg_308 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_308_VECTOR_ADDRESS_308_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_308_VECTOR_ADDRESS_308_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_308_VECTOR_ADDRESS_308_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_308_RESETVAL (0x00000000u)

/* vector_address_reg_309 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_309_VECTOR_ADDRESS_309_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_309_VECTOR_ADDRESS_309_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_309_VECTOR_ADDRESS_309_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_309_RESETVAL (0x00000000u)

/* vector_address_reg_310 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_310_VECTOR_ADDRESS_310_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_310_VECTOR_ADDRESS_310_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_310_VECTOR_ADDRESS_310_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_310_RESETVAL (0x00000000u)

/* vector_address_reg_311 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_311_VECTOR_ADDRESS_311_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_311_VECTOR_ADDRESS_311_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_311_VECTOR_ADDRESS_311_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_311_RESETVAL (0x00000000u)

/* vector_address_reg_312 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_312_VECTOR_ADDRESS_312_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_312_VECTOR_ADDRESS_312_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_312_VECTOR_ADDRESS_312_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_312_RESETVAL (0x00000000u)

/* vector_address_reg_313 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_313_VECTOR_ADDRESS_313_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_313_VECTOR_ADDRESS_313_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_313_VECTOR_ADDRESS_313_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_313_RESETVAL (0x00000000u)

/* vector_address_reg_314 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_314_VECTOR_ADDRESS_314_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_314_VECTOR_ADDRESS_314_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_314_VECTOR_ADDRESS_314_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_314_RESETVAL (0x00000000u)

/* vector_address_reg_315 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_315_VECTOR_ADDRESS_315_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_315_VECTOR_ADDRESS_315_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_315_VECTOR_ADDRESS_315_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_315_RESETVAL (0x00000000u)

/* vector_address_reg_316 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_316_VECTOR_ADDRESS_316_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_316_VECTOR_ADDRESS_316_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_316_VECTOR_ADDRESS_316_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_316_RESETVAL (0x00000000u)

/* vector_address_reg_317 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_317_VECTOR_ADDRESS_317_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_317_VECTOR_ADDRESS_317_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_317_VECTOR_ADDRESS_317_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_317_RESETVAL (0x00000000u)

/* vector_address_reg_318 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_318_VECTOR_ADDRESS_318_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_318_VECTOR_ADDRESS_318_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_318_VECTOR_ADDRESS_318_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_318_RESETVAL (0x00000000u)

/* vector_address_reg_319 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_319_VECTOR_ADDRESS_319_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_319_VECTOR_ADDRESS_319_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_319_VECTOR_ADDRESS_319_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_319_RESETVAL (0x00000000u)

/* vector_address_reg_320 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_320_VECTOR_ADDRESS_320_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_320_VECTOR_ADDRESS_320_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_320_VECTOR_ADDRESS_320_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_320_RESETVAL (0x00000000u)

/* vector_address_reg_321 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_321_VECTOR_ADDRESS_321_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_321_VECTOR_ADDRESS_321_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_321_VECTOR_ADDRESS_321_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_321_RESETVAL (0x00000000u)

/* vector_address_reg_322 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_322_VECTOR_ADDRESS_322_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_322_VECTOR_ADDRESS_322_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_322_VECTOR_ADDRESS_322_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_322_RESETVAL (0x00000000u)

/* vector_address_reg_323 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_323_VECTOR_ADDRESS_323_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_323_VECTOR_ADDRESS_323_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_323_VECTOR_ADDRESS_323_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_323_RESETVAL (0x00000000u)

/* vector_address_reg_324 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_324_VECTOR_ADDRESS_324_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_324_VECTOR_ADDRESS_324_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_324_VECTOR_ADDRESS_324_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_324_RESETVAL (0x00000000u)

/* vector_address_reg_325 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_325_VECTOR_ADDRESS_325_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_325_VECTOR_ADDRESS_325_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_325_VECTOR_ADDRESS_325_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_325_RESETVAL (0x00000000u)

/* vector_address_reg_326 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_326_VECTOR_ADDRESS_326_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_326_VECTOR_ADDRESS_326_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_326_VECTOR_ADDRESS_326_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_326_RESETVAL (0x00000000u)

/* vector_address_reg_327 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_327_VECTOR_ADDRESS_327_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_327_VECTOR_ADDRESS_327_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_327_VECTOR_ADDRESS_327_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_327_RESETVAL (0x00000000u)

/* vector_address_reg_328 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_328_VECTOR_ADDRESS_328_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_328_VECTOR_ADDRESS_328_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_328_VECTOR_ADDRESS_328_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_328_RESETVAL (0x00000000u)

/* vector_address_reg_329 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_329_VECTOR_ADDRESS_329_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_329_VECTOR_ADDRESS_329_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_329_VECTOR_ADDRESS_329_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_329_RESETVAL (0x00000000u)

/* vector_address_reg_330 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_330_VECTOR_ADDRESS_330_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_330_VECTOR_ADDRESS_330_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_330_VECTOR_ADDRESS_330_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_330_RESETVAL (0x00000000u)

/* vector_address_reg_331 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_331_VECTOR_ADDRESS_331_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_331_VECTOR_ADDRESS_331_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_331_VECTOR_ADDRESS_331_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_331_RESETVAL (0x00000000u)

/* vector_address_reg_332 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_332_VECTOR_ADDRESS_332_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_332_VECTOR_ADDRESS_332_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_332_VECTOR_ADDRESS_332_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_332_RESETVAL (0x00000000u)

/* vector_address_reg_333 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_333_VECTOR_ADDRESS_333_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_333_VECTOR_ADDRESS_333_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_333_VECTOR_ADDRESS_333_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_333_RESETVAL (0x00000000u)

/* vector_address_reg_334 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_334_VECTOR_ADDRESS_334_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_334_VECTOR_ADDRESS_334_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_334_VECTOR_ADDRESS_334_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_334_RESETVAL (0x00000000u)

/* vector_address_reg_335 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_335_VECTOR_ADDRESS_335_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_335_VECTOR_ADDRESS_335_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_335_VECTOR_ADDRESS_335_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_335_RESETVAL (0x00000000u)

/* vector_address_reg_336 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_336_VECTOR_ADDRESS_336_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_336_VECTOR_ADDRESS_336_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_336_VECTOR_ADDRESS_336_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_336_RESETVAL (0x00000000u)

/* vector_address_reg_337 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_337_VECTOR_ADDRESS_337_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_337_VECTOR_ADDRESS_337_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_337_VECTOR_ADDRESS_337_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_337_RESETVAL (0x00000000u)

/* vector_address_reg_338 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_338_VECTOR_ADDRESS_338_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_338_VECTOR_ADDRESS_338_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_338_VECTOR_ADDRESS_338_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_338_RESETVAL (0x00000000u)

/* vector_address_reg_339 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_339_VECTOR_ADDRESS_339_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_339_VECTOR_ADDRESS_339_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_339_VECTOR_ADDRESS_339_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_339_RESETVAL (0x00000000u)

/* vector_address_reg_340 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_340_VECTOR_ADDRESS_340_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_340_VECTOR_ADDRESS_340_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_340_VECTOR_ADDRESS_340_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_340_RESETVAL (0x00000000u)

/* vector_address_reg_341 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_341_VECTOR_ADDRESS_341_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_341_VECTOR_ADDRESS_341_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_341_VECTOR_ADDRESS_341_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_341_RESETVAL (0x00000000u)

/* vector_address_reg_342 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_342_VECTOR_ADDRESS_342_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_342_VECTOR_ADDRESS_342_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_342_VECTOR_ADDRESS_342_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_342_RESETVAL (0x00000000u)

/* vector_address_reg_343 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_343_VECTOR_ADDRESS_343_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_343_VECTOR_ADDRESS_343_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_343_VECTOR_ADDRESS_343_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_343_RESETVAL (0x00000000u)

/* vector_address_reg_344 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_344_VECTOR_ADDRESS_344_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_344_VECTOR_ADDRESS_344_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_344_VECTOR_ADDRESS_344_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_344_RESETVAL (0x00000000u)

/* vector_address_reg_345 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_345_VECTOR_ADDRESS_345_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_345_VECTOR_ADDRESS_345_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_345_VECTOR_ADDRESS_345_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_345_RESETVAL (0x00000000u)

/* vector_address_reg_346 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_346_VECTOR_ADDRESS_346_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_346_VECTOR_ADDRESS_346_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_346_VECTOR_ADDRESS_346_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_346_RESETVAL (0x00000000u)

/* vector_address_reg_347 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_347_VECTOR_ADDRESS_347_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_347_VECTOR_ADDRESS_347_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_347_VECTOR_ADDRESS_347_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_347_RESETVAL (0x00000000u)

/* vector_address_reg_348 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_348_VECTOR_ADDRESS_348_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_348_VECTOR_ADDRESS_348_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_348_VECTOR_ADDRESS_348_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_348_RESETVAL (0x00000000u)

/* vector_address_reg_349 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_349_VECTOR_ADDRESS_349_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_349_VECTOR_ADDRESS_349_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_349_VECTOR_ADDRESS_349_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_349_RESETVAL (0x00000000u)

/* vector_address_reg_350 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_350_VECTOR_ADDRESS_350_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_350_VECTOR_ADDRESS_350_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_350_VECTOR_ADDRESS_350_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_350_RESETVAL (0x00000000u)

/* vector_address_reg_351 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_351_VECTOR_ADDRESS_351_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_351_VECTOR_ADDRESS_351_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_351_VECTOR_ADDRESS_351_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_351_RESETVAL (0x00000000u)

/* vector_address_reg_352 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_352_VECTOR_ADDRESS_352_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_352_VECTOR_ADDRESS_352_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_352_VECTOR_ADDRESS_352_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_352_RESETVAL (0x00000000u)

/* vector_address_reg_353 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_353_VECTOR_ADDRESS_353_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_353_VECTOR_ADDRESS_353_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_353_VECTOR_ADDRESS_353_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_353_RESETVAL (0x00000000u)

/* vector_address_reg_354 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_354_VECTOR_ADDRESS_354_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_354_VECTOR_ADDRESS_354_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_354_VECTOR_ADDRESS_354_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_354_RESETVAL (0x00000000u)

/* vector_address_reg_355 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_355_VECTOR_ADDRESS_355_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_355_VECTOR_ADDRESS_355_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_355_VECTOR_ADDRESS_355_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_355_RESETVAL (0x00000000u)

/* vector_address_reg_356 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_356_VECTOR_ADDRESS_356_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_356_VECTOR_ADDRESS_356_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_356_VECTOR_ADDRESS_356_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_356_RESETVAL (0x00000000u)

/* vector_address_reg_357 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_357_VECTOR_ADDRESS_357_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_357_VECTOR_ADDRESS_357_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_357_VECTOR_ADDRESS_357_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_357_RESETVAL (0x00000000u)

/* vector_address_reg_358 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_358_VECTOR_ADDRESS_358_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_358_VECTOR_ADDRESS_358_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_358_VECTOR_ADDRESS_358_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_358_RESETVAL (0x00000000u)

/* vector_address_reg_359 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_359_VECTOR_ADDRESS_359_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_359_VECTOR_ADDRESS_359_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_359_VECTOR_ADDRESS_359_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_359_RESETVAL (0x00000000u)

/* vector_address_reg_360 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_360_VECTOR_ADDRESS_360_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_360_VECTOR_ADDRESS_360_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_360_VECTOR_ADDRESS_360_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_360_RESETVAL (0x00000000u)

/* vector_address_reg_361 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_361_VECTOR_ADDRESS_361_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_361_VECTOR_ADDRESS_361_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_361_VECTOR_ADDRESS_361_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_361_RESETVAL (0x00000000u)

/* vector_address_reg_362 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_362_VECTOR_ADDRESS_362_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_362_VECTOR_ADDRESS_362_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_362_VECTOR_ADDRESS_362_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_362_RESETVAL (0x00000000u)

/* vector_address_reg_363 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_363_VECTOR_ADDRESS_363_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_363_VECTOR_ADDRESS_363_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_363_VECTOR_ADDRESS_363_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_363_RESETVAL (0x00000000u)

/* vector_address_reg_364 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_364_VECTOR_ADDRESS_364_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_364_VECTOR_ADDRESS_364_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_364_VECTOR_ADDRESS_364_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_364_RESETVAL (0x00000000u)

/* vector_address_reg_365 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_365_VECTOR_ADDRESS_365_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_365_VECTOR_ADDRESS_365_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_365_VECTOR_ADDRESS_365_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_365_RESETVAL (0x00000000u)

/* vector_address_reg_366 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_366_VECTOR_ADDRESS_366_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_366_VECTOR_ADDRESS_366_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_366_VECTOR_ADDRESS_366_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_366_RESETVAL (0x00000000u)

/* vector_address_reg_367 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_367_VECTOR_ADDRESS_367_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_367_VECTOR_ADDRESS_367_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_367_VECTOR_ADDRESS_367_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_367_RESETVAL (0x00000000u)

/* vector_address_reg_368 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_368_VECTOR_ADDRESS_368_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_368_VECTOR_ADDRESS_368_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_368_VECTOR_ADDRESS_368_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_368_RESETVAL (0x00000000u)

/* vector_address_reg_369 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_369_VECTOR_ADDRESS_369_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_369_VECTOR_ADDRESS_369_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_369_VECTOR_ADDRESS_369_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_369_RESETVAL (0x00000000u)

/* vector_address_reg_370 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_370_VECTOR_ADDRESS_370_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_370_VECTOR_ADDRESS_370_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_370_VECTOR_ADDRESS_370_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_370_RESETVAL (0x00000000u)

/* vector_address_reg_371 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_371_VECTOR_ADDRESS_371_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_371_VECTOR_ADDRESS_371_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_371_VECTOR_ADDRESS_371_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_371_RESETVAL (0x00000000u)

/* vector_address_reg_372 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_372_VECTOR_ADDRESS_372_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_372_VECTOR_ADDRESS_372_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_372_VECTOR_ADDRESS_372_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_372_RESETVAL (0x00000000u)

/* vector_address_reg_373 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_373_VECTOR_ADDRESS_373_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_373_VECTOR_ADDRESS_373_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_373_VECTOR_ADDRESS_373_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_373_RESETVAL (0x00000000u)

/* vector_address_reg_374 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_374_VECTOR_ADDRESS_374_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_374_VECTOR_ADDRESS_374_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_374_VECTOR_ADDRESS_374_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_374_RESETVAL (0x00000000u)

/* vector_address_reg_375 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_375_VECTOR_ADDRESS_375_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_375_VECTOR_ADDRESS_375_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_375_VECTOR_ADDRESS_375_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_375_RESETVAL (0x00000000u)

/* vector_address_reg_376 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_376_VECTOR_ADDRESS_376_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_376_VECTOR_ADDRESS_376_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_376_VECTOR_ADDRESS_376_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_376_RESETVAL (0x00000000u)

/* vector_address_reg_377 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_377_VECTOR_ADDRESS_377_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_377_VECTOR_ADDRESS_377_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_377_VECTOR_ADDRESS_377_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_377_RESETVAL (0x00000000u)

/* vector_address_reg_378 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_378_VECTOR_ADDRESS_378_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_378_VECTOR_ADDRESS_378_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_378_VECTOR_ADDRESS_378_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_378_RESETVAL (0x00000000u)

/* vector_address_reg_379 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_379_VECTOR_ADDRESS_379_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_379_VECTOR_ADDRESS_379_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_379_VECTOR_ADDRESS_379_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_379_RESETVAL (0x00000000u)

/* vector_address_reg_380 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_380_VECTOR_ADDRESS_380_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_380_VECTOR_ADDRESS_380_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_380_VECTOR_ADDRESS_380_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_380_RESETVAL (0x00000000u)

/* vector_address_reg_381 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_381_VECTOR_ADDRESS_381_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_381_VECTOR_ADDRESS_381_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_381_VECTOR_ADDRESS_381_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_381_RESETVAL (0x00000000u)

/* vector_address_reg_382 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_382_VECTOR_ADDRESS_382_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_382_VECTOR_ADDRESS_382_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_382_VECTOR_ADDRESS_382_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_382_RESETVAL (0x00000000u)

/* vector_address_reg_383 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_383_VECTOR_ADDRESS_383_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_383_VECTOR_ADDRESS_383_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_383_VECTOR_ADDRESS_383_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_383_RESETVAL (0x00000000u)

/* vector_address_reg_384 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_384_VECTOR_ADDRESS_384_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_384_VECTOR_ADDRESS_384_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_384_VECTOR_ADDRESS_384_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_384_RESETVAL (0x00000000u)

/* vector_address_reg_385 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_385_VECTOR_ADDRESS_385_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_385_VECTOR_ADDRESS_385_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_385_VECTOR_ADDRESS_385_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_385_RESETVAL (0x00000000u)

/* vector_address_reg_386 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_386_VECTOR_ADDRESS_386_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_386_VECTOR_ADDRESS_386_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_386_VECTOR_ADDRESS_386_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_386_RESETVAL (0x00000000u)

/* vector_address_reg_387 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_387_VECTOR_ADDRESS_387_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_387_VECTOR_ADDRESS_387_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_387_VECTOR_ADDRESS_387_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_387_RESETVAL (0x00000000u)

/* vector_address_reg_388 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_388_VECTOR_ADDRESS_388_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_388_VECTOR_ADDRESS_388_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_388_VECTOR_ADDRESS_388_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_388_RESETVAL (0x00000000u)

/* vector_address_reg_389 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_389_VECTOR_ADDRESS_389_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_389_VECTOR_ADDRESS_389_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_389_VECTOR_ADDRESS_389_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_389_RESETVAL (0x00000000u)

/* vector_address_reg_390 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_390_VECTOR_ADDRESS_390_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_390_VECTOR_ADDRESS_390_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_390_VECTOR_ADDRESS_390_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_390_RESETVAL (0x00000000u)

/* vector_address_reg_391 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_391_VECTOR_ADDRESS_391_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_391_VECTOR_ADDRESS_391_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_391_VECTOR_ADDRESS_391_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_391_RESETVAL (0x00000000u)

/* vector_address_reg_392 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_392_VECTOR_ADDRESS_392_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_392_VECTOR_ADDRESS_392_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_392_VECTOR_ADDRESS_392_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_392_RESETVAL (0x00000000u)

/* vector_address_reg_393 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_393_VECTOR_ADDRESS_393_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_393_VECTOR_ADDRESS_393_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_393_VECTOR_ADDRESS_393_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_393_RESETVAL (0x00000000u)

/* vector_address_reg_394 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_394_VECTOR_ADDRESS_394_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_394_VECTOR_ADDRESS_394_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_394_VECTOR_ADDRESS_394_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_394_RESETVAL (0x00000000u)

/* vector_address_reg_395 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_395_VECTOR_ADDRESS_395_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_395_VECTOR_ADDRESS_395_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_395_VECTOR_ADDRESS_395_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_395_RESETVAL (0x00000000u)

/* vector_address_reg_396 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_396_VECTOR_ADDRESS_396_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_396_VECTOR_ADDRESS_396_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_396_VECTOR_ADDRESS_396_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_396_RESETVAL (0x00000000u)

/* vector_address_reg_397 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_397_VECTOR_ADDRESS_397_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_397_VECTOR_ADDRESS_397_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_397_VECTOR_ADDRESS_397_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_397_RESETVAL (0x00000000u)

/* vector_address_reg_398 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_398_VECTOR_ADDRESS_398_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_398_VECTOR_ADDRESS_398_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_398_VECTOR_ADDRESS_398_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_398_RESETVAL (0x00000000u)

/* vector_address_reg_399 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_399_VECTOR_ADDRESS_399_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_399_VECTOR_ADDRESS_399_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_399_VECTOR_ADDRESS_399_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_399_RESETVAL (0x00000000u)

/* vector_address_reg_400 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_400_VECTOR_ADDRESS_400_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_400_VECTOR_ADDRESS_400_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_400_VECTOR_ADDRESS_400_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_400_RESETVAL (0x00000000u)

/* vector_address_reg_401 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_401_VECTOR_ADDRESS_401_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_401_VECTOR_ADDRESS_401_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_401_VECTOR_ADDRESS_401_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_401_RESETVAL (0x00000000u)

/* vector_address_reg_402 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_402_VECTOR_ADDRESS_402_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_402_VECTOR_ADDRESS_402_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_402_VECTOR_ADDRESS_402_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_402_RESETVAL (0x00000000u)

/* vector_address_reg_403 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_403_VECTOR_ADDRESS_403_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_403_VECTOR_ADDRESS_403_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_403_VECTOR_ADDRESS_403_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_403_RESETVAL (0x00000000u)

/* vector_address_reg_404 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_404_VECTOR_ADDRESS_404_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_404_VECTOR_ADDRESS_404_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_404_VECTOR_ADDRESS_404_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_404_RESETVAL (0x00000000u)

/* vector_address_reg_405 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_405_VECTOR_ADDRESS_405_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_405_VECTOR_ADDRESS_405_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_405_VECTOR_ADDRESS_405_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_405_RESETVAL (0x00000000u)

/* vector_address_reg_406 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_406_VECTOR_ADDRESS_406_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_406_VECTOR_ADDRESS_406_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_406_VECTOR_ADDRESS_406_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_406_RESETVAL (0x00000000u)

/* vector_address_reg_407 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_407_VECTOR_ADDRESS_407_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_407_VECTOR_ADDRESS_407_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_407_VECTOR_ADDRESS_407_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_407_RESETVAL (0x00000000u)

/* vector_address_reg_408 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_408_VECTOR_ADDRESS_408_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_408_VECTOR_ADDRESS_408_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_408_VECTOR_ADDRESS_408_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_408_RESETVAL (0x00000000u)

/* vector_address_reg_409 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_409_VECTOR_ADDRESS_409_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_409_VECTOR_ADDRESS_409_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_409_VECTOR_ADDRESS_409_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_409_RESETVAL (0x00000000u)

/* vector_address_reg_410 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_410_VECTOR_ADDRESS_410_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_410_VECTOR_ADDRESS_410_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_410_VECTOR_ADDRESS_410_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_410_RESETVAL (0x00000000u)

/* vector_address_reg_411 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_411_VECTOR_ADDRESS_411_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_411_VECTOR_ADDRESS_411_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_411_VECTOR_ADDRESS_411_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_411_RESETVAL (0x00000000u)

/* vector_address_reg_412 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_412_VECTOR_ADDRESS_412_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_412_VECTOR_ADDRESS_412_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_412_VECTOR_ADDRESS_412_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_412_RESETVAL (0x00000000u)

/* vector_address_reg_413 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_413_VECTOR_ADDRESS_413_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_413_VECTOR_ADDRESS_413_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_413_VECTOR_ADDRESS_413_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_413_RESETVAL (0x00000000u)

/* vector_address_reg_414 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_414_VECTOR_ADDRESS_414_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_414_VECTOR_ADDRESS_414_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_414_VECTOR_ADDRESS_414_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_414_RESETVAL (0x00000000u)

/* vector_address_reg_415 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_415_VECTOR_ADDRESS_415_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_415_VECTOR_ADDRESS_415_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_415_VECTOR_ADDRESS_415_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_415_RESETVAL (0x00000000u)

/* vector_address_reg_416 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_416_VECTOR_ADDRESS_416_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_416_VECTOR_ADDRESS_416_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_416_VECTOR_ADDRESS_416_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_416_RESETVAL (0x00000000u)

/* vector_address_reg_417 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_417_VECTOR_ADDRESS_417_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_417_VECTOR_ADDRESS_417_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_417_VECTOR_ADDRESS_417_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_417_RESETVAL (0x00000000u)

/* vector_address_reg_418 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_418_VECTOR_ADDRESS_418_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_418_VECTOR_ADDRESS_418_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_418_VECTOR_ADDRESS_418_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_418_RESETVAL (0x00000000u)

/* vector_address_reg_419 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_419_VECTOR_ADDRESS_419_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_419_VECTOR_ADDRESS_419_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_419_VECTOR_ADDRESS_419_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_419_RESETVAL (0x00000000u)

/* vector_address_reg_420 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_420_VECTOR_ADDRESS_420_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_420_VECTOR_ADDRESS_420_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_420_VECTOR_ADDRESS_420_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_420_RESETVAL (0x00000000u)

/* vector_address_reg_421 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_421_VECTOR_ADDRESS_421_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_421_VECTOR_ADDRESS_421_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_421_VECTOR_ADDRESS_421_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_421_RESETVAL (0x00000000u)

/* vector_address_reg_422 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_422_VECTOR_ADDRESS_422_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_422_VECTOR_ADDRESS_422_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_422_VECTOR_ADDRESS_422_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_422_RESETVAL (0x00000000u)

/* vector_address_reg_423 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_423_VECTOR_ADDRESS_423_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_423_VECTOR_ADDRESS_423_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_423_VECTOR_ADDRESS_423_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_423_RESETVAL (0x00000000u)

/* vector_address_reg_424 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_424_VECTOR_ADDRESS_424_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_424_VECTOR_ADDRESS_424_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_424_VECTOR_ADDRESS_424_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_424_RESETVAL (0x00000000u)

/* vector_address_reg_425 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_425_VECTOR_ADDRESS_425_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_425_VECTOR_ADDRESS_425_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_425_VECTOR_ADDRESS_425_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_425_RESETVAL (0x00000000u)

/* vector_address_reg_426 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_426_VECTOR_ADDRESS_426_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_426_VECTOR_ADDRESS_426_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_426_VECTOR_ADDRESS_426_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_426_RESETVAL (0x00000000u)

/* vector_address_reg_427 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_427_VECTOR_ADDRESS_427_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_427_VECTOR_ADDRESS_427_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_427_VECTOR_ADDRESS_427_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_427_RESETVAL (0x00000000u)

/* vector_address_reg_428 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_428_VECTOR_ADDRESS_428_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_428_VECTOR_ADDRESS_428_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_428_VECTOR_ADDRESS_428_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_428_RESETVAL (0x00000000u)

/* vector_address_reg_429 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_429_VECTOR_ADDRESS_429_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_429_VECTOR_ADDRESS_429_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_429_VECTOR_ADDRESS_429_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_429_RESETVAL (0x00000000u)

/* vector_address_reg_430 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_430_VECTOR_ADDRESS_430_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_430_VECTOR_ADDRESS_430_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_430_VECTOR_ADDRESS_430_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_430_RESETVAL (0x00000000u)

/* vector_address_reg_431 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_431_VECTOR_ADDRESS_431_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_431_VECTOR_ADDRESS_431_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_431_VECTOR_ADDRESS_431_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_431_RESETVAL (0x00000000u)

/* vector_address_reg_432 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_432_VECTOR_ADDRESS_432_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_432_VECTOR_ADDRESS_432_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_432_VECTOR_ADDRESS_432_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_432_RESETVAL (0x00000000u)

/* vector_address_reg_433 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_433_VECTOR_ADDRESS_433_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_433_VECTOR_ADDRESS_433_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_433_VECTOR_ADDRESS_433_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_433_RESETVAL (0x00000000u)

/* vector_address_reg_434 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_434_VECTOR_ADDRESS_434_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_434_VECTOR_ADDRESS_434_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_434_VECTOR_ADDRESS_434_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_434_RESETVAL (0x00000000u)

/* vector_address_reg_435 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_435_VECTOR_ADDRESS_435_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_435_VECTOR_ADDRESS_435_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_435_VECTOR_ADDRESS_435_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_435_RESETVAL (0x00000000u)

/* vector_address_reg_436 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_436_VECTOR_ADDRESS_436_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_436_VECTOR_ADDRESS_436_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_436_VECTOR_ADDRESS_436_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_436_RESETVAL (0x00000000u)

/* vector_address_reg_437 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_437_VECTOR_ADDRESS_437_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_437_VECTOR_ADDRESS_437_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_437_VECTOR_ADDRESS_437_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_437_RESETVAL (0x00000000u)

/* vector_address_reg_438 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_438_VECTOR_ADDRESS_438_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_438_VECTOR_ADDRESS_438_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_438_VECTOR_ADDRESS_438_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_438_RESETVAL (0x00000000u)

/* vector_address_reg_439 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_439_VECTOR_ADDRESS_439_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_439_VECTOR_ADDRESS_439_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_439_VECTOR_ADDRESS_439_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_439_RESETVAL (0x00000000u)

/* vector_address_reg_440 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_440_VECTOR_ADDRESS_440_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_440_VECTOR_ADDRESS_440_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_440_VECTOR_ADDRESS_440_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_440_RESETVAL (0x00000000u)

/* vector_address_reg_441 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_441_VECTOR_ADDRESS_441_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_441_VECTOR_ADDRESS_441_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_441_VECTOR_ADDRESS_441_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_441_RESETVAL (0x00000000u)

/* vector_address_reg_442 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_442_VECTOR_ADDRESS_442_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_442_VECTOR_ADDRESS_442_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_442_VECTOR_ADDRESS_442_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_442_RESETVAL (0x00000000u)

/* vector_address_reg_443 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_443_VECTOR_ADDRESS_443_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_443_VECTOR_ADDRESS_443_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_443_VECTOR_ADDRESS_443_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_443_RESETVAL (0x00000000u)

/* vector_address_reg_444 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_444_VECTOR_ADDRESS_444_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_444_VECTOR_ADDRESS_444_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_444_VECTOR_ADDRESS_444_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_444_RESETVAL (0x00000000u)

/* vector_address_reg_445 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_445_VECTOR_ADDRESS_445_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_445_VECTOR_ADDRESS_445_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_445_VECTOR_ADDRESS_445_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_445_RESETVAL (0x00000000u)

/* vector_address_reg_446 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_446_VECTOR_ADDRESS_446_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_446_VECTOR_ADDRESS_446_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_446_VECTOR_ADDRESS_446_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_446_RESETVAL (0x00000000u)

/* vector_address_reg_447 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_447_VECTOR_ADDRESS_447_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_447_VECTOR_ADDRESS_447_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_447_VECTOR_ADDRESS_447_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_447_RESETVAL (0x00000000u)

/* vector_address_reg_448 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_448_VECTOR_ADDRESS_448_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_448_VECTOR_ADDRESS_448_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_448_VECTOR_ADDRESS_448_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_448_RESETVAL (0x00000000u)

/* vector_address_reg_449 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_449_VECTOR_ADDRESS_449_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_449_VECTOR_ADDRESS_449_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_449_VECTOR_ADDRESS_449_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_449_RESETVAL (0x00000000u)

/* vector_address_reg_450 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_450_VECTOR_ADDRESS_450_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_450_VECTOR_ADDRESS_450_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_450_VECTOR_ADDRESS_450_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_450_RESETVAL (0x00000000u)

/* vector_address_reg_451 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_451_VECTOR_ADDRESS_451_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_451_VECTOR_ADDRESS_451_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_451_VECTOR_ADDRESS_451_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_451_RESETVAL (0x00000000u)

/* vector_address_reg_452 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_452_VECTOR_ADDRESS_452_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_452_VECTOR_ADDRESS_452_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_452_VECTOR_ADDRESS_452_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_452_RESETVAL (0x00000000u)

/* vector_address_reg_453 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_453_VECTOR_ADDRESS_453_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_453_VECTOR_ADDRESS_453_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_453_VECTOR_ADDRESS_453_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_453_RESETVAL (0x00000000u)

/* vector_address_reg_454 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_454_VECTOR_ADDRESS_454_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_454_VECTOR_ADDRESS_454_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_454_VECTOR_ADDRESS_454_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_454_RESETVAL (0x00000000u)

/* vector_address_reg_455 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_455_VECTOR_ADDRESS_455_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_455_VECTOR_ADDRESS_455_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_455_VECTOR_ADDRESS_455_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_455_RESETVAL (0x00000000u)

/* vector_address_reg_456 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_456_VECTOR_ADDRESS_456_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_456_VECTOR_ADDRESS_456_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_456_VECTOR_ADDRESS_456_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_456_RESETVAL (0x00000000u)

/* vector_address_reg_457 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_457_VECTOR_ADDRESS_457_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_457_VECTOR_ADDRESS_457_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_457_VECTOR_ADDRESS_457_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_457_RESETVAL (0x00000000u)

/* vector_address_reg_458 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_458_VECTOR_ADDRESS_458_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_458_VECTOR_ADDRESS_458_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_458_VECTOR_ADDRESS_458_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_458_RESETVAL (0x00000000u)

/* vector_address_reg_459 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_459_VECTOR_ADDRESS_459_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_459_VECTOR_ADDRESS_459_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_459_VECTOR_ADDRESS_459_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_459_RESETVAL (0x00000000u)

/* vector_address_reg_460 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_460_VECTOR_ADDRESS_460_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_460_VECTOR_ADDRESS_460_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_460_VECTOR_ADDRESS_460_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_460_RESETVAL (0x00000000u)

/* vector_address_reg_461 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_461_VECTOR_ADDRESS_461_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_461_VECTOR_ADDRESS_461_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_461_VECTOR_ADDRESS_461_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_461_RESETVAL (0x00000000u)

/* vector_address_reg_462 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_462_VECTOR_ADDRESS_462_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_462_VECTOR_ADDRESS_462_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_462_VECTOR_ADDRESS_462_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_462_RESETVAL (0x00000000u)

/* vector_address_reg_463 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_463_VECTOR_ADDRESS_463_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_463_VECTOR_ADDRESS_463_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_463_VECTOR_ADDRESS_463_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_463_RESETVAL (0x00000000u)

/* vector_address_reg_464 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_464_VECTOR_ADDRESS_464_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_464_VECTOR_ADDRESS_464_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_464_VECTOR_ADDRESS_464_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_464_RESETVAL (0x00000000u)

/* vector_address_reg_465 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_465_VECTOR_ADDRESS_465_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_465_VECTOR_ADDRESS_465_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_465_VECTOR_ADDRESS_465_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_465_RESETVAL (0x00000000u)

/* vector_address_reg_466 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_466_VECTOR_ADDRESS_466_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_466_VECTOR_ADDRESS_466_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_466_VECTOR_ADDRESS_466_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_466_RESETVAL (0x00000000u)

/* vector_address_reg_467 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_467_VECTOR_ADDRESS_467_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_467_VECTOR_ADDRESS_467_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_467_VECTOR_ADDRESS_467_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_467_RESETVAL (0x00000000u)

/* vector_address_reg_468 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_468_VECTOR_ADDRESS_468_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_468_VECTOR_ADDRESS_468_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_468_VECTOR_ADDRESS_468_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_468_RESETVAL (0x00000000u)

/* vector_address_reg_469 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_469_VECTOR_ADDRESS_469_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_469_VECTOR_ADDRESS_469_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_469_VECTOR_ADDRESS_469_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_469_RESETVAL (0x00000000u)

/* vector_address_reg_470 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_470_VECTOR_ADDRESS_470_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_470_VECTOR_ADDRESS_470_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_470_VECTOR_ADDRESS_470_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_470_RESETVAL (0x00000000u)

/* vector_address_reg_471 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_471_VECTOR_ADDRESS_471_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_471_VECTOR_ADDRESS_471_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_471_VECTOR_ADDRESS_471_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_471_RESETVAL (0x00000000u)

/* vector_address_reg_472 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_472_VECTOR_ADDRESS_472_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_472_VECTOR_ADDRESS_472_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_472_VECTOR_ADDRESS_472_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_472_RESETVAL (0x00000000u)

/* vector_address_reg_473 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_473_VECTOR_ADDRESS_473_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_473_VECTOR_ADDRESS_473_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_473_VECTOR_ADDRESS_473_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_473_RESETVAL (0x00000000u)

/* vector_address_reg_474 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_474_VECTOR_ADDRESS_474_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_474_VECTOR_ADDRESS_474_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_474_VECTOR_ADDRESS_474_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_474_RESETVAL (0x00000000u)

/* vector_address_reg_475 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_475_VECTOR_ADDRESS_475_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_475_VECTOR_ADDRESS_475_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_475_VECTOR_ADDRESS_475_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_475_RESETVAL (0x00000000u)

/* vector_address_reg_476 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_476_VECTOR_ADDRESS_476_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_476_VECTOR_ADDRESS_476_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_476_VECTOR_ADDRESS_476_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_476_RESETVAL (0x00000000u)

/* vector_address_reg_477 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_477_VECTOR_ADDRESS_477_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_477_VECTOR_ADDRESS_477_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_477_VECTOR_ADDRESS_477_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_477_RESETVAL (0x00000000u)

/* vector_address_reg_478 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_478_VECTOR_ADDRESS_478_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_478_VECTOR_ADDRESS_478_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_478_VECTOR_ADDRESS_478_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_478_RESETVAL (0x00000000u)

/* vector_address_reg_479 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_479_VECTOR_ADDRESS_479_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_479_VECTOR_ADDRESS_479_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_479_VECTOR_ADDRESS_479_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_479_RESETVAL (0x00000000u)

/* vector_address_reg_480 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_480_VECTOR_ADDRESS_480_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_480_VECTOR_ADDRESS_480_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_480_VECTOR_ADDRESS_480_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_480_RESETVAL (0x00000000u)

/* vector_address_reg_481 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_481_VECTOR_ADDRESS_481_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_481_VECTOR_ADDRESS_481_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_481_VECTOR_ADDRESS_481_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_481_RESETVAL (0x00000000u)

/* vector_address_reg_482 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_482_VECTOR_ADDRESS_482_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_482_VECTOR_ADDRESS_482_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_482_VECTOR_ADDRESS_482_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_482_RESETVAL (0x00000000u)

/* vector_address_reg_483 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_483_VECTOR_ADDRESS_483_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_483_VECTOR_ADDRESS_483_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_483_VECTOR_ADDRESS_483_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_483_RESETVAL (0x00000000u)

/* vector_address_reg_484 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_484_VECTOR_ADDRESS_484_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_484_VECTOR_ADDRESS_484_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_484_VECTOR_ADDRESS_484_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_484_RESETVAL (0x00000000u)

/* vector_address_reg_485 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_485_VECTOR_ADDRESS_485_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_485_VECTOR_ADDRESS_485_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_485_VECTOR_ADDRESS_485_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_485_RESETVAL (0x00000000u)

/* vector_address_reg_486 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_486_VECTOR_ADDRESS_486_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_486_VECTOR_ADDRESS_486_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_486_VECTOR_ADDRESS_486_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_486_RESETVAL (0x00000000u)

/* vector_address_reg_487 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_487_VECTOR_ADDRESS_487_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_487_VECTOR_ADDRESS_487_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_487_VECTOR_ADDRESS_487_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_487_RESETVAL (0x00000000u)

/* vector_address_reg_488 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_488_VECTOR_ADDRESS_488_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_488_VECTOR_ADDRESS_488_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_488_VECTOR_ADDRESS_488_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_488_RESETVAL (0x00000000u)

/* vector_address_reg_489 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_489_VECTOR_ADDRESS_489_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_489_VECTOR_ADDRESS_489_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_489_VECTOR_ADDRESS_489_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_489_RESETVAL (0x00000000u)

/* vector_address_reg_490 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_490_VECTOR_ADDRESS_490_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_490_VECTOR_ADDRESS_490_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_490_VECTOR_ADDRESS_490_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_490_RESETVAL (0x00000000u)

/* vector_address_reg_491 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_491_VECTOR_ADDRESS_491_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_491_VECTOR_ADDRESS_491_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_491_VECTOR_ADDRESS_491_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_491_RESETVAL (0x00000000u)

/* vector_address_reg_492 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_492_VECTOR_ADDRESS_492_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_492_VECTOR_ADDRESS_492_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_492_VECTOR_ADDRESS_492_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_492_RESETVAL (0x00000000u)

/* vector_address_reg_493 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_493_VECTOR_ADDRESS_493_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_493_VECTOR_ADDRESS_493_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_493_VECTOR_ADDRESS_493_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_493_RESETVAL (0x00000000u)

/* vector_address_reg_494 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_494_VECTOR_ADDRESS_494_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_494_VECTOR_ADDRESS_494_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_494_VECTOR_ADDRESS_494_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_494_RESETVAL (0x00000000u)

/* vector_address_reg_495 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_495_VECTOR_ADDRESS_495_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_495_VECTOR_ADDRESS_495_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_495_VECTOR_ADDRESS_495_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_495_RESETVAL (0x00000000u)

/* vector_address_reg_496 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_496_VECTOR_ADDRESS_496_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_496_VECTOR_ADDRESS_496_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_496_VECTOR_ADDRESS_496_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_496_RESETVAL (0x00000000u)

/* vector_address_reg_497 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_497_VECTOR_ADDRESS_497_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_497_VECTOR_ADDRESS_497_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_497_VECTOR_ADDRESS_497_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_497_RESETVAL (0x00000000u)

/* vector_address_reg_498 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_498_VECTOR_ADDRESS_498_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_498_VECTOR_ADDRESS_498_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_498_VECTOR_ADDRESS_498_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_498_RESETVAL (0x00000000u)

/* vector_address_reg_499 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_499_VECTOR_ADDRESS_499_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_499_VECTOR_ADDRESS_499_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_499_VECTOR_ADDRESS_499_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_499_RESETVAL (0x00000000u)

/* vector_address_reg_500 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_500_VECTOR_ADDRESS_500_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_500_VECTOR_ADDRESS_500_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_500_VECTOR_ADDRESS_500_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_500_RESETVAL (0x00000000u)

/* vector_address_reg_501 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_501_VECTOR_ADDRESS_501_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_501_VECTOR_ADDRESS_501_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_501_VECTOR_ADDRESS_501_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_501_RESETVAL (0x00000000u)

/* vector_address_reg_502 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_502_VECTOR_ADDRESS_502_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_502_VECTOR_ADDRESS_502_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_502_VECTOR_ADDRESS_502_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_502_RESETVAL (0x00000000u)

/* vector_address_reg_503 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_503_VECTOR_ADDRESS_503_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_503_VECTOR_ADDRESS_503_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_503_VECTOR_ADDRESS_503_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_503_RESETVAL (0x00000000u)

/* vector_address_reg_504 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_504_VECTOR_ADDRESS_504_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_504_VECTOR_ADDRESS_504_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_504_VECTOR_ADDRESS_504_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_504_RESETVAL (0x00000000u)

/* vector_address_reg_505 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_505_VECTOR_ADDRESS_505_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_505_VECTOR_ADDRESS_505_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_505_VECTOR_ADDRESS_505_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_505_RESETVAL (0x00000000u)

/* vector_address_reg_506 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_506_VECTOR_ADDRESS_506_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_506_VECTOR_ADDRESS_506_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_506_VECTOR_ADDRESS_506_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_506_RESETVAL (0x00000000u)

/* vector_address_reg_507 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_507_VECTOR_ADDRESS_507_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_507_VECTOR_ADDRESS_507_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_507_VECTOR_ADDRESS_507_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_507_RESETVAL (0x00000000u)

/* vector_address_reg_508 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_508_VECTOR_ADDRESS_508_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_508_VECTOR_ADDRESS_508_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_508_VECTOR_ADDRESS_508_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_508_RESETVAL (0x00000000u)

/* vector_address_reg_509 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_509_VECTOR_ADDRESS_509_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_509_VECTOR_ADDRESS_509_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_509_VECTOR_ADDRESS_509_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_509_RESETVAL (0x00000000u)

/* vector_address_reg_510 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_510_VECTOR_ADDRESS_510_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_510_VECTOR_ADDRESS_510_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_510_VECTOR_ADDRESS_510_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_510_RESETVAL (0x00000000u)

/* vector_address_reg_511 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_511_VECTOR_ADDRESS_511_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_511_VECTOR_ADDRESS_511_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_511_VECTOR_ADDRESS_511_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_511_RESETVAL (0x00000000u)

/* vector_address_reg_512 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_512_VECTOR_ADDRESS_512_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_512_VECTOR_ADDRESS_512_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_512_VECTOR_ADDRESS_512_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_512_RESETVAL (0x00000000u)

/* vector_address_reg_513 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_513_VECTOR_ADDRESS_513_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_513_VECTOR_ADDRESS_513_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_513_VECTOR_ADDRESS_513_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_513_RESETVAL (0x00000000u)

/* vector_address_reg_514 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_514_VECTOR_ADDRESS_514_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_514_VECTOR_ADDRESS_514_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_514_VECTOR_ADDRESS_514_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_514_RESETVAL (0x00000000u)

/* vector_address_reg_515 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_515_VECTOR_ADDRESS_515_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_515_VECTOR_ADDRESS_515_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_515_VECTOR_ADDRESS_515_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_515_RESETVAL (0x00000000u)

/* vector_address_reg_516 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_516_VECTOR_ADDRESS_516_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_516_VECTOR_ADDRESS_516_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_516_VECTOR_ADDRESS_516_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_516_RESETVAL (0x00000000u)

/* vector_address_reg_517 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_517_VECTOR_ADDRESS_517_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_517_VECTOR_ADDRESS_517_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_517_VECTOR_ADDRESS_517_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_517_RESETVAL (0x00000000u)

/* vector_address_reg_518 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_518_VECTOR_ADDRESS_518_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_518_VECTOR_ADDRESS_518_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_518_VECTOR_ADDRESS_518_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_518_RESETVAL (0x00000000u)

/* vector_address_reg_519 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_519_VECTOR_ADDRESS_519_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_519_VECTOR_ADDRESS_519_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_519_VECTOR_ADDRESS_519_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_519_RESETVAL (0x00000000u)

/* vector_address_reg_520 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_520_VECTOR_ADDRESS_520_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_520_VECTOR_ADDRESS_520_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_520_VECTOR_ADDRESS_520_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_520_RESETVAL (0x00000000u)

/* vector_address_reg_521 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_521_VECTOR_ADDRESS_521_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_521_VECTOR_ADDRESS_521_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_521_VECTOR_ADDRESS_521_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_521_RESETVAL (0x00000000u)

/* vector_address_reg_522 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_522_VECTOR_ADDRESS_522_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_522_VECTOR_ADDRESS_522_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_522_VECTOR_ADDRESS_522_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_522_RESETVAL (0x00000000u)

/* vector_address_reg_523 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_523_VECTOR_ADDRESS_523_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_523_VECTOR_ADDRESS_523_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_523_VECTOR_ADDRESS_523_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_523_RESETVAL (0x00000000u)

/* vector_address_reg_524 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_524_VECTOR_ADDRESS_524_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_524_VECTOR_ADDRESS_524_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_524_VECTOR_ADDRESS_524_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_524_RESETVAL (0x00000000u)

/* vector_address_reg_525 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_525_VECTOR_ADDRESS_525_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_525_VECTOR_ADDRESS_525_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_525_VECTOR_ADDRESS_525_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_525_RESETVAL (0x00000000u)

/* vector_address_reg_526 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_526_VECTOR_ADDRESS_526_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_526_VECTOR_ADDRESS_526_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_526_VECTOR_ADDRESS_526_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_526_RESETVAL (0x00000000u)

/* vector_address_reg_527 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_527_VECTOR_ADDRESS_527_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_527_VECTOR_ADDRESS_527_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_527_VECTOR_ADDRESS_527_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_527_RESETVAL (0x00000000u)

/* vector_address_reg_528 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_528_VECTOR_ADDRESS_528_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_528_VECTOR_ADDRESS_528_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_528_VECTOR_ADDRESS_528_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_528_RESETVAL (0x00000000u)

/* vector_address_reg_529 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_529_VECTOR_ADDRESS_529_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_529_VECTOR_ADDRESS_529_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_529_VECTOR_ADDRESS_529_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_529_RESETVAL (0x00000000u)

/* vector_address_reg_530 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_530_VECTOR_ADDRESS_530_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_530_VECTOR_ADDRESS_530_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_530_VECTOR_ADDRESS_530_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_530_RESETVAL (0x00000000u)

/* vector_address_reg_531 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_531_VECTOR_ADDRESS_531_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_531_VECTOR_ADDRESS_531_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_531_VECTOR_ADDRESS_531_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_531_RESETVAL (0x00000000u)

/* vector_address_reg_532 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_532_VECTOR_ADDRESS_532_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_532_VECTOR_ADDRESS_532_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_532_VECTOR_ADDRESS_532_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_532_RESETVAL (0x00000000u)

/* vector_address_reg_533 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_533_VECTOR_ADDRESS_533_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_533_VECTOR_ADDRESS_533_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_533_VECTOR_ADDRESS_533_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_533_RESETVAL (0x00000000u)

/* vector_address_reg_534 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_534_VECTOR_ADDRESS_534_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_534_VECTOR_ADDRESS_534_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_534_VECTOR_ADDRESS_534_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_534_RESETVAL (0x00000000u)

/* vector_address_reg_535 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_535_VECTOR_ADDRESS_535_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_535_VECTOR_ADDRESS_535_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_535_VECTOR_ADDRESS_535_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_535_RESETVAL (0x00000000u)

/* vector_address_reg_536 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_536_VECTOR_ADDRESS_536_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_536_VECTOR_ADDRESS_536_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_536_VECTOR_ADDRESS_536_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_536_RESETVAL (0x00000000u)

/* vector_address_reg_537 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_537_VECTOR_ADDRESS_537_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_537_VECTOR_ADDRESS_537_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_537_VECTOR_ADDRESS_537_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_537_RESETVAL (0x00000000u)

/* vector_address_reg_538 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_538_VECTOR_ADDRESS_538_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_538_VECTOR_ADDRESS_538_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_538_VECTOR_ADDRESS_538_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_538_RESETVAL (0x00000000u)

/* vector_address_reg_539 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_539_VECTOR_ADDRESS_539_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_539_VECTOR_ADDRESS_539_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_539_VECTOR_ADDRESS_539_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_539_RESETVAL (0x00000000u)

/* vector_address_reg_540 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_540_VECTOR_ADDRESS_540_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_540_VECTOR_ADDRESS_540_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_540_VECTOR_ADDRESS_540_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_540_RESETVAL (0x00000000u)

/* vector_address_reg_541 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_541_VECTOR_ADDRESS_541_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_541_VECTOR_ADDRESS_541_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_541_VECTOR_ADDRESS_541_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_541_RESETVAL (0x00000000u)

/* vector_address_reg_542 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_542_VECTOR_ADDRESS_542_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_542_VECTOR_ADDRESS_542_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_542_VECTOR_ADDRESS_542_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_542_RESETVAL (0x00000000u)

/* vector_address_reg_543 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_543_VECTOR_ADDRESS_543_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_543_VECTOR_ADDRESS_543_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_543_VECTOR_ADDRESS_543_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_543_RESETVAL (0x00000000u)

/* vector_address_reg_544 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_544_VECTOR_ADDRESS_544_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_544_VECTOR_ADDRESS_544_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_544_VECTOR_ADDRESS_544_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_544_RESETVAL (0x00000000u)

/* vector_address_reg_545 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_545_VECTOR_ADDRESS_545_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_545_VECTOR_ADDRESS_545_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_545_VECTOR_ADDRESS_545_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_545_RESETVAL (0x00000000u)

/* vector_address_reg_546 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_546_VECTOR_ADDRESS_546_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_546_VECTOR_ADDRESS_546_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_546_VECTOR_ADDRESS_546_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_546_RESETVAL (0x00000000u)

/* vector_address_reg_547 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_547_VECTOR_ADDRESS_547_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_547_VECTOR_ADDRESS_547_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_547_VECTOR_ADDRESS_547_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_547_RESETVAL (0x00000000u)

/* vector_address_reg_548 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_548_VECTOR_ADDRESS_548_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_548_VECTOR_ADDRESS_548_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_548_VECTOR_ADDRESS_548_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_548_RESETVAL (0x00000000u)

/* vector_address_reg_549 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_549_VECTOR_ADDRESS_549_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_549_VECTOR_ADDRESS_549_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_549_VECTOR_ADDRESS_549_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_549_RESETVAL (0x00000000u)

/* vector_address_reg_550 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_550_VECTOR_ADDRESS_550_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_550_VECTOR_ADDRESS_550_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_550_VECTOR_ADDRESS_550_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_550_RESETVAL (0x00000000u)

/* vector_address_reg_551 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_551_VECTOR_ADDRESS_551_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_551_VECTOR_ADDRESS_551_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_551_VECTOR_ADDRESS_551_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_551_RESETVAL (0x00000000u)

/* vector_address_reg_552 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_552_VECTOR_ADDRESS_552_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_552_VECTOR_ADDRESS_552_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_552_VECTOR_ADDRESS_552_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_552_RESETVAL (0x00000000u)

/* vector_address_reg_553 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_553_VECTOR_ADDRESS_553_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_553_VECTOR_ADDRESS_553_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_553_VECTOR_ADDRESS_553_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_553_RESETVAL (0x00000000u)

/* vector_address_reg_554 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_554_VECTOR_ADDRESS_554_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_554_VECTOR_ADDRESS_554_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_554_VECTOR_ADDRESS_554_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_554_RESETVAL (0x00000000u)

/* vector_address_reg_555 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_555_VECTOR_ADDRESS_555_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_555_VECTOR_ADDRESS_555_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_555_VECTOR_ADDRESS_555_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_555_RESETVAL (0x00000000u)

/* vector_address_reg_556 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_556_VECTOR_ADDRESS_556_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_556_VECTOR_ADDRESS_556_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_556_VECTOR_ADDRESS_556_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_556_RESETVAL (0x00000000u)

/* vector_address_reg_557 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_557_VECTOR_ADDRESS_557_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_557_VECTOR_ADDRESS_557_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_557_VECTOR_ADDRESS_557_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_557_RESETVAL (0x00000000u)

/* vector_address_reg_558 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_558_VECTOR_ADDRESS_558_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_558_VECTOR_ADDRESS_558_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_558_VECTOR_ADDRESS_558_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_558_RESETVAL (0x00000000u)

/* vector_address_reg_559 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_559_VECTOR_ADDRESS_559_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_559_VECTOR_ADDRESS_559_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_559_VECTOR_ADDRESS_559_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_559_RESETVAL (0x00000000u)

/* vector_address_reg_560 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_560_VECTOR_ADDRESS_560_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_560_VECTOR_ADDRESS_560_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_560_VECTOR_ADDRESS_560_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_560_RESETVAL (0x00000000u)

/* vector_address_reg_561 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_561_VECTOR_ADDRESS_561_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_561_VECTOR_ADDRESS_561_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_561_VECTOR_ADDRESS_561_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_561_RESETVAL (0x00000000u)

/* vector_address_reg_562 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_562_VECTOR_ADDRESS_562_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_562_VECTOR_ADDRESS_562_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_562_VECTOR_ADDRESS_562_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_562_RESETVAL (0x00000000u)

/* vector_address_reg_563 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_563_VECTOR_ADDRESS_563_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_563_VECTOR_ADDRESS_563_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_563_VECTOR_ADDRESS_563_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_563_RESETVAL (0x00000000u)

/* vector_address_reg_564 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_564_VECTOR_ADDRESS_564_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_564_VECTOR_ADDRESS_564_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_564_VECTOR_ADDRESS_564_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_564_RESETVAL (0x00000000u)

/* vector_address_reg_565 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_565_VECTOR_ADDRESS_565_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_565_VECTOR_ADDRESS_565_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_565_VECTOR_ADDRESS_565_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_565_RESETVAL (0x00000000u)

/* vector_address_reg_566 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_566_VECTOR_ADDRESS_566_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_566_VECTOR_ADDRESS_566_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_566_VECTOR_ADDRESS_566_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_566_RESETVAL (0x00000000u)

/* vector_address_reg_567 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_567_VECTOR_ADDRESS_567_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_567_VECTOR_ADDRESS_567_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_567_VECTOR_ADDRESS_567_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_567_RESETVAL (0x00000000u)

/* vector_address_reg_568 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_568_VECTOR_ADDRESS_568_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_568_VECTOR_ADDRESS_568_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_568_VECTOR_ADDRESS_568_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_568_RESETVAL (0x00000000u)

/* vector_address_reg_569 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_569_VECTOR_ADDRESS_569_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_569_VECTOR_ADDRESS_569_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_569_VECTOR_ADDRESS_569_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_569_RESETVAL (0x00000000u)

/* vector_address_reg_570 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_570_VECTOR_ADDRESS_570_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_570_VECTOR_ADDRESS_570_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_570_VECTOR_ADDRESS_570_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_570_RESETVAL (0x00000000u)

/* vector_address_reg_571 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_571_VECTOR_ADDRESS_571_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_571_VECTOR_ADDRESS_571_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_571_VECTOR_ADDRESS_571_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_571_RESETVAL (0x00000000u)

/* vector_address_reg_572 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_572_VECTOR_ADDRESS_572_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_572_VECTOR_ADDRESS_572_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_572_VECTOR_ADDRESS_572_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_572_RESETVAL (0x00000000u)

/* vector_address_reg_573 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_573_VECTOR_ADDRESS_573_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_573_VECTOR_ADDRESS_573_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_573_VECTOR_ADDRESS_573_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_573_RESETVAL (0x00000000u)

/* vector_address_reg_574 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_574_VECTOR_ADDRESS_574_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_574_VECTOR_ADDRESS_574_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_574_VECTOR_ADDRESS_574_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_574_RESETVAL (0x00000000u)

/* vector_address_reg_575 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_575_VECTOR_ADDRESS_575_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_575_VECTOR_ADDRESS_575_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_575_VECTOR_ADDRESS_575_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_575_RESETVAL (0x00000000u)

/* vector_address_reg_576 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_576_VECTOR_ADDRESS_576_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_576_VECTOR_ADDRESS_576_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_576_VECTOR_ADDRESS_576_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_576_RESETVAL (0x00000000u)

/* vector_address_reg_577 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_577_VECTOR_ADDRESS_577_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_577_VECTOR_ADDRESS_577_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_577_VECTOR_ADDRESS_577_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_577_RESETVAL (0x00000000u)

/* vector_address_reg_578 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_578_VECTOR_ADDRESS_578_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_578_VECTOR_ADDRESS_578_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_578_VECTOR_ADDRESS_578_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_578_RESETVAL (0x00000000u)

/* vector_address_reg_579 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_579_VECTOR_ADDRESS_579_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_579_VECTOR_ADDRESS_579_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_579_VECTOR_ADDRESS_579_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_579_RESETVAL (0x00000000u)

/* vector_address_reg_580 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_580_VECTOR_ADDRESS_580_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_580_VECTOR_ADDRESS_580_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_580_VECTOR_ADDRESS_580_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_580_RESETVAL (0x00000000u)

/* vector_address_reg_581 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_581_VECTOR_ADDRESS_581_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_581_VECTOR_ADDRESS_581_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_581_VECTOR_ADDRESS_581_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_581_RESETVAL (0x00000000u)

/* vector_address_reg_582 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_582_VECTOR_ADDRESS_582_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_582_VECTOR_ADDRESS_582_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_582_VECTOR_ADDRESS_582_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_582_RESETVAL (0x00000000u)

/* vector_address_reg_583 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_583_VECTOR_ADDRESS_583_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_583_VECTOR_ADDRESS_583_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_583_VECTOR_ADDRESS_583_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_583_RESETVAL (0x00000000u)

/* vector_address_reg_584 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_584_VECTOR_ADDRESS_584_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_584_VECTOR_ADDRESS_584_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_584_VECTOR_ADDRESS_584_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_584_RESETVAL (0x00000000u)

/* vector_address_reg_585 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_585_VECTOR_ADDRESS_585_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_585_VECTOR_ADDRESS_585_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_585_VECTOR_ADDRESS_585_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_585_RESETVAL (0x00000000u)

/* vector_address_reg_586 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_586_VECTOR_ADDRESS_586_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_586_VECTOR_ADDRESS_586_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_586_VECTOR_ADDRESS_586_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_586_RESETVAL (0x00000000u)

/* vector_address_reg_587 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_587_VECTOR_ADDRESS_587_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_587_VECTOR_ADDRESS_587_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_587_VECTOR_ADDRESS_587_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_587_RESETVAL (0x00000000u)

/* vector_address_reg_588 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_588_VECTOR_ADDRESS_588_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_588_VECTOR_ADDRESS_588_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_588_VECTOR_ADDRESS_588_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_588_RESETVAL (0x00000000u)

/* vector_address_reg_589 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_589_VECTOR_ADDRESS_589_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_589_VECTOR_ADDRESS_589_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_589_VECTOR_ADDRESS_589_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_589_RESETVAL (0x00000000u)

/* vector_address_reg_590 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_590_VECTOR_ADDRESS_590_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_590_VECTOR_ADDRESS_590_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_590_VECTOR_ADDRESS_590_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_590_RESETVAL (0x00000000u)

/* vector_address_reg_591 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_591_VECTOR_ADDRESS_591_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_591_VECTOR_ADDRESS_591_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_591_VECTOR_ADDRESS_591_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_591_RESETVAL (0x00000000u)

/* vector_address_reg_592 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_592_VECTOR_ADDRESS_592_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_592_VECTOR_ADDRESS_592_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_592_VECTOR_ADDRESS_592_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_592_RESETVAL (0x00000000u)

/* vector_address_reg_593 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_593_VECTOR_ADDRESS_593_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_593_VECTOR_ADDRESS_593_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_593_VECTOR_ADDRESS_593_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_593_RESETVAL (0x00000000u)

/* vector_address_reg_594 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_594_VECTOR_ADDRESS_594_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_594_VECTOR_ADDRESS_594_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_594_VECTOR_ADDRESS_594_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_594_RESETVAL (0x00000000u)

/* vector_address_reg_595 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_595_VECTOR_ADDRESS_595_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_595_VECTOR_ADDRESS_595_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_595_VECTOR_ADDRESS_595_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_595_RESETVAL (0x00000000u)

/* vector_address_reg_596 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_596_VECTOR_ADDRESS_596_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_596_VECTOR_ADDRESS_596_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_596_VECTOR_ADDRESS_596_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_596_RESETVAL (0x00000000u)

/* vector_address_reg_597 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_597_VECTOR_ADDRESS_597_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_597_VECTOR_ADDRESS_597_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_597_VECTOR_ADDRESS_597_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_597_RESETVAL (0x00000000u)

/* vector_address_reg_598 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_598_VECTOR_ADDRESS_598_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_598_VECTOR_ADDRESS_598_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_598_VECTOR_ADDRESS_598_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_598_RESETVAL (0x00000000u)

/* vector_address_reg_599 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_599_VECTOR_ADDRESS_599_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_599_VECTOR_ADDRESS_599_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_599_VECTOR_ADDRESS_599_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_599_RESETVAL (0x00000000u)

/* vector_address_reg_600 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_600_VECTOR_ADDRESS_600_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_600_VECTOR_ADDRESS_600_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_600_VECTOR_ADDRESS_600_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_600_RESETVAL (0x00000000u)

/* vector_address_reg_601 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_601_VECTOR_ADDRESS_601_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_601_VECTOR_ADDRESS_601_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_601_VECTOR_ADDRESS_601_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_601_RESETVAL (0x00000000u)

/* vector_address_reg_602 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_602_VECTOR_ADDRESS_602_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_602_VECTOR_ADDRESS_602_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_602_VECTOR_ADDRESS_602_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_602_RESETVAL (0x00000000u)

/* vector_address_reg_603 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_603_VECTOR_ADDRESS_603_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_603_VECTOR_ADDRESS_603_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_603_VECTOR_ADDRESS_603_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_603_RESETVAL (0x00000000u)

/* vector_address_reg_604 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_604_VECTOR_ADDRESS_604_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_604_VECTOR_ADDRESS_604_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_604_VECTOR_ADDRESS_604_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_604_RESETVAL (0x00000000u)

/* vector_address_reg_605 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_605_VECTOR_ADDRESS_605_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_605_VECTOR_ADDRESS_605_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_605_VECTOR_ADDRESS_605_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_605_RESETVAL (0x00000000u)

/* vector_address_reg_606 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_606_VECTOR_ADDRESS_606_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_606_VECTOR_ADDRESS_606_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_606_VECTOR_ADDRESS_606_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_606_RESETVAL (0x00000000u)

/* vector_address_reg_607 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_607_VECTOR_ADDRESS_607_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_607_VECTOR_ADDRESS_607_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_607_VECTOR_ADDRESS_607_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_607_RESETVAL (0x00000000u)

/* vector_address_reg_608 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_608_VECTOR_ADDRESS_608_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_608_VECTOR_ADDRESS_608_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_608_VECTOR_ADDRESS_608_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_608_RESETVAL (0x00000000u)

/* vector_address_reg_609 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_609_VECTOR_ADDRESS_609_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_609_VECTOR_ADDRESS_609_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_609_VECTOR_ADDRESS_609_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_609_RESETVAL (0x00000000u)

/* vector_address_reg_610 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_610_VECTOR_ADDRESS_610_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_610_VECTOR_ADDRESS_610_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_610_VECTOR_ADDRESS_610_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_610_RESETVAL (0x00000000u)

/* vector_address_reg_611 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_611_VECTOR_ADDRESS_611_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_611_VECTOR_ADDRESS_611_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_611_VECTOR_ADDRESS_611_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_611_RESETVAL (0x00000000u)

/* vector_address_reg_612 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_612_VECTOR_ADDRESS_612_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_612_VECTOR_ADDRESS_612_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_612_VECTOR_ADDRESS_612_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_612_RESETVAL (0x00000000u)

/* vector_address_reg_613 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_613_VECTOR_ADDRESS_613_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_613_VECTOR_ADDRESS_613_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_613_VECTOR_ADDRESS_613_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_613_RESETVAL (0x00000000u)

/* vector_address_reg_614 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_614_VECTOR_ADDRESS_614_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_614_VECTOR_ADDRESS_614_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_614_VECTOR_ADDRESS_614_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_614_RESETVAL (0x00000000u)

/* vector_address_reg_615 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_615_VECTOR_ADDRESS_615_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_615_VECTOR_ADDRESS_615_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_615_VECTOR_ADDRESS_615_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_615_RESETVAL (0x00000000u)

/* vector_address_reg_616 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_616_VECTOR_ADDRESS_616_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_616_VECTOR_ADDRESS_616_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_616_VECTOR_ADDRESS_616_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_616_RESETVAL (0x00000000u)

/* vector_address_reg_617 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_617_VECTOR_ADDRESS_617_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_617_VECTOR_ADDRESS_617_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_617_VECTOR_ADDRESS_617_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_617_RESETVAL (0x00000000u)

/* vector_address_reg_618 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_618_VECTOR_ADDRESS_618_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_618_VECTOR_ADDRESS_618_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_618_VECTOR_ADDRESS_618_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_618_RESETVAL (0x00000000u)

/* vector_address_reg_619 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_619_VECTOR_ADDRESS_619_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_619_VECTOR_ADDRESS_619_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_619_VECTOR_ADDRESS_619_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_619_RESETVAL (0x00000000u)

/* vector_address_reg_620 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_620_VECTOR_ADDRESS_620_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_620_VECTOR_ADDRESS_620_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_620_VECTOR_ADDRESS_620_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_620_RESETVAL (0x00000000u)

/* vector_address_reg_621 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_621_VECTOR_ADDRESS_621_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_621_VECTOR_ADDRESS_621_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_621_VECTOR_ADDRESS_621_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_621_RESETVAL (0x00000000u)

/* vector_address_reg_622 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_622_VECTOR_ADDRESS_622_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_622_VECTOR_ADDRESS_622_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_622_VECTOR_ADDRESS_622_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_622_RESETVAL (0x00000000u)

/* vector_address_reg_623 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_623_VECTOR_ADDRESS_623_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_623_VECTOR_ADDRESS_623_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_623_VECTOR_ADDRESS_623_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_623_RESETVAL (0x00000000u)

/* vector_address_reg_624 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_624_VECTOR_ADDRESS_624_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_624_VECTOR_ADDRESS_624_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_624_VECTOR_ADDRESS_624_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_624_RESETVAL (0x00000000u)

/* vector_address_reg_625 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_625_VECTOR_ADDRESS_625_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_625_VECTOR_ADDRESS_625_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_625_VECTOR_ADDRESS_625_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_625_RESETVAL (0x00000000u)

/* vector_address_reg_626 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_626_VECTOR_ADDRESS_626_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_626_VECTOR_ADDRESS_626_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_626_VECTOR_ADDRESS_626_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_626_RESETVAL (0x00000000u)

/* vector_address_reg_627 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_627_VECTOR_ADDRESS_627_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_627_VECTOR_ADDRESS_627_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_627_VECTOR_ADDRESS_627_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_627_RESETVAL (0x00000000u)

/* vector_address_reg_628 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_628_VECTOR_ADDRESS_628_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_628_VECTOR_ADDRESS_628_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_628_VECTOR_ADDRESS_628_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_628_RESETVAL (0x00000000u)

/* vector_address_reg_629 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_629_VECTOR_ADDRESS_629_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_629_VECTOR_ADDRESS_629_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_629_VECTOR_ADDRESS_629_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_629_RESETVAL (0x00000000u)

/* vector_address_reg_630 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_630_VECTOR_ADDRESS_630_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_630_VECTOR_ADDRESS_630_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_630_VECTOR_ADDRESS_630_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_630_RESETVAL (0x00000000u)

/* vector_address_reg_631 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_631_VECTOR_ADDRESS_631_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_631_VECTOR_ADDRESS_631_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_631_VECTOR_ADDRESS_631_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_631_RESETVAL (0x00000000u)

/* vector_address_reg_632 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_632_VECTOR_ADDRESS_632_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_632_VECTOR_ADDRESS_632_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_632_VECTOR_ADDRESS_632_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_632_RESETVAL (0x00000000u)

/* vector_address_reg_633 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_633_VECTOR_ADDRESS_633_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_633_VECTOR_ADDRESS_633_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_633_VECTOR_ADDRESS_633_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_633_RESETVAL (0x00000000u)

/* vector_address_reg_634 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_634_VECTOR_ADDRESS_634_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_634_VECTOR_ADDRESS_634_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_634_VECTOR_ADDRESS_634_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_634_RESETVAL (0x00000000u)

/* vector_address_reg_635 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_635_VECTOR_ADDRESS_635_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_635_VECTOR_ADDRESS_635_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_635_VECTOR_ADDRESS_635_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_635_RESETVAL (0x00000000u)

/* vector_address_reg_636 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_636_VECTOR_ADDRESS_636_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_636_VECTOR_ADDRESS_636_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_636_VECTOR_ADDRESS_636_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_636_RESETVAL (0x00000000u)

/* vector_address_reg_637 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_637_VECTOR_ADDRESS_637_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_637_VECTOR_ADDRESS_637_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_637_VECTOR_ADDRESS_637_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_637_RESETVAL (0x00000000u)

/* vector_address_reg_638 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_638_VECTOR_ADDRESS_638_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_638_VECTOR_ADDRESS_638_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_638_VECTOR_ADDRESS_638_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_638_RESETVAL (0x00000000u)

/* vector_address_reg_639 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_639_VECTOR_ADDRESS_639_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_639_VECTOR_ADDRESS_639_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_639_VECTOR_ADDRESS_639_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_639_RESETVAL (0x00000000u)

/* vector_address_reg_640 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_640_VECTOR_ADDRESS_640_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_640_VECTOR_ADDRESS_640_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_640_VECTOR_ADDRESS_640_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_640_RESETVAL (0x00000000u)

/* vector_address_reg_641 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_641_VECTOR_ADDRESS_641_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_641_VECTOR_ADDRESS_641_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_641_VECTOR_ADDRESS_641_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_641_RESETVAL (0x00000000u)

/* vector_address_reg_642 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_642_VECTOR_ADDRESS_642_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_642_VECTOR_ADDRESS_642_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_642_VECTOR_ADDRESS_642_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_642_RESETVAL (0x00000000u)

/* vector_address_reg_643 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_643_VECTOR_ADDRESS_643_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_643_VECTOR_ADDRESS_643_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_643_VECTOR_ADDRESS_643_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_643_RESETVAL (0x00000000u)

/* vector_address_reg_644 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_644_VECTOR_ADDRESS_644_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_644_VECTOR_ADDRESS_644_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_644_VECTOR_ADDRESS_644_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_644_RESETVAL (0x00000000u)

/* vector_address_reg_645 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_645_VECTOR_ADDRESS_645_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_645_VECTOR_ADDRESS_645_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_645_VECTOR_ADDRESS_645_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_645_RESETVAL (0x00000000u)

/* vector_address_reg_646 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_646_VECTOR_ADDRESS_646_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_646_VECTOR_ADDRESS_646_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_646_VECTOR_ADDRESS_646_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_646_RESETVAL (0x00000000u)

/* vector_address_reg_647 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_647_VECTOR_ADDRESS_647_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_647_VECTOR_ADDRESS_647_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_647_VECTOR_ADDRESS_647_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_647_RESETVAL (0x00000000u)

/* vector_address_reg_648 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_648_VECTOR_ADDRESS_648_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_648_VECTOR_ADDRESS_648_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_648_VECTOR_ADDRESS_648_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_648_RESETVAL (0x00000000u)

/* vector_address_reg_649 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_649_VECTOR_ADDRESS_649_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_649_VECTOR_ADDRESS_649_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_649_VECTOR_ADDRESS_649_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_649_RESETVAL (0x00000000u)

/* vector_address_reg_650 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_650_VECTOR_ADDRESS_650_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_650_VECTOR_ADDRESS_650_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_650_VECTOR_ADDRESS_650_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_650_RESETVAL (0x00000000u)

/* vector_address_reg_651 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_651_VECTOR_ADDRESS_651_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_651_VECTOR_ADDRESS_651_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_651_VECTOR_ADDRESS_651_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_651_RESETVAL (0x00000000u)

/* vector_address_reg_652 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_652_VECTOR_ADDRESS_652_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_652_VECTOR_ADDRESS_652_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_652_VECTOR_ADDRESS_652_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_652_RESETVAL (0x00000000u)

/* vector_address_reg_653 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_653_VECTOR_ADDRESS_653_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_653_VECTOR_ADDRESS_653_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_653_VECTOR_ADDRESS_653_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_653_RESETVAL (0x00000000u)

/* vector_address_reg_654 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_654_VECTOR_ADDRESS_654_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_654_VECTOR_ADDRESS_654_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_654_VECTOR_ADDRESS_654_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_654_RESETVAL (0x00000000u)

/* vector_address_reg_655 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_655_VECTOR_ADDRESS_655_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_655_VECTOR_ADDRESS_655_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_655_VECTOR_ADDRESS_655_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_655_RESETVAL (0x00000000u)

/* vector_address_reg_656 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_656_VECTOR_ADDRESS_656_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_656_VECTOR_ADDRESS_656_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_656_VECTOR_ADDRESS_656_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_656_RESETVAL (0x00000000u)

/* vector_address_reg_657 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_657_VECTOR_ADDRESS_657_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_657_VECTOR_ADDRESS_657_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_657_VECTOR_ADDRESS_657_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_657_RESETVAL (0x00000000u)

/* vector_address_reg_658 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_658_VECTOR_ADDRESS_658_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_658_VECTOR_ADDRESS_658_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_658_VECTOR_ADDRESS_658_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_658_RESETVAL (0x00000000u)

/* vector_address_reg_659 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_659_VECTOR_ADDRESS_659_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_659_VECTOR_ADDRESS_659_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_659_VECTOR_ADDRESS_659_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_659_RESETVAL (0x00000000u)

/* vector_address_reg_660 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_660_VECTOR_ADDRESS_660_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_660_VECTOR_ADDRESS_660_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_660_VECTOR_ADDRESS_660_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_660_RESETVAL (0x00000000u)

/* vector_address_reg_661 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_661_VECTOR_ADDRESS_661_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_661_VECTOR_ADDRESS_661_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_661_VECTOR_ADDRESS_661_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_661_RESETVAL (0x00000000u)

/* vector_address_reg_662 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_662_VECTOR_ADDRESS_662_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_662_VECTOR_ADDRESS_662_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_662_VECTOR_ADDRESS_662_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_662_RESETVAL (0x00000000u)

/* vector_address_reg_663 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_663_VECTOR_ADDRESS_663_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_663_VECTOR_ADDRESS_663_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_663_VECTOR_ADDRESS_663_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_663_RESETVAL (0x00000000u)

/* vector_address_reg_664 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_664_VECTOR_ADDRESS_664_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_664_VECTOR_ADDRESS_664_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_664_VECTOR_ADDRESS_664_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_664_RESETVAL (0x00000000u)

/* vector_address_reg_665 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_665_VECTOR_ADDRESS_665_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_665_VECTOR_ADDRESS_665_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_665_VECTOR_ADDRESS_665_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_665_RESETVAL (0x00000000u)

/* vector_address_reg_666 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_666_VECTOR_ADDRESS_666_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_666_VECTOR_ADDRESS_666_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_666_VECTOR_ADDRESS_666_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_666_RESETVAL (0x00000000u)

/* vector_address_reg_667 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_667_VECTOR_ADDRESS_667_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_667_VECTOR_ADDRESS_667_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_667_VECTOR_ADDRESS_667_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_667_RESETVAL (0x00000000u)

/* vector_address_reg_668 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_668_VECTOR_ADDRESS_668_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_668_VECTOR_ADDRESS_668_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_668_VECTOR_ADDRESS_668_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_668_RESETVAL (0x00000000u)

/* vector_address_reg_669 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_669_VECTOR_ADDRESS_669_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_669_VECTOR_ADDRESS_669_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_669_VECTOR_ADDRESS_669_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_669_RESETVAL (0x00000000u)

/* vector_address_reg_670 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_670_VECTOR_ADDRESS_670_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_670_VECTOR_ADDRESS_670_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_670_VECTOR_ADDRESS_670_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_670_RESETVAL (0x00000000u)

/* vector_address_reg_671 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_671_VECTOR_ADDRESS_671_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_671_VECTOR_ADDRESS_671_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_671_VECTOR_ADDRESS_671_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_671_RESETVAL (0x00000000u)

/* vector_address_reg_672 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_672_VECTOR_ADDRESS_672_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_672_VECTOR_ADDRESS_672_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_672_VECTOR_ADDRESS_672_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_672_RESETVAL (0x00000000u)

/* vector_address_reg_673 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_673_VECTOR_ADDRESS_673_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_673_VECTOR_ADDRESS_673_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_673_VECTOR_ADDRESS_673_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_673_RESETVAL (0x00000000u)

/* vector_address_reg_674 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_674_VECTOR_ADDRESS_674_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_674_VECTOR_ADDRESS_674_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_674_VECTOR_ADDRESS_674_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_674_RESETVAL (0x00000000u)

/* vector_address_reg_675 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_675_VECTOR_ADDRESS_675_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_675_VECTOR_ADDRESS_675_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_675_VECTOR_ADDRESS_675_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_675_RESETVAL (0x00000000u)

/* vector_address_reg_676 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_676_VECTOR_ADDRESS_676_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_676_VECTOR_ADDRESS_676_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_676_VECTOR_ADDRESS_676_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_676_RESETVAL (0x00000000u)

/* vector_address_reg_677 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_677_VECTOR_ADDRESS_677_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_677_VECTOR_ADDRESS_677_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_677_VECTOR_ADDRESS_677_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_677_RESETVAL (0x00000000u)

/* vector_address_reg_678 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_678_VECTOR_ADDRESS_678_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_678_VECTOR_ADDRESS_678_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_678_VECTOR_ADDRESS_678_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_678_RESETVAL (0x00000000u)

/* vector_address_reg_679 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_679_VECTOR_ADDRESS_679_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_679_VECTOR_ADDRESS_679_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_679_VECTOR_ADDRESS_679_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_679_RESETVAL (0x00000000u)

/* vector_address_reg_680 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_680_VECTOR_ADDRESS_680_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_680_VECTOR_ADDRESS_680_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_680_VECTOR_ADDRESS_680_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_680_RESETVAL (0x00000000u)

/* vector_address_reg_681 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_681_VECTOR_ADDRESS_681_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_681_VECTOR_ADDRESS_681_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_681_VECTOR_ADDRESS_681_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_681_RESETVAL (0x00000000u)

/* vector_address_reg_682 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_682_VECTOR_ADDRESS_682_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_682_VECTOR_ADDRESS_682_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_682_VECTOR_ADDRESS_682_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_682_RESETVAL (0x00000000u)

/* vector_address_reg_683 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_683_VECTOR_ADDRESS_683_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_683_VECTOR_ADDRESS_683_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_683_VECTOR_ADDRESS_683_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_683_RESETVAL (0x00000000u)

/* vector_address_reg_684 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_684_VECTOR_ADDRESS_684_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_684_VECTOR_ADDRESS_684_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_684_VECTOR_ADDRESS_684_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_684_RESETVAL (0x00000000u)

/* vector_address_reg_685 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_685_VECTOR_ADDRESS_685_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_685_VECTOR_ADDRESS_685_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_685_VECTOR_ADDRESS_685_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_685_RESETVAL (0x00000000u)

/* vector_address_reg_686 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_686_VECTOR_ADDRESS_686_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_686_VECTOR_ADDRESS_686_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_686_VECTOR_ADDRESS_686_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_686_RESETVAL (0x00000000u)

/* vector_address_reg_687 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_687_VECTOR_ADDRESS_687_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_687_VECTOR_ADDRESS_687_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_687_VECTOR_ADDRESS_687_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_687_RESETVAL (0x00000000u)

/* vector_address_reg_688 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_688_VECTOR_ADDRESS_688_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_688_VECTOR_ADDRESS_688_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_688_VECTOR_ADDRESS_688_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_688_RESETVAL (0x00000000u)

/* vector_address_reg_689 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_689_VECTOR_ADDRESS_689_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_689_VECTOR_ADDRESS_689_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_689_VECTOR_ADDRESS_689_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_689_RESETVAL (0x00000000u)

/* vector_address_reg_690 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_690_VECTOR_ADDRESS_690_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_690_VECTOR_ADDRESS_690_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_690_VECTOR_ADDRESS_690_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_690_RESETVAL (0x00000000u)

/* vector_address_reg_691 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_691_VECTOR_ADDRESS_691_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_691_VECTOR_ADDRESS_691_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_691_VECTOR_ADDRESS_691_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_691_RESETVAL (0x00000000u)

/* vector_address_reg_692 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_692_VECTOR_ADDRESS_692_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_692_VECTOR_ADDRESS_692_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_692_VECTOR_ADDRESS_692_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_692_RESETVAL (0x00000000u)

/* vector_address_reg_693 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_693_VECTOR_ADDRESS_693_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_693_VECTOR_ADDRESS_693_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_693_VECTOR_ADDRESS_693_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_693_RESETVAL (0x00000000u)

/* vector_address_reg_694 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_694_VECTOR_ADDRESS_694_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_694_VECTOR_ADDRESS_694_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_694_VECTOR_ADDRESS_694_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_694_RESETVAL (0x00000000u)

/* vector_address_reg_695 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_695_VECTOR_ADDRESS_695_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_695_VECTOR_ADDRESS_695_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_695_VECTOR_ADDRESS_695_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_695_RESETVAL (0x00000000u)

/* vector_address_reg_696 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_696_VECTOR_ADDRESS_696_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_696_VECTOR_ADDRESS_696_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_696_VECTOR_ADDRESS_696_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_696_RESETVAL (0x00000000u)

/* vector_address_reg_697 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_697_VECTOR_ADDRESS_697_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_697_VECTOR_ADDRESS_697_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_697_VECTOR_ADDRESS_697_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_697_RESETVAL (0x00000000u)

/* vector_address_reg_698 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_698_VECTOR_ADDRESS_698_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_698_VECTOR_ADDRESS_698_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_698_VECTOR_ADDRESS_698_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_698_RESETVAL (0x00000000u)

/* vector_address_reg_699 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_699_VECTOR_ADDRESS_699_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_699_VECTOR_ADDRESS_699_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_699_VECTOR_ADDRESS_699_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_699_RESETVAL (0x00000000u)

/* vector_address_reg_700 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_700_VECTOR_ADDRESS_700_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_700_VECTOR_ADDRESS_700_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_700_VECTOR_ADDRESS_700_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_700_RESETVAL (0x00000000u)

/* vector_address_reg_701 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_701_VECTOR_ADDRESS_701_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_701_VECTOR_ADDRESS_701_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_701_VECTOR_ADDRESS_701_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_701_RESETVAL (0x00000000u)

/* vector_address_reg_702 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_702_VECTOR_ADDRESS_702_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_702_VECTOR_ADDRESS_702_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_702_VECTOR_ADDRESS_702_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_702_RESETVAL (0x00000000u)

/* vector_address_reg_703 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_703_VECTOR_ADDRESS_703_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_703_VECTOR_ADDRESS_703_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_703_VECTOR_ADDRESS_703_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_703_RESETVAL (0x00000000u)

/* vector_address_reg_704 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_704_VECTOR_ADDRESS_704_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_704_VECTOR_ADDRESS_704_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_704_VECTOR_ADDRESS_704_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_704_RESETVAL (0x00000000u)

/* vector_address_reg_705 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_705_VECTOR_ADDRESS_705_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_705_VECTOR_ADDRESS_705_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_705_VECTOR_ADDRESS_705_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_705_RESETVAL (0x00000000u)

/* vector_address_reg_706 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_706_VECTOR_ADDRESS_706_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_706_VECTOR_ADDRESS_706_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_706_VECTOR_ADDRESS_706_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_706_RESETVAL (0x00000000u)

/* vector_address_reg_707 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_707_VECTOR_ADDRESS_707_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_707_VECTOR_ADDRESS_707_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_707_VECTOR_ADDRESS_707_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_707_RESETVAL (0x00000000u)

/* vector_address_reg_708 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_708_VECTOR_ADDRESS_708_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_708_VECTOR_ADDRESS_708_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_708_VECTOR_ADDRESS_708_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_708_RESETVAL (0x00000000u)

/* vector_address_reg_709 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_709_VECTOR_ADDRESS_709_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_709_VECTOR_ADDRESS_709_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_709_VECTOR_ADDRESS_709_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_709_RESETVAL (0x00000000u)

/* vector_address_reg_710 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_710_VECTOR_ADDRESS_710_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_710_VECTOR_ADDRESS_710_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_710_VECTOR_ADDRESS_710_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_710_RESETVAL (0x00000000u)

/* vector_address_reg_711 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_711_VECTOR_ADDRESS_711_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_711_VECTOR_ADDRESS_711_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_711_VECTOR_ADDRESS_711_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_711_RESETVAL (0x00000000u)

/* vector_address_reg_712 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_712_VECTOR_ADDRESS_712_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_712_VECTOR_ADDRESS_712_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_712_VECTOR_ADDRESS_712_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_712_RESETVAL (0x00000000u)

/* vector_address_reg_713 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_713_VECTOR_ADDRESS_713_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_713_VECTOR_ADDRESS_713_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_713_VECTOR_ADDRESS_713_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_713_RESETVAL (0x00000000u)

/* vector_address_reg_714 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_714_VECTOR_ADDRESS_714_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_714_VECTOR_ADDRESS_714_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_714_VECTOR_ADDRESS_714_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_714_RESETVAL (0x00000000u)

/* vector_address_reg_715 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_715_VECTOR_ADDRESS_715_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_715_VECTOR_ADDRESS_715_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_715_VECTOR_ADDRESS_715_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_715_RESETVAL (0x00000000u)

/* vector_address_reg_716 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_716_VECTOR_ADDRESS_716_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_716_VECTOR_ADDRESS_716_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_716_VECTOR_ADDRESS_716_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_716_RESETVAL (0x00000000u)

/* vector_address_reg_717 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_717_VECTOR_ADDRESS_717_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_717_VECTOR_ADDRESS_717_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_717_VECTOR_ADDRESS_717_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_717_RESETVAL (0x00000000u)

/* vector_address_reg_718 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_718_VECTOR_ADDRESS_718_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_718_VECTOR_ADDRESS_718_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_718_VECTOR_ADDRESS_718_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_718_RESETVAL (0x00000000u)

/* vector_address_reg_719 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_719_VECTOR_ADDRESS_719_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_719_VECTOR_ADDRESS_719_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_719_VECTOR_ADDRESS_719_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_719_RESETVAL (0x00000000u)

/* vector_address_reg_720 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_720_VECTOR_ADDRESS_720_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_720_VECTOR_ADDRESS_720_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_720_VECTOR_ADDRESS_720_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_720_RESETVAL (0x00000000u)

/* vector_address_reg_721 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_721_VECTOR_ADDRESS_721_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_721_VECTOR_ADDRESS_721_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_721_VECTOR_ADDRESS_721_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_721_RESETVAL (0x00000000u)

/* vector_address_reg_722 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_722_VECTOR_ADDRESS_722_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_722_VECTOR_ADDRESS_722_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_722_VECTOR_ADDRESS_722_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_722_RESETVAL (0x00000000u)

/* vector_address_reg_723 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_723_VECTOR_ADDRESS_723_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_723_VECTOR_ADDRESS_723_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_723_VECTOR_ADDRESS_723_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_723_RESETVAL (0x00000000u)

/* vector_address_reg_724 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_724_VECTOR_ADDRESS_724_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_724_VECTOR_ADDRESS_724_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_724_VECTOR_ADDRESS_724_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_724_RESETVAL (0x00000000u)

/* vector_address_reg_725 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_725_VECTOR_ADDRESS_725_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_725_VECTOR_ADDRESS_725_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_725_VECTOR_ADDRESS_725_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_725_RESETVAL (0x00000000u)

/* vector_address_reg_726 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_726_VECTOR_ADDRESS_726_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_726_VECTOR_ADDRESS_726_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_726_VECTOR_ADDRESS_726_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_726_RESETVAL (0x00000000u)

/* vector_address_reg_727 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_727_VECTOR_ADDRESS_727_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_727_VECTOR_ADDRESS_727_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_727_VECTOR_ADDRESS_727_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_727_RESETVAL (0x00000000u)

/* vector_address_reg_728 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_728_VECTOR_ADDRESS_728_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_728_VECTOR_ADDRESS_728_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_728_VECTOR_ADDRESS_728_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_728_RESETVAL (0x00000000u)

/* vector_address_reg_729 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_729_VECTOR_ADDRESS_729_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_729_VECTOR_ADDRESS_729_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_729_VECTOR_ADDRESS_729_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_729_RESETVAL (0x00000000u)

/* vector_address_reg_730 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_730_VECTOR_ADDRESS_730_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_730_VECTOR_ADDRESS_730_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_730_VECTOR_ADDRESS_730_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_730_RESETVAL (0x00000000u)

/* vector_address_reg_731 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_731_VECTOR_ADDRESS_731_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_731_VECTOR_ADDRESS_731_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_731_VECTOR_ADDRESS_731_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_731_RESETVAL (0x00000000u)

/* vector_address_reg_732 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_732_VECTOR_ADDRESS_732_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_732_VECTOR_ADDRESS_732_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_732_VECTOR_ADDRESS_732_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_732_RESETVAL (0x00000000u)

/* vector_address_reg_733 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_733_VECTOR_ADDRESS_733_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_733_VECTOR_ADDRESS_733_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_733_VECTOR_ADDRESS_733_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_733_RESETVAL (0x00000000u)

/* vector_address_reg_734 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_734_VECTOR_ADDRESS_734_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_734_VECTOR_ADDRESS_734_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_734_VECTOR_ADDRESS_734_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_734_RESETVAL (0x00000000u)

/* vector_address_reg_735 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_735_VECTOR_ADDRESS_735_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_735_VECTOR_ADDRESS_735_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_735_VECTOR_ADDRESS_735_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_735_RESETVAL (0x00000000u)

/* vector_address_reg_736 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_736_VECTOR_ADDRESS_736_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_736_VECTOR_ADDRESS_736_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_736_VECTOR_ADDRESS_736_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_736_RESETVAL (0x00000000u)

/* vector_address_reg_737 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_737_VECTOR_ADDRESS_737_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_737_VECTOR_ADDRESS_737_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_737_VECTOR_ADDRESS_737_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_737_RESETVAL (0x00000000u)

/* vector_address_reg_738 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_738_VECTOR_ADDRESS_738_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_738_VECTOR_ADDRESS_738_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_738_VECTOR_ADDRESS_738_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_738_RESETVAL (0x00000000u)

/* vector_address_reg_739 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_739_VECTOR_ADDRESS_739_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_739_VECTOR_ADDRESS_739_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_739_VECTOR_ADDRESS_739_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_739_RESETVAL (0x00000000u)

/* vector_address_reg_740 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_740_VECTOR_ADDRESS_740_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_740_VECTOR_ADDRESS_740_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_740_VECTOR_ADDRESS_740_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_740_RESETVAL (0x00000000u)

/* vector_address_reg_741 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_741_VECTOR_ADDRESS_741_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_741_VECTOR_ADDRESS_741_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_741_VECTOR_ADDRESS_741_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_741_RESETVAL (0x00000000u)

/* vector_address_reg_742 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_742_VECTOR_ADDRESS_742_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_742_VECTOR_ADDRESS_742_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_742_VECTOR_ADDRESS_742_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_742_RESETVAL (0x00000000u)

/* vector_address_reg_743 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_743_VECTOR_ADDRESS_743_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_743_VECTOR_ADDRESS_743_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_743_VECTOR_ADDRESS_743_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_743_RESETVAL (0x00000000u)

/* vector_address_reg_744 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_744_VECTOR_ADDRESS_744_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_744_VECTOR_ADDRESS_744_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_744_VECTOR_ADDRESS_744_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_744_RESETVAL (0x00000000u)

/* vector_address_reg_745 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_745_VECTOR_ADDRESS_745_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_745_VECTOR_ADDRESS_745_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_745_VECTOR_ADDRESS_745_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_745_RESETVAL (0x00000000u)

/* vector_address_reg_746 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_746_VECTOR_ADDRESS_746_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_746_VECTOR_ADDRESS_746_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_746_VECTOR_ADDRESS_746_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_746_RESETVAL (0x00000000u)

/* vector_address_reg_747 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_747_VECTOR_ADDRESS_747_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_747_VECTOR_ADDRESS_747_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_747_VECTOR_ADDRESS_747_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_747_RESETVAL (0x00000000u)

/* vector_address_reg_748 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_748_VECTOR_ADDRESS_748_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_748_VECTOR_ADDRESS_748_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_748_VECTOR_ADDRESS_748_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_748_RESETVAL (0x00000000u)

/* vector_address_reg_749 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_749_VECTOR_ADDRESS_749_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_749_VECTOR_ADDRESS_749_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_749_VECTOR_ADDRESS_749_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_749_RESETVAL (0x00000000u)

/* vector_address_reg_750 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_750_VECTOR_ADDRESS_750_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_750_VECTOR_ADDRESS_750_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_750_VECTOR_ADDRESS_750_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_750_RESETVAL (0x00000000u)

/* vector_address_reg_751 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_751_VECTOR_ADDRESS_751_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_751_VECTOR_ADDRESS_751_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_751_VECTOR_ADDRESS_751_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_751_RESETVAL (0x00000000u)

/* vector_address_reg_752 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_752_VECTOR_ADDRESS_752_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_752_VECTOR_ADDRESS_752_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_752_VECTOR_ADDRESS_752_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_752_RESETVAL (0x00000000u)

/* vector_address_reg_753 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_753_VECTOR_ADDRESS_753_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_753_VECTOR_ADDRESS_753_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_753_VECTOR_ADDRESS_753_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_753_RESETVAL (0x00000000u)

/* vector_address_reg_754 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_754_VECTOR_ADDRESS_754_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_754_VECTOR_ADDRESS_754_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_754_VECTOR_ADDRESS_754_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_754_RESETVAL (0x00000000u)

/* vector_address_reg_755 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_755_VECTOR_ADDRESS_755_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_755_VECTOR_ADDRESS_755_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_755_VECTOR_ADDRESS_755_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_755_RESETVAL (0x00000000u)

/* vector_address_reg_756 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_756_VECTOR_ADDRESS_756_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_756_VECTOR_ADDRESS_756_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_756_VECTOR_ADDRESS_756_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_756_RESETVAL (0x00000000u)

/* vector_address_reg_757 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_757_VECTOR_ADDRESS_757_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_757_VECTOR_ADDRESS_757_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_757_VECTOR_ADDRESS_757_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_757_RESETVAL (0x00000000u)

/* vector_address_reg_758 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_758_VECTOR_ADDRESS_758_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_758_VECTOR_ADDRESS_758_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_758_VECTOR_ADDRESS_758_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_758_RESETVAL (0x00000000u)

/* vector_address_reg_759 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_759_VECTOR_ADDRESS_759_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_759_VECTOR_ADDRESS_759_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_759_VECTOR_ADDRESS_759_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_759_RESETVAL (0x00000000u)

/* vector_address_reg_760 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_760_VECTOR_ADDRESS_760_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_760_VECTOR_ADDRESS_760_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_760_VECTOR_ADDRESS_760_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_760_RESETVAL (0x00000000u)

/* vector_address_reg_761 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_761_VECTOR_ADDRESS_761_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_761_VECTOR_ADDRESS_761_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_761_VECTOR_ADDRESS_761_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_761_RESETVAL (0x00000000u)

/* vector_address_reg_762 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_762_VECTOR_ADDRESS_762_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_762_VECTOR_ADDRESS_762_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_762_VECTOR_ADDRESS_762_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_762_RESETVAL (0x00000000u)

/* vector_address_reg_763 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_763_VECTOR_ADDRESS_763_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_763_VECTOR_ADDRESS_763_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_763_VECTOR_ADDRESS_763_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_763_RESETVAL (0x00000000u)

/* vector_address_reg_764 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_764_VECTOR_ADDRESS_764_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_764_VECTOR_ADDRESS_764_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_764_VECTOR_ADDRESS_764_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_764_RESETVAL (0x00000000u)

/* vector_address_reg_765 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_765_VECTOR_ADDRESS_765_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_765_VECTOR_ADDRESS_765_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_765_VECTOR_ADDRESS_765_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_765_RESETVAL (0x00000000u)

/* vector_address_reg_766 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_766_VECTOR_ADDRESS_766_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_766_VECTOR_ADDRESS_766_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_766_VECTOR_ADDRESS_766_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_766_RESETVAL (0x00000000u)

/* vector_address_reg_767 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_767_VECTOR_ADDRESS_767_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_767_VECTOR_ADDRESS_767_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_767_VECTOR_ADDRESS_767_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_767_RESETVAL (0x00000000u)

/* vector_address_reg_768 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_768_VECTOR_ADDRESS_768_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_768_VECTOR_ADDRESS_768_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_768_VECTOR_ADDRESS_768_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_768_RESETVAL (0x00000000u)

/* vector_address_reg_769 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_769_VECTOR_ADDRESS_769_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_769_VECTOR_ADDRESS_769_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_769_VECTOR_ADDRESS_769_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_769_RESETVAL (0x00000000u)

/* vector_address_reg_770 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_770_VECTOR_ADDRESS_770_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_770_VECTOR_ADDRESS_770_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_770_VECTOR_ADDRESS_770_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_770_RESETVAL (0x00000000u)

/* vector_address_reg_771 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_771_VECTOR_ADDRESS_771_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_771_VECTOR_ADDRESS_771_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_771_VECTOR_ADDRESS_771_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_771_RESETVAL (0x00000000u)

/* vector_address_reg_772 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_772_VECTOR_ADDRESS_772_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_772_VECTOR_ADDRESS_772_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_772_VECTOR_ADDRESS_772_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_772_RESETVAL (0x00000000u)

/* vector_address_reg_773 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_773_VECTOR_ADDRESS_773_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_773_VECTOR_ADDRESS_773_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_773_VECTOR_ADDRESS_773_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_773_RESETVAL (0x00000000u)

/* vector_address_reg_774 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_774_VECTOR_ADDRESS_774_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_774_VECTOR_ADDRESS_774_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_774_VECTOR_ADDRESS_774_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_774_RESETVAL (0x00000000u)

/* vector_address_reg_775 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_775_VECTOR_ADDRESS_775_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_775_VECTOR_ADDRESS_775_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_775_VECTOR_ADDRESS_775_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_775_RESETVAL (0x00000000u)

/* vector_address_reg_776 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_776_VECTOR_ADDRESS_776_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_776_VECTOR_ADDRESS_776_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_776_VECTOR_ADDRESS_776_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_776_RESETVAL (0x00000000u)

/* vector_address_reg_777 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_777_VECTOR_ADDRESS_777_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_777_VECTOR_ADDRESS_777_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_777_VECTOR_ADDRESS_777_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_777_RESETVAL (0x00000000u)

/* vector_address_reg_778 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_778_VECTOR_ADDRESS_778_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_778_VECTOR_ADDRESS_778_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_778_VECTOR_ADDRESS_778_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_778_RESETVAL (0x00000000u)

/* vector_address_reg_779 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_779_VECTOR_ADDRESS_779_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_779_VECTOR_ADDRESS_779_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_779_VECTOR_ADDRESS_779_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_779_RESETVAL (0x00000000u)

/* vector_address_reg_780 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_780_VECTOR_ADDRESS_780_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_780_VECTOR_ADDRESS_780_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_780_VECTOR_ADDRESS_780_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_780_RESETVAL (0x00000000u)

/* vector_address_reg_781 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_781_VECTOR_ADDRESS_781_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_781_VECTOR_ADDRESS_781_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_781_VECTOR_ADDRESS_781_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_781_RESETVAL (0x00000000u)

/* vector_address_reg_782 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_782_VECTOR_ADDRESS_782_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_782_VECTOR_ADDRESS_782_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_782_VECTOR_ADDRESS_782_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_782_RESETVAL (0x00000000u)

/* vector_address_reg_783 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_783_VECTOR_ADDRESS_783_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_783_VECTOR_ADDRESS_783_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_783_VECTOR_ADDRESS_783_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_783_RESETVAL (0x00000000u)

/* vector_address_reg_784 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_784_VECTOR_ADDRESS_784_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_784_VECTOR_ADDRESS_784_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_784_VECTOR_ADDRESS_784_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_784_RESETVAL (0x00000000u)

/* vector_address_reg_785 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_785_VECTOR_ADDRESS_785_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_785_VECTOR_ADDRESS_785_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_785_VECTOR_ADDRESS_785_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_785_RESETVAL (0x00000000u)

/* vector_address_reg_786 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_786_VECTOR_ADDRESS_786_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_786_VECTOR_ADDRESS_786_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_786_VECTOR_ADDRESS_786_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_786_RESETVAL (0x00000000u)

/* vector_address_reg_787 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_787_VECTOR_ADDRESS_787_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_787_VECTOR_ADDRESS_787_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_787_VECTOR_ADDRESS_787_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_787_RESETVAL (0x00000000u)

/* vector_address_reg_788 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_788_VECTOR_ADDRESS_788_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_788_VECTOR_ADDRESS_788_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_788_VECTOR_ADDRESS_788_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_788_RESETVAL (0x00000000u)

/* vector_address_reg_789 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_789_VECTOR_ADDRESS_789_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_789_VECTOR_ADDRESS_789_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_789_VECTOR_ADDRESS_789_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_789_RESETVAL (0x00000000u)

/* vector_address_reg_790 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_790_VECTOR_ADDRESS_790_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_790_VECTOR_ADDRESS_790_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_790_VECTOR_ADDRESS_790_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_790_RESETVAL (0x00000000u)

/* vector_address_reg_791 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_791_VECTOR_ADDRESS_791_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_791_VECTOR_ADDRESS_791_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_791_VECTOR_ADDRESS_791_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_791_RESETVAL (0x00000000u)

/* vector_address_reg_792 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_792_VECTOR_ADDRESS_792_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_792_VECTOR_ADDRESS_792_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_792_VECTOR_ADDRESS_792_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_792_RESETVAL (0x00000000u)

/* vector_address_reg_793 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_793_VECTOR_ADDRESS_793_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_793_VECTOR_ADDRESS_793_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_793_VECTOR_ADDRESS_793_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_793_RESETVAL (0x00000000u)

/* vector_address_reg_794 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_794_VECTOR_ADDRESS_794_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_794_VECTOR_ADDRESS_794_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_794_VECTOR_ADDRESS_794_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_794_RESETVAL (0x00000000u)

/* vector_address_reg_795 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_795_VECTOR_ADDRESS_795_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_795_VECTOR_ADDRESS_795_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_795_VECTOR_ADDRESS_795_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_795_RESETVAL (0x00000000u)

/* vector_address_reg_796 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_796_VECTOR_ADDRESS_796_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_796_VECTOR_ADDRESS_796_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_796_VECTOR_ADDRESS_796_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_796_RESETVAL (0x00000000u)

/* vector_address_reg_797 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_797_VECTOR_ADDRESS_797_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_797_VECTOR_ADDRESS_797_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_797_VECTOR_ADDRESS_797_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_797_RESETVAL (0x00000000u)

/* vector_address_reg_798 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_798_VECTOR_ADDRESS_798_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_798_VECTOR_ADDRESS_798_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_798_VECTOR_ADDRESS_798_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_798_RESETVAL (0x00000000u)

/* vector_address_reg_799 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_799_VECTOR_ADDRESS_799_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_799_VECTOR_ADDRESS_799_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_799_VECTOR_ADDRESS_799_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_799_RESETVAL (0x00000000u)

/* vector_address_reg_800 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_800_VECTOR_ADDRESS_800_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_800_VECTOR_ADDRESS_800_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_800_VECTOR_ADDRESS_800_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_800_RESETVAL (0x00000000u)

/* vector_address_reg_801 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_801_VECTOR_ADDRESS_801_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_801_VECTOR_ADDRESS_801_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_801_VECTOR_ADDRESS_801_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_801_RESETVAL (0x00000000u)

/* vector_address_reg_802 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_802_VECTOR_ADDRESS_802_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_802_VECTOR_ADDRESS_802_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_802_VECTOR_ADDRESS_802_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_802_RESETVAL (0x00000000u)

/* vector_address_reg_803 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_803_VECTOR_ADDRESS_803_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_803_VECTOR_ADDRESS_803_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_803_VECTOR_ADDRESS_803_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_803_RESETVAL (0x00000000u)

/* vector_address_reg_804 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_804_VECTOR_ADDRESS_804_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_804_VECTOR_ADDRESS_804_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_804_VECTOR_ADDRESS_804_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_804_RESETVAL (0x00000000u)

/* vector_address_reg_805 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_805_VECTOR_ADDRESS_805_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_805_VECTOR_ADDRESS_805_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_805_VECTOR_ADDRESS_805_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_805_RESETVAL (0x00000000u)

/* vector_address_reg_806 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_806_VECTOR_ADDRESS_806_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_806_VECTOR_ADDRESS_806_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_806_VECTOR_ADDRESS_806_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_806_RESETVAL (0x00000000u)

/* vector_address_reg_807 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_807_VECTOR_ADDRESS_807_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_807_VECTOR_ADDRESS_807_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_807_VECTOR_ADDRESS_807_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_807_RESETVAL (0x00000000u)

/* vector_address_reg_808 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_808_VECTOR_ADDRESS_808_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_808_VECTOR_ADDRESS_808_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_808_VECTOR_ADDRESS_808_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_808_RESETVAL (0x00000000u)

/* vector_address_reg_809 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_809_VECTOR_ADDRESS_809_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_809_VECTOR_ADDRESS_809_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_809_VECTOR_ADDRESS_809_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_809_RESETVAL (0x00000000u)

/* vector_address_reg_810 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_810_VECTOR_ADDRESS_810_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_810_VECTOR_ADDRESS_810_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_810_VECTOR_ADDRESS_810_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_810_RESETVAL (0x00000000u)

/* vector_address_reg_811 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_811_VECTOR_ADDRESS_811_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_811_VECTOR_ADDRESS_811_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_811_VECTOR_ADDRESS_811_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_811_RESETVAL (0x00000000u)

/* vector_address_reg_812 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_812_VECTOR_ADDRESS_812_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_812_VECTOR_ADDRESS_812_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_812_VECTOR_ADDRESS_812_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_812_RESETVAL (0x00000000u)

/* vector_address_reg_813 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_813_VECTOR_ADDRESS_813_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_813_VECTOR_ADDRESS_813_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_813_VECTOR_ADDRESS_813_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_813_RESETVAL (0x00000000u)

/* vector_address_reg_814 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_814_VECTOR_ADDRESS_814_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_814_VECTOR_ADDRESS_814_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_814_VECTOR_ADDRESS_814_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_814_RESETVAL (0x00000000u)

/* vector_address_reg_815 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_815_VECTOR_ADDRESS_815_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_815_VECTOR_ADDRESS_815_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_815_VECTOR_ADDRESS_815_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_815_RESETVAL (0x00000000u)

/* vector_address_reg_816 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_816_VECTOR_ADDRESS_816_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_816_VECTOR_ADDRESS_816_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_816_VECTOR_ADDRESS_816_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_816_RESETVAL (0x00000000u)

/* vector_address_reg_817 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_817_VECTOR_ADDRESS_817_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_817_VECTOR_ADDRESS_817_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_817_VECTOR_ADDRESS_817_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_817_RESETVAL (0x00000000u)

/* vector_address_reg_818 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_818_VECTOR_ADDRESS_818_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_818_VECTOR_ADDRESS_818_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_818_VECTOR_ADDRESS_818_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_818_RESETVAL (0x00000000u)

/* vector_address_reg_819 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_819_VECTOR_ADDRESS_819_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_819_VECTOR_ADDRESS_819_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_819_VECTOR_ADDRESS_819_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_819_RESETVAL (0x00000000u)

/* vector_address_reg_820 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_820_VECTOR_ADDRESS_820_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_820_VECTOR_ADDRESS_820_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_820_VECTOR_ADDRESS_820_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_820_RESETVAL (0x00000000u)

/* vector_address_reg_821 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_821_VECTOR_ADDRESS_821_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_821_VECTOR_ADDRESS_821_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_821_VECTOR_ADDRESS_821_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_821_RESETVAL (0x00000000u)

/* vector_address_reg_822 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_822_VECTOR_ADDRESS_822_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_822_VECTOR_ADDRESS_822_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_822_VECTOR_ADDRESS_822_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_822_RESETVAL (0x00000000u)

/* vector_address_reg_823 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_823_VECTOR_ADDRESS_823_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_823_VECTOR_ADDRESS_823_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_823_VECTOR_ADDRESS_823_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_823_RESETVAL (0x00000000u)

/* vector_address_reg_824 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_824_VECTOR_ADDRESS_824_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_824_VECTOR_ADDRESS_824_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_824_VECTOR_ADDRESS_824_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_824_RESETVAL (0x00000000u)

/* vector_address_reg_825 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_825_VECTOR_ADDRESS_825_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_825_VECTOR_ADDRESS_825_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_825_VECTOR_ADDRESS_825_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_825_RESETVAL (0x00000000u)

/* vector_address_reg_826 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_826_VECTOR_ADDRESS_826_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_826_VECTOR_ADDRESS_826_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_826_VECTOR_ADDRESS_826_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_826_RESETVAL (0x00000000u)

/* vector_address_reg_827 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_827_VECTOR_ADDRESS_827_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_827_VECTOR_ADDRESS_827_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_827_VECTOR_ADDRESS_827_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_827_RESETVAL (0x00000000u)

/* vector_address_reg_828 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_828_VECTOR_ADDRESS_828_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_828_VECTOR_ADDRESS_828_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_828_VECTOR_ADDRESS_828_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_828_RESETVAL (0x00000000u)

/* vector_address_reg_829 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_829_VECTOR_ADDRESS_829_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_829_VECTOR_ADDRESS_829_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_829_VECTOR_ADDRESS_829_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_829_RESETVAL (0x00000000u)

/* vector_address_reg_830 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_830_VECTOR_ADDRESS_830_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_830_VECTOR_ADDRESS_830_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_830_VECTOR_ADDRESS_830_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_830_RESETVAL (0x00000000u)

/* vector_address_reg_831 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_831_VECTOR_ADDRESS_831_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_831_VECTOR_ADDRESS_831_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_831_VECTOR_ADDRESS_831_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_831_RESETVAL (0x00000000u)

/* vector_address_reg_832 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_832_VECTOR_ADDRESS_832_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_832_VECTOR_ADDRESS_832_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_832_VECTOR_ADDRESS_832_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_832_RESETVAL (0x00000000u)

/* vector_address_reg_833 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_833_VECTOR_ADDRESS_833_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_833_VECTOR_ADDRESS_833_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_833_VECTOR_ADDRESS_833_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_833_RESETVAL (0x00000000u)

/* vector_address_reg_834 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_834_VECTOR_ADDRESS_834_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_834_VECTOR_ADDRESS_834_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_834_VECTOR_ADDRESS_834_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_834_RESETVAL (0x00000000u)

/* vector_address_reg_835 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_835_VECTOR_ADDRESS_835_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_835_VECTOR_ADDRESS_835_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_835_VECTOR_ADDRESS_835_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_835_RESETVAL (0x00000000u)

/* vector_address_reg_836 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_836_VECTOR_ADDRESS_836_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_836_VECTOR_ADDRESS_836_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_836_VECTOR_ADDRESS_836_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_836_RESETVAL (0x00000000u)

/* vector_address_reg_837 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_837_VECTOR_ADDRESS_837_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_837_VECTOR_ADDRESS_837_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_837_VECTOR_ADDRESS_837_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_837_RESETVAL (0x00000000u)

/* vector_address_reg_838 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_838_VECTOR_ADDRESS_838_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_838_VECTOR_ADDRESS_838_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_838_VECTOR_ADDRESS_838_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_838_RESETVAL (0x00000000u)

/* vector_address_reg_839 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_839_VECTOR_ADDRESS_839_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_839_VECTOR_ADDRESS_839_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_839_VECTOR_ADDRESS_839_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_839_RESETVAL (0x00000000u)

/* vector_address_reg_840 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_840_VECTOR_ADDRESS_840_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_840_VECTOR_ADDRESS_840_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_840_VECTOR_ADDRESS_840_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_840_RESETVAL (0x00000000u)

/* vector_address_reg_841 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_841_VECTOR_ADDRESS_841_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_841_VECTOR_ADDRESS_841_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_841_VECTOR_ADDRESS_841_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_841_RESETVAL (0x00000000u)

/* vector_address_reg_842 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_842_VECTOR_ADDRESS_842_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_842_VECTOR_ADDRESS_842_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_842_VECTOR_ADDRESS_842_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_842_RESETVAL (0x00000000u)

/* vector_address_reg_843 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_843_VECTOR_ADDRESS_843_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_843_VECTOR_ADDRESS_843_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_843_VECTOR_ADDRESS_843_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_843_RESETVAL (0x00000000u)

/* vector_address_reg_844 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_844_VECTOR_ADDRESS_844_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_844_VECTOR_ADDRESS_844_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_844_VECTOR_ADDRESS_844_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_844_RESETVAL (0x00000000u)

/* vector_address_reg_845 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_845_VECTOR_ADDRESS_845_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_845_VECTOR_ADDRESS_845_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_845_VECTOR_ADDRESS_845_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_845_RESETVAL (0x00000000u)

/* vector_address_reg_846 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_846_VECTOR_ADDRESS_846_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_846_VECTOR_ADDRESS_846_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_846_VECTOR_ADDRESS_846_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_846_RESETVAL (0x00000000u)

/* vector_address_reg_847 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_847_VECTOR_ADDRESS_847_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_847_VECTOR_ADDRESS_847_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_847_VECTOR_ADDRESS_847_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_847_RESETVAL (0x00000000u)

/* vector_address_reg_848 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_848_VECTOR_ADDRESS_848_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_848_VECTOR_ADDRESS_848_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_848_VECTOR_ADDRESS_848_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_848_RESETVAL (0x00000000u)

/* vector_address_reg_849 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_849_VECTOR_ADDRESS_849_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_849_VECTOR_ADDRESS_849_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_849_VECTOR_ADDRESS_849_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_849_RESETVAL (0x00000000u)

/* vector_address_reg_850 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_850_VECTOR_ADDRESS_850_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_850_VECTOR_ADDRESS_850_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_850_VECTOR_ADDRESS_850_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_850_RESETVAL (0x00000000u)

/* vector_address_reg_851 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_851_VECTOR_ADDRESS_851_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_851_VECTOR_ADDRESS_851_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_851_VECTOR_ADDRESS_851_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_851_RESETVAL (0x00000000u)

/* vector_address_reg_852 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_852_VECTOR_ADDRESS_852_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_852_VECTOR_ADDRESS_852_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_852_VECTOR_ADDRESS_852_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_852_RESETVAL (0x00000000u)

/* vector_address_reg_853 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_853_VECTOR_ADDRESS_853_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_853_VECTOR_ADDRESS_853_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_853_VECTOR_ADDRESS_853_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_853_RESETVAL (0x00000000u)

/* vector_address_reg_854 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_854_VECTOR_ADDRESS_854_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_854_VECTOR_ADDRESS_854_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_854_VECTOR_ADDRESS_854_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_854_RESETVAL (0x00000000u)

/* vector_address_reg_855 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_855_VECTOR_ADDRESS_855_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_855_VECTOR_ADDRESS_855_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_855_VECTOR_ADDRESS_855_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_855_RESETVAL (0x00000000u)

/* vector_address_reg_856 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_856_VECTOR_ADDRESS_856_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_856_VECTOR_ADDRESS_856_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_856_VECTOR_ADDRESS_856_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_856_RESETVAL (0x00000000u)

/* vector_address_reg_857 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_857_VECTOR_ADDRESS_857_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_857_VECTOR_ADDRESS_857_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_857_VECTOR_ADDRESS_857_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_857_RESETVAL (0x00000000u)

/* vector_address_reg_858 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_858_VECTOR_ADDRESS_858_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_858_VECTOR_ADDRESS_858_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_858_VECTOR_ADDRESS_858_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_858_RESETVAL (0x00000000u)

/* vector_address_reg_859 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_859_VECTOR_ADDRESS_859_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_859_VECTOR_ADDRESS_859_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_859_VECTOR_ADDRESS_859_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_859_RESETVAL (0x00000000u)

/* vector_address_reg_860 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_860_VECTOR_ADDRESS_860_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_860_VECTOR_ADDRESS_860_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_860_VECTOR_ADDRESS_860_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_860_RESETVAL (0x00000000u)

/* vector_address_reg_861 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_861_VECTOR_ADDRESS_861_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_861_VECTOR_ADDRESS_861_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_861_VECTOR_ADDRESS_861_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_861_RESETVAL (0x00000000u)

/* vector_address_reg_862 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_862_VECTOR_ADDRESS_862_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_862_VECTOR_ADDRESS_862_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_862_VECTOR_ADDRESS_862_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_862_RESETVAL (0x00000000u)

/* vector_address_reg_863 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_863_VECTOR_ADDRESS_863_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_863_VECTOR_ADDRESS_863_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_863_VECTOR_ADDRESS_863_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_863_RESETVAL (0x00000000u)

/* vector_address_reg_864 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_864_VECTOR_ADDRESS_864_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_864_VECTOR_ADDRESS_864_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_864_VECTOR_ADDRESS_864_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_864_RESETVAL (0x00000000u)

/* vector_address_reg_865 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_865_VECTOR_ADDRESS_865_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_865_VECTOR_ADDRESS_865_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_865_VECTOR_ADDRESS_865_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_865_RESETVAL (0x00000000u)

/* vector_address_reg_866 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_866_VECTOR_ADDRESS_866_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_866_VECTOR_ADDRESS_866_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_866_VECTOR_ADDRESS_866_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_866_RESETVAL (0x00000000u)

/* vector_address_reg_867 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_867_VECTOR_ADDRESS_867_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_867_VECTOR_ADDRESS_867_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_867_VECTOR_ADDRESS_867_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_867_RESETVAL (0x00000000u)

/* vector_address_reg_868 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_868_VECTOR_ADDRESS_868_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_868_VECTOR_ADDRESS_868_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_868_VECTOR_ADDRESS_868_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_868_RESETVAL (0x00000000u)

/* vector_address_reg_869 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_869_VECTOR_ADDRESS_869_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_869_VECTOR_ADDRESS_869_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_869_VECTOR_ADDRESS_869_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_869_RESETVAL (0x00000000u)

/* vector_address_reg_870 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_870_VECTOR_ADDRESS_870_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_870_VECTOR_ADDRESS_870_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_870_VECTOR_ADDRESS_870_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_870_RESETVAL (0x00000000u)

/* vector_address_reg_871 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_871_VECTOR_ADDRESS_871_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_871_VECTOR_ADDRESS_871_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_871_VECTOR_ADDRESS_871_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_871_RESETVAL (0x00000000u)

/* vector_address_reg_872 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_872_VECTOR_ADDRESS_872_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_872_VECTOR_ADDRESS_872_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_872_VECTOR_ADDRESS_872_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_872_RESETVAL (0x00000000u)

/* vector_address_reg_873 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_873_VECTOR_ADDRESS_873_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_873_VECTOR_ADDRESS_873_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_873_VECTOR_ADDRESS_873_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_873_RESETVAL (0x00000000u)

/* vector_address_reg_874 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_874_VECTOR_ADDRESS_874_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_874_VECTOR_ADDRESS_874_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_874_VECTOR_ADDRESS_874_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_874_RESETVAL (0x00000000u)

/* vector_address_reg_875 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_875_VECTOR_ADDRESS_875_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_875_VECTOR_ADDRESS_875_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_875_VECTOR_ADDRESS_875_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_875_RESETVAL (0x00000000u)

/* vector_address_reg_876 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_876_VECTOR_ADDRESS_876_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_876_VECTOR_ADDRESS_876_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_876_VECTOR_ADDRESS_876_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_876_RESETVAL (0x00000000u)

/* vector_address_reg_877 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_877_VECTOR_ADDRESS_877_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_877_VECTOR_ADDRESS_877_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_877_VECTOR_ADDRESS_877_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_877_RESETVAL (0x00000000u)

/* vector_address_reg_878 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_878_VECTOR_ADDRESS_878_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_878_VECTOR_ADDRESS_878_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_878_VECTOR_ADDRESS_878_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_878_RESETVAL (0x00000000u)

/* vector_address_reg_879 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_879_VECTOR_ADDRESS_879_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_879_VECTOR_ADDRESS_879_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_879_VECTOR_ADDRESS_879_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_879_RESETVAL (0x00000000u)

/* vector_address_reg_880 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_880_VECTOR_ADDRESS_880_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_880_VECTOR_ADDRESS_880_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_880_VECTOR_ADDRESS_880_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_880_RESETVAL (0x00000000u)

/* vector_address_reg_881 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_881_VECTOR_ADDRESS_881_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_881_VECTOR_ADDRESS_881_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_881_VECTOR_ADDRESS_881_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_881_RESETVAL (0x00000000u)

/* vector_address_reg_882 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_882_VECTOR_ADDRESS_882_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_882_VECTOR_ADDRESS_882_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_882_VECTOR_ADDRESS_882_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_882_RESETVAL (0x00000000u)

/* vector_address_reg_883 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_883_VECTOR_ADDRESS_883_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_883_VECTOR_ADDRESS_883_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_883_VECTOR_ADDRESS_883_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_883_RESETVAL (0x00000000u)

/* vector_address_reg_884 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_884_VECTOR_ADDRESS_884_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_884_VECTOR_ADDRESS_884_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_884_VECTOR_ADDRESS_884_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_884_RESETVAL (0x00000000u)

/* vector_address_reg_885 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_885_VECTOR_ADDRESS_885_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_885_VECTOR_ADDRESS_885_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_885_VECTOR_ADDRESS_885_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_885_RESETVAL (0x00000000u)

/* vector_address_reg_886 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_886_VECTOR_ADDRESS_886_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_886_VECTOR_ADDRESS_886_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_886_VECTOR_ADDRESS_886_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_886_RESETVAL (0x00000000u)

/* vector_address_reg_887 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_887_VECTOR_ADDRESS_887_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_887_VECTOR_ADDRESS_887_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_887_VECTOR_ADDRESS_887_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_887_RESETVAL (0x00000000u)

/* vector_address_reg_888 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_888_VECTOR_ADDRESS_888_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_888_VECTOR_ADDRESS_888_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_888_VECTOR_ADDRESS_888_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_888_RESETVAL (0x00000000u)

/* vector_address_reg_889 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_889_VECTOR_ADDRESS_889_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_889_VECTOR_ADDRESS_889_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_889_VECTOR_ADDRESS_889_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_889_RESETVAL (0x00000000u)

/* vector_address_reg_890 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_890_VECTOR_ADDRESS_890_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_890_VECTOR_ADDRESS_890_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_890_VECTOR_ADDRESS_890_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_890_RESETVAL (0x00000000u)

/* vector_address_reg_891 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_891_VECTOR_ADDRESS_891_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_891_VECTOR_ADDRESS_891_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_891_VECTOR_ADDRESS_891_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_891_RESETVAL (0x00000000u)

/* vector_address_reg_892 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_892_VECTOR_ADDRESS_892_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_892_VECTOR_ADDRESS_892_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_892_VECTOR_ADDRESS_892_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_892_RESETVAL (0x00000000u)

/* vector_address_reg_893 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_893_VECTOR_ADDRESS_893_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_893_VECTOR_ADDRESS_893_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_893_VECTOR_ADDRESS_893_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_893_RESETVAL (0x00000000u)

/* vector_address_reg_894 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_894_VECTOR_ADDRESS_894_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_894_VECTOR_ADDRESS_894_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_894_VECTOR_ADDRESS_894_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_894_RESETVAL (0x00000000u)

/* vector_address_reg_895 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_895_VECTOR_ADDRESS_895_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_895_VECTOR_ADDRESS_895_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_895_VECTOR_ADDRESS_895_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_895_RESETVAL (0x00000000u)

/* vector_address_reg_896 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_896_VECTOR_ADDRESS_896_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_896_VECTOR_ADDRESS_896_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_896_VECTOR_ADDRESS_896_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_896_RESETVAL (0x00000000u)

/* vector_address_reg_897 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_897_VECTOR_ADDRESS_897_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_897_VECTOR_ADDRESS_897_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_897_VECTOR_ADDRESS_897_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_897_RESETVAL (0x00000000u)

/* vector_address_reg_898 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_898_VECTOR_ADDRESS_898_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_898_VECTOR_ADDRESS_898_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_898_VECTOR_ADDRESS_898_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_898_RESETVAL (0x00000000u)

/* vector_address_reg_899 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_899_VECTOR_ADDRESS_899_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_899_VECTOR_ADDRESS_899_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_899_VECTOR_ADDRESS_899_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_899_RESETVAL (0x00000000u)

/* vector_address_reg_900 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_900_VECTOR_ADDRESS_900_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_900_VECTOR_ADDRESS_900_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_900_VECTOR_ADDRESS_900_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_900_RESETVAL (0x00000000u)

/* vector_address_reg_901 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_901_VECTOR_ADDRESS_901_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_901_VECTOR_ADDRESS_901_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_901_VECTOR_ADDRESS_901_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_901_RESETVAL (0x00000000u)

/* vector_address_reg_902 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_902_VECTOR_ADDRESS_902_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_902_VECTOR_ADDRESS_902_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_902_VECTOR_ADDRESS_902_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_902_RESETVAL (0x00000000u)

/* vector_address_reg_903 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_903_VECTOR_ADDRESS_903_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_903_VECTOR_ADDRESS_903_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_903_VECTOR_ADDRESS_903_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_903_RESETVAL (0x00000000u)

/* vector_address_reg_904 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_904_VECTOR_ADDRESS_904_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_904_VECTOR_ADDRESS_904_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_904_VECTOR_ADDRESS_904_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_904_RESETVAL (0x00000000u)

/* vector_address_reg_905 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_905_VECTOR_ADDRESS_905_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_905_VECTOR_ADDRESS_905_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_905_VECTOR_ADDRESS_905_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_905_RESETVAL (0x00000000u)

/* vector_address_reg_906 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_906_VECTOR_ADDRESS_906_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_906_VECTOR_ADDRESS_906_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_906_VECTOR_ADDRESS_906_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_906_RESETVAL (0x00000000u)

/* vector_address_reg_907 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_907_VECTOR_ADDRESS_907_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_907_VECTOR_ADDRESS_907_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_907_VECTOR_ADDRESS_907_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_907_RESETVAL (0x00000000u)

/* vector_address_reg_908 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_908_VECTOR_ADDRESS_908_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_908_VECTOR_ADDRESS_908_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_908_VECTOR_ADDRESS_908_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_908_RESETVAL (0x00000000u)

/* vector_address_reg_909 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_909_VECTOR_ADDRESS_909_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_909_VECTOR_ADDRESS_909_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_909_VECTOR_ADDRESS_909_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_909_RESETVAL (0x00000000u)

/* vector_address_reg_910 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_910_VECTOR_ADDRESS_910_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_910_VECTOR_ADDRESS_910_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_910_VECTOR_ADDRESS_910_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_910_RESETVAL (0x00000000u)

/* vector_address_reg_911 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_911_VECTOR_ADDRESS_911_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_911_VECTOR_ADDRESS_911_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_911_VECTOR_ADDRESS_911_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_911_RESETVAL (0x00000000u)

/* vector_address_reg_912 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_912_VECTOR_ADDRESS_912_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_912_VECTOR_ADDRESS_912_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_912_VECTOR_ADDRESS_912_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_912_RESETVAL (0x00000000u)

/* vector_address_reg_913 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_913_VECTOR_ADDRESS_913_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_913_VECTOR_ADDRESS_913_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_913_VECTOR_ADDRESS_913_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_913_RESETVAL (0x00000000u)

/* vector_address_reg_914 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_914_VECTOR_ADDRESS_914_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_914_VECTOR_ADDRESS_914_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_914_VECTOR_ADDRESS_914_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_914_RESETVAL (0x00000000u)

/* vector_address_reg_915 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_915_VECTOR_ADDRESS_915_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_915_VECTOR_ADDRESS_915_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_915_VECTOR_ADDRESS_915_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_915_RESETVAL (0x00000000u)

/* vector_address_reg_916 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_916_VECTOR_ADDRESS_916_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_916_VECTOR_ADDRESS_916_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_916_VECTOR_ADDRESS_916_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_916_RESETVAL (0x00000000u)

/* vector_address_reg_917 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_917_VECTOR_ADDRESS_917_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_917_VECTOR_ADDRESS_917_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_917_VECTOR_ADDRESS_917_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_917_RESETVAL (0x00000000u)

/* vector_address_reg_918 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_918_VECTOR_ADDRESS_918_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_918_VECTOR_ADDRESS_918_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_918_VECTOR_ADDRESS_918_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_918_RESETVAL (0x00000000u)

/* vector_address_reg_919 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_919_VECTOR_ADDRESS_919_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_919_VECTOR_ADDRESS_919_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_919_VECTOR_ADDRESS_919_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_919_RESETVAL (0x00000000u)

/* vector_address_reg_920 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_920_VECTOR_ADDRESS_920_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_920_VECTOR_ADDRESS_920_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_920_VECTOR_ADDRESS_920_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_920_RESETVAL (0x00000000u)

/* vector_address_reg_921 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_921_VECTOR_ADDRESS_921_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_921_VECTOR_ADDRESS_921_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_921_VECTOR_ADDRESS_921_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_921_RESETVAL (0x00000000u)

/* vector_address_reg_922 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_922_VECTOR_ADDRESS_922_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_922_VECTOR_ADDRESS_922_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_922_VECTOR_ADDRESS_922_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_922_RESETVAL (0x00000000u)

/* vector_address_reg_923 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_923_VECTOR_ADDRESS_923_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_923_VECTOR_ADDRESS_923_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_923_VECTOR_ADDRESS_923_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_923_RESETVAL (0x00000000u)

/* vector_address_reg_924 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_924_VECTOR_ADDRESS_924_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_924_VECTOR_ADDRESS_924_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_924_VECTOR_ADDRESS_924_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_924_RESETVAL (0x00000000u)

/* vector_address_reg_925 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_925_VECTOR_ADDRESS_925_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_925_VECTOR_ADDRESS_925_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_925_VECTOR_ADDRESS_925_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_925_RESETVAL (0x00000000u)

/* vector_address_reg_926 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_926_VECTOR_ADDRESS_926_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_926_VECTOR_ADDRESS_926_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_926_VECTOR_ADDRESS_926_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_926_RESETVAL (0x00000000u)

/* vector_address_reg_927 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_927_VECTOR_ADDRESS_927_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_927_VECTOR_ADDRESS_927_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_927_VECTOR_ADDRESS_927_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_927_RESETVAL (0x00000000u)

/* vector_address_reg_928 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_928_VECTOR_ADDRESS_928_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_928_VECTOR_ADDRESS_928_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_928_VECTOR_ADDRESS_928_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_928_RESETVAL (0x00000000u)

/* vector_address_reg_929 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_929_VECTOR_ADDRESS_929_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_929_VECTOR_ADDRESS_929_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_929_VECTOR_ADDRESS_929_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_929_RESETVAL (0x00000000u)

/* vector_address_reg_930 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_930_VECTOR_ADDRESS_930_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_930_VECTOR_ADDRESS_930_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_930_VECTOR_ADDRESS_930_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_930_RESETVAL (0x00000000u)

/* vector_address_reg_931 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_931_VECTOR_ADDRESS_931_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_931_VECTOR_ADDRESS_931_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_931_VECTOR_ADDRESS_931_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_931_RESETVAL (0x00000000u)

/* vector_address_reg_932 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_932_VECTOR_ADDRESS_932_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_932_VECTOR_ADDRESS_932_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_932_VECTOR_ADDRESS_932_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_932_RESETVAL (0x00000000u)

/* vector_address_reg_933 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_933_VECTOR_ADDRESS_933_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_933_VECTOR_ADDRESS_933_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_933_VECTOR_ADDRESS_933_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_933_RESETVAL (0x00000000u)

/* vector_address_reg_934 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_934_VECTOR_ADDRESS_934_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_934_VECTOR_ADDRESS_934_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_934_VECTOR_ADDRESS_934_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_934_RESETVAL (0x00000000u)

/* vector_address_reg_935 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_935_VECTOR_ADDRESS_935_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_935_VECTOR_ADDRESS_935_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_935_VECTOR_ADDRESS_935_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_935_RESETVAL (0x00000000u)

/* vector_address_reg_936 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_936_VECTOR_ADDRESS_936_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_936_VECTOR_ADDRESS_936_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_936_VECTOR_ADDRESS_936_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_936_RESETVAL (0x00000000u)

/* vector_address_reg_937 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_937_VECTOR_ADDRESS_937_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_937_VECTOR_ADDRESS_937_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_937_VECTOR_ADDRESS_937_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_937_RESETVAL (0x00000000u)

/* vector_address_reg_938 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_938_VECTOR_ADDRESS_938_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_938_VECTOR_ADDRESS_938_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_938_VECTOR_ADDRESS_938_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_938_RESETVAL (0x00000000u)

/* vector_address_reg_939 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_939_VECTOR_ADDRESS_939_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_939_VECTOR_ADDRESS_939_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_939_VECTOR_ADDRESS_939_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_939_RESETVAL (0x00000000u)

/* vector_address_reg_940 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_940_VECTOR_ADDRESS_940_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_940_VECTOR_ADDRESS_940_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_940_VECTOR_ADDRESS_940_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_940_RESETVAL (0x00000000u)

/* vector_address_reg_941 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_941_VECTOR_ADDRESS_941_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_941_VECTOR_ADDRESS_941_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_941_VECTOR_ADDRESS_941_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_941_RESETVAL (0x00000000u)

/* vector_address_reg_942 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_942_VECTOR_ADDRESS_942_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_942_VECTOR_ADDRESS_942_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_942_VECTOR_ADDRESS_942_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_942_RESETVAL (0x00000000u)

/* vector_address_reg_943 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_943_VECTOR_ADDRESS_943_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_943_VECTOR_ADDRESS_943_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_943_VECTOR_ADDRESS_943_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_943_RESETVAL (0x00000000u)

/* vector_address_reg_944 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_944_VECTOR_ADDRESS_944_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_944_VECTOR_ADDRESS_944_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_944_VECTOR_ADDRESS_944_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_944_RESETVAL (0x00000000u)

/* vector_address_reg_945 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_945_VECTOR_ADDRESS_945_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_945_VECTOR_ADDRESS_945_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_945_VECTOR_ADDRESS_945_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_945_RESETVAL (0x00000000u)

/* vector_address_reg_946 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_946_VECTOR_ADDRESS_946_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_946_VECTOR_ADDRESS_946_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_946_VECTOR_ADDRESS_946_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_946_RESETVAL (0x00000000u)

/* vector_address_reg_947 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_947_VECTOR_ADDRESS_947_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_947_VECTOR_ADDRESS_947_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_947_VECTOR_ADDRESS_947_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_947_RESETVAL (0x00000000u)

/* vector_address_reg_948 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_948_VECTOR_ADDRESS_948_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_948_VECTOR_ADDRESS_948_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_948_VECTOR_ADDRESS_948_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_948_RESETVAL (0x00000000u)

/* vector_address_reg_949 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_949_VECTOR_ADDRESS_949_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_949_VECTOR_ADDRESS_949_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_949_VECTOR_ADDRESS_949_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_949_RESETVAL (0x00000000u)

/* vector_address_reg_950 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_950_VECTOR_ADDRESS_950_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_950_VECTOR_ADDRESS_950_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_950_VECTOR_ADDRESS_950_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_950_RESETVAL (0x00000000u)

/* vector_address_reg_951 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_951_VECTOR_ADDRESS_951_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_951_VECTOR_ADDRESS_951_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_951_VECTOR_ADDRESS_951_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_951_RESETVAL (0x00000000u)

/* vector_address_reg_952 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_952_VECTOR_ADDRESS_952_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_952_VECTOR_ADDRESS_952_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_952_VECTOR_ADDRESS_952_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_952_RESETVAL (0x00000000u)

/* vector_address_reg_953 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_953_VECTOR_ADDRESS_953_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_953_VECTOR_ADDRESS_953_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_953_VECTOR_ADDRESS_953_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_953_RESETVAL (0x00000000u)

/* vector_address_reg_954 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_954_VECTOR_ADDRESS_954_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_954_VECTOR_ADDRESS_954_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_954_VECTOR_ADDRESS_954_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_954_RESETVAL (0x00000000u)

/* vector_address_reg_955 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_955_VECTOR_ADDRESS_955_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_955_VECTOR_ADDRESS_955_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_955_VECTOR_ADDRESS_955_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_955_RESETVAL (0x00000000u)

/* vector_address_reg_956 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_956_VECTOR_ADDRESS_956_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_956_VECTOR_ADDRESS_956_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_956_VECTOR_ADDRESS_956_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_956_RESETVAL (0x00000000u)

/* vector_address_reg_957 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_957_VECTOR_ADDRESS_957_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_957_VECTOR_ADDRESS_957_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_957_VECTOR_ADDRESS_957_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_957_RESETVAL (0x00000000u)

/* vector_address_reg_958 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_958_VECTOR_ADDRESS_958_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_958_VECTOR_ADDRESS_958_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_958_VECTOR_ADDRESS_958_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_958_RESETVAL (0x00000000u)

/* vector_address_reg_959 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_959_VECTOR_ADDRESS_959_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_959_VECTOR_ADDRESS_959_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_959_VECTOR_ADDRESS_959_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_959_RESETVAL (0x00000000u)

/* vector_address_reg_960 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_960_VECTOR_ADDRESS_960_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_960_VECTOR_ADDRESS_960_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_960_VECTOR_ADDRESS_960_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_960_RESETVAL (0x00000000u)

/* vector_address_reg_961 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_961_VECTOR_ADDRESS_961_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_961_VECTOR_ADDRESS_961_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_961_VECTOR_ADDRESS_961_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_961_RESETVAL (0x00000000u)

/* vector_address_reg_962 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_962_VECTOR_ADDRESS_962_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_962_VECTOR_ADDRESS_962_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_962_VECTOR_ADDRESS_962_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_962_RESETVAL (0x00000000u)

/* vector_address_reg_963 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_963_VECTOR_ADDRESS_963_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_963_VECTOR_ADDRESS_963_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_963_VECTOR_ADDRESS_963_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_963_RESETVAL (0x00000000u)

/* vector_address_reg_964 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_964_VECTOR_ADDRESS_964_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_964_VECTOR_ADDRESS_964_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_964_VECTOR_ADDRESS_964_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_964_RESETVAL (0x00000000u)

/* vector_address_reg_965 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_965_VECTOR_ADDRESS_965_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_965_VECTOR_ADDRESS_965_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_965_VECTOR_ADDRESS_965_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_965_RESETVAL (0x00000000u)

/* vector_address_reg_966 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_966_VECTOR_ADDRESS_966_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_966_VECTOR_ADDRESS_966_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_966_VECTOR_ADDRESS_966_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_966_RESETVAL (0x00000000u)

/* vector_address_reg_967 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_967_VECTOR_ADDRESS_967_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_967_VECTOR_ADDRESS_967_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_967_VECTOR_ADDRESS_967_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_967_RESETVAL (0x00000000u)

/* vector_address_reg_968 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_968_VECTOR_ADDRESS_968_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_968_VECTOR_ADDRESS_968_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_968_VECTOR_ADDRESS_968_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_968_RESETVAL (0x00000000u)

/* vector_address_reg_969 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_969_VECTOR_ADDRESS_969_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_969_VECTOR_ADDRESS_969_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_969_VECTOR_ADDRESS_969_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_969_RESETVAL (0x00000000u)

/* vector_address_reg_970 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_970_VECTOR_ADDRESS_970_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_970_VECTOR_ADDRESS_970_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_970_VECTOR_ADDRESS_970_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_970_RESETVAL (0x00000000u)

/* vector_address_reg_971 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_971_VECTOR_ADDRESS_971_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_971_VECTOR_ADDRESS_971_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_971_VECTOR_ADDRESS_971_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_971_RESETVAL (0x00000000u)

/* vector_address_reg_972 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_972_VECTOR_ADDRESS_972_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_972_VECTOR_ADDRESS_972_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_972_VECTOR_ADDRESS_972_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_972_RESETVAL (0x00000000u)

/* vector_address_reg_973 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_973_VECTOR_ADDRESS_973_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_973_VECTOR_ADDRESS_973_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_973_VECTOR_ADDRESS_973_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_973_RESETVAL (0x00000000u)

/* vector_address_reg_974 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_974_VECTOR_ADDRESS_974_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_974_VECTOR_ADDRESS_974_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_974_VECTOR_ADDRESS_974_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_974_RESETVAL (0x00000000u)

/* vector_address_reg_975 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_975_VECTOR_ADDRESS_975_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_975_VECTOR_ADDRESS_975_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_975_VECTOR_ADDRESS_975_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_975_RESETVAL (0x00000000u)

/* vector_address_reg_976 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_976_VECTOR_ADDRESS_976_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_976_VECTOR_ADDRESS_976_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_976_VECTOR_ADDRESS_976_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_976_RESETVAL (0x00000000u)

/* vector_address_reg_977 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_977_VECTOR_ADDRESS_977_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_977_VECTOR_ADDRESS_977_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_977_VECTOR_ADDRESS_977_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_977_RESETVAL (0x00000000u)

/* vector_address_reg_978 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_978_VECTOR_ADDRESS_978_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_978_VECTOR_ADDRESS_978_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_978_VECTOR_ADDRESS_978_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_978_RESETVAL (0x00000000u)

/* vector_address_reg_979 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_979_VECTOR_ADDRESS_979_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_979_VECTOR_ADDRESS_979_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_979_VECTOR_ADDRESS_979_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_979_RESETVAL (0x00000000u)

/* vector_address_reg_980 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_980_VECTOR_ADDRESS_980_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_980_VECTOR_ADDRESS_980_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_980_VECTOR_ADDRESS_980_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_980_RESETVAL (0x00000000u)

/* vector_address_reg_981 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_981_VECTOR_ADDRESS_981_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_981_VECTOR_ADDRESS_981_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_981_VECTOR_ADDRESS_981_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_981_RESETVAL (0x00000000u)

/* vector_address_reg_982 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_982_VECTOR_ADDRESS_982_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_982_VECTOR_ADDRESS_982_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_982_VECTOR_ADDRESS_982_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_982_RESETVAL (0x00000000u)

/* vector_address_reg_983 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_983_VECTOR_ADDRESS_983_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_983_VECTOR_ADDRESS_983_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_983_VECTOR_ADDRESS_983_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_983_RESETVAL (0x00000000u)

/* vector_address_reg_984 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_984_VECTOR_ADDRESS_984_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_984_VECTOR_ADDRESS_984_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_984_VECTOR_ADDRESS_984_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_984_RESETVAL (0x00000000u)

/* vector_address_reg_985 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_985_VECTOR_ADDRESS_985_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_985_VECTOR_ADDRESS_985_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_985_VECTOR_ADDRESS_985_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_985_RESETVAL (0x00000000u)

/* vector_address_reg_986 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_986_VECTOR_ADDRESS_986_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_986_VECTOR_ADDRESS_986_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_986_VECTOR_ADDRESS_986_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_986_RESETVAL (0x00000000u)

/* vector_address_reg_987 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_987_VECTOR_ADDRESS_987_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_987_VECTOR_ADDRESS_987_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_987_VECTOR_ADDRESS_987_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_987_RESETVAL (0x00000000u)

/* vector_address_reg_988 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_988_VECTOR_ADDRESS_988_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_988_VECTOR_ADDRESS_988_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_988_VECTOR_ADDRESS_988_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_988_RESETVAL (0x00000000u)

/* vector_address_reg_989 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_989_VECTOR_ADDRESS_989_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_989_VECTOR_ADDRESS_989_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_989_VECTOR_ADDRESS_989_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_989_RESETVAL (0x00000000u)

/* vector_address_reg_990 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_990_VECTOR_ADDRESS_990_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_990_VECTOR_ADDRESS_990_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_990_VECTOR_ADDRESS_990_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_990_RESETVAL (0x00000000u)

/* vector_address_reg_991 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_991_VECTOR_ADDRESS_991_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_991_VECTOR_ADDRESS_991_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_991_VECTOR_ADDRESS_991_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_991_RESETVAL (0x00000000u)

/* vector_address_reg_992 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_992_VECTOR_ADDRESS_992_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_992_VECTOR_ADDRESS_992_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_992_VECTOR_ADDRESS_992_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_992_RESETVAL (0x00000000u)

/* vector_address_reg_993 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_993_VECTOR_ADDRESS_993_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_993_VECTOR_ADDRESS_993_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_993_VECTOR_ADDRESS_993_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_993_RESETVAL (0x00000000u)

/* vector_address_reg_994 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_994_VECTOR_ADDRESS_994_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_994_VECTOR_ADDRESS_994_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_994_VECTOR_ADDRESS_994_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_994_RESETVAL (0x00000000u)

/* vector_address_reg_995 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_995_VECTOR_ADDRESS_995_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_995_VECTOR_ADDRESS_995_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_995_VECTOR_ADDRESS_995_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_995_RESETVAL (0x00000000u)

/* vector_address_reg_996 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_996_VECTOR_ADDRESS_996_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_996_VECTOR_ADDRESS_996_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_996_VECTOR_ADDRESS_996_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_996_RESETVAL (0x00000000u)

/* vector_address_reg_997 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_997_VECTOR_ADDRESS_997_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_997_VECTOR_ADDRESS_997_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_997_VECTOR_ADDRESS_997_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_997_RESETVAL (0x00000000u)

/* vector_address_reg_998 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_998_VECTOR_ADDRESS_998_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_998_VECTOR_ADDRESS_998_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_998_VECTOR_ADDRESS_998_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_998_RESETVAL (0x00000000u)

/* vector_address_reg_999 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_999_VECTOR_ADDRESS_999_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_999_VECTOR_ADDRESS_999_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_999_VECTOR_ADDRESS_999_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_999_RESETVAL (0x00000000u)

/* vector_address_reg_1000 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1000_VECTOR_ADDRESS_1000_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1000_VECTOR_ADDRESS_1000_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1000_VECTOR_ADDRESS_1000_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1000_RESETVAL (0x00000000u)

/* vector_address_reg_1001 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1001_VECTOR_ADDRESS_1001_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1001_VECTOR_ADDRESS_1001_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1001_VECTOR_ADDRESS_1001_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1001_RESETVAL (0x00000000u)

/* vector_address_reg_1002 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1002_VECTOR_ADDRESS_1002_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1002_VECTOR_ADDRESS_1002_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1002_VECTOR_ADDRESS_1002_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1002_RESETVAL (0x00000000u)

/* vector_address_reg_1003 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1003_VECTOR_ADDRESS_1003_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1003_VECTOR_ADDRESS_1003_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1003_VECTOR_ADDRESS_1003_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1003_RESETVAL (0x00000000u)

/* vector_address_reg_1004 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1004_VECTOR_ADDRESS_1004_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1004_VECTOR_ADDRESS_1004_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1004_VECTOR_ADDRESS_1004_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1004_RESETVAL (0x00000000u)

/* vector_address_reg_1005 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1005_VECTOR_ADDRESS_1005_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1005_VECTOR_ADDRESS_1005_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1005_VECTOR_ADDRESS_1005_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1005_RESETVAL (0x00000000u)

/* vector_address_reg_1006 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1006_VECTOR_ADDRESS_1006_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1006_VECTOR_ADDRESS_1006_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1006_VECTOR_ADDRESS_1006_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1006_RESETVAL (0x00000000u)

/* vector_address_reg_1007 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1007_VECTOR_ADDRESS_1007_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1007_VECTOR_ADDRESS_1007_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1007_VECTOR_ADDRESS_1007_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1007_RESETVAL (0x00000000u)

/* vector_address_reg_1008 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1008_VECTOR_ADDRESS_1008_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1008_VECTOR_ADDRESS_1008_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1008_VECTOR_ADDRESS_1008_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1008_RESETVAL (0x00000000u)

/* vector_address_reg_1009 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1009_VECTOR_ADDRESS_1009_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1009_VECTOR_ADDRESS_1009_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1009_VECTOR_ADDRESS_1009_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1009_RESETVAL (0x00000000u)

/* vector_address_reg_1010 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1010_VECTOR_ADDRESS_1010_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1010_VECTOR_ADDRESS_1010_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1010_VECTOR_ADDRESS_1010_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1010_RESETVAL (0x00000000u)

/* vector_address_reg_1011 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1011_VECTOR_ADDRESS_1011_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1011_VECTOR_ADDRESS_1011_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1011_VECTOR_ADDRESS_1011_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1011_RESETVAL (0x00000000u)

/* vector_address_reg_1012 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1012_VECTOR_ADDRESS_1012_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1012_VECTOR_ADDRESS_1012_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1012_VECTOR_ADDRESS_1012_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1012_RESETVAL (0x00000000u)

/* vector_address_reg_1013 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1013_VECTOR_ADDRESS_1013_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1013_VECTOR_ADDRESS_1013_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1013_VECTOR_ADDRESS_1013_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1013_RESETVAL (0x00000000u)

/* vector_address_reg_1014 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1014_VECTOR_ADDRESS_1014_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1014_VECTOR_ADDRESS_1014_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1014_VECTOR_ADDRESS_1014_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1014_RESETVAL (0x00000000u)

/* vector_address_reg_1015 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1015_VECTOR_ADDRESS_1015_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1015_VECTOR_ADDRESS_1015_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1015_VECTOR_ADDRESS_1015_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1015_RESETVAL (0x00000000u)

/* vector_address_reg_1016 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1016_VECTOR_ADDRESS_1016_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1016_VECTOR_ADDRESS_1016_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1016_VECTOR_ADDRESS_1016_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1016_RESETVAL (0x00000000u)

/* vector_address_reg_1017 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1017_VECTOR_ADDRESS_1017_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1017_VECTOR_ADDRESS_1017_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1017_VECTOR_ADDRESS_1017_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1017_RESETVAL (0x00000000u)

/* vector_address_reg_1018 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1018_VECTOR_ADDRESS_1018_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1018_VECTOR_ADDRESS_1018_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1018_VECTOR_ADDRESS_1018_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1018_RESETVAL (0x00000000u)

/* vector_address_reg_1019 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1019_VECTOR_ADDRESS_1019_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1019_VECTOR_ADDRESS_1019_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1019_VECTOR_ADDRESS_1019_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1019_RESETVAL (0x00000000u)

/* vector_address_reg_1020 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1020_VECTOR_ADDRESS_1020_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1020_VECTOR_ADDRESS_1020_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1020_VECTOR_ADDRESS_1020_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1020_RESETVAL (0x00000000u)

/* vector_address_reg_1021 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1021_VECTOR_ADDRESS_1021_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1021_VECTOR_ADDRESS_1021_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1021_VECTOR_ADDRESS_1021_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1021_RESETVAL (0x00000000u)

/* vector_address_reg_1022 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1022_VECTOR_ADDRESS_1022_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1022_VECTOR_ADDRESS_1022_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1022_VECTOR_ADDRESS_1022_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1022_RESETVAL (0x00000000u)

/* vector_address_reg_1023 */

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1023_VECTOR_ADDRESS_1023_MASK (0xFFFFFFFFu)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1023_VECTOR_ADDRESS_1023_SHIFT (0x00000000u)
#define CSL_CPINTC_VECTOR_ADDRESS_REG_1023_VECTOR_ADDRESS_1023_RESETVAL (0x00000000u)

#define CSL_CPINTC_VECTOR_ADDRESS_REG_1023_RESETVAL (0x00000000u)

#endif

