/********************************************************************
* Copyright (C) 2003-2008 Texas Instruments Incorporated.
 * 
 *  Redistribution and use in source and binary forms, with or without 
 *  modification, are permitted provided that the following conditions 
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright 
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the 
 *    documentation and/or other materials provided with the   
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/
#ifndef _CSLR_TCP3D_CFG_H_
#define _CSLR_TCP3D_CFG_H_

/* CSL Modification:
 *  The file has been modified from the AUTOGEN file for the following
 *  reasons:-
 *      a) Modified the header file includes to be RTSC compliant
 */

#include <ti/csl/cslr.h>
#include <ti/csl/tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 TCP3_PID;
    volatile Uint32 TCP3_MODE;
    volatile Uint32 TCP3_END;
    volatile Uint32 TCP3_EMU;
    volatile Uint32 TCP3_EOI;
    volatile Uint32 TCP3_SOFT_RESET;
    volatile Uint8 RSVD0[136];
    volatile Uint32 TCP3_EINT_STAT_P1;
    volatile Uint8 RSVD1[92];
    volatile Uint32 TCP3_EXE_P0;
    volatile Uint32 TCP3_STS_P0;
    volatile Uint32 TCP3_EV_SET_P0;
    volatile Uint8 RSVD2[52];
    volatile Uint32 TCP3_EINT_STAT_P0;
    volatile Uint32 TCP3_EINT_CLR_P0;
    volatile Uint32 TCP3_EINT_EN_STAT_P0;
    volatile Uint32 TCP3_EINT_EN_P0;
    volatile Uint32 TCP3_EINT_EN_CLR_P0;
    volatile Uint8 RSVD3[172];
    volatile Uint32 TCP3_EXE_P1;
    volatile Uint32 TCP3_STS_P1;
    volatile Uint32 TCP3_EV_SET_P1;
    volatile Uint8 RSVD4[56];
    volatile Uint32 TCP3_EINT_CLR_P1;
    volatile Uint32 TCP3_EINT_EN_STAT_P1;
    volatile Uint32 TCP3_EINT_EN_P1;
    volatile Uint32 TCP3_EINT_EN_CLR_P1;
} CSL_Tcp3d_cfgRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* TCP3_PID */

#define CSL_TCP3D_CFG_TCP3_PID_MINOR_MASK (0x0000003Fu)
#define CSL_TCP3D_CFG_TCP3_PID_MINOR_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_PID_MINOR_RESETVAL (0x00000022u)

#define CSL_TCP3D_CFG_TCP3_PID_CUSTOM_MASK (0x000000C0u)
#define CSL_TCP3D_CFG_TCP3_PID_CUSTOM_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_PID_CUSTOM_RESETVAL (0x00000000u)

#define CSL_TCP3D_CFG_TCP3_PID_MAJOR_MASK (0x00000700u)
#define CSL_TCP3D_CFG_TCP3_PID_MAJOR_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_PID_MAJOR_RESETVAL (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_PID_RTL_MASK  (0x0000F800u)
#define CSL_TCP3D_CFG_TCP3_PID_RTL_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_PID_RTL_RESETVAL (0x00000000u)

#define CSL_TCP3D_CFG_TCP3_PID_FUNCTION_MASK (0x0FFF0000u)
#define CSL_TCP3D_CFG_TCP3_PID_FUNCTION_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_PID_FUNCTION_RESETVAL (0x00000804u)


#define CSL_TCP3D_CFG_TCP3_PID_SCHEME_MASK (0xC0000000u)
#define CSL_TCP3D_CFG_TCP3_PID_SCHEME_SHIFT (0x0000001Eu)
#define CSL_TCP3D_CFG_TCP3_PID_SCHEME_RESETVAL (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_PID_RESETVAL  (0x48040122u)

/* TCP3_MODE */

#define CSL_TCP3D_CFG_TCP3_MODE_MODE_SEL_MASK (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_MODE_MODE_SEL_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_MODE_MODE_SEL_RESETVAL (0x00000000u)
/*----MODE_SEL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_MODE_MODE_SEL_3GPP (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_MODE_MODE_SEL_LTE (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_MODE_MODE_SEL_WIMAX (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_MODE_MODE_SEL_HSUPA (0x00000003u)


#define CSL_TCP3D_CFG_TCP3_MODE_IN_MEM_DB_EN_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_MODE_IN_MEM_DB_EN_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_MODE_IN_MEM_DB_EN_RESETVAL (0x00000000u)
/*----IN_MEM_DB_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_MODE_IN_MEM_DB_EN_DISABLE (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_MODE_IN_MEM_DB_EN_ENABLE (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_MODE_ITG_EN_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_MODE_ITG_EN_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_MODE_ITG_EN_RESETVAL (0x00000000u)
/*----ITG_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_MODE_ITG_EN_DISABLE (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_MODE_ITG_EN_ENABLE (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_MODE_ERROR_IGNORE_EN_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_MODE_ERROR_IGNORE_EN_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_MODE_ERROR_IGNORE_EN_RESETVAL (0x00000000u)
/*----ERROR_IGNORE_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_MODE_ERROR_IGNORE_EN_STOP (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_MODE_ERROR_IGNORE_EN_DONT_STOP (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_MODE_AUTO_TRIG_EN_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_MODE_AUTO_TRIG_EN_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_MODE_AUTO_TRIG_EN_RESETVAL (0x00000000u)
/*----AUTO_TRIG_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_MODE_AUTO_TRIG_EN_DISABLE (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_MODE_AUTO_TRIG_EN_ENABLE (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_MODE_LTE_CRC_ISEL_MASK (0x00000080u)
#define CSL_TCP3D_CFG_TCP3_MODE_LTE_CRC_ISEL_SHIFT (0x00000007u)
#define CSL_TCP3D_CFG_TCP3_MODE_LTE_CRC_ISEL_RESETVAL (0x00000000u)
/*----LTE_CRC_ISEL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_MODE_LTE_CRC_ISEL_USE_ZERO (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_MODE_LTE_CRC_ISEL_USE_ONES (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_MODE_RESETVAL (0x00000000u)

/* TCP3_END */

#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INTR_MASK (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INTR_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INTR_RESETVAL (0x00000000u)
/*----ENDIAN_INTR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INTR_32_BIT_PACKED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INTR_16_BIT_NATIVE (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INDATA_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INDATA_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INDATA_RESETVAL (0x00000000u)
/*----ENDIAN_INDATA Tokens----*/
#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INDATA_32_BIT_PACKED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_END_ENDIAN_INDATA_8_BIT_NATIVE (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_END_RESETVAL  (0x00000000u)

/* TCP3_EMU */

#define CSL_TCP3D_CFG_TCP3_EMU_FREERUN_MASK (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EMU_FREERUN_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EMU_FREERUN_RESETVAL (0x00000000u)
/*----FREERUN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EMU_FREERUN_RESPOND (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EMU_FREERUN_IGNORE (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EMU_SOFT_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EMU_SOFT_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EMU_SOFT_RESETVAL (0x00000000u)
/*----SOFT Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EMU_SOFT_HARD_STOP (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EMU_SOFT_SOFT_STOP (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EMU_RT_SEL_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EMU_RT_SEL_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EMU_RT_SEL_RESETVAL (0x00000000u)
/*----RT_SEL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EMU_RT_SEL_EMU_DBGSUSP (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EMU_RT_SEL_EMU_DBGSUSP_RT (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EMU_RESETVAL  (0x00000000u)

/* TCP3_EOI */

#define CSL_TCP3D_CFG_TCP3_EOI_EOI_VECTOR_MASK (0x000000FFu)
#define CSL_TCP3D_CFG_TCP3_EOI_EOI_VECTOR_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EOI_EOI_VECTOR_RESETVAL (0x00000000u)


#define CSL_TCP3D_CFG_TCP3_EOI_RESETVAL  (0x00000000u)

/* TCP3_SOFT_RESET */

#define CSL_TCP3D_CFG_TCP3_SOFT_RESET_SOFT_RESET_MASK (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_SOFT_RESET_SOFT_RESET_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_SOFT_RESET_SOFT_RESET_RESETVAL (0x00000000u)
/*----SOFT_RESET Tokens----*/
#define CSL_TCP3D_CFG_TCP3_SOFT_RESET_SOFT_RESET_NEGATE (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_SOFT_RESET_SOFT_RESET_ASSERT (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_SOFT_RESET_RESETVAL (0x00000000u)

/* TCP3_EINT_STAT_P1 */


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_BLK_LN_ERR_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_BLK_LN_ERR_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_BLK_LN_ERR_RESETVAL (0x00000000u)
/*----BLK_LN_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_BLK_LN_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_BLK_LN_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_INTLV_CONT_ERR_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_INTLV_CONT_ERR_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_INTLV_CONT_ERR_RESETVAL (0x00000000u)
/*----INTLV_CONT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_INTLV_CONT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_INTLV_CONT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MODE_REG_WR_ERR_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MODE_REG_WR_ERR_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MODE_REG_WR_ERR_RESETVAL (0x00000000u)
/*----MODE_REG_WR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MODE_REG_WR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MODE_REG_WR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SPLIT_TCP_ERR_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SPLIT_TCP_ERR_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SPLIT_TCP_ERR_RESETVAL (0x00000000u)
/*----SPLIT_TCP_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SPLIT_TCP_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SPLIT_TCP_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_END_REG_WR_ERR_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_END_REG_WR_ERR_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_END_REG_WR_ERR_RESETVAL (0x00000000u)
/*----END_REG_WR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_END_REG_WR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_END_REG_WR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SW0_LN_ERR_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SW0_LN_ERR_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SW0_LN_ERR_RESETVAL (0x00000000u)
/*----SW0_LN_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SW0_LN_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SW0_LN_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SNR_VAL_ERR_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SNR_VAL_ERR_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SNR_VAL_ERR_RESETVAL (0x00000000u)
/*----SNR_VAL_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SNR_VAL_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_SNR_VAL_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IDAT_FMT_ERR_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IDAT_FMT_ERR_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IDAT_FMT_ERR_RESETVAL (0x00000000u)
/*----IDAT_FMT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IDAT_FMT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IDAT_FMT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_ICFG_ACC_ERR_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_ICFG_ACC_ERR_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_ICFG_ACC_ERR_RESETVAL (0x00000000u)
/*----ICFG_ACC_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_ICFG_ACC_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_ICFG_ACC_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IPROG_ACC_ERR_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IPROG_ACC_ERR_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IPROG_ACC_ERR_RESETVAL (0x00000000u)
/*----IPROG_ACC_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IPROG_ACC_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_IPROG_ACC_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MAX_MIN_IT_ERR_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MAX_MIN_IT_ERR_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MAX_MIN_IT_ERR_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MAX_MIN_IT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_MAX_MIN_IT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_TRIG_ERR_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_TRIG_ERR_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_TRIG_ERR_RESETVAL (0x00000000u)
/*----TRIG_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_TRIG_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_TRIG_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UCFG_ERR_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UCFG_ERR_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UCFG_ERR_RESETVAL (0x00000000u)
/*----DMA_UCFG_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UCFG_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UCFG_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_USYS_ERR_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_USYS_ERR_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_USYS_ERR_RESETVAL (0x00000000u)
/*----DMA_USYS_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_USYS_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_USYS_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR0_ERR_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR0_ERR_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR0_ERR_RESETVAL (0x00000000u)
/*----DMA_UPAR0_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR0_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR0_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR1_ERR_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR1_ERR_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR1_ERR_RESETVAL (0x00000000u)
/*----DMA_UPAR1_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR1_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_UPAR1_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OSYS_ERR_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OSYS_ERR_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OSYS_ERR_RESETVAL (0x00000000u)
/*----DMA_OSYS_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OSYS_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OSYS_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR0_ERR_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR0_ERR_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR0_ERR_RESETVAL (0x00000000u)
/*----DMA_OPAR0_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR0_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR0_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR1_ERR_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR1_ERR_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR1_ERR_RESETVAL (0x00000000u)
/*----DMA_OPAR1_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR1_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OPAR1_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OINTLV_ERR_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OINTLV_ERR_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OINTLV_ERR_RESETVAL (0x00000000u)
/*----DMA_OINTLV_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OINTLV_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_DMA_OINTLV_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_RADDR_ERR_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_RADDR_ERR_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_RADDR_ERR_RESETVAL (0x00000000u)
/*----VC_RADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_RADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_RADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_WADDR_ERR_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_WADDR_ERR_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_WADDR_ERR_RESETVAL (0x00000000u)
/*----VC_WADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_WADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VC_WADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_RADDR_ERR_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_RADDR_ERR_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_RADDR_ERR_RESETVAL (0x00000000u)
/*----VD_RADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_RADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_RADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_WADDR_ERR_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_WADDR_ERR_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_WADDR_ERR_RESETVAL (0x00000000u)
/*----VD_WADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_WADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_VD_WADDR_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P1_RESETVAL (0x00000000u)

/* TCP3_EXE_P0 */

#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_MASK (0x00000007u)
#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_RESETVAL (0x00000000u)
/*----EXE_CMD Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_NO_INSTRUCTION (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_ENABLE (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_DEBUG_NORMAL (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_DEBUG_ONE_MAP (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_DEBUG_REMAING_MAP (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EXE_P0_EXE_CMD_CLEAR (0x00000007u)


#define CSL_TCP3D_CFG_TCP3_EXE_P0_RESETVAL (0x00000000u)

/* TCP3_STS_P0 */

#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_PEND_MASK (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_PEND_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_PEND_RESETVAL (0x00000000u)
/*----PROC_PEND Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_PEND_DOES_NOT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_PEND_HAS (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_BUSY_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_BUSY_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_BUSY_RESETVAL (0x00000000u)
/*----PROC_BUSY Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_BUSY_NOT_BUSY (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_PROC_BUSY_BUSY (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_SYS_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_SYS_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_SYS_RESETVAL (0x00000000u)
/*----WAIT_WR_SYS Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_SYS_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_SYS_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P0_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P0_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P0_RESETVAL (0x00000000u)
/*----WAIT_WR_P0 Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P0_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P0_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P1_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P1_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P1_RESETVAL (0x00000000u)
/*----WAIT_WR_P1 Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P1_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_P1_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IL_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IL_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IL_RESETVAL (0x00000000u)
/*----WAIT_WR_IL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IL_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IL_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IC_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IC_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IC_RESETVAL (0x00000000u)
/*----WAIT_WR_IC Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IC_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_WR_IC_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_SO_MASK (0x00000080u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_SO_SHIFT (0x00000007u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_SO_RESETVAL (0x00000000u)
/*----WAIT_RD_SO Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_SO_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_SO_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_HD_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_HD_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_HD_RESETVAL (0x00000000u)
/*----WAIT_RD_HD Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_HD_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_HD_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_OS_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_OS_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_OS_RESETVAL (0x00000000u)
/*----WAIT_RD_OS Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_OS_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_WAIT_RD_OS_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_EMU_HALT_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_EMU_HALT_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_STS_P0_EMU_HALT_RESETVAL (0x00000000u)
/*----EMU_HALT Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_EMU_HALT_NOT_HALTED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_EMU_HALT_HALTED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_ITR_MASK (0x0000F000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_ITR_SHIFT (0x0000000Cu)
#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_ITR_RESETVAL (0x00000000u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_MASK (0x000F0000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_RESETVAL (0x00000000u)
/*----TCP_IF_STATE Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_IDLE (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_WAIT_TRIG (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_START_MAP (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_WAIT_INTLV (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_DEBUG (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_WAIT_MAP (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_WAIT_RD (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_ERROR (0x0000000cu)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_END_CLR (0x0000000eu)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_IF_STATE_IF_CLEAR (0x0000000fu)

#define CSL_TCP3D_CFG_TCP3_STS_P0_SNR_EXCEED_MASK (0x00300000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_SNR_EXCEED_SHIFT (0x00000014u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_SNR_EXCEED_RESETVAL (0x00000000u)
/*----SNR_EXCEED Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_SNR_EXCEED_MAP0_FAILED_SNR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_SNR_EXCEED_MAP0_PASSED_SNR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_MAP_MASK (0x00C00000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_MAP_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_MAP_RESETVAL (0x00000000u)
/*----ACTIVE_MAP Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_MAP_NO_ACTIVE_MAP (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_MAP_ACTIVE_MAP0 (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_ACTIVE_MAP_ACTIVE_MAP1 (0x00000002u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_MASK (0x0F000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_RESETVAL (0x00000000u)
/*----TCP_MAIN_STATE Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_IDLE (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_ZAPM (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_MAP0X (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_WAIT0 (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_MAP1X (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_WAIT1 (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_DITR (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_TCP_MAIN_STATE_DONE (0x00000007u)

#define CSL_TCP3D_CFG_TCP3_STS_P0_LTE_CRC_CHK_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_LTE_CRC_CHK_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_STS_P0_LTE_CRC_CHK_RESETVAL (0x00000000u)
/*----LTE_CRC_CHK Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P0_LTE_CRC_CHK_FAILED_CRC (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P0_LTE_CRC_CHK_PASSED_CRC (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_STS_P0_RESETVAL (0x00000000u)

/* TCP3_EV_SET_P0 */

#define CSL_TCP3D_CFG_TCP3_EV_SET_P0_REVT_MASK (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EV_SET_P0_REVT_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EV_SET_P0_REVT_RESETVAL (0x00000000u)
/*----REVT Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EV_SET_P0_REVT_REVT (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EV_SET_P0_RESETVAL (0x00000000u)

/* TCP3_EINT_STAT_P0 */


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_BLK_LN_ERR_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_BLK_LN_ERR_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_BLK_LN_ERR_RESETVAL (0x00000000u)
/*----BLK_LN_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_BLK_LN_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_BLK_LN_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_INTLV_CONT_ERR_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_INTLV_CONT_ERR_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_INTLV_CONT_ERR_RESETVAL (0x00000000u)
/*----INTLV_CONT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_INTLV_CONT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_INTLV_CONT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MODE_REG_WR_ERR_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MODE_REG_WR_ERR_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MODE_REG_WR_ERR_RESETVAL (0x00000000u)
/*----MODE_REG_WR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MODE_REG_WR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MODE_REG_WR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SPLIT_TCP_ERR_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SPLIT_TCP_ERR_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SPLIT_TCP_ERR_RESETVAL (0x00000000u)
/*----SPLIT_TCP_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SPLIT_TCP_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SPLIT_TCP_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_END_REG_WR_ERR_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_END_REG_WR_ERR_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_END_REG_WR_ERR_RESETVAL (0x00000000u)
/*----END_REG_WR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_END_REG_WR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_END_REG_WR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SW0_LN_ERR_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SW0_LN_ERR_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SW0_LN_ERR_RESETVAL (0x00000000u)
/*----SW0_LN_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SW0_LN_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SW0_LN_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SNR_VAL_ERR_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SNR_VAL_ERR_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SNR_VAL_ERR_RESETVAL (0x00000000u)
/*----SNR_VAL_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SNR_VAL_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_SNR_VAL_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IDAT_FMT_ERR_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IDAT_FMT_ERR_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IDAT_FMT_ERR_RESETVAL (0x00000000u)
/*----IDAT_FMT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IDAT_FMT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IDAT_FMT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_ICFG_ACC_ERR_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_ICFG_ACC_ERR_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_ICFG_ACC_ERR_RESETVAL (0x00000000u)
/*----ICFG_ACC_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_ICFG_ACC_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_ICFG_ACC_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IPROG_ACC_ERR_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IPROG_ACC_ERR_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IPROG_ACC_ERR_RESETVAL (0x00000000u)
/*----IPROG_ACC_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IPROG_ACC_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_IPROG_ACC_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MAX_MIN_IT_ERR_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MAX_MIN_IT_ERR_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MAX_MIN_IT_ERR_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MAX_MIN_IT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_MAX_MIN_IT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_TRIG_ERR_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_TRIG_ERR_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_TRIG_ERR_RESETVAL (0x00000000u)
/*----TRIG_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_TRIG_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_TRIG_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UCFG_ERR_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UCFG_ERR_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UCFG_ERR_RESETVAL (0x00000000u)
/*----DMA_UCFG_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UCFG_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UCFG_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_USYS_ERR_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_USYS_ERR_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_USYS_ERR_RESETVAL (0x00000000u)
/*----DMA_USYS_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_USYS_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_USYS_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR0_ERR_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR0_ERR_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR0_ERR_RESETVAL (0x00000000u)
/*----DMA_UPAR0_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR0_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR0_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR1_ERR_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR1_ERR_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR1_ERR_RESETVAL (0x00000000u)
/*----DMA_UPAR1_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR1_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_UPAR1_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OSYS_ERR_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OSYS_ERR_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OSYS_ERR_RESETVAL (0x00000000u)
/*----DMA_OSYS_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OSYS_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OSYS_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR0_ERR_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR0_ERR_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR0_ERR_RESETVAL (0x00000000u)
/*----DMA_OPAR0_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR0_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR0_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR1_ERR_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR1_ERR_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR1_ERR_RESETVAL (0x00000000u)
/*----DMA_OPAR1_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR1_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OPAR1_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OINTLV_ERR_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OINTLV_ERR_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OINTLV_ERR_RESETVAL (0x00000000u)
/*----DMA_OINTLV_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OINTLV_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_DMA_OINTLV_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_RADDR_ERR_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_RADDR_ERR_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_RADDR_ERR_RESETVAL (0x00000000u)
/*----VC_RADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_RADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_RADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_WADDR_ERR_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_WADDR_ERR_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_WADDR_ERR_RESETVAL (0x00000000u)
/*----VC_WADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_WADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VC_WADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_RADDR_ERR_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_RADDR_ERR_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_RADDR_ERR_RESETVAL (0x00000000u)
/*----VD_RADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_RADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_RADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_WADDR_ERR_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_WADDR_ERR_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_WADDR_ERR_RESETVAL (0x00000000u)
/*----VD_WADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_WADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_VD_WADDR_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_STAT_P0_RESETVAL (0x00000000u)

/* TCP3_EINT_CLR_P0 */


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_BLK_LN_CLR_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_BLK_LN_CLR_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_BLK_LN_CLR_RESETVAL (0x00000000u)
/*----BLK_LN_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_BLK_LN_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_INTLV_CONT_CLR_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_INTLV_CONT_CLR_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_INTLV_CONT_CLR_RESETVAL (0x00000000u)
/*----INTLV_CONT_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_INTLV_CONT_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_MODE_REG_WR_CLR_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_MODE_REG_WR_CLR_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_MODE_REG_WR_CLR_RESETVAL (0x00000000u)
/*----MODE_REG_WR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_MODE_REG_WR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SPLIT_TCP_CLR_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SPLIT_TCP_CLR_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SPLIT_TCP_CLR_RESETVAL (0x00000000u)
/*----SPLIT_TCP_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SPLIT_TCP_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_END_REG_WR_CLR_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_END_REG_WR_CLR_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_END_REG_WR_CLR_RESETVAL (0x00000000u)
/*----END_REG_WR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_END_REG_WR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SW0_LN_ERR_CLR_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SW0_LN_ERR_CLR_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SW0_LN_ERR_CLR_RESETVAL (0x00000000u)
/*----SW0_LN_ERR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SW0_LN_ERR_CLR_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SNR_VAL_CLR_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SNR_VAL_CLR_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SNR_VAL_CLR_RESETVAL (0x00000000u)
/*----SNR_VAL_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_SNR_VAL_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_IDAT_FMT_CLR_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_IDAT_FMT_CLR_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_IDAT_FMT_CLR_RESETVAL (0x00000000u)
/*----IDAT_FMT_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_IDAT_FMT_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_ICFG_ACC_CLR_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_ICFG_ACC_CLR_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_ICFG_ACC_CLR_RESETVAL (0x00000000u)
/*----ICFG_ACC_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_ICFG_ACC_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_IPROG_ACC_CLR_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_IPROG_ACC_CLR_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_IPROG_ACC_CLR_RESETVAL (0x00000000u)
/*----IPROG_ACC_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_IPROG_ACC_CLR_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_MAX_MIN_IT_CLR_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_MAX_MIN_IT_CLR_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_MAX_MIN_IT_CLR_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_MAX_MIN_IT_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_TRIG_CLR_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_TRIG_CLR_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_TRIG_CLR_RESETVAL (0x00000000u)
/*----TRIG_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_TRIG_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UCFG_CLR_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UCFG_CLR_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UCFG_CLR_RESETVAL (0x00000000u)
/*----DMA_UCFG_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UCFG_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_USYS_CLR_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_USYS_CLR_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_USYS_CLR_RESETVAL (0x00000000u)
/*----DMA_USYS_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_USYS_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UPAR0_CLR_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UPAR0_CLR_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UPAR0_CLR_RESETVAL (0x00000000u)
/*----DMA_UPAR0_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UPAR0_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UPAR1_CLR_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UPAR1_CLR_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UPAR1_CLR_RESETVAL (0x00000000u)
/*----DMA_UPAR1_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_UPAR1_CLR_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OSYS_CLR_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OSYS_CLR_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OSYS_CLR_RESETVAL (0x00000000u)
/*----DMA_OSYS_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OSYS_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OPAR0_CLR_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OPAR0_CLR_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OPAR0_CLR_RESETVAL (0x00000000u)
/*----DMA_OPAR0_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OPAR0_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OPAR1_CLR_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OPAR1_CLR_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OPAR1_CLR_RESETVAL (0x00000000u)
/*----DMA_OPAR1_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OPAR1_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OINTLV_CLR_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OINTLV_CLR_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OINTLV_CLR_RESETVAL (0x00000000u)
/*----DMA_OINTLV_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_DMA_OINTLV_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VC_RADDR_CLR_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VC_RADDR_CLR_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VC_RADDR_CLR_RESETVAL (0x00000000u)
/*----VC_RADDR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VC_RADDR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VC_WADDR_CLR_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VC_WADDR_CLR_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VC_WADDR_CLR_RESETVAL (0x00000000u)
/*----VC_WADDR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VC_WADDR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VD_RADDR_CLR_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VD_RADDR_CLR_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VD_RADDR_CLR_RESETVAL (0x00000000u)
/*----VD_RADDR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VD_RADDR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VD_WADDR_CLR_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VD_WADDR_CLR_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VD_WADDR_CLR_RESETVAL (0x00000000u)
/*----VD_WADDR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_VD_WADDR_CLR_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P0_RESETVAL (0x00000000u)

/* TCP3_EINT_EN_STAT_P0 */


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_BLK_LN_ERR_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_BLK_LN_ERR_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_BLK_LN_ERR_RESETVAL (0x00000000u)
/*----BLK_LN_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_BLK_LN_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_BLK_LN_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_INTLV_CONT_ERR_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_INTLV_CONT_ERR_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_INTLV_CONT_ERR_RESETVAL (0x00000000u)
/*----INTLV_CONT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_INTLV_CONT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_INTLV_CONT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MODE_REG_WR_ERR_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MODE_REG_WR_ERR_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MODE_REG_WR_ERR_RESETVAL (0x00000000u)
/*----MODE_REG_WR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MODE_REG_WR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MODE_REG_WR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SPLIT_TCP_ERR_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SPLIT_TCP_ERR_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SPLIT_TCP_ERR_RESETVAL (0x00000000u)
/*----SPLIT_TCP_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SPLIT_TCP_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SPLIT_TCP_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_END_REG_WR_ERR_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_END_REG_WR_ERR_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_END_REG_WR_ERR_RESETVAL (0x00000000u)
/*----END_REG_WR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_END_REG_WR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_END_REG_WR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SW0_LN_ERR_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SW0_LN_ERR_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SW0_LN_ERR_RESETVAL (0x00000000u)
/*----SW0_LN_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SW0_LN_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SW0_LN_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SNR_VAL_ERR_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SNR_VAL_ERR_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SNR_VAL_ERR_RESETVAL (0x00000000u)
/*----SNR_VAL_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SNR_VAL_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_SNR_VAL_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IDAT_FMT_ERR_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IDAT_FMT_ERR_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IDAT_FMT_ERR_RESETVAL (0x00000000u)
/*----IDAT_FMT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IDAT_FMT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IDAT_FMT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_ICFG_ACC_ERR_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_ICFG_ACC_ERR_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_ICFG_ACC_ERR_RESETVAL (0x00000000u)
/*----ICFG_ACC_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_ICFG_ACC_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_ICFG_ACC_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IPROG_ACC_ERR_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IPROG_ACC_ERR_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IPROG_ACC_ERR_RESETVAL (0x00000000u)
/*----IPROG_ACC_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IPROG_ACC_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_IPROG_ACC_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MAX_MIN_IT_ERR_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MAX_MIN_IT_ERR_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MAX_MIN_IT_ERR_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MAX_MIN_IT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_MAX_MIN_IT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_TRIG_ERR_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_TRIG_ERR_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_TRIG_ERR_RESETVAL (0x00000000u)
/*----TRIG_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_TRIG_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_TRIG_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UCFG_ERR_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UCFG_ERR_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UCFG_ERR_RESETVAL (0x00000000u)
/*----DMA_UCFG_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UCFG_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UCFG_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_USYS_ERR_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_USYS_ERR_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_USYS_ERR_RESETVAL (0x00000000u)
/*----DMA_USYS_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_USYS_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_USYS_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR0_ERR_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR0_ERR_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR0_ERR_RESETVAL (0x00000000u)
/*----DMA_UPAR0_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR0_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR0_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR1_ERR_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR1_ERR_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR1_ERR_RESETVAL (0x00000000u)
/*----DMA_UPAR1_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR1_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_UPAR1_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OSYS_ERR_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OSYS_ERR_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OSYS_ERR_RESETVAL (0x00000000u)
/*----DMA_OSYS_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OSYS_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OSYS_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR0_ERR_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR0_ERR_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR0_ERR_RESETVAL (0x00000000u)
/*----DMA_OPAR0_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR0_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR0_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR1_ERR_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR1_ERR_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR1_ERR_RESETVAL (0x00000000u)
/*----DMA_OPAR1_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR1_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OPAR1_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OINTLV_ERR_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OINTLV_ERR_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OINTLV_ERR_RESETVAL (0x00000000u)
/*----DMA_OINTLV_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OINTLV_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_DMA_OINTLV_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_RADDR_ERR_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_RADDR_ERR_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_RADDR_ERR_RESETVAL (0x00000000u)
/*----VC_RADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_RADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_RADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_WADDR_ERR_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_WADDR_ERR_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_WADDR_ERR_RESETVAL (0x00000000u)
/*----VC_WADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_WADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VC_WADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_RADDR_ERR_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_RADDR_ERR_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_RADDR_ERR_RESETVAL (0x00000000u)
/*----VD_RADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_RADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_RADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_WADDR_ERR_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_WADDR_ERR_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_WADDR_ERR_RESETVAL (0x00000000u)
/*----VD_WADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_WADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_VD_WADDR_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P0_RESETVAL (0x00000000u)

/* TCP3_EINT_EN_P0 */


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_BLK_LN_EN_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_BLK_LN_EN_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_BLK_LN_EN_RESETVAL (0x00000000u)
/*----BLK_LN_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_BLK_LN_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_BLK_LN_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_INTLV_CONT_EN_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_INTLV_CONT_EN_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_INTLV_CONT_EN_RESETVAL (0x00000000u)
/*----INTLV_CONT_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_INTLV_CONT_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_INTLV_CONT_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MODE_REG_WR_EN_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MODE_REG_WR_EN_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MODE_REG_WR_EN_RESETVAL (0x00000000u)
/*----MODE_REG_WR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MODE_REG_WR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MODE_REG_WR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SPLIT_TCP_EN_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SPLIT_TCP_EN_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SPLIT_TCP_EN_RESETVAL (0x00000000u)
/*----SPLIT_TCP_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SPLIT_TCP_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SPLIT_TCP_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_END_REG_WR_EN_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_END_REG_WR_EN_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_END_REG_WR_EN_RESETVAL (0x00000000u)
/*----END_REG_WR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_END_REG_WR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_END_REG_WR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SW0_LN_EN_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SW0_LN_EN_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SW0_LN_EN_RESETVAL (0x00000000u)
/*----SW0_LN_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SW0_LN_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SW0_LN_EN_ENABLED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SNR_VAL_EN_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SNR_VAL_EN_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SNR_VAL_EN_RESETVAL (0x00000000u)
/*----SNR_VAL_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SNR_VAL_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_SNR_VAL_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IDAT_FMT_EN_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IDAT_FMT_EN_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IDAT_FMT_EN_RESETVAL (0x00000000u)
/*----IDAT_FMT_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IDAT_FMT_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IDAT_FMT_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_ICFG_ACC_EN_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_ICFG_ACC_EN_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_ICFG_ACC_EN_RESETVAL (0x00000000u)
/*----ICFG_ACC_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_ICFG_ACC_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_ICFG_ACC_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IPROG_ACC_EN_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IPROG_ACC_EN_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IPROG_ACC_EN_RESETVAL (0x00000000u)
/*----IPROG_ACC_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IPROG_ACC_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_IPROG_ACC_EN_ENABLED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MAX_MIN_IT_EN_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MAX_MIN_IT_EN_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MAX_MIN_IT_EN_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MAX_MIN_IT_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_MAX_MIN_IT_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_TRIG_EN_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_TRIG_EN_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_TRIG_EN_RESETVAL (0x00000000u)
/*----TRIG_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_TRIG_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_TRIG_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UCFG_EN_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UCFG_EN_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UCFG_EN_RESETVAL (0x00000000u)
/*----DMA_UCFG_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UCFG_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UCFG_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_USYS_EN_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_USYS_EN_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_USYS_EN_RESETVAL (0x00000000u)
/*----DMA_USYS_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_USYS_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_USYS_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR0_EN_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR0_EN_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR0_EN_RESETVAL (0x00000000u)
/*----DMA_UPAR0_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR0_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR0_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR1_EN_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR1_EN_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR1_EN_RESETVAL (0x00000000u)
/*----DMA_UPAR1_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR1_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_UPAR1_EN_ENABLED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OSYS_EN_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OSYS_EN_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OSYS_EN_RESETVAL (0x00000000u)
/*----DMA_OSYS_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OSYS_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OSYS_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR0_EN_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR0_EN_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR0_EN_RESETVAL (0x00000000u)
/*----DMA_OPAR0_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR0_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR0_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR1_EN_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR1_EN_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR1_EN_RESETVAL (0x00000000u)
/*----DMA_OPAR1_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR1_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OPAR1_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OINTLV_EN_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OINTLV_EN_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OINTLV_EN_RESETVAL (0x00000000u)
/*----DMA_OINTLV_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OINTLV_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_DMA_OINTLV_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_RADDR_EN_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_RADDR_EN_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_RADDR_EN_RESETVAL (0x00000000u)
/*----VC_RADDR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_RADDR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_RADDR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_WADDR_EN_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_WADDR_EN_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_WADDR_EN_RESETVAL (0x00000000u)
/*----VC_WADDR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_WADDR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VC_WADDR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_RADDR_EN_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_RADDR_EN_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_RADDR_EN_RESETVAL (0x00000000u)
/*----VD_RADDR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_RADDR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_RADDR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_WADDR_EN_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_WADDR_EN_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_WADDR_EN_RESETVAL (0x00000000u)
/*----VD_WADDR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_WADDR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_VD_WADDR_EN_ENABLED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P0_RESETVAL (0x00000000u)

/* TCP3_EINT_EN_CLR_P0 */


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_BLK_LN_ECL_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_BLK_LN_ECL_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_BLK_LN_ECL_RESETVAL (0x00000000u)
/*----BLK_LN_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_BLK_LN_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_INTLV_CONT_ECL_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_INTLV_CONT_ECL_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_INTLV_CONT_ECL_RESETVAL (0x00000000u)
/*----INTLV_CONT_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_INTLV_CONT_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_MODE_REG_WR_ECL_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_MODE_REG_WR_ECL_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_MODE_REG_WR_ECL_RESETVAL (0x00000000u)
/*----MODE_REG_WR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_MODE_REG_WR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SPLIT_TCP_ECL_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SPLIT_TCP_ECL_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SPLIT_TCP_ECL_RESETVAL (0x00000000u)
/*----SPLIT_TCP_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SPLIT_TCP_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_END_REG_WR_ECL_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_END_REG_WR_ECL_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_END_REG_WR_ECL_RESETVAL (0x00000000u)
/*----END_REG_WR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_END_REG_WR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SW0_LN_ECL_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SW0_LN_ECL_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SW0_LN_ECL_RESETVAL (0x00000000u)
/*----SW0_LN_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SW0_LN_ECL_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SNR_VAL_ECL_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SNR_VAL_ECL_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SNR_VAL_ECL_RESETVAL (0x00000000u)
/*----SNR_VAL_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_SNR_VAL_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_IDAT_FMT_ECL_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_IDAT_FMT_ECL_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_IDAT_FMT_ECL_RESETVAL (0x00000000u)
/*----IDAT_FMT_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_IDAT_FMT_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_ICFG_ACC_ECL_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_ICFG_ACC_ECL_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_ICFG_ACC_ECL_RESETVAL (0x00000000u)
/*----ICFG_ACC_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_ICFG_ACC_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_IPROG_ACC_ECL_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_IPROG_ACC_ECL_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_IPROG_ACC_ECL_RESETVAL (0x00000000u)
/*----IPROG_ACC_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_IPROG_ACC_ECL_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_MAX_MIN_IT_ECL_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_MAX_MIN_IT_ECL_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_MAX_MIN_IT_ECL_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_MAX_MIN_IT_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_TRIG_ECL_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_TRIG_ECL_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_TRIG_ECL_RESETVAL (0x00000000u)
/*----TRIG_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_TRIG_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UCFG_ECL_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UCFG_ECL_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UCFG_ECL_RESETVAL (0x00000000u)
/*----DMA_UCFG_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UCFG_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_USYS_ECL_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_USYS_ECL_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_USYS_ECL_RESETVAL (0x00000000u)
/*----DMA_USYS_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_USYS_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UPAR0_ECL_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UPAR0_ECL_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UPAR0_ECL_RESETVAL (0x00000000u)
/*----DMA_UPAR0_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UPAR0_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UPAR1_ECL_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UPAR1_ECL_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UPAR1_ECL_RESETVAL (0x00000000u)
/*----DMA_UPAR1_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_UPAR1_ECL_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OSYS_ECL_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OSYS_ECL_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OSYS_ECL_RESETVAL (0x00000000u)
/*----DMA_OSYS_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OSYS_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OPAR0_ECL_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OPAR0_ECL_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OPAR0_ECL_RESETVAL (0x00000000u)
/*----DMA_OPAR0_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OPAR0_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OPAR1_ECL_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OPAR1_ECL_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OPAR1_ECL_RESETVAL (0x00000000u)
/*----DMA_OPAR1_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OPAR1_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OINTLV_ECL_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OINTLV_ECL_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OINTLV_ECL_RESETVAL (0x00000000u)
/*----DMA_OINTLV_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_DMA_OINTLV_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VC_RADDR_ECL_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VC_RADDR_ECL_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VC_RADDR_ECL_RESETVAL (0x00000000u)
/*----VC_RADDR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VC_RADDR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VC_WADDR_ECL_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VC_WADDR_ECL_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VC_WADDR_ECL_RESETVAL (0x00000000u)
/*----VC_WADDR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VC_WADDR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VD_RADDR_ECL_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VD_RADDR_ECL_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VD_RADDR_ECL_RESETVAL (0x00000000u)
/*----VD_RADDR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VD_RADDR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VD_WADDR_ECL_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VD_WADDR_ECL_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VD_WADDR_ECL_RESETVAL (0x00000000u)
/*----VD_WADDR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_VD_WADDR_ECL_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P0_RESETVAL (0x00000000u)

/* TCP3_EXE_P1 */

#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_MASK (0x00000007u)
#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_RESETVAL (0x00000000u)
/*----EXE_CMD Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_NO_INSTRUCTION (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_ENABLE (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_DEBUG_NORMAL (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_DEBUG_ONE_MAP (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_DEBUG_REMAING_MAP (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EXE_P1_EXE_CMD_CLEAR (0x00000007u)


#define CSL_TCP3D_CFG_TCP3_EXE_P1_RESETVAL (0x00000000u)

/* TCP3_STS_P1 */

#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_PEND_MASK (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_PEND_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_PEND_RESETVAL (0x00000000u)
/*----PROC_PEND Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_PEND_DOES_NOT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_PEND_HAS (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_BUSY_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_BUSY_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_BUSY_RESETVAL (0x00000000u)
/*----PROC_BUSY Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_BUSY_NOT_BUSY (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_PROC_BUSY_BUSY (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_SYS_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_SYS_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_SYS_RESETVAL (0x00000000u)
/*----WAIT_WR_SYS Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_SYS_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_SYS_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P0_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P0_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P0_RESETVAL (0x00000000u)
/*----WAIT_WR_P0 Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P0_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P0_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P1_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P1_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P1_RESETVAL (0x00000000u)
/*----WAIT_WR_P1 Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P1_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_P1_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IL_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IL_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IL_RESETVAL (0x00000000u)
/*----WAIT_WR_IL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IL_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IL_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IC_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IC_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IC_RESETVAL (0x00000000u)
/*----WAIT_WR_IC Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IC_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_WR_IC_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_SO_MASK (0x00000080u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_SO_SHIFT (0x00000007u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_SO_RESETVAL (0x00000000u)
/*----WAIT_RD_SO Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_SO_NOT_WAITING (0x00000000u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_HD_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_HD_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_HD_RESETVAL (0x00000000u)
/*----WAIT_RD_HD Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_HD_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_HD_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_OS_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_OS_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_OS_RESETVAL (0x00000000u)
/*----WAIT_RD_OS Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_OS_NOT_WAITING (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_WAIT_RD_OS_WAITING (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_EMU_HALT_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_EMU_HALT_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_STS_P1_EMU_HALT_RESETVAL (0x00000000u)
/*----EMU_HALT Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_EMU_HALT_NOT_HALTED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_EMU_HALT_HALTED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_ITR_MASK (0x0000F000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_ITR_SHIFT (0x0000000Cu)
#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_ITR_RESETVAL (0x00000000u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_MASK (0x000F0000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_RESETVAL (0x00000000u)
/*----TCP_IF_STATE Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_IDLE (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_WAIT_TRIG (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_START_MAP (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_WAIT_INTLV (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_DEBUG (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_WAIT_MAP (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_WAIT_RD (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_ERROR (0x0000000cu)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_END_CLR (0x0000000eu)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_IF_STATE_IF_CLEAR (0x0000000fu)

#define CSL_TCP3D_CFG_TCP3_STS_P1_SNR_EXCEED_MASK (0x00300000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_SNR_EXCEED_SHIFT (0x00000014u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_SNR_EXCEED_RESETVAL (0x00000000u)
/*----SNR_EXCEED Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_SNR_EXCEED_MAP0_FAILED_SNR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_SNR_EXCEED_MAP0_PASSED_SNR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_MAP_MASK (0x00C00000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_MAP_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_MAP_RESETVAL (0x00000000u)
/*----ACTIVE_MAP Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_MAP_NO_ACTIVE_MAP (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_MAP_ACTIVE_MAP0 (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_ACTIVE_MAP_ACTIVE_MAP1 (0x00000002u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_MASK (0x0F000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_RESETVAL (0x00000000u)
/*----TCP_MAIN_STATE Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_IDLE (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_ZAPM (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_MAP0X (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_WAIT0 (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_MAP1X (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_WAIT1 (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_DITR (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_TCP_MAIN_STATE_DONE (0x00000007u)

#define CSL_TCP3D_CFG_TCP3_STS_P1_LTE_CRC_CHK_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_LTE_CRC_CHK_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_STS_P1_LTE_CRC_CHK_RESETVAL (0x00000000u)
/*----LTE_CRC_CHK Tokens----*/
#define CSL_TCP3D_CFG_TCP3_STS_P1_LTE_CRC_CHK_FAILED_CRC (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_STS_P1_LTE_CRC_CHK_PASSED_CRC (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_STS_P1_RESETVAL (0x00000000u)

/* TCP3_EV_SET_P1 */

#define CSL_TCP3D_CFG_TCP3_EV_SET_P1_REVT_MASK (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EV_SET_P1_REVT_SHIFT (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EV_SET_P1_REVT_RESETVAL (0x00000000u)
/*----REVT Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EV_SET_P1_REVT_REVT (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EV_SET_P1_RESETVAL (0x00000000u)

/* TCP3_EINT_CLR_P1 */


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_BLK_LN_CLR_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_BLK_LN_CLR_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_BLK_LN_CLR_RESETVAL (0x00000000u)
/*----BLK_LN_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_BLK_LN_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_INTLV_CONT_CLR_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_INTLV_CONT_CLR_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_INTLV_CONT_CLR_RESETVAL (0x00000000u)
/*----INTLV_CONT_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_INTLV_CONT_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_MODE_REG_WR_CLR_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_MODE_REG_WR_CLR_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_MODE_REG_WR_CLR_RESETVAL (0x00000000u)
/*----MODE_REG_WR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_MODE_REG_WR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SPLIT_TCP_CLR_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SPLIT_TCP_CLR_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SPLIT_TCP_CLR_RESETVAL (0x00000000u)
/*----SPLIT_TCP_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SPLIT_TCP_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_END_REG_WR_CLR_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_END_REG_WR_CLR_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_END_REG_WR_CLR_RESETVAL (0x00000000u)
/*----END_REG_WR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_END_REG_WR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SW0_LN_ERR_CLR_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SW0_LN_ERR_CLR_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SW0_LN_ERR_CLR_RESETVAL (0x00000000u)
/*----SW0_LN_ERR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SW0_LN_ERR_CLR_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SNR_VAL_CLR_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SNR_VAL_CLR_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SNR_VAL_CLR_RESETVAL (0x00000000u)
/*----SNR_VAL_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_SNR_VAL_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_IDAT_FMT_CLR_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_IDAT_FMT_CLR_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_IDAT_FMT_CLR_RESETVAL (0x00000000u)
/*----IDAT_FMT_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_IDAT_FMT_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_ICFG_ACC_CLR_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_ICFG_ACC_CLR_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_ICFG_ACC_CLR_RESETVAL (0x00000000u)
/*----ICFG_ACC_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_ICFG_ACC_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_IPROG_ACC_CLR_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_IPROG_ACC_CLR_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_IPROG_ACC_CLR_RESETVAL (0x00000000u)
/*----IPROG_ACC_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_IPROG_ACC_CLR_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_MAX_MIN_IT_CLR_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_MAX_MIN_IT_CLR_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_MAX_MIN_IT_CLR_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_MAX_MIN_IT_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_TRIG_CLR_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_TRIG_CLR_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_TRIG_CLR_RESETVAL (0x00000000u)
/*----TRIG_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_TRIG_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UCFG_CLR_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UCFG_CLR_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UCFG_CLR_RESETVAL (0x00000000u)
/*----DMA_UCFG_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UCFG_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_USYS_CLR_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_USYS_CLR_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_USYS_CLR_RESETVAL (0x00000000u)
/*----DMA_USYS_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_USYS_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UPAR0_CLR_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UPAR0_CLR_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UPAR0_CLR_RESETVAL (0x00000000u)
/*----DMA_UPAR0_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UPAR0_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UPAR1_CLR_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UPAR1_CLR_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UPAR1_CLR_RESETVAL (0x00000000u)
/*----DMA_UPAR1_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_UPAR1_CLR_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OSYS_CLR_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OSYS_CLR_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OSYS_CLR_RESETVAL (0x00000000u)
/*----DMA_OSYS_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OSYS_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OPAR0_CLR_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OPAR0_CLR_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OPAR0_CLR_RESETVAL (0x00000000u)
/*----DMA_OPAR0_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OPAR0_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OPAR1_CLR_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OPAR1_CLR_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OPAR1_CLR_RESETVAL (0x00000000u)
/*----DMA_OPAR1_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OPAR1_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OINTLV_CLR_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OINTLV_CLR_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OINTLV_CLR_RESETVAL (0x00000000u)
/*----DMA_OINTLV_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_DMA_OINTLV_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VC_RADDR_CLR_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VC_RADDR_CLR_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VC_RADDR_CLR_RESETVAL (0x00000000u)
/*----VC_RADDR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VC_RADDR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VC_WADDR_CLR_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VC_WADDR_CLR_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VC_WADDR_CLR_RESETVAL (0x00000000u)
/*----VC_WADDR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VC_WADDR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VD_RADDR_CLR_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VD_RADDR_CLR_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VD_RADDR_CLR_RESETVAL (0x00000000u)
/*----VD_RADDR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VD_RADDR_CLR_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VD_WADDR_CLR_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VD_WADDR_CLR_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VD_WADDR_CLR_RESETVAL (0x00000000u)
/*----VD_WADDR_CLR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_VD_WADDR_CLR_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_CLR_P1_RESETVAL (0x00000000u)

/* TCP3_EINT_EN_STAT_P1 */


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_BLK_LN_ERR_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_BLK_LN_ERR_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_BLK_LN_ERR_RESETVAL (0x00000000u)
/*----BLK_LN_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_BLK_LN_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_BLK_LN_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_INTLV_CONT_ERR_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_INTLV_CONT_ERR_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_INTLV_CONT_ERR_RESETVAL (0x00000000u)
/*----INTLV_CONT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_INTLV_CONT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_INTLV_CONT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MODE_REG_WR_ERR_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MODE_REG_WR_ERR_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MODE_REG_WR_ERR_RESETVAL (0x00000000u)
/*----MODE_REG_WR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MODE_REG_WR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MODE_REG_WR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SPLIT_TCP_ERR_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SPLIT_TCP_ERR_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SPLIT_TCP_ERR_RESETVAL (0x00000000u)
/*----SPLIT_TCP_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SPLIT_TCP_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SPLIT_TCP_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_END_REG_WR_ERR_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_END_REG_WR_ERR_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_END_REG_WR_ERR_RESETVAL (0x00000000u)
/*----END_REG_WR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_END_REG_WR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_END_REG_WR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SW0_LN_ERR_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SW0_LN_ERR_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SW0_LN_ERR_RESETVAL (0x00000000u)
/*----SW0_LN_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SW0_LN_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SW0_LN_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SNR_VAL_ERR_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SNR_VAL_ERR_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SNR_VAL_ERR_RESETVAL (0x00000000u)
/*----SNR_VAL_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SNR_VAL_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_SNR_VAL_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IDAT_FMT_ERR_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IDAT_FMT_ERR_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IDAT_FMT_ERR_RESETVAL (0x00000000u)
/*----IDAT_FMT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IDAT_FMT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IDAT_FMT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_ICFG_ACC_ERR_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_ICFG_ACC_ERR_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_ICFG_ACC_ERR_RESETVAL (0x00000000u)
/*----ICFG_ACC_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_ICFG_ACC_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_ICFG_ACC_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IPROG_ACC_ERR_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IPROG_ACC_ERR_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IPROG_ACC_ERR_RESETVAL (0x00000000u)
/*----IPROG_ACC_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IPROG_ACC_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_IPROG_ACC_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MAX_MIN_IT_ERR_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MAX_MIN_IT_ERR_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MAX_MIN_IT_ERR_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MAX_MIN_IT_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_MAX_MIN_IT_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_TRIG_ERR_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_TRIG_ERR_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_TRIG_ERR_RESETVAL (0x00000000u)
/*----TRIG_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_TRIG_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_TRIG_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UCFG_ERR_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UCFG_ERR_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UCFG_ERR_RESETVAL (0x00000000u)
/*----DMA_UCFG_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UCFG_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UCFG_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_USYS_ERR_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_USYS_ERR_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_USYS_ERR_RESETVAL (0x00000000u)
/*----DMA_USYS_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_USYS_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_USYS_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR0_ERR_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR0_ERR_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR0_ERR_RESETVAL (0x00000000u)
/*----DMA_UPAR0_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR0_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR0_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR1_ERR_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR1_ERR_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR1_ERR_RESETVAL (0x00000000u)
/*----DMA_UPAR1_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR1_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_UPAR1_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OSYS_ERR_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OSYS_ERR_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OSYS_ERR_RESETVAL (0x00000000u)
/*----DMA_OSYS_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OSYS_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OSYS_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR0_ERR_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR0_ERR_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR0_ERR_RESETVAL (0x00000000u)
/*----DMA_OPAR0_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR0_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR0_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR1_ERR_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR1_ERR_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR1_ERR_RESETVAL (0x00000000u)
/*----DMA_OPAR1_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR1_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OPAR1_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OINTLV_ERR_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OINTLV_ERR_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OINTLV_ERR_RESETVAL (0x00000000u)
/*----DMA_OINTLV_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OINTLV_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_DMA_OINTLV_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_RADDR_ERR_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_RADDR_ERR_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_RADDR_ERR_RESETVAL (0x00000000u)
/*----VC_RADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_RADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_RADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_WADDR_ERR_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_WADDR_ERR_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_WADDR_ERR_RESETVAL (0x00000000u)
/*----VC_WADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_WADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VC_WADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_RADDR_ERR_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_RADDR_ERR_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_RADDR_ERR_RESETVAL (0x00000000u)
/*----VD_RADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_RADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_RADDR_ERR_ERROR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_WADDR_ERR_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_WADDR_ERR_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_WADDR_ERR_RESETVAL (0x00000000u)
/*----VD_WADDR_ERR Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_WADDR_ERR_NO_ERROR (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_VD_WADDR_ERR_ERROR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_STAT_P1_RESETVAL (0x00000000u)

/* TCP3_EINT_EN_P1 */


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_BLK_LN_EN_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_BLK_LN_EN_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_BLK_LN_EN_RESETVAL (0x00000000u)
/*----BLK_LN_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_BLK_LN_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_BLK_LN_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_INTLV_CONT_EN_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_INTLV_CONT_EN_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_INTLV_CONT_EN_RESETVAL (0x00000000u)
/*----INTLV_CONT_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_INTLV_CONT_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_INTLV_CONT_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MODE_REG_WR_EN_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MODE_REG_WR_EN_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MODE_REG_WR_EN_RESETVAL (0x00000000u)
/*----MODE_REG_WR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MODE_REG_WR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MODE_REG_WR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SPLIT_TCP_EN_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SPLIT_TCP_EN_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SPLIT_TCP_EN_RESETVAL (0x00000000u)
/*----SPLIT_TCP_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SPLIT_TCP_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SPLIT_TCP_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_END_REG_WR_EN_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_END_REG_WR_EN_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_END_REG_WR_EN_RESETVAL (0x00000000u)
/*----END_REG_WR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_END_REG_WR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_END_REG_WR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SW0_LN_EN_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SW0_LN_EN_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SW0_LN_EN_RESETVAL (0x00000000u)
/*----SW0_LN_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SW0_LN_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SW0_LN_EN_ENABLED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SNR_VAL_EN_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SNR_VAL_EN_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SNR_VAL_EN_RESETVAL (0x00000000u)
/*----SNR_VAL_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SNR_VAL_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_SNR_VAL_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IDAT_FMT_EN_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IDAT_FMT_EN_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IDAT_FMT_EN_RESETVAL (0x00000000u)
/*----IDAT_FMT_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IDAT_FMT_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IDAT_FMT_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_ICFG_ACC_EN_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_ICFG_ACC_EN_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_ICFG_ACC_EN_RESETVAL (0x00000000u)
/*----ICFG_ACC_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_ICFG_ACC_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_ICFG_ACC_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IPROG_ACC_EN_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IPROG_ACC_EN_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IPROG_ACC_EN_RESETVAL (0x00000000u)
/*----IPROG_ACC_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IPROG_ACC_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_IPROG_ACC_EN_ENABLED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MAX_MIN_IT_EN_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MAX_MIN_IT_EN_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MAX_MIN_IT_EN_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MAX_MIN_IT_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_MAX_MIN_IT_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_TRIG_EN_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_TRIG_EN_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_TRIG_EN_RESETVAL (0x00000000u)
/*----TRIG_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_TRIG_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_TRIG_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UCFG_EN_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UCFG_EN_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UCFG_EN_RESETVAL (0x00000000u)
/*----DMA_UCFG_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UCFG_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UCFG_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_USYS_EN_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_USYS_EN_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_USYS_EN_RESETVAL (0x00000000u)
/*----DMA_USYS_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_USYS_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_USYS_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR0_EN_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR0_EN_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR0_EN_RESETVAL (0x00000000u)
/*----DMA_UPAR0_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR0_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR0_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR1_EN_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR1_EN_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR1_EN_RESETVAL (0x00000000u)
/*----DMA_UPAR1_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR1_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_UPAR1_EN_ENABLED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OSYS_EN_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OSYS_EN_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OSYS_EN_RESETVAL (0x00000000u)
/*----DMA_OSYS_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OSYS_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OSYS_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR0_EN_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR0_EN_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR0_EN_RESETVAL (0x00000000u)
/*----DMA_OPAR0_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR0_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR0_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR1_EN_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR1_EN_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR1_EN_RESETVAL (0x00000000u)
/*----DMA_OPAR1_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR1_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OPAR1_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OINTLV_EN_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OINTLV_EN_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OINTLV_EN_RESETVAL (0x00000000u)
/*----DMA_OINTLV_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OINTLV_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_DMA_OINTLV_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_RADDR_EN_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_RADDR_EN_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_RADDR_EN_RESETVAL (0x00000000u)
/*----VC_RADDR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_RADDR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_RADDR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_WADDR_EN_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_WADDR_EN_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_WADDR_EN_RESETVAL (0x00000000u)
/*----VC_WADDR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_WADDR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VC_WADDR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_RADDR_EN_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_RADDR_EN_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_RADDR_EN_RESETVAL (0x00000000u)
/*----VD_RADDR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_RADDR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_RADDR_EN_ENABLED (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_WADDR_EN_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_WADDR_EN_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_WADDR_EN_RESETVAL (0x00000000u)
/*----VD_WADDR_EN Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_WADDR_EN_DISABLED (0x00000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_VD_WADDR_EN_ENABLED (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_P1_RESETVAL (0x00000000u)

/* TCP3_EINT_EN_CLR_P1 */


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_BLK_LN_ECL_MASK (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_BLK_LN_ECL_SHIFT (0x00000001u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_BLK_LN_ECL_RESETVAL (0x00000000u)
/*----BLK_LN_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_BLK_LN_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_INTLV_CONT_ECL_MASK (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_INTLV_CONT_ECL_SHIFT (0x00000002u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_INTLV_CONT_ECL_RESETVAL (0x00000000u)
/*----INTLV_CONT_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_INTLV_CONT_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_MODE_REG_WR_ECL_MASK (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_MODE_REG_WR_ECL_SHIFT (0x00000003u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_MODE_REG_WR_ECL_RESETVAL (0x00000000u)
/*----MODE_REG_WR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_MODE_REG_WR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SPLIT_TCP_ECL_MASK (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SPLIT_TCP_ECL_SHIFT (0x00000004u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SPLIT_TCP_ECL_RESETVAL (0x00000000u)
/*----SPLIT_TCP_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SPLIT_TCP_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_END_REG_WR_ECL_MASK (0x00000020u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_END_REG_WR_ECL_SHIFT (0x00000005u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_END_REG_WR_ECL_RESETVAL (0x00000000u)
/*----END_REG_WR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_END_REG_WR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SW0_LN_ECL_MASK (0x00000040u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SW0_LN_ECL_SHIFT (0x00000006u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SW0_LN_ECL_RESETVAL (0x00000000u)
/*----SW0_LN_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SW0_LN_ECL_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SNR_VAL_ECL_MASK (0x00000100u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SNR_VAL_ECL_SHIFT (0x00000008u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SNR_VAL_ECL_RESETVAL (0x00000000u)
/*----SNR_VAL_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_SNR_VAL_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_IDAT_FMT_ECL_MASK (0x00000200u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_IDAT_FMT_ECL_SHIFT (0x00000009u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_IDAT_FMT_ECL_RESETVAL (0x00000000u)
/*----IDAT_FMT_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_IDAT_FMT_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_ICFG_ACC_ECL_MASK (0x00000400u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_ICFG_ACC_ECL_SHIFT (0x0000000Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_ICFG_ACC_ECL_RESETVAL (0x00000000u)
/*----ICFG_ACC_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_ICFG_ACC_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_IPROG_ACC_ECL_MASK (0x00000800u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_IPROG_ACC_ECL_SHIFT (0x0000000Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_IPROG_ACC_ECL_RESETVAL (0x00000000u)
/*----IPROG_ACC_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_IPROG_ACC_ECL_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_MAX_MIN_IT_ECL_MASK (0x00004000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_MAX_MIN_IT_ECL_SHIFT (0x0000000Eu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_MAX_MIN_IT_ECL_RESETVAL (0x00000000u)
/*----MAX_MIN_IT_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_MAX_MIN_IT_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_TRIG_ECL_MASK (0x00008000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_TRIG_ECL_SHIFT (0x0000000Fu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_TRIG_ECL_RESETVAL (0x00000000u)
/*----TRIG_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_TRIG_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UCFG_ECL_MASK (0x00010000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UCFG_ECL_SHIFT (0x00000010u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UCFG_ECL_RESETVAL (0x00000000u)
/*----DMA_UCFG_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UCFG_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_USYS_ECL_MASK (0x00020000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_USYS_ECL_SHIFT (0x00000011u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_USYS_ECL_RESETVAL (0x00000000u)
/*----DMA_USYS_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_USYS_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UPAR0_ECL_MASK (0x00040000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UPAR0_ECL_SHIFT (0x00000012u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UPAR0_ECL_RESETVAL (0x00000000u)
/*----DMA_UPAR0_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UPAR0_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UPAR1_ECL_MASK (0x00080000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UPAR1_ECL_SHIFT (0x00000013u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UPAR1_ECL_RESETVAL (0x00000000u)
/*----DMA_UPAR1_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_UPAR1_ECL_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OSYS_ECL_MASK (0x00200000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OSYS_ECL_SHIFT (0x00000015u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OSYS_ECL_RESETVAL (0x00000000u)
/*----DMA_OSYS_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OSYS_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OPAR0_ECL_MASK (0x00400000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OPAR0_ECL_SHIFT (0x00000016u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OPAR0_ECL_RESETVAL (0x00000000u)
/*----DMA_OPAR0_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OPAR0_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OPAR1_ECL_MASK (0x00800000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OPAR1_ECL_SHIFT (0x00000017u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OPAR1_ECL_RESETVAL (0x00000000u)
/*----DMA_OPAR1_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OPAR1_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OINTLV_ECL_MASK (0x01000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OINTLV_ECL_SHIFT (0x00000018u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OINTLV_ECL_RESETVAL (0x00000000u)
/*----DMA_OINTLV_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_DMA_OINTLV_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VC_RADDR_ECL_MASK (0x02000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VC_RADDR_ECL_SHIFT (0x00000019u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VC_RADDR_ECL_RESETVAL (0x00000000u)
/*----VC_RADDR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VC_RADDR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VC_WADDR_ECL_MASK (0x04000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VC_WADDR_ECL_SHIFT (0x0000001Au)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VC_WADDR_ECL_RESETVAL (0x00000000u)
/*----VC_WADDR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VC_WADDR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VD_RADDR_ECL_MASK (0x08000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VD_RADDR_ECL_SHIFT (0x0000001Bu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VD_RADDR_ECL_RESETVAL (0x00000000u)
/*----VD_RADDR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VD_RADDR_ECL_CLEAR (0x00000001u)

#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VD_WADDR_ECL_MASK (0x10000000u)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VD_WADDR_ECL_SHIFT (0x0000001Cu)
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VD_WADDR_ECL_RESETVAL (0x00000000u)
/*----VD_WADDR_ECL Tokens----*/
#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_VD_WADDR_ECL_CLEAR (0x00000001u)


#define CSL_TCP3D_CFG_TCP3_EINT_EN_CLR_P1_RESETVAL (0x00000000u)

#endif
